@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
@@ -121,7 +121,6 @@ import org.eclipse.jdt.core.dom.ASTParser;
 import org.eclipse.jdt.core.dom.ASTRequestor;
 import org.eclipse.jdt.core.dom.ASTVisitor;
 import org.eclipse.jdt.core.dom.Block;
-import org.eclipse.jdt.core.dom.BreakStatement;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.Expression;
 import org.eclipse.jdt.core.dom.ExpressionStatement;
@@ -129,41 +128,47 @@ import org.eclipse.jdt.core.dom.IBinding;
 import org.eclipse.jdt.core.dom.NodeFinder;
 import org.eclipse.jdt.core.dom.Statement;
 import org.eclipse.jdt.core.dom.SwitchExpression;
-import org.eclipse.jdt.core.dom.SwitchStatement;
+import org.eclipse.jdt.core.dom.YieldStatement;
 import org.eclipse.jdt.core.manipulation.SharedASTProviderCore;
 import org.eclipse.jdt.ui.JavaUI;
 
 
 public class ASTView extends ViewPart implements IShowInSource, IShowInTargetList {
-	
-	static final int JLS_LATEST= AST.JLS12;
 
+	static final int JLS_LATEST= AST.JLS13;
+
+	private static final int JLS13= AST.JLS13;
+
+	/**
+	 * @deprecated to get rid of deprecation warnings in code
+	 */
+	@Deprecated
 	private static final int JLS12= AST.JLS12;
-	
+
 	/**
 	 * @deprecated to get rid of deprecation warnings in code
 	 */
 	@Deprecated
 	private static final int JLS11= AST.JLS11;
-	
+
 	/**
 	 * @deprecated to get rid of deprecation warnings in code
 	 */
 	@Deprecated
 	private static final int JLS10= AST.JLS10;
-	
+
 	/**
 	 * @deprecated to get rid of deprecation warnings in code
 	 */
 	@Deprecated
 	private static final int JLS9= AST.JLS9;
-	
+
 	/**
 	 * @deprecated to get rid of deprecation warnings in code
 	 */
 	@Deprecated
 	private static final int JLS8= AST.JLS8;
-	
+
 	/**
 	 * @deprecated to get rid of deprecation warnings in code
 	 */
@@ -221,23 +226,23 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 				setChecked(true);
 			}
 		}
-	
+
 		public int getLevel() {
 			return fLevel;
 		}
-		
+
 		@Override
 		public void run() {
 			setASTLevel(fLevel, true);
 		}
 	}
-	
+
 	private class ASTInputKindAction extends Action {
 		public static final int USE_PARSER= 1;
 		public static final int USE_RECONCILE= 2;
 		public static final int USE_CACHE= 3;
 		public static final int USE_FOCAL= 4;
-		
+
 		private int fInputKind;
 
 		public ASTInputKindAction(String label, int inputKind) {
@@ -247,27 +252,27 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 				setChecked(true);
 			}
 		}
-	
+
 		public int getInputKind() {
 			return fInputKind;
 		}
-		
+
 		@Override
 		public void run() {
 			setASTInputType(fInputKind);
 		}
 	}
-	
-	
+
+
 	private static class ListenerMix implements ISelectionListener, IFileBufferListener, IDocumentListener, ISelectionChangedListener, IDoubleClickListener, IPartListener2 {
-		
+
 		private boolean fASTViewVisible= true;
 		private ASTView fView;
-		
+
 		public ListenerMix(ASTView view) {
 			fView= view;
 		}
-		
+
 		public void dispose() {
 			fView= null;
 		}
@@ -350,7 +355,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		public void doubleClick(DoubleClickEvent event) {
 			fView.handleDoubleClick();
 		}
-		
+
 		@Override
 		public void partHidden(IWorkbenchPartReference partRef) {
 			IWorkbenchPart part= partRef.getPart(false);
@@ -398,28 +403,25 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		}
 	}
 
-	private static final class BreakStatementChecker extends ASTVisitor {
+	private static final class StatementChecker extends ASTVisitor {
 
 		@Override
-		public boolean visit(BreakStatement node) {
+		public boolean visit(YieldStatement node) {
 			try {
-				if (node != null && node.isImplicit() && isInSwitchExpressionOrStatement(node)) {
+				if (node != null && node.isImplicit() && isInSwitchExpression(node)) {
 					ASTNode parent= node.getParent();
 					List<Statement> statements= null;
 					if (parent instanceof Block) {
 						statements= ((Block) parent).statements();
 					} else if (parent instanceof SwitchExpression) {
 						statements= ((SwitchExpression) parent).statements();
-					} else if (parent instanceof SwitchStatement) {
-						statements= ((SwitchStatement) parent).statements();
 					}
 					if (statements == null) {
 						return true;
 					}
 					Expression exp= node.getExpression();
 					if (exp == null) {
-						statements.remove(node);
-						return false;
+						return true;
 					} else {
 						int index= statements.indexOf(node);
 						statements.remove(node);
@@ -437,11 +439,11 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 			return true;
 		}
 
-		private boolean isInSwitchExpressionOrStatement(BreakStatement node) {
+		private boolean isInSwitchExpression(YieldStatement node) {
 			boolean result= false;
 			ASTNode parent= node;
 			while (parent != null) {
-				if (parent instanceof SwitchStatement || parent instanceof SwitchExpression) {
+				if (parent instanceof SwitchExpression) {
 					result= true;
 					break;
 				}
@@ -464,7 +466,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 	private TreeViewer fViewer;
 	private ASTViewLabelProvider fASTLabelProvider;
 	private TreeViewer fTray;
-	
+
 	private DrillDownAdapter fDrillDownAdapter;
 	private Action fFocusAction;
 	private Action fRefreshAction;
@@ -484,34 +486,34 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 	private Action fLinkWithEditor;
 	private Action fAddToTrayAction;
 	private Action fDeleteAction;
-	
+
 	private ASTLevelToggle[] fASTVersionToggleActions;
 	private int fCurrentASTLevel;
-	
+
 	private ASTInputKindAction[] fASTInputKindActions;
 	private int fCurrentInputKind;
-	
+
 	private ITextEditor fEditor;
 	private ITypeRoot fTypeRoot;
 	private CompilationUnit fRoot;
 	private IDocument fCurrentDocument;
 	private ArrayList<Object> fTrayRoots;
-	
+
 	private boolean fDoLinkWithEditor;
 	private boolean fCreateBindings;
 	private NonRelevantFilter fNonRelevantFilter;
 	private boolean fStatementsRecovery;
 	private boolean fBindingsRecovery;
 	private boolean fIgnoreMethodBodies;
-	
+
 	private Object fPreviousDouble;
-	
+
 	private ListenerMix fSuperListener;
 	private ISelectionChangedListener fTrayUpdater;
 
 	private IDialogSettings fDialogSettings;
 
-	
+
 	public ASTView() {
 		fSuperListener= null;
 		fDialogSettings= ASTViewPlugin.getDefault().getDialogSettings();
@@ -537,6 +539,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 				case JLS10:
 				case JLS11:
 				case JLS12:
+				case JLS13:
 					fCurrentASTLevel= level;
 			}
 		} catch (NumberFormatException e) {
@@ -545,7 +548,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fNonRelevantFilter= new NonRelevantFilter();
 		fNonRelevantFilter.setShowNonRelevant(fDialogSettings.getBoolean(SETTINGS_SHOW_NON_RELEVANT));
 	}
-	
+
 	final void notifyWorkbenchPartClosed(IWorkbenchPartReference partRef) {
 		if (fEditor != null && fEditor.equals(partRef.getPart(false))) {
 			try {
@@ -561,18 +564,18 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		super.setSite(site);
 		if (fSuperListener == null) {
 			fSuperListener= new ListenerMix(this);
-			
+
 			ISelectionService service= site.getWorkbenchWindow().getSelectionService();
 			service.addPostSelectionListener(fSuperListener);
 			site.getPage().addPartListener(fSuperListener);
 			FileBuffers.getTextFileBufferManager().addFileBufferListener(fSuperListener);
 		}
 	}
-	
+
 	public int getCurrentASTLevel() {
 		return fCurrentASTLevel;
 	}
-	
+
 	public int getCurrentInputKind() {
 		return fCurrentInputKind;
 	}
@@ -581,17 +584,17 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		if (fEditor != null) {
 			uninstallModificationListener();
 		}
-		
+
 		fEditor= null;
 		fRoot= null;
-		
+
 		if (editor != null) {
 			ITypeRoot typeRoot= EditorUtility.getJavaInput(editor);
 			if (typeRoot == null) {
 				throw new CoreException(getErrorStatus("Editor not showing a CU or class file", null)); //$NON-NLS-1$
 			}
 			fTypeRoot= typeRoot;
-			
+
 			ISelection selection= editor.getSelectionProvider().getSelection();
 			if (selection instanceof ITextSelection) {
 				ITextSelection textSelection= (ITextSelection) selection;
@@ -602,12 +605,12 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		}
 
 	}
-	
+
 	private CompilationUnit internalSetInput(ITypeRoot input, int offset, int length) throws CoreException {
 		if (input.getBuffer() == null) {
 			throw new CoreException(getErrorStatus("Input has no buffer", null)); //$NON-NLS-1$
 		}
-		
+
 		CompilationUnit root;
 		try {
 			root= createAST(input, offset);
@@ -619,7 +622,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		} catch (RuntimeException e) {
 			throw new CoreException(getErrorStatus("Could not create AST:\n" + e.getMessage(), e)); //$NON-NLS-1$
 		}
-		
+
 		try {
 			ASTNode node= NodeFinder.perform(root, offset, length);
 			if (node != null) {
@@ -634,15 +637,15 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		} catch (RuntimeException e) {
 			showAndLogError("Could not select node for editor selection", e); //$NON-NLS-1$
 		}
-		
+
 		return root;
 	}
-	
+
 	private void clearView() {
 		resetView(null);
 		setContentDescription("Open a Java editor and press the 'Show AST of active editor' toolbar button"); //$NON-NLS-1$
 	}
-	
+
 
 	private void resetView(CompilationUnit root) {
 		fViewer.setInput(root);
@@ -656,12 +659,12 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fFindDeclaringNodeAction.setEnabled(root != null);
 		fPreviousDouble= null; // avoid leaking AST
 	}
-	
+
 	private CompilationUnit createAST(ITypeRoot input, int offset) throws JavaModelException, CoreException {
 		long startTime;
 		long endTime;
 		CompilationUnit root;
-		
+
 		if ((getCurrentInputKind() == ASTInputKindAction.USE_RECONCILE)) {
 			final IProblemRequestor problemRequestor= new IProblemRequestor() { //strange: don't get bindings when supplying null as problemRequestor
 				@Override
@@ -696,13 +699,13 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 			} finally {
 				wc.discardWorkingCopy();
 			}
-			
+
 		} else if (input instanceof ICompilationUnit && (getCurrentInputKind() == ASTInputKindAction.USE_CACHE)) {
 			ICompilationUnit cu= (ICompilationUnit) input;
 			startTime= System.currentTimeMillis();
 			root= SharedASTProviderCore.getAST(cu, SharedASTProviderCore.WAIT_NO, null);
 			endTime= System.currentTimeMillis();
-			
+
 		} else {
 			ASTParser parser= ASTParser.newParser(fCurrentASTLevel);
 			parser.setResolveBindings(fCreateBindings);
@@ -718,8 +721,8 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 			endTime= System.currentTimeMillis();
 		}
 		if (root != null) {
-			root.accept(new BreakStatementChecker());	
-			updateContentDescription(input, root, endTime - startTime);			
+			root.accept(new StatementChecker());
+			updateContentDescription(input, root, endTime - startTime);
 		}
 		return root;
 	}
@@ -738,19 +741,25 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fStatementsRecoveryAction.setEnabled(enabled);
 		fBindingsRecoveryAction.setEnabled(enabled);
 		fIgnoreMethodBodiesAction.setEnabled(enabled);
-		for (int i= 0; i < fASTVersionToggleActions.length; i++) {
-			fASTVersionToggleActions[i].setEnabled(enabled);
+		for (ASTView.ASTLevelToggle action : fASTVersionToggleActions) {
+			action.setEnabled(enabled);
 		}
 	}
 
 	private void updateContentDescription(IJavaElement element, CompilationUnit root, long time) {
 		String version= "AST Level " + root.getAST().apiLevel();
-		if (getCurrentInputKind() == ASTInputKindAction.USE_RECONCILE) {
+		switch (getCurrentInputKind()) {
+		case ASTInputKindAction.USE_RECONCILE:
 			version+= ", from reconciler"; //$NON-NLS-1$
-		} else if (getCurrentInputKind() == ASTInputKindAction.USE_CACHE) {
+			break;
+		case ASTInputKindAction.USE_CACHE:
 			version+= ", from ASTProvider"; //$NON-NLS-1$
-		} else if (getCurrentInputKind() == ASTInputKindAction.USE_FOCAL) {
+			break;
+		case ASTInputKindAction.USE_FOCAL:
 			version+= ", using focal position"; //$NON-NLS-1$
+			break;
+		default:
+			break;
 		}
 		TreeInfoCollector collector= new TreeInfoCollector(root);
 
@@ -780,11 +789,11 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		}
 		super.dispose();
 	}
-	
+
 	private IStatus getErrorStatus(String message, Throwable th) {
 		return new Status(IStatus.ERROR, ASTViewPlugin.getPluginId(), IStatus.ERROR, message, th);
 	}
-	
+
 	@Override
 	public void createPartControl(Composite parent) {
 		fSash= new SashForm(parent, SWT.VERTICAL | SWT.SMOOTH);
@@ -804,16 +813,16 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 			}
 		});
 		fViewer.addFilter(fNonRelevantFilter);
-		
-		
+
+
 		ViewForm trayForm= new ViewForm(fSash, SWT.NONE);
 		Label label= new Label(trayForm, SWT.NONE);
 		label.setText(" Comparison Tray (* = selection in the upper tree):"); //$NON-NLS-1$
 		trayForm.setTopLeft(label);
-		
+
 		fTray= new TreeViewer(trayForm, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL);
 		trayForm.setContent(fTray.getTree());
-		
+
 		fTrayRoots= new ArrayList<>();
 		fTray.setContentProvider(new TrayContentProvider());
 		final TrayLabelProvider trayLabelProvider= new TrayLabelProvider();
@@ -859,13 +868,13 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 				fDeleteAction.setEnabled(false);
 			}
 		});
-		
+
 		makeActions();
 		hookContextMenu();
 		hookTrayContextMenu();
 		contributeToActionBars();
 		getSite().setSelectionProvider(new ASTViewSelectionProvider());
-		
+
 		try {
 			IEditorPart part= EditorUtility.getActiveEditor();
 			if (part instanceof ITextEditor) {
@@ -912,7 +921,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fTray.getControl().setMenu(menu);
 		getSite().registerContextMenu("#TrayPopupMenu", menuMgr, fTray); //$NON-NLS-1$
 	}
-	
+
 	private void contributeToActionBars() {
 		IActionBars bars = getViewSite().getActionBars();
 		fillLocalPullDown(bars.getMenuManager());
@@ -920,14 +929,14 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		bars.setGlobalActionHandler(ActionFactory.COPY.getId(), fCopyAction);
 		bars.setGlobalActionHandler(ActionFactory.REFRESH.getId(), fFocusAction);
 		bars.setGlobalActionHandler(ActionFactory.DELETE.getId(), fDeleteAction);
-		
+
 		IHandlerService handlerService= getViewSite().getService(IHandlerService.class);
 		handlerService.activateHandler(IWorkbenchCommandConstants.NAVIGATE_TOGGLE_LINK_WITH_EDITOR, new ActionHandler(fLinkWithEditor));
 	}
 
 	private void fillLocalPullDown(IMenuManager manager) {
-		for (int i= 0; i < fASTVersionToggleActions.length; i++) {
-			manager.add(fASTVersionToggleActions[i]);
+		for (ASTView.ASTLevelToggle action : fASTVersionToggleActions) {
+			manager.add(action);
 		}
 		manager.add(new Separator());
 		manager.add(fCreateBindingsAction);
@@ -935,8 +944,8 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		manager.add(fBindingsRecoveryAction);
 		manager.add(fIgnoreMethodBodiesAction);
 		manager.add(new Separator());
-		for (int i= 0; i < fASTInputKindActions.length; i++) {
-			manager.add(fASTInputKindActions[i]);
+		for (ASTView.ASTInputKindAction action : fASTInputKindActions) {
+			manager.add(action);
 		}
 		manager.add(new Separator());
 		manager.add(fFindDeclaringNodeAction);
@@ -996,11 +1005,11 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		manager.add(fCollapseAction);
 		manager.add(fLinkWithEditor);
 	}
-	
+
 	private void setASTUptoDate(boolean isuptoDate) {
 		fRefreshAction.setEnabled(!isuptoDate && fTypeRoot != null);
 	}
-	
+
 	private void makeActions() {
 		fRefreshAction = new Action() {
 			@Override
@@ -1023,14 +1032,14 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fClearAction.setToolTipText("Clear AST and release memory"); //$NON-NLS-1$
 		fClearAction.setEnabled(false);
 		ASTViewImages.setImageDescriptors(fClearAction, ASTViewImages.CLEAR);
-				
+
 		fASTInputKindActions= new ASTInputKindAction[] {
 				new ASTInputKindAction("Use ASTParser.&createAST", ASTInputKindAction.USE_PARSER), //$NON-NLS-1$
 				new ASTInputKindAction("Use ASTParser with &focal position", ASTInputKindAction.USE_FOCAL), //$NON-NLS-1$
 				new ASTInputKindAction("Use ICompilationUnit.&reconcile", ASTInputKindAction.USE_RECONCILE), //$NON-NLS-1$
 				new ASTInputKindAction("Use SharedASTProvider.&getAST", ASTInputKindAction.USE_CACHE) //$NON-NLS-1$
 		};
-		
+
 		fCreateBindingsAction = new Action("&Create Bindings", IAction.AS_CHECK_BOX) { //$NON-NLS-1$
 			@Override
 			public void run() {
@@ -1040,7 +1049,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fCreateBindingsAction.setChecked(fCreateBindings);
 		fCreateBindingsAction.setToolTipText("Create Bindings"); //$NON-NLS-1$
 		fCreateBindingsAction.setEnabled(true);
-		
+
 		fStatementsRecoveryAction = new Action("&Statements Recovery", IAction.AS_CHECK_BOX) { //$NON-NLS-1$
 			@Override
 			public void run() {
@@ -1049,7 +1058,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		};
 		fStatementsRecoveryAction.setChecked(fStatementsRecovery);
 		fStatementsRecoveryAction.setEnabled(true);
-		
+
 		fBindingsRecoveryAction = new Action("&Bindings Recovery", IAction.AS_CHECK_BOX) { //$NON-NLS-1$
 			@Override
 			public void run() {
@@ -1058,7 +1067,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		};
 		fBindingsRecoveryAction.setChecked(fBindingsRecovery);
 		fBindingsRecoveryAction.setEnabled(true);
-		
+
 		fIgnoreMethodBodiesAction = new Action("&Ignore Method Bodies", IAction.AS_CHECK_BOX) { //$NON-NLS-1$
 			@Override
 			public void run() {
@@ -1067,7 +1076,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		};
 		fIgnoreMethodBodiesAction.setChecked(fIgnoreMethodBodies);
 		fIgnoreMethodBodiesAction.setEnabled(true);
-		
+
 		fFilterNonRelevantAction = new Action("&Hide Non-Relevant Attributes", IAction.AS_CHECK_BOX) { //$NON-NLS-1$
 			@Override
 			public void run() {
@@ -1086,7 +1095,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		};
 		fFindDeclaringNodeAction.setToolTipText("Find Declaring Node..."); //$NON-NLS-1$
 		fFindDeclaringNodeAction.setEnabled(false);
-		
+
 		fParseBindingFromElementAction= new Action("&Parse Binding from &Element Handle...", IAction.AS_PUSH_BUTTON) { //$NON-NLS-1$
 			@Override
 			public void run() {
@@ -1095,7 +1104,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		};
 		fParseBindingFromElementAction.setToolTipText("Parse Binding from Element Handle..."); //$NON-NLS-1$
 		fParseBindingFromElementAction.setEnabled(true);
-		
+
 		fParseBindingFromKeyAction= new Action("Parse Binding from &Key...", IAction.AS_PUSH_BUTTON) { //$NON-NLS-1$
 			@Override
 			public void run() {
@@ -1104,7 +1113,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		};
 		fParseBindingFromKeyAction.setToolTipText("Parse Binding from Key..."); //$NON-NLS-1$
 		fParseBindingFromKeyAction.setEnabled(true);
-		
+
 		fFocusAction = new Action() {
 			@Override
 			public void run() {
@@ -1113,7 +1122,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		};
 		fFocusAction.setText("&Show AST of active editor"); //$NON-NLS-1$
 		fFocusAction.setToolTipText("Show AST of active editor"); //$NON-NLS-1$
-		fFocusAction.setActionDefinitionId(IWorkbenchCommandConstants.FILE_REFRESH); //$NON-NLS-1$
+		fFocusAction.setActionDefinitionId(IWorkbenchCommandConstants.FILE_REFRESH);
 		ASTViewImages.setImageDescriptors(fFocusAction, ASTViewImages.SETFOCUS);
 
 		fCollapseAction = new Action() {
@@ -1126,7 +1135,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fCollapseAction.setToolTipText("Collapse Selected Node"); //$NON-NLS-1$
 		fCollapseAction.setEnabled(false);
 		ASTViewImages.setImageDescriptors(fCollapseAction, ASTViewImages.COLLAPSE);
-		
+
 		fExpandAction = new Action() {
 			@Override
 			public void run() {
@@ -1137,16 +1146,16 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fExpandAction.setToolTipText("Expand Selected Node"); //$NON-NLS-1$
 		fExpandAction.setEnabled(false);
 		ASTViewImages.setImageDescriptors(fExpandAction, ASTViewImages.EXPAND);
-		
+
 		fCopyAction= new TreeCopyAction(new Tree[] {fViewer.getTree(), fTray.getTree()});
-		
+
 		fDoubleClickAction = new Action() {
 			@Override
 			public void run() {
 				performDoubleClick();
 			}
 		};
-		
+
 		fLinkWithEditor = new Action() {
 			@Override
 			public void run() {
@@ -1158,7 +1167,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fLinkWithEditor.setToolTipText("Link With Editor"); //$NON-NLS-1$
 		fLinkWithEditor.setActionDefinitionId(IWorkbenchCommandConstants.NAVIGATE_TOGGLE_LINK_WITH_EDITOR);
 		ASTViewImages.setImageDescriptors(fLinkWithEditor, ASTViewImages.LINK_WITH_EDITOR);
-			
+
 		fASTVersionToggleActions= new ASTLevelToggle[] {
 				new ASTLevelToggle("AST Level &2 (1.2)", JLS2), //$NON-NLS-1$
 				new ASTLevelToggle("AST Level &3 (1.5)", JLS3), //$NON-NLS-1$
@@ -1168,8 +1177,9 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 				new ASTLevelToggle("AST Level 1&0 (10)", JLS10), //$NON-NLS-1$
 				new ASTLevelToggle("AST Level 1&1 (11)", JLS11), //$NON-NLS-1$
 				new ASTLevelToggle("AST Level 1&2 (12)", JLS12), //$NON-NLS-1$
+				new ASTLevelToggle("AST Level 1&3 (13)", JLS13), //$NON-NLS-1$
 		};
-		
+
 		fAddToTrayAction= new Action() {
 			@Override
 			public void run() {
@@ -1180,7 +1190,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fAddToTrayAction.setToolTipText("Add Selected Node to Comparison Tray"); //$NON-NLS-1$
 		fAddToTrayAction.setEnabled(false);
 		ASTViewImages.setImageDescriptors(fAddToTrayAction, ASTViewImages.ADD_TO_TRAY);
-		
+
 		fDeleteAction= new Action() {
 			@Override
 			public void run() {
@@ -1190,13 +1200,13 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fDeleteAction.setText("&Delete"); //$NON-NLS-1$
 		fDeleteAction.setToolTipText("Delete Binding from Tray"); //$NON-NLS-1$
 		fDeleteAction.setEnabled(false);
-		fDeleteAction.setImageDescriptor(ASTViewPlugin.getDefault().getWorkbench().getSharedImages().getImageDescriptor(ISharedImages.IMG_TOOL_DELETE));
+		fDeleteAction.setImageDescriptor(PlatformUI.getWorkbench().getSharedImages().getImageDescriptor(ISharedImages.IMG_TOOL_DELETE));
 		fDeleteAction.setId(ActionFactory.DELETE.getId());
 		fDeleteAction.setActionDefinitionId(IWorkbenchCommandConstants.EDIT_DELETE);
-		
+
 		refreshASTSettingsActions();
 	}
-	
+
 
 	private void refreshAST() throws CoreException {
 		ASTNode node= getASTNodeNearSelection((IStructuredSelection) fViewer.getSelection());
@@ -1209,13 +1219,13 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 
 		internalSetInput(fTypeRoot, offset, length);
 	}
-		
+
 	protected void setASTLevel(int level, boolean doRefresh) {
 		int oldLevel= fCurrentASTLevel;
 		fCurrentASTLevel= level;
 
 		fDialogSettings.put(SETTINGS_JLS, fCurrentASTLevel);
-		
+
 		if (doRefresh && fTypeRoot != null && oldLevel != fCurrentASTLevel) {
 			try {
 				refreshAST();
@@ -1226,25 +1236,23 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 			}
 		}
 		// update action state
-		for (int i= 0; i < fASTVersionToggleActions.length; i++) {
-			ASTLevelToggle curr= fASTVersionToggleActions[i];
-			curr.setChecked(curr.getLevel() == fCurrentASTLevel);
+		for (ASTView.ASTLevelToggle action : fASTVersionToggleActions) {
+			action.setChecked(action.getLevel() == fCurrentASTLevel);
 		}
 	}
-	
+
 	protected void setASTInputType(int inputKind) {
 		if (inputKind != fCurrentInputKind) {
 			fCurrentInputKind= inputKind;
 			fDialogSettings.put(SETTINGS_INPUT_KIND, inputKind);
-			for (int i= 0; i < fASTInputKindActions.length; i++) {
-				ASTInputKindAction curr= fASTInputKindActions[i];
-				curr.setChecked(curr.getInputKind() == inputKind);
+			for (ASTView.ASTInputKindAction action : fASTInputKindActions) {
+				action.setChecked(action.getInputKind() == inputKind);
 			}
 			refreshASTSettingsActions();
 			performRefresh();
 		}
 	}
-	
+
 	private ASTNode getASTNodeNearSelection(IStructuredSelection selection) {
 		Object elem= selection.getFirstElement();
 		if (elem instanceof ASTAttribute) {
@@ -1254,32 +1262,32 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		}
 		return null;
 	}
-	
+
 	private void installModificationListener() {
 		fCurrentDocument= fEditor.getDocumentProvider().getDocument(fEditor.getEditorInput());
 		fCurrentDocument.addDocumentListener(fSuperListener);
 	}
-	
+
 	private void uninstallModificationListener() {
 		if (fCurrentDocument != null) {
 			fCurrentDocument.removeDocumentListener(fSuperListener);
 			fCurrentDocument= null;
 		}
 	}
-		
+
 	protected void handleDocumentDisposed() {
 		uninstallModificationListener();
 	}
-	
+
 	protected void handleDocumentChanged() {
 		setASTUptoDate(false);
 	}
-	
+
 	protected void handleSelectionChanged(ISelection selection) {
 		fExpandAction.setEnabled(!selection.isEmpty());
 		fCollapseAction.setEnabled(!selection.isEmpty());
 		fCopyAction.setEnabled(!selection.isEmpty());
-		
+
 		boolean addEnabled= false;
 		IStructuredSelection structuredSelection= (IStructuredSelection) selection;
 		if (structuredSelection.size() == 1 && fViewer.getTree().isFocusControl()) {
@@ -1314,17 +1322,17 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 					setContentDescription(e.getStatus().getMessage());
 				}
 			}
-			
+
 		} else { // fRoot != null && part == fEditor
 			doLinkWithEditor(selection);
 		}
 	}
-	
+
 	private void doLinkWithEditor(ISelection selection) {
 		ITextSelection textSelection= (ITextSelection) selection;
 		int offset= textSelection.getOffset();
 		int length= textSelection.getLength();
-		
+
 		ASTNode covering= NodeFinder.perform(fRoot, offset, length);
 		if (covering != null) {
 			fViewer.reveal(covering);
@@ -1339,7 +1347,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 	protected void performLinkWithEditor() {
 		fDoLinkWithEditor= fLinkWithEditor.isChecked();
 		fDialogSettings.put(SETTINGS_LINK_WITH_EDITOR, fDoLinkWithEditor);
-		
+
 
 		if (fDoLinkWithEditor && fEditor != null) {
 			ISelectionProvider selectionProvider= fEditor.getSelectionProvider();
@@ -1354,10 +1362,9 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		if (selection.isEmpty()) {
 			fViewer.collapseAll();
 		} else {
-			Object[] selected= selection.toArray();
 			fViewer.getTree().setRedraw(false);
-			for (int i= 0; i < selected.length; i++) {
-				fViewer.collapseToLevel(selected[i], AbstractTreeViewer.ALL_LEVELS);
+			for (Object s : selection.toArray()) {
+				fViewer.collapseToLevel(s, AbstractTreeViewer.ALL_LEVELS);
 			}
 			fViewer.getTree().setRedraw(true);
 		}
@@ -1368,10 +1375,9 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		if (selection.isEmpty()) {
 			fViewer.expandToLevel(3);
 		} else {
-			Object[] selected= selection.toArray();
 			fViewer.getTree().setRedraw(false);
-			for (int i= 0; i < selected.length; i++) {
-				fViewer.expandToLevel(selected[i], 3);
+			for (Object s : selection.toArray()) {
+				fViewer.expandToLevel(s, 3);
 			}
 			fViewer.getTree().setRedraw(true);
 		}
@@ -1387,7 +1393,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 			}
 		}
 	}
-	
+
 	protected void performRefresh() {
 		if (fTypeRoot != null) {
 			try {
@@ -1412,44 +1418,44 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		ASTViewPlugin.log(message, e);
 		ErrorDialog.openError(getSite().getShell(), "AST View", message, e.getStatus()); //$NON-NLS-1$
 	}
-	
+
 	private void showAndLogError(String message, Throwable e) {
 		IStatus status= new Status(IStatus.ERROR, ASTViewPlugin.getPluginId(), 0, message, e);
 		ASTViewPlugin.log(status);
 		ErrorDialog.openError(getSite().getShell(), "AST View", null, status); //$NON-NLS-1$
 	}
-		
+
 	protected void performCreateBindings() {
 		fCreateBindings= fCreateBindingsAction.isChecked();
 		fDialogSettings.put(SETTINGS_NO_BINDINGS, !fCreateBindings);
 		performRefresh();
 	}
-	
+
 	protected void performStatementsRecovery() {
 		fStatementsRecovery= fStatementsRecoveryAction.isChecked();
 		fDialogSettings.put(SETTINGS_NO_STATEMENTS_RECOVERY, !fStatementsRecovery);
 		performRefresh();
 	}
-	
+
 	protected void performBindingsRecovery() {
 		fBindingsRecovery= fBindingsRecoveryAction.isChecked();
 		fDialogSettings.put(SETTINGS_NO_BINDINGS_RECOVERY, !fBindingsRecovery);
 		performRefresh();
 	}
-	
+
 	protected void performIgnoreMethodBodies() {
 		fIgnoreMethodBodies= fIgnoreMethodBodiesAction.isChecked();
 		fDialogSettings.put(SETTINGS_IGNORE_METHOD_BODIES, fIgnoreMethodBodies);
 		performRefresh();
 	}
-	
+
 	protected void performFilterNonRelevant() {
 		boolean showNonRelevant= !fFilterNonRelevantAction.isChecked();
 		fNonRelevantFilter.setShowNonRelevant(showNonRelevant);
 		fDialogSettings.put(SETTINGS_SHOW_NON_RELEVANT, showNonRelevant);
 		fViewer.refresh();
 	}
-	
+
 	protected void performFindDeclaringNode() {
 		String msg= "Find Declaring Node from Key";
 		String key= askForKey(msg);
@@ -1470,13 +1476,13 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		InputDialog dialog= new InputDialog(getSite().getShell(), dialogTitle, "Key: (optionally surrounded by <KEY: \"> and <\">)", "", null);
 		if (dialog.open() != Window.OK)
 			return null;
-		
+
 		String key= dialog.getValue();
 		if (key.startsWith("KEY: \"") && key.endsWith("\""))
 			key= key.substring(6, key.length() - 1);
 		return key;
 	}
-	
+
 	protected void performParseBindingFromKey() {
 		String msg= "Parse Binding from Key";
 		String key= askForKey(msg);
@@ -1511,15 +1517,15 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fViewer.add(viewerInput, item);
 		fViewer.setSelection(new StructuredSelection(item), true);
 	}
-	
+
 	protected void performParseBindingFromElement() {
 		InputDialog dialog= new InputDialog(getSite().getShell(), "Parse Binding from Java Element", "IJavaElement#getHandleIdentifier():", "", null);
 		if (dialog.open() != Window.OK)
 			return;
-		
+
 		String handleIdentifier= dialog.getValue();
 		IJavaElement handle= JavaCore.create(handleIdentifier);
-		
+
 		Object viewerInput= fViewer.getInput();
 		ASTAttribute item;
 		if (handle == null) {
@@ -1539,18 +1545,18 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		fViewer.add(viewerInput, item);
 		fViewer.setSelection(new StructuredSelection(item), true);
 	}
-	
+
 	protected void performDoubleClick() {
 		if (fEditor == null) {
 			return;
 		}
-		
+
 		ISelection selection = fViewer.getSelection();
 		Object obj = ((IStructuredSelection) selection).getFirstElement();
 
 		boolean isTripleClick= (obj == fPreviousDouble);
 		fPreviousDouble= isTripleClick ? null : obj;
-		
+
 		if (obj instanceof ExceptionAttribute) {
 			Throwable exception= ((ExceptionAttribute) obj).getException();
 			if (exception != null) {
@@ -1559,11 +1565,11 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 				return;
 			}
 		}
-		
+
 		ASTNode node= null, nodeEnd= null;
 		if (obj instanceof ASTNode) {
 			node= (ASTNode) obj;
-			
+
 		} else if (obj instanceof NodeProperty) {
 			Object val= ((NodeProperty) obj).getNode();
 			if (val instanceof ASTNode) {
@@ -1577,7 +1583,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 					fViewer.getTree().getDisplay().beep();
 				}
 			}
-			
+
 		} else if (obj instanceof Binding) {
 			IBinding binding= ((Binding) obj).getBinding();
 			ASTNode declaring= fRoot.findDeclaringNode(binding);
@@ -1588,12 +1594,12 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 				fViewer.getTree().getDisplay().beep();
 			}
 			return;
-			
+
 		} else if (obj instanceof ProblemNode) {
 			ProblemNode problemNode= (ProblemNode) obj;
 			EditorUtility.selectInEditor(fEditor, problemNode.getOffset(), problemNode.getLength());
 			return;
-			
+
 		} else if (obj instanceof JavaElement) {
 			IJavaElement javaElement= ((JavaElement) obj).getJavaElement();
 			if (javaElement instanceof IPackageFragment) {
@@ -1619,7 +1625,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 			}
 			return;
 		}
-		
+
 		if (node != null) {
 			int offset= isTripleClick ? fRoot.getExtendedStartPosition(node) : node.getStartPosition();
 			int length;
@@ -1649,7 +1655,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		}
 		setTraySelection(selection);
 	}
-	
+
 	private void setTraySelection(IStructuredSelection selection) {
 		fTray.setSelection(selection, true);
 		TreeItem[] itemSelection= fTray.getTree().getSelection();
@@ -1675,7 +1681,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 			fViewer.setSelection(new StructuredSelection(binding), true);
 		}
 	}
-		
+
 	protected void performDelete() {
 		boolean removed= false;
 		IStructuredSelection selection= (IStructuredSelection) fTray.getSelection();
@@ -1685,13 +1691,13 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 				obj= ((DynamicAttributeProperty) obj).getParent();
 			if (obj instanceof DynamicBindingProperty)
 				obj= ((DynamicBindingProperty) obj).getParent();
-			
+
 			removed|= fTrayRoots.remove(obj);
 		}
 		if (removed)
 			fTray.setInput(fTrayRoots);
 	}
-	
+
 	@Override
 	public void setFocus() {
 		fViewer.getControl().setFocus();
