@@ -23,7 +23,6 @@ import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTNode;
 import org.eclipse.jdt.core.dom.AnnotatableType;
-import org.eclipse.jdt.core.dom.BreakStatement;
 import org.eclipse.jdt.core.dom.ClassInstanceCreation;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.ContinueStatement;
@@ -62,6 +61,7 @@ import org.eclipse.jdt.core.dom.ThisExpression;
 import org.eclipse.jdt.core.dom.TypeDeclaration;
 import org.eclipse.jdt.core.dom.TypeMethodReference;
 import org.eclipse.jdt.core.dom.UsesDirective;
+import org.eclipse.jdt.core.dom.YieldStatement;
 
 import org.eclipse.jdt.internal.corext.dom.GenericVisitor;
 import org.eclipse.jdt.internal.corext.dom.ScopeAnalyzer;
@@ -291,7 +291,7 @@ public class ImportReferencesCollector extends GenericVisitor {
 		doVisitChildren(node.annotations());
 		return false;
 	}
-	
+
 	@Override
 	public boolean visit(LabeledStatement node) {
 		doVisitNode(node.getBody());
@@ -302,16 +302,15 @@ public class ImportReferencesCollector extends GenericVisitor {
 	public boolean visit(ContinueStatement node) {
 		return false;
 	}
-	
+
 	@Override
-	public boolean visit(BreakStatement node) {
-		int apiLevel= node.getAST().apiLevel();
-		if (apiLevel >= AST.JLS12) {
-			evalQualifyingExpression(node.getExpression(), null);			
+	public boolean visit(YieldStatement node) {
+		if (node.getAST().isPreviewEnabled()) {
+			evalQualifyingExpression(node.getExpression(), null);
 		}
 		return false;
 	}
-	
+
 	/*
 	 * @see ASTVisitor#visit(ThisExpression)
 	 */
@@ -320,7 +319,7 @@ public class ImportReferencesCollector extends GenericVisitor {
 		typeRefFound(node.getQualifier());
 		return false;
 	}
-	
+
 	@Override
 	public boolean visit(SuperFieldAccess node) {
 		typeRefFound(node.getQualifier());
@@ -373,7 +372,7 @@ public class ImportReferencesCollector extends GenericVisitor {
 		doVisitChildren(node.typeArguments());
 		return false;
 	}
-	
+
 	@Override
 	public boolean visit(ExpressionMethodReference node) {
 		evalQualifyingExpression(node.getExpression(), node.getName());
@@ -387,7 +386,7 @@ public class ImportReferencesCollector extends GenericVisitor {
 		doVisitChildren(node.typeArguments());
 		return false;
 	}
-	
+
 	@Override
 	public boolean visit(TypeMethodReference node) {
 		doVisitNode(node.getType());
@@ -409,7 +408,7 @@ public class ImportReferencesCollector extends GenericVisitor {
 		}
 		return false;
 	}
-	
+
 	/*
 	 * @see ASTVisitor#visit(SuperConstructorInvocation)
 	 */
@@ -492,7 +491,7 @@ public class ImportReferencesCollector extends GenericVisitor {
 			doVisitNode(node.getReturnType2());
 		}
 		// name not visited
-		
+
 		int apiLevel= node.getAST().apiLevel();
 		if (apiLevel >= AST.JLS8) {
 			doVisitNode(node.getReceiverType());
@@ -569,7 +568,7 @@ public class ImportReferencesCollector extends GenericVisitor {
 		}
 		return false;
 	}
-	
+
 	@Override
 	public boolean visit(MethodRefParameter node) {
 		doVisitNode(node.getType());
