@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
@@ -46,8 +46,6 @@ public class ASTFlattener extends GenericVisitor {
 	 */
 	@Deprecated
 	private static final int JLS9= AST.JLS9;
-	
-	private static final int JLS12= AST.JLS12;
 
 	/**
 	 * The string buffer into which the serialized representation of the AST is
@@ -135,7 +133,7 @@ public class ASTFlattener extends GenericVisitor {
 			this.fBuffer.append('>');
 		}
 	}
-	
+
 	void printTypeAnnotations(AnnotatableType node) {
 		if (node.getAST().apiLevel() >= JLS8) {
 			printAnnotationsList(node.annotations());
@@ -143,8 +141,7 @@ public class ASTFlattener extends GenericVisitor {
 	}
 
 	void printAnnotationsList(List<? extends Annotation> annotations) {
-		for (Iterator<? extends Annotation> it = annotations.iterator(); it.hasNext(); ) {
-			Annotation annotation = it.next();
+		for (Annotation annotation : annotations) {
 			annotation.accept(this);
 			this.fBuffer.append(' ');
 		}
@@ -371,21 +368,11 @@ public class ASTFlattener extends GenericVisitor {
 	 */
 	@Override
 	public boolean visit(BreakStatement node) {
-		int apiLevel= node.getAST().apiLevel();
-		if (apiLevel >= JLS12 && node.isImplicit() && node.getExpression() == null) {
-			return false;
-		}
-		if (apiLevel < JLS12 || (apiLevel >= JLS12 && !node.isImplicit())) {
-			this.fBuffer.append("break");//$NON-NLS-1$
-		}
+		this.fBuffer.append("break");//$NON-NLS-1$
 		if (node.getLabel() != null) {
 			this.fBuffer.append(" ");//$NON-NLS-1$
 			node.getLabel().accept(this);
 		}
-		if (apiLevel >= JLS12 && node.getExpression() != null) {
-			this.fBuffer.append(" ");//$NON-NLS-1$
-			node.getExpression().accept(this);
-		}
 		this.fBuffer.append(";");//$NON-NLS-1$
 		return false;
 	}
@@ -542,7 +529,7 @@ public class ASTFlattener extends GenericVisitor {
 		this.fBuffer.append(";");//$NON-NLS-1$
 		return false;
 	}
-	
+
 	/*
 	 * @see ASTVisitor#visit(CreationReference)
 	 */
@@ -807,7 +794,7 @@ public class ASTFlattener extends GenericVisitor {
 		this.fBuffer.append(' ');
 		node.getRightOperand().accept(this);
 		final List<Expression>extendedOperands = node.extendedOperands();
-		if (extendedOperands.size() != 0) {
+		if (!extendedOperands.isEmpty()) {
 			this.fBuffer.append(' ');
 			for (Iterator<Expression> it = extendedOperands.iterator(); it.hasNext(); ) {
 				this.fBuffer.append(node.getOperator().toString()).append(' ');
@@ -1441,6 +1428,15 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
+	/*
+	 * @see ASTVisitor#visit(StringLiteral)
+	 */
+	@Override
+	public boolean visit(TextBlock node) {
+		this.fBuffer.append(node.getEscapedValue());
+		return false;
+	}
+
 	/*
 	 * @see ASTVisitor#visit(SuperConstructorInvocation)
 	 */
@@ -1542,7 +1538,7 @@ public class ASTFlattener extends GenericVisitor {
 
 	@Override
 	public boolean visit(SwitchCase node) {
-		if (node.getAST().apiLevel() >= JLS12) {
+		if (node.getAST().isPreviewEnabled()) {
 			if (node.isDefault()) {
 				this.fBuffer.append("default");//$NON-NLS-1$
 				this.fBuffer.append(node.isSwitchLabeledRule() ? " ->" : ":");//$NON-NLS-1$ //$NON-NLS-2$
@@ -1567,12 +1563,26 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
+	@Override
+	public boolean visit(YieldStatement node) {
+		if (node.getAST().isPreviewEnabled() && node.isImplicit() && node.getExpression() == null) {
+			return false;
+		}
+		this.fBuffer.append("yield"); //$NON-NLS-1$
+		if (node.getExpression() != null) {
+			this.fBuffer.append(" ");//$NON-NLS-1$
+			node.getExpression().accept(this);
+		}
+		this.fBuffer.append(";");//$NON-NLS-1$
+		return false;
+	}
+
 	@Override
 	public boolean visit(SwitchStatement node) {
 		visitSwitchNode(node);
 		return false;
 	}
-	
+
 	@Override
 	public boolean visit(SwitchExpression node) {
 		visitSwitchNode(node);
