@@ -479,6 +479,16 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 		endVisit((Expression)node);
 	}
 
+	@Override
+	public boolean visit(YieldStatement node) {
+		return visit((Statement)node);
+	}
+
+	@Override
+	public void endVisit(YieldStatement node) {
+		endVisit((Statement)node);
+	}
+
 	//---- Begin MethodReference Hierarchy ----------------------------------
 	public boolean visit(MethodReference node) {
 		return visit((Expression)node);
@@ -636,11 +646,21 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 		return visit((Expression)node);
 	}
 
+	@Override
+	public boolean visit(TextBlock node) {
+		return visit((Expression)node);
+	}
+
 	@Override
 	public void endVisit(SuperMethodInvocation node) {
 		endVisit((Expression)node);
 	}
 
+	@Override
+	public void endVisit(TextBlock node) {
+		endVisit((Expression)node);
+	}
+
 	@Override
 	public boolean visit(ThisExpression node) {
 		return visit((Expression)node);
@@ -737,12 +757,12 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 	public boolean visit(ModuleDeclaration node) {
 		return visit((ASTNode)node);
 	}
-	
+
 	@Override
 	public void endVisit(ModuleDeclaration node) {
 		endVisit((ASTNode)node);
 	}
-	
+
 	//---- Begin ModuleDirective Hierarchy ----------------------------------
 
 	public boolean visit(ModuleDirective node) {
@@ -754,11 +774,11 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 	}
 
 	//---- Begin ModulePackageAccess Hierarchy ----------------------------------
-	
+
 	public boolean visit(ModulePackageAccess node) {
 		return visit((ModuleDirective)node);
 	}
-	
+
 	public void endVisit(ModulePackageAccess node) {
 		endVisit((ModuleDirective)node);
 	}
@@ -767,7 +787,7 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 	public boolean visit(ExportsDirective node) {
 		return visit((ModulePackageAccess)node);
 	}
-	
+
 	@Override
 	public void endVisit(ExportsDirective node) {
 		endVisit((ModulePackageAccess)node);
@@ -777,24 +797,24 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 	public boolean visit(OpensDirective node) {
 		return visit((ModulePackageAccess)node);
 	}
-	
+
 	@Override
 	public void endVisit(OpensDirective node) {
 		endVisit((ModulePackageAccess)node);
 	}
-	
+
 	//---- End ModulePackageAccess Hierarchy ------------------------------------
-	
+
 	@Override
 	public boolean visit(ProvidesDirective node) {
 		return visit((ModuleDirective)node);
 	}
-	
+
 	@Override
 	public void endVisit(ProvidesDirective node) {
 		endVisit((ModuleDirective)node);
 	}
-	
+
 	@Override
 	public boolean visit(RequiresDirective node) {
 		return visit((ModuleDirective)node);
@@ -809,24 +829,24 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 	public boolean visit(UsesDirective node) {
 		return visit((ModuleDirective)node);
 	}
-	
+
 	@Override
 	public void endVisit(UsesDirective node) {
 		endVisit((ModuleDirective)node);
 	}
-	
+
 	//---- End ModuleDirective Hierarchy ------------------------------------
-	
+
 	@Override
 	public boolean visit(ModuleModifier node) {
 		return visit((ASTNode)node);
 	}
-	
+
 	@Override
 	public void endVisit(ModuleModifier node) {
 		endVisit((ASTNode)node);
 	}
-	
+
 	@Override
 	public boolean visit(PackageDeclaration node) {
 		return visit((ASTNode)node);
