@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -176,7 +176,7 @@ public class Checks {
 	 */
 	public static RefactoringStatus checkTypeName(String name, IJavaElement context) {
 		//fix for: 1GF5Z0Z: ITPJUI:WINNT - assertion failed after renameType refactoring
-		if (name.indexOf(".") != -1) //$NON-NLS-1$
+		if (name.contains(".")) //$NON-NLS-1$
 			return RefactoringStatus.createFatalErrorStatus(RefactoringCoreMessages.Checks_no_dot);
 		else
 			return checkName(name, JavaConventionsUtil.validateJavaTypeName(name, context));
@@ -209,7 +209,7 @@ public class Checks {
 	/**
 	 * Returns OK status if the new name is OK, i.e. when no file with that name exists.
 	 * The name of the given CU is not OK.
-	 * 
+	 *
 	 * @param cu CU to rename
 	 * @param newBareName the new name of the CU (without extension)
 	 * @return the status: FATAL if the CU already exists, OK if OK
@@ -224,13 +224,15 @@ public class Checks {
 	}
 
 	public static boolean startsWithLowerCase(String s){
-		if (s == null)
+		if (null == s)
 			return false;
-		else if ("".equals(s)) //$NON-NLS-1$
+		else switch (s) {
+		case "": //$NON-NLS-1$
 			return false;
-		else
+		default:
 			//workaround for JDK bug (see 26529)
 			return s.charAt(0) == Character.toLowerCase(s.charAt(0));
+		}
 	}
 
 	public static boolean resourceExists(IPath resourcePath){
@@ -269,8 +271,9 @@ public class Checks {
 
 	public static RefactoringStatus checkForMainAndNativeMethods(IType[] types) throws JavaModelException {
 		RefactoringStatus result= new RefactoringStatus();
-		for (int i= 0; i < types.length; i++)
-			result.merge(checkForMainAndNativeMethods(types[i]));
+		for (IType type : types) {
+			result.merge(checkForMainAndNativeMethods(type));
+		}
 		return result;
 	}
 
@@ -283,18 +286,17 @@ public class Checks {
 
 	private static RefactoringStatus checkForMainAndNativeMethods(IMethod[] methods) throws JavaModelException {
 		RefactoringStatus result= new RefactoringStatus();
-		for (int i= 0; i < methods.length; i++) {
-			if (JdtFlags.isNative(methods[i])){
-				String typeName= JavaElementLabelsCore.getElementLabel(methods[i].getDeclaringType(), JavaElementLabelsCore.ALL_FULLY_QUALIFIED);
-				String methodName= JavaElementLabelsCore.getElementLabel(methods[i], JavaElementLabelsCore.ALL_DEFAULT);
+		for (IMethod method : methods) {
+			if (JdtFlags.isNative(method)) {
+				String typeName= JavaElementLabelsCore.getElementLabel(method.getDeclaringType(), JavaElementLabelsCore.ALL_FULLY_QUALIFIED);
+				String methodName= JavaElementLabelsCore.getElementLabel(method, JavaElementLabelsCore.ALL_DEFAULT);
 				String msg= Messages.format(RefactoringCoreMessages.Checks_method_native,
-								new String[]{typeName, methodName, "UnsatisfiedLinkError"});//$NON-NLS-1$
-				result.addEntry(RefactoringStatus.ERROR, msg, JavaStatusContext.create(methods[i]), JavaManipulation.getPreferenceNodeId(), RefactoringStatusCodes.NATIVE_METHOD);
+					new String[]{typeName, methodName, "UnsatisfiedLinkError"});//$NON-NLS-1$
+				result.addEntry(RefactoringStatus.ERROR, msg, JavaStatusContext.create(method), JavaManipulation.getPreferenceNodeId(), RefactoringStatusCodes.NATIVE_METHOD);
 			}
-			if (methods[i].isMainMethod()) {
-				String msg= Messages.format(RefactoringCoreMessages.Checks_has_main,
-						JavaElementLabelsCore.getElementLabel(methods[i].getDeclaringType(), JavaElementLabelsCore.ALL_FULLY_QUALIFIED));
-				result.addEntry(RefactoringStatus.WARNING, msg, JavaStatusContext.create(methods[i]), JavaManipulation.getPreferenceNodeId(), RefactoringStatusCodes.MAIN_METHOD);
+			if (method.isMainMethod()) {
+				String msg= Messages.format(RefactoringCoreMessages.Checks_has_main, JavaElementLabelsCore.getElementLabel(method.getDeclaringType(), JavaElementLabelsCore.ALL_FULLY_QUALIFIED));
+				result.addEntry(RefactoringStatus.WARNING, msg, JavaStatusContext.create(method), JavaManipulation.getPreferenceNodeId(), RefactoringStatusCodes.MAIN_METHOD);
 			}
 		}
 		return result;
@@ -386,14 +388,28 @@ public class Checks {
 	public static boolean isEnumCase(ASTNode node) {
 		if (node instanceof SwitchCase) {
 			final SwitchCase caze= (SwitchCase) node;
-			final Expression expression= caze.getExpression();
-			if (expression instanceof Name) {
-				final Name name= (Name) expression;
-				final IBinding binding= name.resolveBinding();
-				if (binding instanceof IVariableBinding) {
-					IVariableBinding variableBinding= (IVariableBinding) binding;
-					return variableBinding.isEnumConstant();
+			if (node.getAST().isPreviewEnabled()) {
+				List<Expression> expressions= caze.expressions();
+				boolean isEnumConst= true;
+				for (Expression expression : expressions) {
+					isEnumConst= isEnumConst && isEnumConst(expression);
 				}
+				return isEnumConst;
+			} else {
+				Expression expression= caze.getExpression();
+				return isEnumConst(expression);
+			}
+		}
+		return false;
+	}
+
+	private static boolean isEnumConst(final Expression expression) {
+		if (expression instanceof Name) {
+			final Name name= (Name) expression;
+			final IBinding binding= name.resolveBinding();
+			if (binding instanceof IVariableBinding) {
+				IVariableBinding variableBinding= (IVariableBinding) binding;
+				return variableBinding.isEnumConstant();
 			}
 		}
 		return false;
@@ -526,8 +542,7 @@ public class Checks {
 	 */
 	public static IMethod findSimilarMethod(IMethod method, IMethod[] methods) throws JavaModelException {
 		boolean isConstructor= method.isConstructor();
-		for (int i= 0; i < methods.length; i++) {
-			IMethod otherMethod= methods[i];
+		for (IMethod otherMethod : methods) {
 			if (otherMethod.isConstructor() == isConstructor && method.isSimilar(otherMethod))
 				return otherMethod;
 		}
@@ -577,8 +592,8 @@ public class Checks {
 	public static SearchResultGroup[] excludeCompilationUnits(SearchResultGroup[] grouped, RefactoringStatus status) throws JavaModelException{
 		List<SearchResultGroup> result= new ArrayList<>();
 		boolean wasEmpty= grouped.length == 0;
-		for (int i= 0; i < grouped.length; i++){
-			IResource resource= grouped[i].getResource();
+		for (SearchResultGroup g : grouped) {
+			IResource resource= g.getResource();
 			IJavaElement element= JavaCore.create(resource);
 			if (! (element instanceof ICompilationUnit))
 				continue;
@@ -588,7 +603,7 @@ public class Checks {
 				status.addError(Messages.format(RefactoringCoreMessages.Checks_cannot_be_parsed, BasicElementLabels.getPathLabel(cu.getPath(), false)));
 				continue; //removed, go to the next one
 			}
-			result.add(grouped[i]);
+			result.add(g);
 		}
 
 		if ((!wasEmpty) && result.isEmpty())
@@ -599,8 +614,9 @@ public class Checks {
 
 	public static RefactoringStatus checkCompileErrorsInAffectedFiles(SearchResultGroup[] grouped) throws JavaModelException {
 		RefactoringStatus result= new RefactoringStatus();
-		for (int i= 0; i < grouped.length; i++)
-			checkCompileErrorsInAffectedFile(result, grouped[i].getResource());
+		for (SearchResultGroup g : grouped) {
+			checkCompileErrorsInAffectedFile(result, g.getResource());
+		}
 		return result;
 	}
 
@@ -611,8 +627,8 @@ public class Checks {
 
 	public static RefactoringStatus checkCompileErrorsInAffectedFiles(SearchResultGroup[] references, IResource declaring) throws JavaModelException {
 		RefactoringStatus result= new RefactoringStatus();
-		for (int i= 0; i < references.length; i++){
-			IResource resource= references[i].getResource();
+		for (SearchResultGroup reference : references) {
+			IResource resource= reference.getResource();
 			if (resource.equals(declaring))
 				declaring= null;
 			checkCompileErrorsInAffectedFile(result, resource);
@@ -624,10 +640,10 @@ public class Checks {
 
 	private static boolean hasCompileErrors(IResource resource) throws JavaModelException {
 		try {
-			IMarker[] problemMarkers= resource.findMarkers(IJavaModelMarker.JAVA_MODEL_PROBLEM_MARKER, true, IResource.DEPTH_INFINITE);
-			for (int i= 0; i < problemMarkers.length; i++) {
-				if (problemMarkers[i].getAttribute(IMarker.SEVERITY, -1) == IMarker.SEVERITY_ERROR)
+			for (IMarker problemMarker : resource.findMarkers(IJavaModelMarker.JAVA_MODEL_PROBLEM_MARKER, true, IResource.DEPTH_INFINITE)) {
+				if (problemMarker.getAttribute(IMarker.SEVERITY, -1) == IMarker.SEVERITY_ERROR) {
 					return true;
+				}
 			}
 			return false;
 		} catch (JavaModelException e){
@@ -662,10 +678,10 @@ public class Checks {
 
 		IContainer container= (IContainer)res;
 		try {
-			IResource[] children= container.members();
-			for (int i= 0; i < children.length; i++) {
-				if (isReadOnly(children[i]))
+			for (IResource child : container.members()) {
+				if (isReadOnly(child)) {
 					return true;
+				}
 			}
 			return false;
 		} catch (JavaModelException e){
@@ -708,8 +724,8 @@ public class Checks {
 		ResourceChangeChecker checker= context.getChecker(ResourceChangeChecker.class);
 		IResourceChangeDescriptionFactory deltaFactory= checker.getDeltaFactory();
 
-		for (int i= 0; i < filesToModify.length; i++) {
-			deltaFactory.change(filesToModify[i]);
+		for (IFile file : filesToModify) {
+			deltaFactory.change(file);
 		}
 	}
 
@@ -834,9 +850,10 @@ public class Checks {
 			if (! iType.isClass())
 				return false;
 			IType[] superTypes= iType.newSupertypeHierarchy(pm).getAllSupertypes(iType);
-			for (int i= 0; i < superTypes.length; i++) {
-				if ("java.lang.Throwable".equals(superTypes[i].getFullyQualifiedName())) //$NON-NLS-1$
+			for (IType superType : superTypes) {
+				if ("java.lang.Throwable".equals(superType.getFullyQualifiedName())) { //$NON-NLS-1$
 					return true;
+				}
 			}
 			return false;
 		} finally{
@@ -860,7 +877,7 @@ public class Checks {
 		}
 		if (e instanceof Annotation)
 			return NOT_RVALUE_MISC;
-			
+
 
 		ITypeBinding tb= e.resolveTypeBinding();
 		boolean guessingRequired= false;
