@@ -70,14 +70,14 @@ import org.eclipse.jdt.launching.environments.IExecutionEnvironment;
  */
 // @see JDTUIHelperClasses
 public final class JavaModelUtil {
-	
+
 	/**
 	 * The latest available {@link JavaCore}{@code #VERSION_*} level.
 	 * @since 3.7
 	 */
 	public static final String VERSION_LATEST;
 	static {
-		VERSION_LATEST= JavaCore.VERSION_12; // make sure it is not inlined
+		VERSION_LATEST= JavaCore.VERSION_13; // make sure it is not inlined
 	}
 
 	public static final int VALIDATE_EDIT_CHANGED_CONTENT= 10003;
@@ -102,7 +102,7 @@ public final class JavaModelUtil {
 	 * @since 3.8
 	 */
 	public static final String PACKAGE_INFO_JAVA= "package-info.java"; //$NON-NLS-1$
-	
+
 	/**
 	 * The name of the package-info.class file.
 	 * @since 3.9
@@ -137,7 +137,7 @@ public final class JavaModelUtil {
 	 * Finds a type container by container name. The returned element will be of type
 	 * <code>IType</code> or a <code>IPackageFragment</code>. <code>null</code> is returned if the
 	 * type container could not be found.
-	 * 
+	 *
 	 * @param jproject The Java project defining the context to search
 	 * @param typeContainerName A dot separated name of the type container
 	 * @return returns the container
@@ -168,11 +168,10 @@ public final class JavaModelUtil {
 	 * @throws JavaModelException thrown when the cu can not be accessed
 	 */
 	public static IType findTypeInCompilationUnit(ICompilationUnit cu, String typeQualifiedName) throws JavaModelException {
-		IType[] types= cu.getAllTypes();
-		for (int i= 0; i < types.length; i++) {
-			String currName= types[i].getTypeQualifiedName('.');
+		for (IType type : cu.getAllTypes()) {
+			String currName= type.getTypeQualifiedName('.');
 			if (typeQualifiedName.equals(currName)) {
-				return types[i];
+				return type;
 			}
 		}
 		return null;
@@ -217,7 +216,7 @@ public final class JavaModelUtil {
 	 * @return the concatenated name
 	 */
 	public static String concatenateName(String name1, String name2) {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		if (name1 != null && name1.length() > 0) {
 			buf.append(name1);
 		}
@@ -238,7 +237,7 @@ public final class JavaModelUtil {
 	 * @return the concatenated string
 	 */
 	public static String concatenateName(char[] name1, char[] name2) {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		if (name1 != null && name1.length > 0) {
 			buf.append(name1);
 		}
@@ -254,7 +253,7 @@ public final class JavaModelUtil {
 	/**
 	 * Returns whether the two names match. They match if they
 	 * are equal, or if they are the same name but one is missing a dot-separated qualifier.
-	 * 
+	 *
 	 * @param nameA a potentially qualified name
 	 * @param nameB a potentially qualified name
 	 * @return <code>true</code> iff the given names match
@@ -352,10 +351,9 @@ public final class JavaModelUtil {
 	 * @throws JavaModelException thrown when the type can not be accessed
 	 */
 	public static IMethod findMethod(String name, String[] paramTypes, boolean isConstructor, IType type) throws JavaModelException {
-		IMethod[] methods= type.getMethods();
-		for (int i= 0; i < methods.length; i++) {
-			if (isSameMethodSignature(name, paramTypes, isConstructor, methods[i])) {
-				return methods[i];
+		for (IMethod method : type.getMethods()) {
+			if (isSameMethodSignature(name, paramTypes, isConstructor, method)) {
+				return method;
 			}
 		}
 		return null;
@@ -388,9 +386,8 @@ public final class JavaModelUtil {
 			}
 		}
 		if (!isConstructor) {
-			IType[] superInterfaces= hierarchy.getSuperInterfaces(type);
-			for (int i= 0; i < superInterfaces.length; i++) {
-				IMethod res= findMethodInHierarchy(hierarchy, superInterfaces[i], name, paramTypes, false);
+			for (IType superInterface : hierarchy.getSuperInterfaces(type)) {
+				IMethod res= findMethodInHierarchy(hierarchy, superInterface, name, paramTypes, false);
 				if (res != null) {
 					return res;
 				}
@@ -448,9 +445,8 @@ public final class JavaModelUtil {
 	 * @throws JavaModelException thrown when the type can not be accessed
 	 */
 	public static boolean hasMainMethod(IType type) throws JavaModelException {
-		IMethod[] methods= type.getMethods();
-		for (int i= 0; i < methods.length; i++) {
-			if (methods[i].isMainMethod()) {
+		for (IMethod method : type.getMethods()) {
+			if (method.isMainMethod()) {
 				return true;
 			}
 		}
@@ -493,7 +489,7 @@ public final class JavaModelUtil {
 	 *
 	 * @param refTypeSig the type name in signature notation (for example 'QVector') this can also be an array type, but dimensions will be ignored.
 	 * @param declaringType the context for resolving (type where the reference was made in)
-	 * @param enclosingTypeSeparator the enclosing type separator used in the qualified type name 
+	 * @param enclosingTypeSeparator the enclosing type separator used in the qualified type name
 	 * @return returns the fully qualified type name or build-in-type name. if a unresolved type couldn't be resolved null is returned
 	 * @throws JavaModelException thrown when the type can not be accessed
 	 */
@@ -544,7 +540,7 @@ public final class JavaModelUtil {
 
 	/**
 	 * Checks whether the given type signature is from a primitive type.
-	 * 
+	 *
 	 * @param typeSignature the type signature string to check
 	 * @return <code>true</code> if the type is a primitive type, <code> false</code> otherwise
 	 * @throws JavaModelException if this element does not exist or if an exception occurs while
@@ -597,9 +593,7 @@ public final class JavaModelUtil {
 			return true;
 		}
 		if (Flags.isInterface(hierarchy.getCachedFlags(possibleSuperType))) {
-			IType[] superInterfaces= hierarchy.getSuperInterfaces(type);
-			for (int i= 0; i < superInterfaces.length; i++) {
-				IType curr= superInterfaces[i];
+			for (IType curr : hierarchy.getSuperInterfaces(type)) {
 				if (possibleSuperType.equals(curr) || isSuperType(hierarchy, possibleSuperType, curr)) {
 					return true;
 				}
@@ -681,9 +675,7 @@ public final class JavaModelUtil {
 	 * <code>null</code> if the container can not be modified.
 	 */
 	public static IClasspathEntry findEntryInContainer(IClasspathContainer container, IPath libPath) {
-		IClasspathEntry[] entries= container.getClasspathEntries();
-		for (int i= 0; i < entries.length; i++) {
-			IClasspathEntry curr= entries[i];
+		for (IClasspathEntry curr : container.getClasspathEntries()) {
 			IClasspathEntry resolved= JavaCore.getResolvedClasspathEntry(curr);
 			if (resolved != null && libPath.equals(resolved.getPath())) {
 				return curr; // return the real entry
@@ -695,7 +687,7 @@ public final class JavaModelUtil {
 	/**
 	 * Returns the classpath entry of the given package fragment root. This is the raw entry, except
 	 * if the root is a referenced library, in which case it's the resolved entry.
-	 * 
+	 *
 	 * @param root a package fragment root
 	 * @return the corresponding classpath entry
 	 * @throws JavaModelException if accessing the entry failed
@@ -729,8 +721,8 @@ public final class JavaModelUtil {
 	 */
 	public static ICompilationUnit[] getAllCompilationUnits(IJavaElement[] javaElements) throws JavaModelException {
 		HashSet<ICompilationUnit> result= new HashSet<>();
-		for (int i= 0; i < javaElements.length; i++) {
-			addAllCus(result, javaElements[i]);
+		for (IJavaElement javaElement : javaElements) {
+			addAllCus(result, javaElement);
 		}
 		return result.toArray(new ICompilationUnit[result.size()]);
 	}
@@ -739,20 +731,22 @@ public final class JavaModelUtil {
 		switch (javaElement.getElementType()) {
 			case IJavaElement.JAVA_PROJECT:
 				IJavaProject javaProject= (IJavaProject) javaElement;
-				IPackageFragmentRoot[] packageFragmentRoots= javaProject.getPackageFragmentRoots();
-				for (int i= 0; i < packageFragmentRoots.length; i++)
-					addAllCus(collector, packageFragmentRoots[i]);
+				for (IPackageFragmentRoot packageFragmentRoot : javaProject.getPackageFragmentRoots()) {
+					addAllCus(collector, packageFragmentRoot);
+				}
 				return;
 
+
 			case IJavaElement.PACKAGE_FRAGMENT_ROOT:
 				IPackageFragmentRoot packageFragmentRoot= (IPackageFragmentRoot) javaElement;
 				if (packageFragmentRoot.getKind() != IPackageFragmentRoot.K_SOURCE)
 					return;
-				IJavaElement[] packageFragments= packageFragmentRoot.getChildren();
-				for (int j= 0; j < packageFragments.length; j++)
-					addAllCus(collector, packageFragments[j]);
+				for (IJavaElement packageFragment : packageFragmentRoot.getChildren()) {
+					addAllCus(collector, packageFragment);
+				}
 				return;
 
+
 			case IJavaElement.PACKAGE_FRAGMENT:
 				IPackageFragment packageFragment= (IPackageFragment) javaElement;
 				collector.addAll(Arrays.asList(packageFragment.getCompilationUnits()));
@@ -795,11 +789,11 @@ public final class JavaModelUtil {
 	public static boolean is50OrHigher(String compliance) {
 		return !isVersionLessThan(compliance, JavaCore.VERSION_1_5);
 	}
-	
+
 	public static boolean is16OrHigher(String compliance) {
 		return !isVersionLessThan(compliance, JavaCore.VERSION_1_6);
 	}
-	
+
 	public static boolean is17OrHigher(String compliance) {
 		return !isVersionLessThan(compliance, JavaCore.VERSION_1_7);
 	}
@@ -811,7 +805,7 @@ public final class JavaModelUtil {
 	public static boolean is9OrHigher(String compliance) {
 		return !isVersionLessThan(compliance, JavaCore.VERSION_9);
 	}
-	
+
 	public static boolean is10OrHigher(String compliance) {
 		return !isVersionLessThan(compliance, JavaCore.VERSION_10);
 	}
@@ -824,6 +818,10 @@ public final class JavaModelUtil {
 		return !isVersionLessThan(compliance, JavaCore.VERSION_12);
 	}
 
+	public static boolean is13OrHigher(String compliance) {
+		return !isVersionLessThan(compliance, JavaCore.VERSION_13);
+	}
+
 	/**
 	 * Checks if the given project or workspace has source compliance 1.5 or greater.
 	 *
@@ -843,10 +841,10 @@ public final class JavaModelUtil {
 	public static boolean is17OrHigher(IJavaProject project) {
 		return is17OrHigher(getSourceCompliance(project));
 	}
-	
+
 	/**
 	 * Checks if the given project or workspace has source compliance 1.8 or greater.
-	 * 
+	 *
 	 * @param project the project to test or <code>null</code> to test the workspace settings
 	 * @return <code>true</code> if the given project or workspace has source compliance 1.8 or
 	 *         greater.
@@ -857,7 +855,7 @@ public final class JavaModelUtil {
 
 	/**
 	 * Checks if the given project or workspace has source compliance 9 or greater.
-	 * 
+	 *
 	 * @param project the project to test or <code>null</code> to test the workspace settings
 	 * @return <code>true</code> if the given project or workspace has source compliance 9 or
 	 *         greater.
@@ -868,7 +866,7 @@ public final class JavaModelUtil {
 
 	/**
 	 * Checks if the given project or workspace has source compliance 10 or greater.
-	 * 
+	 *
 	 * @param project the project to test or <code>null</code> to test the workspace settings
 	 * @return <code>true</code> if the given project or workspace has source compliance 10 or greater.
 	 */
@@ -878,22 +876,32 @@ public final class JavaModelUtil {
 
 	/**
 	 * Checks if the given project or workspace has source compliance 11 or greater.
-	 * 
+	 *
 	 * @param project the project to test or <code>null</code> to test the workspace settings
 	 * @return <code>true</code> if the given project or workspace has source compliance 11 or greater.
 	 */
 	public static boolean is11OrHigher(IJavaProject project) {
 		return is11OrHigher(getSourceCompliance(project));
 	}
-	
+
 	public static boolean is12OrHigher(IJavaProject project) {
 		return is12OrHigher(getSourceCompliance(project));
 	}
 
+	/**
+	 * Checks if the given project or workspace has source compliance 13 or greater.
+	 *
+	 * @param project the project to test or <code>null</code> to test the workspace settings
+	 * @return <code>true</code> if the given project or workspace has source compliance 13 or greater.
+	 */
+	public static boolean is13OrHigher(IJavaProject project) {
+		return is13OrHigher(getSourceCompliance(project));
+	}
+
 	private static String getSourceCompliance(IJavaProject project) {
 		return project != null ? project.getOption(JavaCore.COMPILER_SOURCE, true) : JavaCore.getOption(JavaCore.COMPILER_SOURCE);
 	}
-	
+
 	/**
 	 * Checks if the JRE of the given project or workspace default JRE have source compliance 1.5 or
 	 * greater.
@@ -923,6 +931,8 @@ public final class JavaModelUtil {
 		String version= vMInstall.getJavaVersion();
 		if (version == null) {
 			return defaultCompliance;
+		} else if (version.startsWith(JavaCore.VERSION_13)) {
+			return JavaCore.VERSION_13;
 		} else if (version.startsWith(JavaCore.VERSION_12)) {
 			return JavaCore.VERSION_12;
 		} else if (version.startsWith(JavaCore.VERSION_11)) {
@@ -958,10 +968,12 @@ public final class JavaModelUtil {
 			if (compliance instanceof String)
 				return (String)compliance;
 		}
-		
+
 		// fallback:
 		String desc= executionEnvironment.getId();
-		if (desc.indexOf(JavaCore.VERSION_12) != -1) {
+		if (desc.indexOf(JavaCore.VERSION_13) != -1) {
+			return JavaCore.VERSION_13;
+		} else if (desc.indexOf(JavaCore.VERSION_12) != -1) {
 			return JavaCore.VERSION_12;
 		} else if (desc.indexOf(JavaCore.VERSION_11) != -1) {
 			return JavaCore.VERSION_11;
@@ -1046,7 +1058,7 @@ public final class JavaModelUtil {
 
 	/**
 	 * Tells whether the given type root represents a module.
-	 * 
+	 *
 	 * @param typeRoot the type root to test
 	 * @return <code>true</code> if the given type root is a module-info.java CU or a module-info.class class file.
 	 * @since 3.14
@@ -1058,7 +1070,7 @@ public final class JavaModelUtil {
 
 	/**
 	 * Tells whether the given Java element represents a module.
-	 * 
+	 *
 	 * @param javaElement the Java element to test
 	 * @return <code>true</code> if the given Java element represents a module.
 	 * @since 3.14
@@ -1072,7 +1084,7 @@ public final class JavaModelUtil {
 	 * Tells whether the given package fragment contains any ordinary compilation unit,
 	 * not counting the modular compilation unit module-info.java nor its class file module-info.class.
 	 * @param fragment a package fragment to test
-	 * @return true iff at least one ordinary compilation unit (or class file) was found. 
+	 * @return true iff at least one ordinary compilation unit (or class file) was found.
 	 * @throws JavaModelException if the package fragment does not exist or if an
 	 *      exception occurs while accessing its corresponding resource
 	 * @since 3.14
@@ -1091,7 +1103,7 @@ public final class JavaModelUtil {
 
 	/**
 	 * Applies a text edit to a compilation unit.
-	 * 
+	 *
 	 * @param cu the compilation unit to apply the edit to
 	 * @param edit the edit to apply
 	 * @param save is set, save the CU after the edit has been applied
