@@ -65,6 +65,7 @@ import org.eclipse.jdt.internal.junit.JUnitPreferencesConstants;
 import org.eclipse.jdt.internal.junit.Messages;
 import org.eclipse.jdt.internal.junit.launcher.JUnitLaunchConfigurationConstants;
 import org.eclipse.jdt.internal.junit.model.TestElement.Status;
+import org.eclipse.jdt.junit.ITestRunListener;
 
 /**
  * Central registry for JUnit test runs.
@@ -136,7 +137,7 @@ public final class JUnitModel {
 		private void connectTestRunner(ILaunch launch, IJavaProject javaProject, int port) {
 			TestRunSession testRunSession= new TestRunSession(launch, javaProject, port);
 			addTestRunSession(testRunSession);
-			
+
 			for (TestRunListener listener : JUnitCorePlugin.getDefault().getNewTestRunListeners()) {
 				listener.sessionLaunched(testRunSession);
 			}
@@ -167,31 +168,31 @@ public final class JUnitModel {
 				@Override
 				public void sessionStarted() {
 					org.eclipse.jdt.junit.ITestRunListener[] testRunListeners= JUnitCorePlugin.getDefault().getTestRunListeners();
-					for (int i= 0; i < testRunListeners.length; i++) {
-						testRunListeners[i].testRunStarted(fActiveTestRunSession.getTotalCount());
+					for (ITestRunListener testRunListener : testRunListeners) {
+						testRunListener.testRunStarted(fActiveTestRunSession.getTotalCount());
 					}
 				}
 				@Override
 				public void sessionTerminated() {
 					org.eclipse.jdt.junit.ITestRunListener[] testRunListeners= JUnitCorePlugin.getDefault().getTestRunListeners();
-					for (int i= 0; i < testRunListeners.length; i++) {
-						testRunListeners[i].testRunTerminated();
+					for (ITestRunListener testRunListener : testRunListeners) {
+						testRunListener.testRunTerminated();
 					}
 					sessionRemoved(fActiveTestRunSession);
 				}
 				@Override
 				public void sessionStopped(long elapsedTime) {
 					org.eclipse.jdt.junit.ITestRunListener[] testRunListeners= JUnitCorePlugin.getDefault().getTestRunListeners();
-					for (int i= 0; i < testRunListeners.length; i++) {
-						testRunListeners[i].testRunStopped(elapsedTime);
+					for (ITestRunListener testRunListener : testRunListeners) {
+						testRunListener.testRunStopped(elapsedTime);
 					}
 					sessionRemoved(fActiveTestRunSession);
 				}
 				@Override
 				public void sessionEnded(long elapsedTime) {
 					org.eclipse.jdt.junit.ITestRunListener[] testRunListeners= JUnitCorePlugin.getDefault().getTestRunListeners();
-					for (int i= 0; i < testRunListeners.length; i++) {
-						testRunListeners[i].testRunEnded(elapsedTime);
+					for (ITestRunListener testRunListener : testRunListeners) {
+						testRunListener.testRunEnded(elapsedTime);
 					}
 					sessionRemoved(fActiveTestRunSession);
 				}
@@ -202,32 +203,32 @@ public final class JUnitModel {
 				@Override
 				public void testStarted(TestCaseElement testCaseElement) {
 					org.eclipse.jdt.junit.ITestRunListener[] testRunListeners= JUnitCorePlugin.getDefault().getTestRunListeners();
-					for (int i= 0; i < testRunListeners.length; i++) {
-						testRunListeners[i].testStarted(testCaseElement.getId(), testCaseElement.getTestName());
+					for (ITestRunListener testRunListener : testRunListeners) {
+						testRunListener.testStarted(testCaseElement.getId(), testCaseElement.getTestName());
 					}
 				}
 
 				@Override
 				public void testFailed(TestElement testElement, Status status, String trace, String expected, String actual) {
 					org.eclipse.jdt.junit.ITestRunListener[] testRunListeners= JUnitCorePlugin.getDefault().getTestRunListeners();
-					for (int i= 0; i < testRunListeners.length; i++) {
-						testRunListeners[i].testFailed(status.getOldCode(), testElement.getId(), testElement.getTestName(), trace);
+					for (ITestRunListener testRunListener : testRunListeners) {
+						testRunListener.testFailed(status.getOldCode(), testElement.getId(), testElement.getTestName(), trace);
 					}
 				}
 
 				@Override
 				public void testEnded(TestCaseElement testCaseElement) {
 					org.eclipse.jdt.junit.ITestRunListener[] testRunListeners= JUnitCorePlugin.getDefault().getTestRunListeners();
-					for (int i= 0; i < testRunListeners.length; i++) {
-						testRunListeners[i].testEnded(testCaseElement.getId(), testCaseElement.getTestName());
+					for (ITestRunListener testRunListener : testRunListeners) {
+						testRunListener.testEnded(testCaseElement.getId(), testCaseElement.getTestName());
 					}
 				}
 
 				@Override
 				public void testReran(TestCaseElement testCaseElement, Status status, String trace, String expectedResult, String actualResult) {
 					org.eclipse.jdt.junit.ITestRunListener[] testRunListeners= JUnitCorePlugin.getDefault().getTestRunListeners();
-					for (int i= 0; i < testRunListeners.length; i++) {
-						testRunListeners[i].testReran(testCaseElement.getId(), testCaseElement.getClassName(), testCaseElement.getTestMethodName(), status.getOldCode(), trace);
+					for (ITestRunListener testRunListener : testRunListeners) {
+						testRunListener.testReran(testCaseElement.getId(), testCaseElement.getClassName(), testCaseElement.getTestMethodName(), status.getOldCode(), trace);
 					}
 				}
 
@@ -304,8 +305,8 @@ public final class JUnitModel {
 		File historyDirectory= JUnitCorePlugin.getHistoryDirectory();
 		File[] swapFiles= historyDirectory.listFiles();
 		if (swapFiles != null) {
-			for (int i= 0; i < swapFiles.length; i++) {
-				swapFiles[i].delete();
+			for (File swapFile : swapFiles) {
+				swapFile.delete();
 			}
 		}
 
@@ -350,11 +351,11 @@ public final class JUnitModel {
 	public void addTestRunSession(TestRunSession testRunSession) {
 		Assert.isNotNull(testRunSession);
 		ArrayList<TestRunSession> toRemove= new ArrayList<>();
-		
+
 		synchronized (this) {
 			Assert.isLegal(! fTestRunSessions.contains(testRunSession));
 			fTestRunSessions.addFirst(testRunSession);
-			
+
 			int maxCount = Platform.getPreferencesService().getInt(JUnitCorePlugin.CORE_PLUGIN_ID, JUnitPreferencesConstants.MAX_TEST_RUNS, 10, null);
 			int size= fTestRunSessions.size();
 			if (size > maxCount) {
@@ -368,7 +369,7 @@ public final class JUnitModel {
 				}
 			}
 		}
-		
+
 		for (int i= 0; i < toRemove.size(); i++) {
 			TestRunSession oldSession= toRemove.get(i);
 			notifyTestRunSessionRemoved(oldSession);
@@ -420,10 +421,10 @@ public final class JUnitModel {
 		monitor.beginTask(ModelMessages.JUnitModel_importing_from_url, IProgressMonitor.UNKNOWN);
 		final String trimmedUrl= url.trim().replaceAll("\r\n?|\n", ""); //$NON-NLS-1$ //$NON-NLS-2$
 		final TestRunHandler handler= new TestRunHandler(monitor);
-		
+
 		final CoreException[] exception= { null };
 		final TestRunSession[] session= { null };
-		
+
 		Thread importThread= new Thread("JUnit URL importer") { //$NON-NLS-1$
 			@Override
 			public void run() {
@@ -452,7 +453,7 @@ public final class JUnitModel {
 			}
 		};
 		importThread.start();
-		
+
 		while (session[0] == null && exception[0] == null && !monitor.isCanceled()) {
 			try {
 				Thread.sleep(100);
@@ -468,7 +469,7 @@ public final class JUnitModel {
 				throw new InterruptedException();
 			}
 		}
-		
+
 		JUnitCorePlugin.getModel().addTestRunSession(session[0]);
 		monitor.done();
 		return session[0];
