@@ -972,15 +972,21 @@ public class TestRunnerViewPart extends ViewPart {
 
 		public ToggleOrientationAction(int orientation) {
 			super("", AS_RADIO_BUTTON); //$NON-NLS-1$
-			if (orientation == TestRunnerViewPart.VIEW_ORIENTATION_HORIZONTAL) {
+			switch (orientation) {
+			case TestRunnerViewPart.VIEW_ORIENTATION_HORIZONTAL:
 				setText(JUnitMessages.TestRunnerViewPart_toggle_horizontal_label);
 				setImageDescriptor(JUnitPlugin.getImageDescriptor("elcl16/th_horizontal.png")); //$NON-NLS-1$
-			} else if (orientation == TestRunnerViewPart.VIEW_ORIENTATION_VERTICAL) {
+				break;
+			case TestRunnerViewPart.VIEW_ORIENTATION_VERTICAL:
 				setText(JUnitMessages.TestRunnerViewPart_toggle_vertical_label);
 				setImageDescriptor(JUnitPlugin.getImageDescriptor("elcl16/th_vertical.png")); //$NON-NLS-1$
-			} else if (orientation == TestRunnerViewPart.VIEW_ORIENTATION_AUTOMATIC) {
+				break;
+			case TestRunnerViewPart.VIEW_ORIENTATION_AUTOMATIC:
 				setText(JUnitMessages.TestRunnerViewPart_toggle_automatic_label);
 				setImageDescriptor(JUnitPlugin.getImageDescriptor("elcl16/th_automatic.png")); //$NON-NLS-1$
+				break;
+			default:
+				break;
 			}
 			fActionOrientation= orientation;
 			PlatformUI.getWorkbench().getHelpSystem().setHelp(this, IJUnitHelpContextIds.RESULTS_VIEW_TOGGLE_ORIENTATION_ACTION);
@@ -1045,9 +1051,10 @@ public class TestRunnerViewPart extends ViewPart {
 			if (affectedChildren == null)
 				return true;
 
-			for (int i= 0; i < affectedChildren.length; i++) {
-				if (!processDelta(affectedChildren[i]))
+			for (IJavaElementDelta affectedChild : affectedChildren) {
+				if (!processDelta(affectedChild)) {
 					return false;
+				}
 			}
 			return true;
 		}
@@ -2206,12 +2213,7 @@ action enablement
 	}
 
 	private void postSyncProcessChanges() {
-		postSyncRunnable(new Runnable() {
-			@Override
-			public void run() {
-				processChangesInUI();
-			}
-		});
+		postSyncRunnable(this::processChangesInUI);
 	}
 
 	public void warnOfContentChange() {
