@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -19,9 +19,12 @@ import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.FileReader;
 import java.io.IOException;
+import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.Hashtable;
 import java.util.List;
+import java.util.concurrent.atomic.AtomicReference;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.NullTestUtils;
@@ -29,12 +32,14 @@ import org.eclipse.jdt.testplugin.TestOptions;
 import org.eclipse.test.OrderedTestSuite;
 
 import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.NullProgressMonitor;
 
 import org.eclipse.jface.preference.IPreferenceStore;
 
 import org.eclipse.jface.text.Document;
 import org.eclipse.jface.text.IDocument;
+import org.eclipse.jface.text.contentassist.ContentAssistant;
 import org.eclipse.jface.text.contentassist.ICompletionProposal;
 import org.eclipse.jface.text.source.ISourceViewer;
 import org.eclipse.jface.text.templates.Template;
@@ -68,6 +73,7 @@ import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 
 import org.eclipse.jdt.ui.JavaUI;
 import org.eclipse.jdt.ui.PreferenceConstants;
+import org.eclipse.jdt.ui.text.IJavaPartitions;
 import org.eclipse.jdt.ui.text.java.CompletionProposalCollector;
 import org.eclipse.jdt.ui.text.java.CompletionProposalComparator;
 import org.eclipse.jdt.ui.text.java.IJavaCompletionProposal;
@@ -77,8 +83,10 @@ import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.javaeditor.JavaEditor;
 import org.eclipse.jdt.internal.ui.text.java.AbstractJavaCompletionProposal;
 import org.eclipse.jdt.internal.ui.text.java.FillArgumentNamesCompletionProposalCollector;
+import org.eclipse.jdt.internal.ui.text.java.JavaCompletionProcessor;
 import org.eclipse.jdt.internal.ui.text.java.JavaCompletionProposalComputer;
 import org.eclipse.jdt.internal.ui.text.java.JavaNoTypeCompletionProposalComputer;
+import org.eclipse.jdt.internal.ui.text.java.JavaTypeCompletionProposalComputer;
 
 import junit.extensions.TestSetup;
 import junit.framework.Test;
@@ -131,20 +139,20 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 		System.out.print("file contents: |");
 		File file= cu.getResource().getLocation().toFile();
 		try {
-			BufferedReader reader= new BufferedReader(new FileReader(file));
-			String line;
-			while ((line= reader.readLine()) != null) {
-				System.out.println(line);
+			try (BufferedReader reader= new BufferedReader(new FileReader(file))) {
+				String line;
+				while ((line= reader.readLine()) != null) {
+					System.out.println(line);
+				}
+				System.out.println("|");
 			}
-			System.out.println("|");
-			reader.close();
 		} catch (FileNotFoundException e1) {
 			e1.printStackTrace();
 		} catch (IOException e1) {
 			e1.printStackTrace();
 		}
 		System.out.println();
-		
+
 		IJavaProject project= cu.getJavaProject();
 		System.out.println(project);
 		for (IPackageFragmentRoot root : project.getAllPackageFragmentRoots()) {
@@ -176,6 +184,7 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 		store.setValue(PreferenceConstants.CODEGEN_ADD_COMMENTS, true);
 		store.setValue(PreferenceConstants.CODEASSIST_GUESS_METHOD_ARGUMENTS, false);
 		store.setValue(PreferenceConstants.CODEASSIST_SHOW_VISIBLE_PROPOSALS, false);
+		store.setValue(PreferenceConstants.CODEASSIST_INSERT_COMPLETION, true);
 
 		StubUtility.setCodeTemplate(CodeTemplateContextType.OVERRIDECOMMENT_ID, "/* (non-Javadoc)\n * ${see_to_overridden}\n */", null);
 		StubUtility.setCodeTemplate(CodeTemplateContextType.DELEGATECOMMENT_ID, "/* (non-Javadoc)\n * ${see_to_target}\n */", null);
@@ -200,18 +209,17 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 	public static void closeEditor(IEditorPart editor) {
 		IWorkbenchPartSite site;
 		IWorkbenchPage page;
-		if (editor != null && (site= editor.getSite()) != null && (page= site.getPage()) != null)
+		if (editor != null && (site= editor.getSite()) != null && (page= site.getPage()) != null) {
 			page.closeEditor(editor, false);
+		}
 	}
 
 	public static void closeAllEditors() {
-		IWorkbenchWindow[] windows= PlatformUI.getWorkbench().getWorkbenchWindows();
-		for (int i= 0; i < windows.length; i++) {
-			IWorkbenchPage[] pages= windows[i].getPages();
-			for (int j= 0; j < pages.length; j++) {
-				IEditorReference[] editorReferences= pages[j].getEditorReferences();
-				for (int k= 0; k < editorReferences.length; k++)
-					closeEditor(editorReferences[k].getEditor(false));
+		for (IWorkbenchWindow window : PlatformUI.getWorkbench().getWorkbenchWindows()) {
+			for (IWorkbenchPage page : window.getPages()) {
+				for (IEditorReference editorReference : page.getEditorReferences()) {
+					closeEditor(editorReference.getEditor(false));
+				}
 			}
 		}
 	}
@@ -526,7 +534,7 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 				"");
 		assertEquals(buf.toString(), doc.get());
 	}
-	
+
 	// same CU
 	// @NonNullByDefault on class
 	// -> don't insert redundant @NonNull
@@ -587,7 +595,7 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 		NullTestUtils.prepareNullDeclarationAnnotations(sourceFolder);
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("test1", false, null);
-		
+
 		String ifcContents=
 				"package test1;\n" +
 				"import annots.*;\n" +
@@ -648,7 +656,7 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 		NullTestUtils.prepareNullDeclarationAnnotations(sourceFolder);
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("test1", false, null);
-		
+
 		String ifcContents=
 				"package test1;\n" +
 				"import annots.*;\n" +
@@ -705,7 +713,7 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 		NullTestUtils.prepareNullDeclarationAnnotations(sourceFolder);
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("test1", false, null);
-		
+
 		String ifcContents=
 				"package test1;\n" +
 				"import annots.*;\n" +
@@ -985,13 +993,11 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 			codeComplete(cu, offset, collector);
 
-			IJavaCompletionProposal[] proposals= collector.getJavaCompletionProposals();
-
 			IJavaCompletionProposal proposal= null;
 
-			for (int i= 0; i < proposals.length; i++) {
-				if (proposals[i].getDisplayString().startsWith("MyClass")) {
-					proposal= proposals[i];
+			for (IJavaCompletionProposal p : collector.getJavaCompletionProposals()) {
+				if (p.getDisplayString().startsWith("MyClass")) {
+					proposal= p;
 				}
 			}
 			assertNotNull("no proposal for MyClass()", proposal);
@@ -1050,12 +1056,10 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 		codeComplete(cu, offset, collector);
 
-		IJavaCompletionProposal[] proposals= collector.getJavaCompletionProposals();
-
 		IJavaCompletionProposal proposal= null;
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("Natural")) {
-				proposal= proposals[i];
+		for (IJavaCompletionProposal p : collector.getJavaCompletionProposals()) {
+			if (p.getDisplayString().startsWith("Natural")) {
+				proposal= p;
 			}
 		}
 		assertNotNull("no proposal for enum Natural()", proposal);
@@ -1121,13 +1125,11 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 			codeComplete(cu, offset, collector);
 
-			IJavaCompletionProposal[] proposals= collector.getJavaCompletionProposals();
-
 			IJavaCompletionProposal proposal= null;
 
-			for (int i= 0; i < proposals.length; i++) {
-				if (proposals[i].getDisplayString().startsWith("getWriter")) {
-					proposal= proposals[i];
+			for (IJavaCompletionProposal p : collector.getJavaCompletionProposals()) {
+				if (p.getDisplayString().startsWith("getWriter")) {
+					proposal= p;
 				}
 			}
 			assertNotNull("no proposal for getWriter()", proposal);
@@ -1183,12 +1185,11 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 			codeComplete(cu, offset, collector);
 
-			IJavaCompletionProposal[] proposals= collector.getJavaCompletionProposals();
 			IJavaCompletionProposal proposal= null;
 
-			for (int i= 0; i < proposals.length; i++) {
-				if (proposals[i].getDisplayString().startsWith("foo")) {
-					proposal= proposals[i];
+			for (IJavaCompletionProposal p : collector.getJavaCompletionProposals()) {
+				if (p.getDisplayString().startsWith("foo")) {
+					proposal= p;
 				}
 			}
 			assertNotNull("no proposal for foo()", proposal);
@@ -1389,12 +1390,11 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 		codeComplete(cu, offset, collector);
 
-		IJavaCompletionProposal[] proposals= collector.getJavaCompletionProposals();
 		IJavaCompletionProposal proposal= null;
 
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("foo")) {
-				proposal= proposals[i];
+		for (IJavaCompletionProposal p : collector.getJavaCompletionProposals()) {
+			if (p.getDisplayString().startsWith("foo")) {
+				proposal= p;
 			}
 		}
 		assertNotNull("no proposal for foomethod()", proposal);
@@ -1445,9 +1445,9 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 		IJavaCompletionProposal toStringProposal= null;
 
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("toString()")) {
-				toStringProposal= proposals[i];
+		for (IJavaCompletionProposal proposal : proposals) {
+			if (proposal.getDisplayString().startsWith("toString()")) {
+				toStringProposal= proposal;
 			}
 		}
 		assertNotNull("no proposal for toString()", toStringProposal);
@@ -1506,9 +1506,9 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 		IJavaCompletionProposal closeProposal= null;
 
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("close()")) {
-				closeProposal= proposals[i];
+		for (IJavaCompletionProposal proposal : proposals) {
+			if (proposal.getDisplayString().startsWith("close()")) {
+				closeProposal= proposal;
 			}
 		}
 		assertNotNull("no proposal for close()", closeProposal);
@@ -1568,9 +1568,9 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 		IJavaCompletionProposal closeProposal= null;
 
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("close()")) {
-				closeProposal= proposals[i];
+		for (IJavaCompletionProposal proposal : proposals) {
+			if (proposal.getDisplayString().startsWith("close()")) {
+				closeProposal= proposal;
 			}
 		}
 		assertNotNull("no proposal for close()", closeProposal);
@@ -1643,9 +1643,9 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 		IJavaCompletionProposal closeProposal= null;
 
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("foo()")) {
-				closeProposal= proposals[i];
+		for (IJavaCompletionProposal proposal : proposals) {
+			if (proposal.getDisplayString().startsWith("foo()")) {
+				closeProposal= proposal;
 			}
 		}
 		assertNotNull("no proposal for foo()", closeProposal);
@@ -1704,9 +1704,9 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 		IJavaCompletionProposal toStringProposal= null;
 
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("run()")) {
-				toStringProposal= proposals[i];
+		for (IJavaCompletionProposal proposal : proposals) {
+			if (proposal.getDisplayString().startsWith("run()")) {
+				toStringProposal= proposal;
 			}
 		}
 		assertNotNull("no proposal for toString()", toStringProposal);
@@ -1770,9 +1770,9 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 		IJavaCompletionProposal closeProposal= null;
 
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("foo(")) {
-				closeProposal= proposals[i];
+		for (IJavaCompletionProposal proposal : proposals) {
+			if (proposal.getDisplayString().startsWith("foo(")) {
+				closeProposal= proposal;
 			}
 		}
 		assertNotNull("no proposal for foo(Sub)", closeProposal);
@@ -1830,9 +1830,9 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 		IJavaCompletionProposal toStringProposal= null;
 
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("foo")) {
-				toStringProposal= proposals[i];
+		for (IJavaCompletionProposal proposal : proposals) {
+			if (proposal.getDisplayString().startsWith("foo")) {
+				toStringProposal= proposal;
 			}
 		}
 		assertNotNull("no proposal for foo(...)", toStringProposal);
@@ -1896,9 +1896,9 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 		IJavaCompletionProposal toStringProposal= null;
 
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("foo")) {
-				toStringProposal= proposals[i];
+		for (IJavaCompletionProposal proposal : proposals) {
+			if (proposal.getDisplayString().startsWith("foo")) {
+				toStringProposal= proposal;
 			}
 		}
 		assertNotNull("no proposal for foo(...)", toStringProposal);
@@ -1964,9 +1964,9 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 		IJavaCompletionProposal toStringProposal= null;
 
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("foo")) {
-				toStringProposal= proposals[i];
+		for (IJavaCompletionProposal proposal : proposals) {
+			if (proposal.getDisplayString().startsWith("foo")) {
+				toStringProposal= proposal;
 			}
 		}
 		assertNotNull("no proposal for foo(...)", toStringProposal);
@@ -2001,7 +2001,7 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 	public void testOverrideCompletion10_bug377184() throws Exception {
 		//https://bugs.eclipse.org/bugs/show_bug.cgi?id=377184
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-	
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test1;\n");
@@ -2013,32 +2013,29 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 		buf.append("    foo//here\n");
 		buf.append("}\n");
 		String contents= buf.toString();
-	
+
 		ICompilationUnit cu= pack1.createCompilationUnit("Impl.java", contents, false, null);
-	
+
 		String str= "//here";
-	
+
 		int offset= contents.indexOf(str);
-	
+
 		CompletionProposalCollector collector= createCollector(cu, offset);
 		collector.setReplacementLength(0);
-	
+
 		codeComplete(cu, offset, collector);
-	
-		IJavaCompletionProposal[] proposals= collector.getJavaCompletionProposals();
-	
+
 		IJavaCompletionProposal toStringProposal= null;
-	
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("foo")) {
-				toStringProposal= proposals[i];
+		for (IJavaCompletionProposal proposal : collector.getJavaCompletionProposals()) {
+			if (proposal.getDisplayString().startsWith("foo")) {
+				toStringProposal= proposal;
 			}
 		}
 		assertNotNull("no proposal for foo(...)", toStringProposal);
-	
+
 		IDocument doc= new Document(contents);
 		toStringProposal.apply(doc);
-	
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("class Super<T> {\n");
@@ -2061,7 +2058,7 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 	public void testOverrideCompletionArrayOfTypeVariable() throws Exception {
 		//https://bugs.eclipse.org/bugs/show_bug.cgi?id=391265
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-	
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test1;\n");
@@ -2073,32 +2070,29 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 		buf.append("    foo//here\n");
 		buf.append("}\n");
 		String contents= buf.toString();
-	
+
 		ICompilationUnit cu= pack1.createCompilationUnit("Impl.java", contents, false, null);
-	
+
 		String str= "//here";
-	
+
 		int offset= contents.indexOf(str);
-	
+
 		CompletionProposalCollector collector= createCollector(cu, offset);
 		collector.setReplacementLength(0);
-	
+
 		codeComplete(cu, offset, collector);
-	
-		IJavaCompletionProposal[] proposals= collector.getJavaCompletionProposals();
-	
+
 		IJavaCompletionProposal toStringProposal= null;
-	
-		for (int i= 0; i < proposals.length; i++) {
-			if (proposals[i].getDisplayString().startsWith("foo")) {
-				toStringProposal= proposals[i];
+		for (IJavaCompletionProposal proposal : collector.getJavaCompletionProposals()) {
+			if (proposal.getDisplayString().startsWith("foo")) {
+				toStringProposal= proposal;
 			}
 		}
 		assertNotNull("no proposal for foo(...)", toStringProposal);
-	
+
 		IDocument doc= new Document(contents);
 		toStringProposal.apply(doc);
-	
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("class Super {\n");
@@ -2146,13 +2140,11 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 
 			codeComplete(cu, offset, collector);
 
-			IJavaCompletionProposal[] proposals= collector.getJavaCompletionProposals();
-
 			IJavaCompletionProposal proposal= null;
 
-			for (int i= 0; i < proposals.length; i++) {
-				if (proposals[i].getDisplayString().startsWith("setWriter")) {
-					proposal= proposals[i];
+			for (IJavaCompletionProposal p : collector.getJavaCompletionProposals()) {
+				if (p.getDisplayString().startsWith("setWriter")) {
+					proposal= p;
 				}
 			}
 			assertNotNull("no proposal for setWriter()", proposal);
@@ -2335,6 +2327,127 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 		}
 	}
 
+	/*
+	 * Ensure no extra ';' is inserted
+	 */
+	public void testImport() throws Exception {
+		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
+
+		IPackageFragment pack1= sourceFolder.createPackageFragment("test1", false, null);
+		StringBuffer buf= new StringBuffer();
+		buf.append("package test1;\n");
+		buf.append("import java.util.ArrayL; // here\n");
+		buf.append("public class A {\n");
+		buf.append("}\n");
+		String contents= buf.toString();
+		ICompilationUnit cu= pack1.createCompilationUnit("A.java", contents, false, null);
+
+		String str= "; // here";
+		int offset= contents.indexOf(str);
+
+		IEditorPart part= JavaUI.openInEditor(cu);
+		ISourceViewer viewer= ((JavaEditor) part).getViewer();
+		JavaContentAssistInvocationContext context= new JavaContentAssistInvocationContext(viewer, offset, part);
+		JavaCompletionProposalComputer computer= new JavaTypeCompletionProposalComputer();
+
+		// make sure we get an import rewrite context
+		SharedASTProviderCore.getAST(cu, SharedASTProviderCore.WAIT_YES, null);
+
+		List<ICompletionProposal> proposals= computer.computeCompletionProposals(context, null);
+		assertEquals("Expecting 1 proposal", 1, proposals.size());
+
+		IDocument doc= JavaUI.getDocumentProvider().getDocument(part.getEditorInput());
+		proposals.get(0).apply(doc);
+
+		buf= new StringBuffer();
+		buf.append("package test1;\n");
+		buf.append("import java.util.ArrayList; // here\n");
+		buf.append("public class A {\n");
+		buf.append("}\n");
+		assertEquals(buf.toString(), doc.get());
+	}
+
+	/*
+	 * Ensure no extra ';' is inserted, whereas a selected text part is correctly replaced
+	 */
+	public void testImportReplacingSelection() throws Exception {
+		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
+
+		IPackageFragment pack1= sourceFolder.createPackageFragment("test1", false, null);
+		StringBuffer buf= new StringBuffer();
+		buf.append("package test1;\n");
+		buf.append("import java.util.ArrayLWrong;\n");
+		buf.append("public class A {\n");
+		buf.append("}\n");
+		String contents= buf.toString();
+		ICompilationUnit cu= pack1.createCompilationUnit("A.java", contents, false, null);
+
+		IEditorPart part= JavaUI.openInEditor(cu);
+		String str= "Wrong";
+
+		int offset= contents.indexOf(str);
+
+		CompletionProposalCollector collector= createCollector(cu, offset);
+		collector.setAllowsRequiredProposals(CompletionProposal.CONSTRUCTOR_INVOCATION, CompletionProposal.TYPE_REF, true);
+		collector.setReplacementLength("Wrong".length());
+
+		codeComplete(cu, offset, collector);
+		IJavaCompletionProposal[] proposals= collector.getJavaCompletionProposals();
+
+		assertEquals("expect 1 proposal", 1, proposals.length);
+
+		IDocument doc= JavaUI.getDocumentProvider().getDocument(part.getEditorInput());
+		proposals[0].apply(doc);
+
+		buf= new StringBuffer();
+		buf.append("package test1;\n");
+		buf.append("import java.util.ArrayList;\n");
+		buf.append("public class A {\n");
+		buf.append("}\n");
+		assertEquals(buf.toString(), doc.get());
+	}
+
+	/*
+	 * Ensure no extra ';' is inserted, whereas remain text is replaced as per the preference option
+	 */
+	public void testImportReplacing() throws Exception {
+		getJDTUIPrefs().setValue(PreferenceConstants.CODEASSIST_INSERT_COMPLETION, false);
+
+		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
+
+		IPackageFragment pack1= sourceFolder.createPackageFragment("test1", false, null);
+		StringBuffer buf= new StringBuffer();
+		buf.append("package test1;\n");
+		buf.append("import java.util.ArrayLWrong;\n");
+		buf.append("public class A {\n");
+		buf.append("}\n");
+		String contents= buf.toString();
+		ICompilationUnit cu= pack1.createCompilationUnit("A.java", contents, false, null);
+
+		IEditorPart part= JavaUI.openInEditor(cu);
+		String str= "Wrong";
+
+		int offset= contents.indexOf(str);
+
+		CompletionProposalCollector collector= createCollector(cu, offset);
+		collector.setAllowsRequiredProposals(CompletionProposal.CONSTRUCTOR_INVOCATION, CompletionProposal.TYPE_REF, true);
+
+		codeComplete(cu, offset, collector);
+		IJavaCompletionProposal[] proposals= collector.getJavaCompletionProposals();
+
+		assertEquals("expect 1 proposal", 1, proposals.length);
+
+		IDocument doc= JavaUI.getDocumentProvider().getDocument(part.getEditorInput());
+		proposals[0].apply(doc);
+
+		buf= new StringBuffer();
+		buf.append("package test1;\n");
+		buf.append("import java.util.ArrayList;\n");
+		buf.append("public class A {\n");
+		buf.append("}\n");
+		assertEquals(buf.toString(), doc.get());
+	}
+
 	public void testConstructorCompletion_Bug336451() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
@@ -2422,7 +2535,7 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 	public void testBug466252() throws CoreException {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 		IPackageFragment pack1= sourceFolder.createPackageFragment("p", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("public class C {\n");
@@ -2465,7 +2578,7 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 			buf.append("\n");
 			buf.append("public enum DefaultLocation { PARAMETER, RETURN_TYPE, FIELD, TYPE_BOUND, TYPE_ARGUMENT, ARRAY_CONTENTS, TYPE_PARAMETER }\n");
 			pack0.createCompilationUnit("DefaultLocation.java", buf.toString(), false, null);
-		
+
 			buf= new StringBuilder();
 			buf.append("package annots;\n");
 			buf.append("\n");
@@ -2528,4 +2641,37 @@ public class CodeCompletionTest extends AbstractCompletionTest {
 		assertTrue("Wrong number of " + name + ", is: " + is + ", expected: " + expected, is == expected);
 	}
 
+	@org.junit.Test
+	public void testComputeCompletionInNonUIThread() throws Exception {
+		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
+		IPackageFragment pack1= sourceFolder.createPackageFragment("test1", false, null);
+		ICompilationUnit cu= pack1.createCompilationUnit("Blah.java", "", true, new NullProgressMonitor());
+		JavaEditor part= (JavaEditor) JavaUI.openInEditor(cu);
+		ContentAssistant assistant= new ContentAssistant();
+		assistant.setDocumentPartitioning(IJavaPartitions.JAVA_PARTITIONING);
+		JavaCompletionProcessor javaProcessor= new JavaCompletionProcessor(part, assistant, getContentType());
+		AtomicReference<Throwable> exception = new AtomicReference<>();
+		List<IStatus> errors = new ArrayList<>();
+		JavaPlugin.getDefault().getLog().addLogListener((status, plugin) -> {
+			if (status.getSeverity() >= IStatus.WARNING) {
+				errors.add(status);
+			}
+		});
+		Thread thread = new Thread(() -> {
+			try {
+				javaProcessor.computeCompletionProposals(part.getViewer(), 0);
+				// a popup can be shown and block the thread in case of error
+			} catch (Exception e) {
+				exception.set(e);
+			}
+		});
+		thread.start();
+		thread.join();
+		if (exception.get() != null) {
+			exception.get().printStackTrace();
+		}
+		assertNull(exception.get());
+		assertEquals(Collections.emptyList(), errors);
+	}
+
 }
