@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -106,10 +106,10 @@ public class InlineMethodTests extends AbstractSelectionTestCase {
 	}
 
 	private IMethod getMethodToInline(IType type) throws CoreException {
-		IMethod[] methods= type.getMethods();
-		for (int i= 0; i < methods.length; i++) {
-			if ("toInline".equals(methods[i].getElementName()))
-				return methods[i];
+		for (IMethod method : type.getMethods()) {
+			if ("toInline".equals(method.getElementName())) {
+				return method;
+			}
 		}
 		return null;
 	}
@@ -128,10 +128,10 @@ public class InlineMethodTests extends AbstractSelectionTestCase {
 	}
 
 	private IMethod getFirstConstructor(IType type) throws CoreException {
-		IMethod[] methods= type.getMethods();
-		for (int i= 0; i < methods.length; i++) {
-			if (methods[i].isConstructor())
-				return methods[i];
+		for (IMethod method : type.getMethods()) {
+			if (method.isConstructor()) {
+				return method;
+			}
 		}
 		return null;
 	}
@@ -356,7 +356,7 @@ public class InlineMethodTests extends AbstractSelectionTestCase {
 	public void test_287378() throws Exception {
 		performBugTest();
 	}
-	
+
 	public void test_267386() throws Exception {
 		performBugTest();
 	}
@@ -506,7 +506,7 @@ public class InlineMethodTests extends AbstractSelectionTestCase {
 	public void test91470() throws Exception {
 		performArgumentTest();
 	}
-	
+
 	//see bug 269401
 	public void testFinalParameter1() throws Exception {
 		performArgumentTest();
@@ -521,7 +521,7 @@ public class InlineMethodTests extends AbstractSelectionTestCase {
 	public void testFinalParameter3() throws Exception {
 		performArgumentTest();
 	}
-	
+
 	/* *********************** Name Conflict Tests ******************************* */
 
 	private void performNameConflictTest() throws Exception {
@@ -847,7 +847,7 @@ public class InlineMethodTests extends AbstractSelectionTestCase {
 	public void testHierarchyOverloadedMultiLevel() throws Exception {
 		performCastTest();
 	}
-	
+
 	public void testHierarchyOverloadedPrivate() throws Exception {
 		performCastTest();
 	}
@@ -967,7 +967,7 @@ public class InlineMethodTests extends AbstractSelectionTestCase {
 	public void testParameterizedType6() throws Exception {
 		performGenericTest();
 	}
-	
+
 	public void testParameterizedMethod() throws Exception {
 		performGenericTest();
 	}
@@ -1067,7 +1067,7 @@ public class InlineMethodTests extends AbstractSelectionTestCase {
 	}
 
 	public void testOperatorPredence() throws Exception {
-		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL);
+		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL, false);
 
 		int assignment= OperatorPrecedence.getExpressionPrecedence(ast.newAssignment());
 		int conditional= OperatorPrecedence.getExpressionPrecedence(ast.newConditionalExpression());
