@@ -219,7 +219,7 @@ public class IntroduceFactoryTests extends RefactoringTest {
 
 		assertEqualLines(getName() + ": ", getFileContents(outputFileName), newSource);
 	}
-	
+
 	private void doSingleUnitTestWithWarning(boolean protectConstructor, ICompilationUnit cu, String outputFileName) throws Exception, JavaModelException, IOException {
 		ISourceRange selection= findSelectionInSource(cu.getSource());
 		IntroduceFactoryRefactoring ref= new IntroduceFactoryRefactoring(cu, selection.getOffset(), selection.getLength());
@@ -274,7 +274,7 @@ public class IntroduceFactoryTests extends RefactoringTest {
 
 		doSingleUnitTest(protectConstructor, cu, getBugTestFileName(null, getPackageP(), baseFileName, false));
 	}
-	
+
 	protected void singleUnitBugHelperWithWarning(String baseFileName, boolean protectConstructor)
 			throws Exception
 	{
@@ -475,37 +475,27 @@ public class IntroduceFactoryTests extends RefactoringTest {
 	}
 
 	private void addProjectDependencies(String[] dependencies, Map<String, IJavaProject> projName2Project) throws JavaModelException {
-		for(int i= 0; i < dependencies.length; i++) {
+		for (String dependency : dependencies) {
 			// dependent:provider
-			String dependency= dependencies[i];
 			int colonIdx= dependency.indexOf(':');
 			String depName= dependency.substring(0, colonIdx);
 			String provName= dependency.substring(colonIdx+1);
-
 			IJavaProject depProj= projName2Project.get(depName);
 			IJavaProject provProj= projName2Project.get(provName);
-
 			JavaProjectHelper.addRequiredProject(depProj, provProj);
 		}
 	}
 
 	private void createProjectPackageStructure(Map<String, Set<String>> projName2PkgNames, Map<String, IJavaProject> projName2Project, Map<IJavaProject, IPackageFragmentRoot> proj2PkgRoot) throws CoreException, JavaModelException {
-		for(Iterator<String> iter= projName2PkgNames.keySet().iterator(); iter.hasNext(); ) {
-			String projName= iter.next();
-			Set<String> projPkgNames= projName2PkgNames.get(projName);
-
+		for (Map.Entry<String, Set<String>> entry : projName2PkgNames.entrySet()) {
+			String projName = entry.getKey();
 			IJavaProject project= JavaProjectHelper.createJavaProject(projName, "bin");
 			IPackageFragmentRoot root= JavaProjectHelper.addSourceContainer(project, CONTAINER);
-
 			JavaProjectHelper.addRTJar(project);
-
 			Set<IPackageFragment> pkgs= new HashSet<>();
-
 			projName2Project.put(projName, project);
 			proj2PkgRoot.put(project, root);
-			for(Iterator<String> pkgIter= projPkgNames.iterator(); pkgIter.hasNext(); ) {
-				String pkgName= pkgIter.next();
-
+			for (String pkgName : entry.getValue()) {
 				pkgs.add(root.createPackageFragment(pkgName, true, null));
 			}
 		}
@@ -514,8 +504,7 @@ public class IntroduceFactoryTests extends RefactoringTest {
 	private Map<String, Set<String>> collectProjectPackages(String[] inputFileBaseNames) {
 		Map<String, Set<String>> proj2Pkgs= new HashMap<>();
 
-		for(int i= 0; i < inputFileBaseNames.length; i++) {
-			String filePath= inputFileBaseNames[i];
+		for (String filePath : inputFileBaseNames) {
 			int projEnd= filePath.indexOf('/');
 			String projName= filePath.substring(0, projEnd);
 			String pkgName= filePath.substring(projEnd+1, filePath.lastIndexOf('/'));
@@ -762,23 +751,23 @@ public class IntroduceFactoryTests extends RefactoringTest {
 	public void test250660() throws Exception {
 		singleUnitBugHelper("HasAnonymous", true);
 	}
-	
+
 	public void test74759() throws Exception {
 		singleUnitBugHelper("Test", true);
 	}
-	
+
 	public void test298281() throws Exception {
 		singleUnitBugHelper("Thing", true);
 	}
-	
+
 	public void test395016_1() throws Exception {
 		singleUnitBugHelperWithWarning("AbstractClass", true);
 	}
-	
+
 	public void test395016_2() throws Exception {
 		singleUnitBugHelperWithWarning("AbstractMethod", true);
 	}
-	
+
 	public void testFactoryClash() throws Exception {
 		failHelper(RefactoringStatus.ERROR);
 	}
