@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -113,6 +113,43 @@ public class PullUpTests extends RefactoringTest {
 		assertEqualLines(expected, actual);
 	}
 
+	private void fieldMethodHelper2(String[] fieldNames, String[] methodNames, String[][] signatures, boolean deleteAllInSourceType, boolean deleteAllMatchingMethods) throws Exception {
+		ICompilationUnit cuQ= createCUfromTestFile(getPackageQ(), "Asuper", "q/");
+		ICompilationUnit cuP= createCUfromTestFile(getPackageP(), "A", "p/");
+		createCUfromTestFile(getPackageP(), "C", "p/");
+		createCUfromTestFile(getPackageQ(), "C", "q/");
+
+		IType type= getType(cuP, "A");
+		IField[] fields= getFields(type, fieldNames);
+		IMethod[] methods= getMethods(type, methodNames, signatures);
+
+		PullUpRefactoringProcessor processor= createRefactoringProcessor(merge(methods, fields));
+
+		Refactoring ref= processor.getRefactoring();
+		RefactoringStatus checkInitialConditions= ref.checkInitialConditions(new NullProgressMonitor());
+		assertTrue("activation", checkInitialConditions.isOK());
+		setSuperclassAsTargetClass(processor);
+
+		if (deleteAllInSourceType) {
+			processor.setDeletedMethods(methods);
+		}
+		if (deleteAllMatchingMethods) {
+			processor.setDeletedMethods(getMethods(processor.getMatchingElements(new NullProgressMonitor(), false)));
+		}
+
+		RefactoringStatus checkInputResult= ref.checkFinalConditions(new NullProgressMonitor());
+		assertTrue("precondition was supposed to pass", !checkInputResult.hasError());
+		performChange(ref, false);
+
+		String expected= getFileContents(getOutputTestFileName("A", "p/"));
+		String actual= cuP.getSource();
+		assertEqualLines(expected, actual);
+
+		String expectedSuper= getFileContents(getOutputTestFileName("Asuper", "q/"));
+		String actualSuper= cuQ.getSource();
+		assertEqualLines(expectedSuper, actualSuper);
+	}
+
 	private IType[] getPossibleTargetClasses(PullUpRefactoringProcessor processor) throws JavaModelException {
 		return processor.getCandidateTypes(new RefactoringStatus(), new NullProgressMonitor());
 	}
@@ -179,6 +216,26 @@ public class PullUpTests extends RefactoringTest {
 		assertEqualLines(expected, actual);
 	}
 
+	private void fieldHelper1b(String[] fieldNames, int targetClassIndex) throws Exception{
+		ICompilationUnit cu= createCUfromTestFile(getPackageP(), "A");
+		IType typeC= getType(cu, "C");
+		IField[] fields= getFields(typeC, fieldNames);
+
+		PullUpRefactoringProcessor processor= createRefactoringProcessor(fields);
+		Refactoring ref= processor.getRefactoring();
+
+		assertTrue("activation", ref.checkInitialConditions(new NullProgressMonitor()).isOK());
+		setTargetClass(processor, targetClassIndex);
+
+		RefactoringStatus checkInputResult= ref.checkFinalConditions(new NullProgressMonitor());
+		assertTrue("precondition was supposed to pass", !checkInputResult.hasError());
+		performChange(ref, false);
+
+		String expected= getFileContents(getOutputTestFileName("A"));
+		String actual= cu.getSource();
+		assertEqualLines(expected, actual);
+	}
+
 	private void fieldHelper2(String[] fieldNames, int targetClassIndex) throws Exception{
 		ICompilationUnit cu= createCUfromTestFile(getPackageP(), "A");
 		IType type= getType(cu, "B");
@@ -1066,6 +1123,34 @@ public class PullUpTests extends RefactoringTest {
 				signaturesOfMethodsToDeclareAbstract, new String[0], true, true, 0);
 	}
 
+	public void test55() throws Exception {
+		// test for bug 355327
+		ICompilationUnit cuA= createCUfromTestFile(getPackageP(), "A");
+		ICompilationUnit cuB= createCUfromTestFile(getPackageP(), "B");
+		ICompilationUnit cuC= createCUfromTestFile(getPackageP(), "C");
+
+		IType typeA= getType(cuA, "A");
+		IType typeB= getType(cuB, "B");
+		String[] fieldNames= new String[] { "k" };
+		IField[] fields= getFields(typeB, fieldNames);
+
+		PullUpRefactoringProcessor processor= createRefactoringProcessor(fields);
+		Refactoring ref= processor.getRefactoring();
+		assertTrue("activation", ref.checkInitialConditions(new NullProgressMonitor()).isOK());
+
+		setTargetClass(processor, 0);
+		processor.setDestinationType(typeA);
+		processor.setMembersToMove(fields);
+
+		assertTrue("final", ref.checkFinalConditions(new NullProgressMonitor()).isOK());
+
+		performChange(ref, false);
+
+		assertEqualLines("A", getFileContents(getOutputTestFileName("A")), cuA.getSource());
+		assertEqualLines("B", getFileContents(getOutputTestFileName("B")), cuB.getSource());
+		assertEqualLines("C", getFileContents(getOutputTestFileName("C")), cuC.getSource());
+	}
+
 	public void testFail0() throws Exception{
 //		printTestDisabledMessage("6538: searchDeclarationsOf* incorrect");
 		helper2(new String[]{"m"}, new String[][]{new String[0]}, true, false, 0);
@@ -1382,11 +1467,11 @@ public class PullUpTests extends RefactoringTest {
 		fieldHelper1(new String[]{"i"}, 0);
 	}
 
-	public void testFieldFail0() throws Exception{
-		fieldHelper2(new String[]{"x"}, 0);
+	public void testField1() throws Exception{
+		fieldHelper1b(new String[]{"x"}, 1);
 	}
 
-	public void testFieldFail1() throws Exception{
+	public void testFieldFail0() throws Exception{
 		fieldHelper2(new String[]{"x"}, 0);
 	}
 
@@ -1400,6 +1485,23 @@ public class PullUpTests extends RefactoringTest {
 		fieldMethodHelper1(new String[]{"f"}, new String[]{"m"}, new String[][]{new String[0]}, true, false);
 	}
 
+	//---------------------------------------------------------
+	public void testFieldMethod1() throws Exception {
+		fieldMethodHelper2(new String[] { "c" }, new String[] {}, new String[][] { new String[0] }, true, false);
+	}
+
+	public void testFieldMethod2() throws Exception {
+		fieldMethodHelper2(new String[] { "c" }, new String[] {}, new String[][] { new String[0] }, true, false);
+	}
+
+	public void testFieldMethod3() throws Exception {
+		fieldMethodHelper2(new String[] { "c" }, new String[] {}, new String[][] { new String[0] }, true, false);
+	}
+
+	public void testFieldMethod4() throws Exception {
+		fieldMethodHelper2(new String[] { "c" }, new String[] {}, new String[][] { new String[0] }, true, false);
+	}
+
 	//----
 	public void testAddingRequiredMembers0() throws Exception{
 		String[] fieldNames= {};
