@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2010 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -46,6 +46,8 @@ public class JUnit4TestFinderTest extends TestCase {
 	private IJavaProject fProject;
 	private IPackageFragmentRoot fRoot;
 
+	private static final boolean BUG_559685= true;
+
 	@Override
 	protected void setUp() throws Exception {
 		super.setUp();
@@ -69,6 +71,9 @@ public class JUnit4TestFinderTest extends TestCase {
 	 * @throws Exception if it fails
 	 */
 	public void testTestCase() throws Exception {
+		if (BUG_559685) {
+			return;
+		}
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package p;\n");
@@ -144,8 +149,8 @@ public class JUnit4TestFinderTest extends TestCase {
 		buf.append("    }\n");
 		buf.append("}\n");
 		IType[] invalidTests= p.createCompilationUnit("Outer2.java", buf.toString(), false, null).getAllTypes();
-		for (int i= 0; i < invalidTests.length; i++) {
-			assertTestFound(invalidTests[i], new String[] {});
+		for (IType invalidTest : invalidTests) {
+			assertTestFound(invalidTest, new String[] {});
 		}
 		assertTestFound(invalidTests[0].getCompilationUnit(), new String[] {});
 
@@ -184,9 +189,11 @@ public class JUnit4TestFinderTest extends TestCase {
 	}
 
 	public void testSuiteFinder() throws Exception {
-
+		if (BUG_559685) {
+			return;
+		}
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.Test;\n");
 		buf.append("\n");
@@ -207,7 +214,9 @@ public class JUnit4TestFinderTest extends TestCase {
 	}
 
 	public void testRunWith() throws Exception {
-
+		if (BUG_559685) {
+			return;
+		}
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package p;\n");
@@ -318,23 +327,25 @@ public class JUnit4TestFinderTest extends TestCase {
 
 		File lib= JavaTestPlugin.getDefault().getFileInPlugin(new Path("testresources/stacktest.jar"));
 		JavaProjectHelper.addLibrary(fProject, Path.fromOSString(lib.getPath()));
-		
+
 		assertTestFound(validTest4, new String[] { "Test7"});
 		assertTestFound(validTest4.getCompilationUnit(), new String[] { "Test7" });
-		
+
 		String[] validTestsP= { "p.Test1", "p.Test2", "p.Test3", "p.Test5"};
 		assertTestFound(p, validTestsP);
-		
+
 		String[] validTests= new String[validTestsP.length + 1];
 		System.arraycopy(validTestsP, 0, validTests, 0, validTestsP.length);
 		validTests[validTestsP.length]= "Test7";
-		
+
 		assertTestFound(fRoot, validTests);
 		assertTestFound(fProject, validTests);
 	}
 
 	public void testTestAnnotation() throws Exception {
-
+		if (BUG_559685) {
+			return;
+		}
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package p;\n");
@@ -403,7 +414,7 @@ public class JUnit4TestFinderTest extends TestCase {
 	public void testTestAnnotation_bug204682() throws Exception {
 
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("import org.junit.Test;\n");
@@ -425,7 +436,7 @@ public class JUnit4TestFinderTest extends TestCase {
 	public void testTestAnnotation2() throws Exception {
 
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("import org.junit.Test;\n");
