@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -272,7 +272,7 @@ public class AddImportTest extends CoreTests {
 
 	public void testRemoveImports3() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack= sourceFolder.createPackageFragment("pack", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package pack;\n");
@@ -282,7 +282,7 @@ public class AddImportTest extends CoreTests {
 		buf.append("    }\n");
 		buf.append("}\n");
 		pack.createCompilationUnit("A.java", buf.toString(), false, null);
-		
+
 		IPackageFragment test1= sourceFolder.createPackageFragment("test1", false, null);
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
@@ -297,22 +297,22 @@ public class AddImportTest extends CoreTests {
 		buf.append("public class T {\n");
 		buf.append("}\n");
 		ICompilationUnit cuT= test1.createCompilationUnit("T.java", buf.toString(), false, null);
-		
+
 		ASTParser parser= ASTParser.newParser(IASTSharedValues.SHARED_AST_LEVEL);
 		parser.setSource(cuT);
 		parser.setResolveBindings(true);
 		CompilationUnit astRoot= (CompilationUnit) parser.createAST(null);
-		
+
 		ImportRewrite imports= newImportsRewrite(astRoot, new String[0], 99, 99, true);
 		imports.setUseContextToFilterImplicitImports(true);
-		
+
 		imports.removeImport("pack.A.Inner");
 		imports.removeImport("pack.A.NotThere");
 		imports.removeImport("pack.B.Inner");
 		imports.removeImport("pack.B.NotThere");
-		
+
 		apply(imports);
-		
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("\n");
@@ -323,8 +323,8 @@ public class AddImportTest extends CoreTests {
 		buf.append("}\n");
 		assertEqualString(cuT.getSource(), buf.toString());
 	}
-	
-	
+
+
 	public void testAddImports_bug23078() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
@@ -525,7 +525,7 @@ public class AddImportTest extends CoreTests {
 
 		String[] order= new String[] { "java.util", "java.io", "java.net" };
 		int threshold= 99;
-		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL);
+		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL, false);
 		ImportRewrite importsRewrite= newImportsRewrite(cu2, order, threshold, true);
 		{
 			IJavaElement[] elements= cu1.codeSelect(content.indexOf("IOException"), "IOException".length());
@@ -574,7 +574,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("\n");
 		buf.append("public class E {\n");
@@ -611,7 +611,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("\n");
 		buf.append("public class E<X> {\n");
@@ -649,7 +649,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("\n");
 		buf.append("public class E<X> {\n");
@@ -711,7 +711,7 @@ public class AddImportTest extends CoreTests {
 
 		String[] order= new String[] { "java.util", "java.io", "java.net" };
 		int threshold= 99;
-		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL);
+		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL, false);
 		ImportRewrite importsRewrite= newImportsRewrite(cu2, order, threshold, true);
 		{
 			IJavaElement[] elements= cu1.codeSelect(content.indexOf("Map"), "Map".length());
@@ -940,7 +940,7 @@ public class AddImportTest extends CoreTests {
 
 	public void testAddImportAction5() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package pack1;\n");
@@ -957,12 +957,12 @@ public class AddImportTest extends CoreTests {
 		buf.append("    Serializable s;\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("C.java", buf.toString(), false, null);
-		
+
 		int selOffset= buf.indexOf("ser=") - 2;
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 0, null, true);
 		op.run(null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
 		buf.append("\n");
@@ -979,113 +979,113 @@ public class AddImportTest extends CoreTests {
 		buf.append("}\n");
 		assertEqualString(cu.getSource(), buf.toString());
 	}
-	
+
 	public void testAddImportActionBug_409594_test1() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("p", false, null);
 		String input =
-				"package p;\n" + 
-				"\n" + 
-				"class A {\n" + 
-				"	static void foo() {\n" + 
-				"		A.bar();\n" + 
-				"	}\n" + 
-				"\n" + 
-				"	private static void bar() {\n" + 
-				"	}\n" + 
+				"package p;\n" +
+				"\n" +
+				"class A {\n" +
+				"	static void foo() {\n" +
+				"		A.bar();\n" +
+				"	}\n" +
+				"\n" +
+				"	private static void bar() {\n" +
+				"	}\n" +
 				"}";
 		ICompilationUnit cu= pack1.createCompilationUnit("A.java", input, false, null);
-		
+
 		int selOffset= input.indexOf("bar");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 3, null, true);
 		op.run(null);
-		
-		String expected = 
-				"package p;\n" + 
-				"\n" + 
-				"class A {\n" + 
-				"	static void foo() {\n" + 
-				"		bar();\n" + 
-				"	}\n" + 
-				"\n" + 
-				"	private static void bar() {\n" + 
-				"	}\n" + 
+
+		String expected =
+				"package p;\n" +
+				"\n" +
+				"class A {\n" +
+				"	static void foo() {\n" +
+				"		bar();\n" +
+				"	}\n" +
+				"\n" +
+				"	private static void bar() {\n" +
+				"	}\n" +
 				"}";
 		assertEqualString(cu.getSource(), expected);
 	}
-	
+
 	public void testAddImportActionBug_409594_test2() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("p", false, null);
 		String input =
-				"package p;\n" + 
-				"\n" + 
-				"class A {\n" + 
-				"	static void foo() {\n" + 
-				"		A.bar();\n" + 
-				"	}\n" + 
-				"\n" + 
-				"	public static void bar() {\n" + 
-				"	}\n" + 
+				"package p;\n" +
+				"\n" +
+				"class A {\n" +
+				"	static void foo() {\n" +
+				"		A.bar();\n" +
+				"	}\n" +
+				"\n" +
+				"	public static void bar() {\n" +
+				"	}\n" +
 				"}";
 		ICompilationUnit cu= pack1.createCompilationUnit("A.java", input, false, null);
-		
+
 		int selOffset= input.indexOf("bar");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 3, null, true);
 		op.run(null);
-		
-		String expected = 
-				"package p;\n" + 
-				"\n" + 
-				"class A {\n" + 
-				"	static void foo() {\n" + 
-				"		bar();\n" + 
-				"	}\n" + 
-				"\n" + 
-				"	public static void bar() {\n" + 
-				"	}\n" + 
+
+		String expected =
+				"package p;\n" +
+				"\n" +
+				"class A {\n" +
+				"	static void foo() {\n" +
+				"		bar();\n" +
+				"	}\n" +
+				"\n" +
+				"	public static void bar() {\n" +
+				"	}\n" +
 				"}";
 		assertEqualString(cu.getSource(), expected);
 	}
-	
+
 	public void testAddImportActionBug_409594_test3() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("p", false, null);
 		String input =
-				"package p;\n" + 
-				"class SnippetX {\n" + 
-				"    private static class Test {\n" + 
-				"        class X {\n" + 
-				"            void foo() {\n" + 
-				"                Test.bar();\n" + 
-				"            }\n" + 
-				"        }\n" + 
-				"        public static void bar() {}\n" + 
-				"    }\n" + 
+				"package p;\n" +
+				"class SnippetX {\n" +
+				"    private static class Test {\n" +
+				"        class X {\n" +
+				"            void foo() {\n" +
+				"                Test.bar();\n" +
+				"            }\n" +
+				"        }\n" +
+				"        public static void bar() {}\n" +
+				"    }\n" +
 				"}";
 		ICompilationUnit cu= pack1.createCompilationUnit("A.java", input, false, null);
-		
+
 		int selOffset= input.indexOf("bar");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 3, null, true);
 		op.run(null);
-		
-		String expected = 
-				"package p;\n" + 
-				"class SnippetX {\n" + 
-				"    private static class Test {\n" + 
-				"        class X {\n" + 
-				"            void foo() {\n" + 
-				"                bar();\n" + 
-				"            }\n" + 
-				"        }\n" + 
-				"        public static void bar() {}\n" + 
-				"    }\n" + 
+
+		String expected =
+				"package p;\n" +
+				"class SnippetX {\n" +
+				"    private static class Test {\n" +
+				"        class X {\n" +
+				"            void foo() {\n" +
+				"                bar();\n" +
+				"            }\n" +
+				"        }\n" +
+				"        public static void bar() {}\n" +
+				"    }\n" +
 				"}";
 		assertEqualString(cu.getSource(), expected);
 	}
@@ -1129,12 +1129,12 @@ public class AddImportTest extends CoreTests {
 		buf.append("}\n");
 		assertEqualString(cu.getSource(), buf.toString());
 	}
-	
+
 	public void testAddImportActionBug_409594_test5() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("p", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package organize.imports.pvtStaticMembers.bug409594;\n");
 		buf.append("\n");
 		buf.append("class SnippetY {    \n");
@@ -1155,7 +1155,7 @@ public class AddImportTest extends CoreTests {
 
 		assertEqualString(cu.getSource(), cu.getSource());
 	}
-	
+
 	public void testAddImportActionBug_409594_test6() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
@@ -1199,7 +1199,7 @@ public class AddImportTest extends CoreTests {
 						"";
 		assertEqualString(cuB.getSource(), expected);
 	}
-	
+
 	public void testAddImportAction_bug107206() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
@@ -1296,7 +1296,7 @@ public class AddImportTest extends CoreTests {
 
 	public void testAddImportActionNestedType1() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package pack1;\n");
@@ -1305,12 +1305,12 @@ public class AddImportTest extends CoreTests {
 		buf.append("    java.lang.Thread.State s;\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("C.java", buf.toString(), false, null);
-				
+
 		int selOffset= buf.indexOf("Thread");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 0, null, true);
 		op.run(null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
 		buf.append("\n");
@@ -1319,10 +1319,10 @@ public class AddImportTest extends CoreTests {
 		buf.append("}\n");
 		assertEqualString(cu.getSource(), buf.toString());
 	}
-	
+
 	public void testAddImportActionNestedType2() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package pack1;\n");
@@ -1331,12 +1331,12 @@ public class AddImportTest extends CoreTests {
 		buf.append("    java.lang.Thread.State s;\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("C.java", buf.toString(), false, null);
-		
+
 		int selOffset= buf.indexOf("State");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 0, null, true);
 		op.run(null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
 		buf.append("\n");
@@ -1347,10 +1347,10 @@ public class AddImportTest extends CoreTests {
 		buf.append("}\n");
 		assertEqualString(cu.getSource(), buf.toString());
 	}
-	
+
 	public void testAddImportActionParameterizedType1() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package pack1;\n");
@@ -1359,12 +1359,12 @@ public class AddImportTest extends CoreTests {
 		buf.append("    java.util.Map<String, Integer> m;\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("C.java", buf.toString(), false, null);
-				
+
 		int selOffset= buf.indexOf("Map");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 0, null, true);
 		op.run(null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
 		buf.append("\n");
@@ -1378,7 +1378,7 @@ public class AddImportTest extends CoreTests {
 
 	public void testAddImportActionParameterizedType2() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package pack1;\n");
@@ -1387,12 +1387,12 @@ public class AddImportTest extends CoreTests {
 		buf.append("    java.util.Map.Entry e;\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("C.java", buf.toString(), false, null);
-				
+
 		int selOffset= buf.indexOf("Entry");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 0, null, true);
 		op.run(null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
 		buf.append("\n");
@@ -1403,10 +1403,10 @@ public class AddImportTest extends CoreTests {
 		buf.append("}\n");
 		assertEqualString(cu.getSource(), buf.toString());
 	}
-	
+
 	public void testAddImportActionParameterizedType3() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package pack1;\n");
@@ -1415,12 +1415,12 @@ public class AddImportTest extends CoreTests {
 		buf.append("    java.util.Map.Entry<String, Object> e;\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("C.java", buf.toString(), false, null);
-				
+
 		int selOffset= buf.indexOf("Map");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 0, null, true);
 		op.run(null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
 		buf.append("\n");
@@ -1431,10 +1431,10 @@ public class AddImportTest extends CoreTests {
 		buf.append("}\n");
 		assertEqualString(cu.getSource(), buf.toString());
 	}
-	
+
 	public void testAddImportActionParameterizedType4() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package pack1;\n");
@@ -1443,12 +1443,12 @@ public class AddImportTest extends CoreTests {
 		buf.append("    java.util.Map.Entry<String, Object> e;\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("C.java", buf.toString(), false, null);
-		
+
 		int selOffset= buf.indexOf("Entry");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 0, null, true);
 		op.run(null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
 		buf.append("\n");
@@ -1459,10 +1459,10 @@ public class AddImportTest extends CoreTests {
 		buf.append("}\n");
 		assertEqualString(cu.getSource(), buf.toString());
 	}
-	
+
 	public void testAddImportActionParameterizedType5() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack2= sourceFolder.createPackageFragment("pack2", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package pack2;\n");
@@ -1474,7 +1474,7 @@ public class AddImportTest extends CoreTests {
 		buf.append("    }\n");
 		buf.append("}\n");
 		pack2.createCompilationUnit("Outer.java", buf.toString(), false, null);
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
@@ -1483,12 +1483,12 @@ public class AddImportTest extends CoreTests {
 		buf.append("    pack2.Outer.Middle<String>.Inner<Integer> i;\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("C.java", buf.toString(), false, null);
-		
+
 		int selOffset= buf.indexOf("Middle");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 0, null, true);
 		op.run(null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
 		buf.append("\n");
@@ -1503,7 +1503,7 @@ public class AddImportTest extends CoreTests {
 	// Don't touch nested type if outer is parameterized.
 	public void testAddImportActionParameterizedType6() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack2= sourceFolder.createPackageFragment("pack2", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package pack2;\n");
@@ -1515,7 +1515,7 @@ public class AddImportTest extends CoreTests {
 		buf.append("    }\n");
 		buf.append("}\n");
 		pack2.createCompilationUnit("Outer.java", buf.toString(), false, null);
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
@@ -1524,12 +1524,12 @@ public class AddImportTest extends CoreTests {
 		buf.append("    pack2.Outer.Middle<String>.Inner<Integer> i;\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("C.java", buf.toString(), false, null);
-		
+
 		int selOffset= buf.indexOf("Inner");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 0, null, true);
 		op.run(null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
 		buf.append("\n");
@@ -1541,7 +1541,7 @@ public class AddImportTest extends CoreTests {
 
 	public void testAddImportActionAnnotatedType1() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package pack1;\n");
@@ -1554,12 +1554,12 @@ public class AddImportTest extends CoreTests {
 		buf.append("}\n");
 		buf.append("@Target(ElementType.TYPE_USE) @interface A {}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("C.java", buf.toString(), false, null);
-		
+
 		int selOffset= buf.indexOf("Format");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 0, null, true);
 		op.run(null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
 		buf.append("\n");
@@ -1577,7 +1577,7 @@ public class AddImportTest extends CoreTests {
 	// Don't touch nested type if outer is annotated.
 	public void testAddImportActionAnnotatedType2() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("package pack1;\n");
@@ -1590,12 +1590,12 @@ public class AddImportTest extends CoreTests {
 		buf.append("}\n");
 		buf.append("@Target(ElementType.TYPE_USE) @interface A {}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("C.java", buf.toString(), false, null);
-		
+
 		int selOffset= buf.indexOf("Field");
-		
+
 		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 0, null, true);
 		op.run(null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package pack1;\n");
 		buf.append("\n");
@@ -1613,7 +1613,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    void foo() {//<-insert\n}\n");
@@ -1628,7 +1628,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    public static final double PI= 3.0;\n");
@@ -1644,7 +1644,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    void foo() {//<-insert\n}\n");
@@ -1659,7 +1659,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    public static final double PI= 3.0;\n");
@@ -1675,7 +1675,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    private class E11 {\n");
@@ -1694,7 +1694,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    private class E11 {\n");
@@ -1713,7 +1713,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    private class E11 {\n");
@@ -1734,7 +1734,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    public static class E2 {}\n");
@@ -1757,7 +1757,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    public static class E2 {\n");
@@ -1782,7 +1782,7 @@ public class AddImportTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    void foo() {\n");
