@@ -63,7 +63,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("public class Outer {\n");
 		buf.append("}\n");
@@ -94,7 +94,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class Outer {\n");
@@ -132,7 +132,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class Outer {\n");
@@ -168,7 +168,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.*;\n");
 		buf.append("import java.io.Serializable;\n");
@@ -212,8 +212,8 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		lab= JavaElementLabels.getTextLabel(e, JavaElementLabels.ALL_POST_QUALIFIED);
 		assertEqualString(lab, "E - java.util.ArrayList");
  */
-		
-		
+
+
 		lab= getBindingLabel(typeParams, 0);
 		assertEqualString(lab, "TypeParams");
 		lab= getBindingLabel(typeParams, JavaElementLabels.ALL_DEFAULT);
@@ -229,7 +229,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.*;\n");
 		buf.append("public class X {\n");
@@ -267,7 +267,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class Outer {\n");
@@ -303,7 +303,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("import java.io.Serializable;\n");
@@ -349,7 +349,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class Outer {\n");
@@ -383,7 +383,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class Outer {\n");
@@ -419,7 +419,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 			IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 			IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-			StringBuffer buf= new StringBuffer();
+			StringBuilder buf= new StringBuilder();
 			buf.append("package org.test;\n");
 			buf.append("public class Wildcards<T> {\n");
 			buf.append("	Wildcards<? extends Number> upper;\n");
@@ -451,12 +451,12 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		IPackageFragment packOrg= sourceFolder.createPackageFragment("org", false, null);
 //		IPackageFragment packOrgTest= sourceFolder.createPackageFragment("org.test", false, null);
 		IPackageFragment packOrgTestLongname= sourceFolder.createPackageFragment("org.test.longname", false, null);
-		
+
 		// to obtain an IPackageBinding go via imported types to their #package:
 		packOrg.createCompilationUnit("T1.java", "package org;\npublic class T1 {}\n", false, null);
 		packOrgTestLongname.createCompilationUnit("T2.java", "package org.test.longname;\npublic class T2 {}\n", false, null);
-		
-		StringBuffer buf= new StringBuffer();
+
+		StringBuilder buf= new StringBuilder();
 		buf.append("import org.T1;\n");
 		buf.append("import org.test.longname.T2;\n");
 		buf.append("public class Main {\n");
@@ -472,7 +472,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		parser.setResolveBindings(true);
 		parser.setProject(fJProject1);
 		IBinding[] bindings= parser.createBindings(new IJavaElement[]{main, t1, t2}, null);
-		
+
 		String lab= JavaElementLinks.getBindingLabel(((ITypeBinding)bindings[0]).getPackage(), main.getAncestor(IJavaElement.PACKAGE_FRAGMENT), JavaElementLabels.ALL_DEFAULT, true);
 		assertEqualString(lab, "(default package)");
 		lab= JavaElementLinks.getBindingLabel(((ITypeBinding)bindings[1]).getPackage(), t1.getAncestor(IJavaElement.PACKAGE_FRAGMENT), JavaElementLabels.ALL_DEFAULT, true);
@@ -523,23 +523,23 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 
 
 			store.setValue(PreferenceConstants.APPEARANCE_ABBREVIATE_PACKAGE_NAMES, true);
-			
+
 			assertExpectedLabel(packOrgTestLongname, "org.te*.longname", JavaElementLabels.P_COMPRESSED);
-			
+
 			store.setValue(PreferenceConstants.APPEARANCE_PKG_NAME_ABBREVIATION_PATTERN_FOR_PKG_VIEW, "#com=@C\norg=@O");
-			
+
 			assertExpectedLabel(packDefault, "(default package)", JavaElementLabels.P_COMPRESSED);
 			assertExpectedLabel(packOrg, "@O", JavaElementLabels.P_COMPRESSED);
 			assertExpectedLabel(packOrgTest, "@O.test", JavaElementLabels.P_COMPRESSED);
 			assertExpectedLabel(packOrgTestLongname, "@O.te*.longname", JavaElementLabels.P_COMPRESSED);
-			
+
 			store.setValue(PreferenceConstants.APPEARANCE_PKG_NAME_ABBREVIATION_PATTERN_FOR_PKG_VIEW, "org=@O\n\norg.test=@OT\n");
-			
+
 			assertExpectedLabel(packDefault, "(default package)", JavaElementLabels.P_COMPRESSED);
 			assertExpectedLabel(packOrg, "@O", JavaElementLabels.P_COMPRESSED);
 			assertExpectedLabel(packOrgTest, "@OT", JavaElementLabels.P_COMPRESSED);
 			assertExpectedLabel(packOrgTestLongname, "@OT.longname", JavaElementLabels.P_COMPRESSED);
-			
+
 		} finally {
 			store.setToDefault(PreferenceConstants.APPEARANCE_PKG_NAME_PATTERN_FOR_PKG_VIEW);
 			store.setValue(PreferenceConstants.APPEARANCE_COMPRESS_PACKAGE_NAMES, false);
@@ -550,11 +550,11 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 	}
 
 	public void testMethodLabelVarargsDeclaration() throws Exception {
-		
+
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("public class Varargs {\n");
 		buf.append("    public void foo(int i, String... varargs) {\n");
@@ -564,7 +564,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		ICompilationUnit cu= pack1.createCompilationUnit("Varargs.java", content, false, null);
 
 		IJavaElement elem= cu.getElementAt(content.indexOf("foo"));
-		
+
 		String lab= getBindingLabel(elem, JavaElementLabels.ALL_DEFAULT);
 		assertLinkMatch(lab, "foo(int, {{java.lang|String}}...)");
 
@@ -573,19 +573,19 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 
 		lab= getBindingLabel(elem, JavaElementLabels.M_PARAMETER_TYPES);
 		assertLinkMatch(lab, "foo(int, {{java.lang|String}}...)");
-		
+
 		lab= getBindingLabel(elem, JavaElementLabels.M_PARAMETER_NAMES | JavaElementLabels.M_PARAMETER_TYPES);
 		assertLinkMatch(lab, "foo(int i, {{java.lang|String}}... varargs)");
-		
+
 		lab= getBindingLabel(elem, JavaElementLabels.M_PARAMETER_TYPES | JavaElementLabels.USE_RESOLVED);
 		assertLinkMatch(lab, "foo(int, {{java.lang|String}}...)");
 	}
 
 	public void testMethodLabelVarargsReference0() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Arrays;\n");
 		buf.append("public class Varargs {\n");
@@ -595,24 +595,24 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		buf.append("}\n");
 		String content= buf.toString();
 		ICompilationUnit cu= pack1.createCompilationUnit("Varargs.java", content, false, null);
-		
+
 		IJavaElement elem= cu.codeSelect(content.indexOf("asList"), 0)[0];
-		
+
 		String lab= getBindingLabel(elem, JavaElementLabels.ALL_DEFAULT);
 		assertLinkMatch(lab, "asList({{java.util.Arrays.asList(...)|T}}...) <{{java.util.Arrays.asList(...)|T}}>");
-		
+
 		lab= getBindingLabel(elem, JavaElementLabels.M_PARAMETER_NAMES);
 		assertEqualString(lab, "asList(arg0)");
-		
+
 		lab= getBindingLabel(elem, JavaElementLabels.M_PARAMETER_TYPES);
 		assertLinkMatch(lab, "asList({{java.util.Arrays.asList(...)|T}}...)");
-		
+
 		lab= getBindingLabel(elem, JavaElementLabels.M_PARAMETER_NAMES | JavaElementLabels.M_PARAMETER_TYPES);
 		assertLinkMatch(lab, "asList({{java.util.Arrays.asList(...)|T}}... arg0)");
-		
+
 		lab= getBindingLabel(elem, JavaElementLabels.ALL_DEFAULT | JavaElementLabels.USE_RESOLVED);
 		assertLinkMatch(lab, "asList({{java.lang|Object}}...) <{{java.lang|Object}}>");
-		
+
 		lab= getBindingLabel(elem, JavaElementLabels.M_PARAMETER_TYPES | JavaElementLabels.USE_RESOLVED);
 		assertLinkMatch(lab, "asList({{java.lang|Object}}...)");
 	}
@@ -620,20 +620,20 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 	public void testMethodLabelVarargsReference1() throws Exception {
 		assertMethodLabelVarargsReference("1");
 	}
-	
+
 	public void testMethodLabelVarargsReference2() throws Exception {
 		assertMethodLabelVarargsReference("1, 2");
 	}
-	
+
 	public void testMethodLabelVarargsReference3() throws Exception {
 		assertMethodLabelVarargsReference("1, 2, Integer.valueOf(3)");
 	}
-	
+
 	private void assertMethodLabelVarargsReference(String args) throws CoreException, JavaModelException {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Arrays;\n");
 		buf.append("public class Varargs {\n");
@@ -645,7 +645,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		ICompilationUnit cu= pack1.createCompilationUnit("Varargs.java", content, false, null);
 
 		IJavaElement elem= cu.codeSelect(content.indexOf("asList"), 0)[0];
-		
+
 		String lab= getBindingLabel(elem, JavaElementLabels.ALL_DEFAULT);
 		assertLinkMatch(lab, "asList({{java.util.Arrays.asList(...)|T}}...) <{{java.util.Arrays.asList(...)|T}}>");
 
@@ -654,22 +654,22 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 
 		lab= getBindingLabel(elem, JavaElementLabels.M_PARAMETER_TYPES);
 		assertLinkMatch(lab, "asList({{java.util.Arrays.asList(...)|T}}...)");
-		
+
 		lab= getBindingLabel(elem, JavaElementLabels.M_PARAMETER_NAMES | JavaElementLabels.M_PARAMETER_TYPES);
 		assertLinkMatch(lab, "asList({{java.util.Arrays.asList(...)|T}}... arg0)");
-		
+
 		lab= getBindingLabel(elem, JavaElementLabels.ALL_DEFAULT | JavaElementLabels.USE_RESOLVED);
 		assertLinkMatch(lab, "asList({{java.lang|Integer}}...) <{{java.lang|Integer}}>");
-		
+
 		lab= getBindingLabel(elem, JavaElementLabels.M_PARAMETER_TYPES | JavaElementLabels.USE_RESOLVED);
 		assertLinkMatch(lab, "asList({{java.lang|Integer}}...)");
 	}
-	
-	
+
+
 	public void testMethodLabelAnnotatedParameters() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("\n");
 		buf.append("import java.lang.annotation.Retention;\n");
@@ -703,13 +703,13 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		lab= getBindingLabel(foo2, JavaElementLabels.ALL_DEFAULT | JavaElementLabels.ALL_FULLY_QUALIFIED | JavaElementLabels.M_PARAMETER_ANNOTATIONS);
 		assertLinkMatch(lab, "{{org.test.Annotations}}.foo2(@{{Ann}}({{value}}=\"\", {{cl}}={{Annotations}}.class, {{ints}}={1, 2, -19}, {{ch}}='\\u0000', {{sh}}=32767, {{r}}=@{{Retention}}({{value}}={{RetentionPolicy}}.{{SOURCE}})) {{String}})");
 	}
-	
+
 	// disabled, because we cannot retrieve a binding for the selected element: local variable inside instance initializer
 	public void testLocalClassInInitializer() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("public class LambdaTests {\n");
 		buf.append("    {\n");
@@ -734,7 +734,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		IJavaElement foo2= cu.codeSelect(content.indexOf("toStringL"), 9)[0];
 		lab= getBindingLabel(foo2, JavaElementLabels.ALL_DEFAULT | JavaElementLabels.ALL_POST_QUALIFIED | JavaElementLabels.F_PRE_TYPE_SIGNATURE);
 		assertLinkMatch(lab, "{{org.test.LambdaTests.{...}|Local}} toStringL - {{org}}.{{test}}.{{LambdaTests}}.{...}");
-		
+
 // can't select the constructor, only the type (label computation works fine once we find the binding)
 //		IJavaElement ctor= cu.codeSelect(content.indexOf("Local()"), 0)[0];
 //		lab= getBindingLabel(ctor, JavaElementLabels.ALL_DEFAULT | JavaElementLabels.ALL_FULLY_QUALIFIED);
@@ -743,9 +743,9 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 
 	public void testLocalClassInStaticInitializer() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("public class LambdaTests {\n");
 		buf.append("    static {\n");
@@ -774,9 +774,9 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 
 	public void testRecursiveType() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("public interface TypeTest {\n");
 		buf.append("    public <V extends Comparable<? super V>> boolean compare(V t);\n");
@@ -798,9 +798,9 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 
 	public void testMultipleTypeVariables() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("class Two<B extends Number, A extends B> { }\n");
 		buf.append("public class Three<E extends Number> {\n");
