@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -89,8 +89,8 @@ public class CodeFormatterUtilTest extends CoreTests {
 			Document doc= createDocument(string, positions);
 			edit.apply(doc, 0);
 			if (positions != null) {
-				for (int i= 0; i < positions.length; i++) {
-					Assert.isTrue(!positions[i].isDeleted, "Position got deleted"); //$NON-NLS-1$
+				for (Position position : positions) {
+					Assert.isTrue(!position.isDeleted, "Position got deleted"); //$NON-NLS-1$
 				}
 			}
 			return doc.get();
@@ -118,11 +118,11 @@ public class CodeFormatterUtilTest extends CoreTests {
 						return true;
 					}
 				});
-				for (int i= 0; i < positions.length; i++) {
+				for (Position position : positions) {
 					try {
-						doc.addPosition(POS_CATEGORY, positions[i]);
+						doc.addPosition(POS_CATEGORY, position);
 					} catch (BadLocationException e) {
-						throw new IllegalArgumentException("Position outside of string. offset: " + positions[i].offset + ", length: " + positions[i].length + ", string size: " + string.length());   //$NON-NLS-1$//$NON-NLS-2$//$NON-NLS-3$
+						throw new IllegalArgumentException("Position outside of string. offset: " + position.offset + ", length: " + position.length + ", string size: " + string.length()); //$NON-NLS-1$//$NON-NLS-2$//$NON-NLS-3$
 					}
 				}
 			}
@@ -284,7 +284,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		buf.append("  package   com . test1;");
 		String contents= buf.toString();
 
-		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL);
+		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL, false);
 		PackageDeclaration decl= ast.newPackageDeclaration();
 
 		TextEdit edit= CodeFormatterUtil.format2(decl, contents, 0, "\n", null);
@@ -302,7 +302,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		buf.append("package   com . test1;");
 		String contents= buf.toString();
 
-		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL);
+		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL, false);
 		PackageDeclaration node= ast.newPackageDeclaration();
 
 		String word1= "com";
@@ -336,7 +336,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		buf.append("x[ ]=\nnew  int[ offset]");
 		String contents= buf.toString();
 
-		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL);
+		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL, false);
 		VariableDeclarationFragment node= ast.newVariableDeclarationFragment();
 
 		String word1= "new";
@@ -372,7 +372,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		buf.append(" */\n");
 		String contents= buf.toString();
 
-		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL);
+		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL, false);
 		Javadoc node= ast.newJavadoc();
 
 		String word1= "bar";
@@ -410,7 +410,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		buf.append(" */");
 		String contents= buf.toString();
 
-		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL);
+		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL, false);
 		Javadoc node= ast.newJavadoc();
 
 		String word1= "bar";
@@ -448,7 +448,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		buf.append(" */");
 		String contents= buf.toString();
 
-		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL);
+		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL, false);
 		Javadoc node= ast.newJavadoc();
 
 		String word1= "bar";
@@ -487,7 +487,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		buf.append("}");
 		String contents= buf.toString();
 
-		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL);
+		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL, false);
 		CatchClause node= ast.newCatchClause();
 
 		String word1= "catch";
@@ -522,7 +522,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		buf.append("\"Hello\" ");
 		String contents= buf.toString();
 
-		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL);
+		AST ast= AST.newAST(IASTSharedValues.SHARED_AST_LEVEL, false);
 		StringLiteral node= ast.newStringLiteral();
 
 		TextEdit edit= CodeFormatterUtil.format2(node, contents, 0, "\n", null);
