@@ -78,7 +78,7 @@ public class JavaElementLabelsTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("public class Outer {\n");
 		buf.append("}\n");
@@ -107,7 +107,7 @@ public class JavaElementLabelsTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class Outer {\n");
@@ -143,7 +143,7 @@ public class JavaElementLabelsTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class Outer {\n");
@@ -177,7 +177,7 @@ public class JavaElementLabelsTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.*;\n");
 		buf.append("import java.io.Serializable;\n");
@@ -216,8 +216,8 @@ public class JavaElementLabelsTest extends CoreTests {
 		assertEqualString(lab, "E"); // no " extends java.lang.Object"!
 		lab= JavaElementLabels.getTextLabel(e, JavaElementLabels.ALL_POST_QUALIFIED);
 		assertEqualString(lab, "E - java.util.ArrayList");
-		
-		
+
+
 		lab= JavaElementLabels.getTextLabel(typeParams, 0);
 		assertEqualString(lab, "TypeParams");
 		lab= JavaElementLabels.getTextLabel(typeParams, JavaElementLabels.ALL_DEFAULT);
@@ -231,7 +231,7 @@ public class JavaElementLabelsTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.*;\n");
 		buf.append("public class X {\n");
@@ -269,7 +269,7 @@ public class JavaElementLabelsTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class Outer {\n");
@@ -303,7 +303,7 @@ public class JavaElementLabelsTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class Outer {\n");
@@ -341,7 +341,7 @@ public class JavaElementLabelsTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class Outer {\n");
@@ -373,7 +373,7 @@ public class JavaElementLabelsTest extends CoreTests {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class Outer {\n");
@@ -407,7 +407,7 @@ public class JavaElementLabelsTest extends CoreTests {
 			IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 			IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-			StringBuffer buf= new StringBuffer();
+			StringBuilder buf= new StringBuilder();
 			buf.append("package org.test;\n");
 			buf.append("public class Wildcards<T> {\n");
 			buf.append("	Wildcards<? extends Number> upper;\n");
@@ -486,23 +486,23 @@ public class JavaElementLabelsTest extends CoreTests {
 
 
 			store.setValue(PreferenceConstants.APPEARANCE_ABBREVIATE_PACKAGE_NAMES, true);
-			
+
 			assertExpectedLabel(packOrgTestLongname, "org.te*.longname", JavaElementLabels.P_COMPRESSED);
-			
+
 			store.setValue(PreferenceConstants.APPEARANCE_PKG_NAME_ABBREVIATION_PATTERN_FOR_PKG_VIEW, "#com=@C\norg=@O");
-			
+
 			assertExpectedLabel(packDefault, "(default package)", JavaElementLabels.P_COMPRESSED);
 			assertExpectedLabel(packOrg, "@O", JavaElementLabels.P_COMPRESSED);
 			assertExpectedLabel(packOrgTest, "@O.test", JavaElementLabels.P_COMPRESSED);
 			assertExpectedLabel(packOrgTestLongname, "@O.te*.longname", JavaElementLabels.P_COMPRESSED);
-			
+
 			store.setValue(PreferenceConstants.APPEARANCE_PKG_NAME_ABBREVIATION_PATTERN_FOR_PKG_VIEW, "org=@O\n\norg.test=@OT\n");
-			
+
 			assertExpectedLabel(packDefault, "(default package)", JavaElementLabels.P_COMPRESSED);
 			assertExpectedLabel(packOrg, "@O", JavaElementLabels.P_COMPRESSED);
 			assertExpectedLabel(packOrgTest, "@OT", JavaElementLabels.P_COMPRESSED);
 			assertExpectedLabel(packOrgTestLongname, "@OT.longname", JavaElementLabels.P_COMPRESSED);
-			
+
 		} finally {
 			store.setToDefault(PreferenceConstants.APPEARANCE_PKG_NAME_PATTERN_FOR_PKG_VIEW);
 			store.setValue(PreferenceConstants.APPEARANCE_COMPRESS_PACKAGE_NAMES, false);
@@ -512,11 +512,11 @@ public class JavaElementLabelsTest extends CoreTests {
 	}
 
 	public void testMethodLabelVarargsDeclaration() throws Exception {
-		
+
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("public class Varargs {\n");
 		buf.append("    public void foo(int i, String... varargs) {\n");
@@ -526,7 +526,7 @@ public class JavaElementLabelsTest extends CoreTests {
 		ICompilationUnit cu= pack1.createCompilationUnit("Varargs.java", content, false, null);
 
 		IJavaElement elem= cu.getElementAt(content.indexOf("foo"));
-		
+
 		String lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.ALL_DEFAULT);
 		assertEqualString(lab, "foo(int, String...)");
 
@@ -535,19 +535,19 @@ public class JavaElementLabelsTest extends CoreTests {
 
 		lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.M_PARAMETER_TYPES);
 		assertEqualString(lab, "foo(int, String...)");
-		
+
 		lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.M_PARAMETER_NAMES | JavaElementLabels.M_PARAMETER_TYPES);
 		assertEqualString(lab, "foo(int i, String... varargs)");
-		
+
 		lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.M_PARAMETER_TYPES | JavaElementLabels.USE_RESOLVED);
 		assertEqualString(lab, "foo(int, String...)");
 	}
 
 	public void testMethodLabelVarargsReference0() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
-		
+
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Arrays;\n");
 		buf.append("public class Varargs {\n");
@@ -557,24 +557,24 @@ public class JavaElementLabelsTest extends CoreTests {
 		buf.append("}\n");
 		String content= buf.toString();
 		ICompilationUnit cu= pack1.createCompilationUnit("Varargs.java", content, false, null);
-		
+
 		IJavaElement elem= cu.codeSelect(content.indexOf("asList"), 0)[0];
-		
+
 		String lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.ALL_DEFAULT);
 		assertEqualString(lab, "asList(T...) <T>");
-		
+
 		lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.M_PARAMETER_NAMES);
 		assertEqualString(lab, "asList(arg0)");
-		
+
 		lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.M_PARAMETER_TYPES);
 		assertEqualString(lab, "asList(T...)");
-		
+
 		lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.M_PARAMETER_NAMES | JavaElementLabels.M_PARAMETER_TYPES);
 		assertEqualString(lab, "asList(T... arg0)");
-		
+
 		lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.ALL_DEFAULT | JavaElementLabels.USE_RESOLVED);
 		assertEqualString(lab, "asList(Object...) <Object>");
-		
+
 		lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.M_PARAMETER_TYPES | JavaElementLabels.USE_RESOLVED);
 		assertEqualString(lab, "asList(Object...)");
 	}
@@ -582,20 +582,20 @@ public class JavaElementLabelsTest extends CoreTests {
 	public void testMethodLabelVarargsReference1() throws Exception {
 		assertMethodLabelVarargsReference("1");
 	}
-	
+
 	public void testMethodLabelVarargsReference2() throws Exception {
 		assertMethodLabelVarargsReference("1, 2");
 	}
-	
+
 	public void testMethodLabelVarargsReference3() throws Exception {
 		assertMethodLabelVarargsReference("1, 2, Integer.valueOf(3)");
 	}
-	
+
 	private void assertMethodLabelVarargsReference(String args) throws CoreException, JavaModelException {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("import java.util.Arrays;\n");
 		buf.append("public class Varargs {\n");
@@ -607,7 +607,7 @@ public class JavaElementLabelsTest extends CoreTests {
 		ICompilationUnit cu= pack1.createCompilationUnit("Varargs.java", content, false, null);
 
 		IJavaElement elem= cu.codeSelect(content.indexOf("asList"), 0)[0];
-		
+
 		String lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.ALL_DEFAULT);
 		assertEqualString(lab, "asList(T...) <T>");
 
@@ -616,22 +616,22 @@ public class JavaElementLabelsTest extends CoreTests {
 
 		lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.M_PARAMETER_TYPES);
 		assertEqualString(lab, "asList(T...)");
-		
+
 		lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.M_PARAMETER_NAMES | JavaElementLabels.M_PARAMETER_TYPES);
 		assertEqualString(lab, "asList(T... arg0)");
-		
+
 		lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.ALL_DEFAULT | JavaElementLabels.USE_RESOLVED);
 		assertEqualString(lab, "asList(Integer...) <Integer>");
-		
+
 		lab= JavaElementLabels.getTextLabel(elem, JavaElementLabels.M_PARAMETER_TYPES | JavaElementLabels.USE_RESOLVED);
 		assertEqualString(lab, "asList(Integer...)");
 	}
-	
-	
+
+
 	public void testMethodLabelAnnotatedParameters() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.test;\n");
 		buf.append("\n");
 		buf.append("import java.lang.annotation.Retention;\n");
