@@ -101,7 +101,7 @@ public class FatJarExportTests extends TestCase {
 	private static final Class<FatJarExportTests> THIS= FatJarExportTests.class;
 
 	private static final int JAVA_RUN_TIMEOUT= 50; // 10th of a second
-	
+
 	public static Test suite() {
 		return setUpTest(new TestSuite(THIS));
 	}
@@ -126,7 +126,7 @@ public class FatJarExportTests extends TestCase {
 
 		fMainRoot= JavaProjectHelper.addSourceContainer(fProject, "src"); //$NON-NLS-1$
 		IPackageFragment fragment= fMainRoot.createPackageFragment("org.eclipse.jdt.ui.test", true, null); //$NON-NLS-1$
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package org.eclipse.jdt.ui.test;\n"); //$NON-NLS-1$
 		buf.append("import mylib.Foo;\n"); //$NON-NLS-1$
 		buf.append("public class Main {\n"); //$NON-NLS-1$
@@ -145,7 +145,7 @@ public class FatJarExportTests extends TestCase {
 	}
 
 	private static String getFooContent() {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package mylib;\n"); //$NON-NLS-1$
 		buf.append("public class Foo {\n"); //$NON-NLS-1$
 		buf.append("    public Foo() {\n"); //$NON-NLS-1$
@@ -188,7 +188,7 @@ public class FatJarExportTests extends TestCase {
 		// check for successful call of Foo
 		String expected= "created mylib.Foo\n"; //$NON-NLS-1$
 		assertEquals(expected, stdout);
-		
+
 		return data;
 	}
 
@@ -201,25 +201,24 @@ public class FatJarExportTests extends TestCase {
 
 		// set compression
 		data.setCompress(compressJar);
-		
-		//create archive
-		ZipFile generatedArchive= createArchive(data);
 
 		//assert archive content as expected
-		assertNotNull(generatedArchive);
-		assertNotNull(generatedArchive.getEntry("org/eclipse/jdt/ui/test/Main.class")); //$NON-NLS-1$
-		assertNotNull(generatedArchive.getEntry("mylib/Foo.class")); //$NON-NLS-1$
-		assertNotNull(generatedArchive.getEntry("mylib/Foo$FooInner.class")); //$NON-NLS-1$
-		assertNotNull(generatedArchive.getEntry("mylib/Foo$FooInner$FooInnerInner.class")); //$NON-NLS-1$
-		
-		generatedArchive.close();
+		try ( //create archive
+			ZipFile generatedArchive = createArchive(data)) {
+			//assert archive content as expected
+			assertNotNull(generatedArchive);
+			assertNotNull(generatedArchive.getEntry("org/eclipse/jdt/ui/test/Main.class")); //$NON-NLS-1$
+			assertNotNull(generatedArchive.getEntry("mylib/Foo.class")); //$NON-NLS-1$
+			assertNotNull(generatedArchive.getEntry("mylib/Foo$FooInner.class")); //$NON-NLS-1$
+			assertNotNull(generatedArchive.getEntry("mylib/Foo$FooInner$FooInnerInner.class")); //$NON-NLS-1$
+		}
 
 		MultiStatus status= new MultiStatus(JavaUI.ID_PLUGIN, 0, "", null); //$NON-NLS-1$
-		
+
 		FatJarAntExporter antExporter= libraryHandler.getAntExporter(antScriptLocation(testName), data.getAbsoluteJarLocation(), createTempLaunchConfig(project));
 		antExporter.run(status);
 		assertTrue(getProblems(status), status.getSeverity() == IStatus.OK || status.getSeverity() == IStatus.INFO);
-		
+
 		return data;
 	}
 
@@ -233,34 +232,33 @@ public class FatJarExportTests extends TestCase {
 		// set compression
 		data.setCompress(compressJar);
 
-		//create archive
-		ZipFile generatedArchive= createArchive(data);
-
 		//assert archive content as expected
-		assertNotNull(generatedArchive);
-		assertNotNull(generatedArchive.getEntry("org/eclipse/jdt/ui/test/Main.class")); //$NON-NLS-1$
-		// get loader entry
-		ZipEntry loaderClassEntry= generatedArchive.getEntry("org/eclipse/jdt/internal/jarinjarloader/JarRsrcLoader.class"); //$NON-NLS-1$
-		assertNotNull(loaderClassEntry);
-		// check version of class file JarRsrcLoader (jdk 1.3.1 = version 45.3)
-		InputStream in = generatedArchive.getInputStream(loaderClassEntry);
-		int magic = 0;
-		for (int i= 0; i < 4; i++)
-			magic = (magic << 8) + in.read();
-		int minorVersion = ((in.read() << 8) + in.read());
-		int majorVersion = ((in.read() << 8) + in.read());
-		in.close();
-		assertEquals("loader is a class file", 0xCAFEBABE, magic); //$NON-NLS-1$
-		assertEquals("loader compiled with JDK 1.3.1", "45.3", majorVersion + "." + minorVersion); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
-		
-		generatedArchive.close();
+		try ( //create archive
+			ZipFile generatedArchive = createArchive(data)) {
+			//assert archive content as expected
+			assertNotNull(generatedArchive);
+			assertNotNull(generatedArchive.getEntry("org/eclipse/jdt/ui/test/Main.class")); //$NON-NLS-1$
+			// get loader entry
+			ZipEntry loaderClassEntry= generatedArchive.getEntry("org/eclipse/jdt/internal/jarinjarloader/JarRsrcLoader.class"); //$NON-NLS-1$
+			assertNotNull(loaderClassEntry);
+			// check version of class file JarRsrcLoader (jdk 1.6 = version 50.0)
+			InputStream in = generatedArchive.getInputStream(loaderClassEntry);
+			int magic = 0;
+			for (int i= 0; i < 4; i++)
+				magic = (magic << 8) + in.read();
+			int minorVersion = ((in.read() << 8) + in.read());
+			int majorVersion = ((in.read() << 8) + in.read());
+			in.close();
+			assertEquals("loader is a class file", 0xCAFEBABE, magic); //$NON-NLS-1$
+			assertEquals("loader compiled with JDK 1.6", "50.0", majorVersion + "." + minorVersion); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+		}
 
 		MultiStatus status= new MultiStatus(JavaUI.ID_PLUGIN, 0, "", null); //$NON-NLS-1$
-		
+
 		FatJarAntExporter antExporter= libraryHandler.getAntExporter(antScriptLocation(testName), data.getAbsoluteJarLocation(), createTempLaunchConfig(project));
 		antExporter.run(status);
 		assertTrue(getProblems(status), status.getSeverity() == IStatus.OK || status.getSeverity() == IStatus.INFO);
-		
+
 		// check that jar-rsrc-loader.zip file was created next to build.xml
 		IPath zipLocation= antScriptLocation(testName).removeLastSegments(1).append(FatJarRsrcUrlBuilder.JAR_RSRC_LOADER_ZIP);
 		assertTrue("loader zip missing: " + zipLocation.toOSString(), zipLocation.toFile().exists());
@@ -278,20 +276,19 @@ public class FatJarExportTests extends TestCase {
 		// set compression
 		data.setCompress(compressJar);
 
-		//create archive
-		ZipFile generatedArchive= createArchive(data);
-
 		//assert archive content as expected
-		assertNotNull(generatedArchive);
-		assertNotNull(generatedArchive.getEntry("org/eclipse/jdt/ui/test/Main.class")); //$NON-NLS-1$
+		try ( //create archive
+			ZipFile generatedArchive = createArchive(data)) {
+			//assert archive content as expected
+			assertNotNull(generatedArchive);
+			assertNotNull(generatedArchive.getEntry("org/eclipse/jdt/ui/test/Main.class")); //$NON-NLS-1$
 
-		// check for libraries sub-folder
-		File jarFile= new File(generatedArchive.getName());
-		String subFolderName= jarFile.getName().replaceFirst("^(.*)[.]jar$", "$1_lib"); //$NON-NLS-1$//$NON-NLS-2$
-		File subFolderDir= new File(jarFile.getParentFile(), subFolderName);
-		assertTrue("actual: '" + subFolderDir.toString() + "'", subFolderDir.isDirectory()); //$NON-NLS-1$//$NON-NLS-2$
-
-		generatedArchive.close();
+			// check for libraries sub-folder
+			File jarFile= new File(generatedArchive.getName());
+			String subFolderName= jarFile.getName().replaceFirst("^(.*)[.]jar$", "$1_lib"); //$NON-NLS-1$//$NON-NLS-2$
+			File subFolderDir= new File(jarFile.getParentFile(), subFolderName);
+			assertTrue("actual: '" + subFolderDir.toString() + "'", subFolderDir.isDirectory()); //$NON-NLS-1$//$NON-NLS-2$
+		}
 
 		MultiStatus status= new MultiStatus(JavaUI.ID_PLUGIN, 0, "", null); //$NON-NLS-1$
 
@@ -305,16 +302,14 @@ public class FatJarExportTests extends TestCase {
 	private static void buildProject() throws CoreException {
 		ResourcesPlugin.getWorkspace().build(IncrementalProjectBuilder.FULL_BUILD, null);
 
-		IMarker[] markers= ResourcesPlugin.getWorkspace().getRoot().findMarkers(null, true, IResource.DEPTH_INFINITE);
-		for (int i= 0; i < markers.length; i++) {
-			IMarker marker= markers[i];
+		for (IMarker marker : ResourcesPlugin.getWorkspace().getRoot().findMarkers(null, true, IResource.DEPTH_INFINITE)) {
 			if (marker.getAttribute(IMarker.SEVERITY, IMarker.SEVERITY_INFO) == IMarker.SEVERITY_ERROR) {
 				assertTrue((String) marker.getAttribute(IMarker.MESSAGE), false);
 			}
 		}
 	}
 
-	
+
 	private static IPath antScriptLocation(String testName) {
 		return ResourcesPlugin.getWorkspace().getRoot().getLocation().append("build_" + testName + ".xml"); //$NON-NLS-1$//$NON-NLS-2$
 	}
@@ -323,7 +318,7 @@ public class FatJarExportTests extends TestCase {
 		JarPackageData data= new JarPackageData();
 		data.setOverwrite(true);
 		data.setIncludeDirectoryEntries(true);
-		
+
 		IPath destination= ResourcesPlugin.getWorkspace().getRoot().getLocation().append(testName + ".jar"); //$NON-NLS-1$
 		data.setJarLocation(destination);
 
@@ -333,18 +328,17 @@ public class FatJarExportTests extends TestCase {
 		Object[] children= FatJarPackageWizardPage.getSelectedElementsWithoutContainedChildren(launchConfig, data, new BusyIndicatorRunnableContext(), status);
 		assertTrue(getProblems(status), status.getSeverity() == IStatus.OK || status.getSeverity() == IStatus.INFO);
 		data.setElements(children);
-		
+
 		data.setJarBuilder(libraryHandler.getBuilder(data));
-		
+
 		return data;
 	}
 
 	private static String getProblems(MultiStatus status) {
-		StringBuffer result= new StringBuffer();
+		StringBuilder result= new StringBuilder();
 
-		IStatus[] children= status.getChildren();
-		for (int i= 0; i < children.length; i++) {
-			result.append(children[i].getMessage()).append("\n"); //$NON-NLS-1$
+		for (IStatus child : status.getChildren()) {
+			result.append(child.getMessage()).append("\n"); //$NON-NLS-1$
 		}
 
 		return result.toString();
@@ -352,7 +346,7 @@ public class FatJarExportTests extends TestCase {
 
 	/*
 	 *  From org.eclipse.jdt.internal.debug.ui.launcher.JavaApplicationLaunchShortcut
-	 * 
+	 *
 	 *  For internal use only (testing), clients must not call.
 	 */
 	public static ILaunchConfiguration createTempLaunchConfig(IJavaProject project) {
@@ -440,7 +434,7 @@ public class FatJarExportTests extends TestCase {
 		if (exitCode != 0) {
 			String stdout= processes[0].getStreamsProxy().getOutputStreamMonitor().getContents();
 			String errout= processes[0].getStreamsProxy().getErrorStreamMonitor().getContents();
-			
+
 			throw new CoreException(new Status(IStatus.ERROR, JavaPlugin.getPluginId(), "Run failed: exitcode=" + exitCode + ", stdout=[" + stdout + "], stderr=[" + errout + "]")); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
 		} else {
 			return processes[0].getStreamsProxy().getOutputStreamMonitor().getContents();
@@ -471,7 +465,7 @@ public class FatJarExportTests extends TestCase {
 
 	private static void assertAntScriptCopy(String archiveName, IPath antScriptLocation, String[] filesets, String[] zipfilesets) throws Exception {
 		String subfolderName= archiveName.replaceFirst("^(.*)[.]jar$", "$1_lib"); //$NON-NLS-1$//$NON-NLS-2$
-			
+
 		String projectNameValue= "Create Runnable Jar for Project TestSetupProject"; //$NON-NLS-1$
 		projectNameValue+= " with libraries in sub-folder"; //$NON-NLS-1$
 
@@ -502,8 +496,8 @@ public class FatJarExportTests extends TestCase {
 		for (int i= 0; i < xmlFilesets.getLength(); i++) {
 			String dir= ((Element)xmlFilesets.item(i)).getAttribute("dir"); //$NON-NLS-1$
 			boolean found= false;
-			for (int j= 0; j < filesets.length; j++) {
-				if (dir.endsWith(filesets[j])) {
+			for (String fileset : filesets) {
+				if (dir.endsWith(fileset)) {
 					found= true;
 					break;
 				}
@@ -524,15 +518,15 @@ public class FatJarExportTests extends TestCase {
 			String absLibPath= ((Element)xmlCopies.item(i)).getAttribute("file"); //$NON-NLS-1$
 			String libName= new File(absLibPath).getName();
 			boolean found= false;
-			for (int j= 0; j < zipfilesets.length; j++) {
-				if (libName.equals(zipfilesets[j])) {
+			for (String zipfileset : zipfilesets) {
+				if (libName.equals(zipfileset)) {
 					found= true;
 					break;
 				}
 			}
 			assertTrue("find zipfileset lib: '" + libName + "'", found); //$NON-NLS-1$  //$NON-NLS-2$
 		}
-		
+
 	}
 
 	private static void assertAntScriptPackage(String archiveName, IPath antScriptLocation, String[] filesets, String[] zipfilesets) throws Exception {
@@ -577,8 +571,8 @@ public class FatJarExportTests extends TestCase {
 		for (int i= 0; i < xmlFilesets.getLength(); i++) {
 			String dir= ((Element)xmlFilesets.item(i)).getAttribute("dir"); //$NON-NLS-1$
 			boolean found= false;
-			for (int j= 0; j < filesets.length; j++) {
-				if (dir.endsWith(filesets[j])) {
+			for (String fileset : filesets) {
+				if (dir.endsWith(fileset)) {
 					found= true;
 					break;
 				}
@@ -589,12 +583,12 @@ public class FatJarExportTests extends TestCase {
 		for (int i= 0; i < xmlZipfilesets.getLength(); i++) {
 			String libName= ((Element)xmlZipfilesets.item(i)).getAttribute("includes"); //$NON-NLS-1$
 			boolean found= false;
-			if (libName.equals("")) { //$NON-NLS-1$
+			if (libName.isEmpty()) {
 				libName= ((Element)xmlZipfilesets.item(i)).getAttribute("src"); //$NON-NLS-1$
-				found= libName.equals(FatJarRsrcUrlBuilder.JAR_RSRC_LOADER_ZIP); //$NON-NLS-1$
+				found= libName.equals(FatJarRsrcUrlBuilder.JAR_RSRC_LOADER_ZIP);
 			}
-			for (int j= 0; j < zipfilesets.length; j++) {
-				if (libName.equals(zipfilesets[j])) {
+			for (String zipfileset : zipfilesets) {
+				if (libName.equals(zipfileset)) {
 					found= true;
 					break;
 				}
@@ -602,7 +596,7 @@ public class FatJarExportTests extends TestCase {
 			assertTrue("find zipfileset lib: '" + libName + "'", found); //$NON-NLS-1$  //$NON-NLS-2$
 		}
 	}
-	
+
 	private static void assertAntScriptExtract(String archiveName, IPath antScriptLocation, String[] filesets, String[] zipfilesets) throws Exception {
 		String projectNameValue= "Create Runnable Jar for Project TestSetupProject"; //$NON-NLS-1$
 
@@ -637,8 +631,8 @@ public class FatJarExportTests extends TestCase {
 		for (int i= 0; i < xmlFilesets.getLength(); i++) {
 			String dir= ((Element)xmlFilesets.item(i)).getAttribute("dir"); //$NON-NLS-1$
 			boolean found= false;
-			for (int j= 0; j < filesets.length; j++) {
-				if (dir.endsWith(filesets[j])) {
+			for (String fileset : filesets) {
+				if (dir.endsWith(fileset)) {
 					found= true;
 					break;
 				}
@@ -651,8 +645,8 @@ public class FatJarExportTests extends TestCase {
 			assertEquals("META-INF/*.SF", excludes); //$NON-NLS-1$
 			String src= ((Element)xmlZipfilesets.item(i)).getAttribute("src"); //$NON-NLS-1$
 			boolean found= false;
-			for (int j= 0; j < zipfilesets.length; j++) {
-				if (src.endsWith(zipfilesets[j])) {
+			for (String zipfileset : zipfilesets) {
+				if (src.endsWith(zipfileset)) {
 					found= true;
 					break;
 				}
@@ -663,24 +657,19 @@ public class FatJarExportTests extends TestCase {
 
 	/**
 	 * Helper class to open a xml file
-	 * 
+	 *
 	 * @param xmlFilePath path to xml file to read
 	 * @return root element of the parsed xml-document
 	 * @throws Exception if anything went wrong
 	 */
 	private static Element readXML(IPath xmlFilePath) throws Exception {
-		InputStream in = null;
-		try {
-			in = new FileInputStream(xmlFilePath.toFile());
+		try (InputStream in = new FileInputStream(xmlFilePath.toFile())) {
 			DocumentBuilder parser= DocumentBuilderFactory.newInstance().newDocumentBuilder();
 			parser.setErrorHandler(new DefaultHandler());
 			Element root= parser.parse(new InputSource(in)).getDocumentElement();
 			in.close();
-			
+
 			return root;
-		} finally {
-			if (in != null)
-				in.close();
 		}
 	}
 
@@ -693,7 +682,7 @@ public class FatJarExportTests extends TestCase {
 			assertAntScript(data, antScriptLocation(getName()), new ExtractLibraryHandler(),
 					new String[] { "TestSetupProject/bin" }, //$NON-NLS-1$
 					new String[] { "rtstubs15.jar" }); //$NON-NLS-1$
-			
+
 			// Jar-in-Jar loader
 			data= createAndRunFatJar(fProject, getName() + "_JiJ", true, new PackageLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_JiJ"), //$NON-NLS-1$
@@ -710,7 +699,7 @@ public class FatJarExportTests extends TestCase {
 			pack.delete(true, null);
 		}
 	}
-	
+
 
 	public void testExportSrcRootWithOutputFolder() throws Exception {
 		IPackageFragmentRoot root= JavaProjectHelper.addSourceContainer(fProject, "other", new IPath[0], new IPath[0], "otherout"); //$NON-NLS-1$  //$NON-NLS-2$
@@ -751,7 +740,7 @@ public class FatJarExportTests extends TestCase {
 			assertAntScript(data, antScriptLocation(getName()),
 					new ExtractLibraryHandler(),
 					new String[] { "TestSetupProject/bin" }, new String[] { "rtstubs15.jar" }); //$NON-NLS-1$ //$NON-NLS-2$
-			
+
 			// Jar-in-Jar loader
 			data= createAndRunFatJar(fProject, getName() + "_JiJ", true, new PackageLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_JiJ"), //$NON-NLS-1$
@@ -785,7 +774,7 @@ public class FatJarExportTests extends TestCase {
 			assertAntScript(data, antScriptLocation(getName()),
 					new ExtractLibraryHandler(),
 					new String[] { "TestSetupProject/bin", "OtherProject/bin" }, new String[] { "rtstubs15.jar" }); //$NON-NLS-1$  //$NON-NLS-2$  //$NON-NLS-3$
-			
+
 			// Jar-in-Jar loader
 			data= createAndRunFatJar(fProject, getName() + "_JiJ", true, new PackageLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_JiJ"), //$NON-NLS-1$
@@ -815,14 +804,14 @@ public class FatJarExportTests extends TestCase {
 					new ExtractLibraryHandler(),
 					new String[] { "TestSetupProject/bin" }, //$NON-NLS-1$
 					new String[] { "rtstubs15.jar", "TestSetupProject/mylib_stdout.jar" }); //$NON-NLS-1$  //$NON-NLS-2$
-			
+
 			// Jar-in-Jar loader
 			data= createAndRunFatJar(fProject, getName() + "_JiJ", true, new PackageLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_JiJ"), //$NON-NLS-1$
 					new PackageLibraryHandler(),
 					new String[] { "TestSetupProject/bin" },//$NON-NLS-1$
 					new String[] { "rtstubs15.jar", "mylib_stdout.jar" }); //$NON-NLS-1$  //$NON-NLS-2$
-			
+
 			// sub-folder libraries
 			data= createAndRunFatJar(fProject, getName() + "_SL", true, new CopyLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_SL"), //$NON-NLS-1$
@@ -843,14 +832,14 @@ public class FatJarExportTests extends TestCase {
 			assertAntScript(data, antScriptLocation(getName()),
 					new ExtractLibraryHandler(),
 					new String[] { "TestSetupProject/bin" }, new String[] { "rtstubs15.jar", "TestSetupProject/mylib_stdout.jar" }); //$NON-NLS-1$  //$NON-NLS-2$  //$NON-NLS-3$
-			
+
 			// Jar-in-Jar loader
 			data= createAndRunFatJar(fProject, getName() + "_JiJ", true, new PackageLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_JiJ"), //$NON-NLS-1$
 					new PackageLibraryHandler(),
 					new String[] { "TestSetupProject/bin" }, //$NON-NLS-1$
 					new String[] { "rtstubs15.jar", "mylib_stdout.jar" }); //$NON-NLS-1$  //$NON-NLS-2$
-			
+
 			// sub-folder libraries
 			data= createAndRunFatJar(fProject, getName() + "_SL", true, new CopyLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_SL"), //$NON-NLS-1$
@@ -872,7 +861,7 @@ public class FatJarExportTests extends TestCase {
 			assertAntScript(data, antScriptLocation(getName()),
 					new ExtractLibraryHandler(),
 					new String[] { "TestSetupProject/bin" }, new String[] { "rtstubs15.jar", "testresources/mylib_stdout.jar" }); //$NON-NLS-1$  //$NON-NLS-2$  //$NON-NLS-3$
-			
+
 			// Jar-in-Jar loader
 			data= createAndRunFatJar(fProject, getName() + "_JiJ", true, new PackageLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_JiJ"), //$NON-NLS-1$
@@ -900,14 +889,14 @@ public class FatJarExportTests extends TestCase {
 			assertAntScript(data, antScriptLocation(getName()),
 					new ExtractLibraryHandler(),
 					new String[] { "TestSetupProject/bin", "TestSetupProject/cf" }, new String[] { "rtstubs15.jar" }); //$NON-NLS-1$  //$NON-NLS-2$  //$NON-NLS-3$
-			
+
 			// Jar-in-Jar loader
 			data= createAndRunFatJar(fProject, getName() + "_JiJ", true, new PackageLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_JiJ"), //$NON-NLS-1$
 					new PackageLibraryHandler(),
 					new String[] { "TestSetupProject/bin", "TestSetupProject/cf" },//$NON-NLS-1$  //$NON-NLS-2$
 					new String[] { "rtstubs15.jar" }); //$NON-NLS-1$
-			
+
 			// sub-folder libraries
 			data= createAndRunFatJar(fProject, getName() + "_SL", true, new CopyLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_SL"), //$NON-NLS-1$
@@ -929,14 +918,14 @@ public class FatJarExportTests extends TestCase {
 			assertAntScript(data, antScriptLocation(getName()),
 					new ExtractLibraryHandler(),
 					new String[] { "TestSetupProject/bin" }, new String[] { "rtstubs15.jar", "testresources/mylib_stdout.jar" }); //$NON-NLS-1$  //$NON-NLS-2$  //$NON-NLS-3$
-			
+
 			// Jar-in-Jar loader
 			data= createAndRunFatJar(fProject, getName() + "_JiJ", true, new PackageLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_JiJ"), //$NON-NLS-1$
 					new PackageLibraryHandler(),
 					new String[] { "TestSetupProject/bin" }, //$NON-NLS-1$
 					new String[] { "rtstubs15.jar", "mylib_stdout.jar" }); //$NON-NLS-1$  //$NON-NLS-2$
-			
+
 			// sub-folder libraries
 			data= createAndRunFatJar(fProject, getName() + "_SL", true, new CopyLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_SL"), //$NON-NLS-1$
@@ -957,7 +946,7 @@ public class FatJarExportTests extends TestCase {
 			assertAntScript(data, antScriptLocation(getName()),
 					new ExtractLibraryHandler(),
 					new String[] { "TestSetupProject/bin" }, new String[] { "rtstubs15.jar", "TestSetupProject/mylib_sig.jar" }); //$NON-NLS-1$  //$NON-NLS-2$  //$NON-NLS-3$
-			
+
 			// Jar-in-Jar loader
 			data= createAndRunFatJar(fProject, getName() + "_JiJ", true, new PackageLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_JiJ"), //$NON-NLS-1$
@@ -974,7 +963,7 @@ public class FatJarExportTests extends TestCase {
 			JavaProjectHelper.removeFromClasspath(fProject, root.getPath());
 		}
 	}
-	
+
 	public void testExternalClassFolder() throws Exception {
 		File classFolder= JavaTestPlugin.getDefault().getFileInPlugin(new Path("testresources/externalClassFolder/"));//$NON-NLS-1$
 		assertTrue("class folder not found", classFolder != null && classFolder.exists());//$NON-NLS-1$
@@ -985,19 +974,19 @@ public class FatJarExportTests extends TestCase {
 			assertAntScript(data, antScriptLocation(getName()),
 					new ExtractLibraryHandler(),
 					new String[] { "TestSetupProject/bin", "testresources/externalClassFolder" }, new String[] { "rtstubs15.jar" }); //$NON-NLS-1$  //$NON-NLS-2$  //$NON-NLS-3$
-			
+
 			// Jar-in-Jar loader
 			data= createAndRunFatJar(fProject, getName() + "_JiJ", true, new PackageLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_JiJ"), //$NON-NLS-1$
 					new PackageLibraryHandler(),
 					new String[] { "TestSetupProject/bin", "testresources/externalClassFolder" }, //$NON-NLS-1$
-					new String[] { "rtstubs15.jar" }); //$NON-NLS-1$  //$NON-NLS-2$
+					new String[] { "rtstubs15.jar" }); //$NON-NLS-1$
 
 			// sub-folder libraries
 			data= createAndRunFatJar(fProject, getName() + "_SL", true, new CopyLibraryHandler()); //$NON-NLS-1$
 			assertAntScript(data, antScriptLocation(getName() + "_SL"), //$NON-NLS-1$
 					new CopyLibraryHandler(), new String[] { "TestSetupProject/bin", "testresources/externalClassFolder" }, //$NON-NLS-1$
-					new String[] { "rtstubs15.jar" }); //$NON-NLS-1$  //$NON-NLS-2$
+					new String[] { "rtstubs15.jar" }); //$NON-NLS-1$
 		} finally {
 			JavaProjectHelper.removeFromClasspath(fProject, externalRoot.getPath());
 		}
