@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2017, 2018 GK Software AG and others.
+ * Copyright (c) 2017, 2020 GK Software AG and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,11 +13,19 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.quickfix;
 
+import static org.junit.Assert.assertEquals;
+
 import java.io.File;
 import java.util.ArrayList;
 import java.util.Hashtable;
 import java.util.Map;
 
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
 import org.osgi.framework.Bundle;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
@@ -45,36 +53,25 @@ import org.eclipse.jdt.internal.core.manipulation.CodeTemplateContextType;
 import org.eclipse.jdt.internal.core.manipulation.StubUtility;
 
 import org.eclipse.jdt.ui.PreferenceConstants;
-import org.eclipse.jdt.ui.tests.core.Java18ProjectTestSetup;
+import org.eclipse.jdt.ui.tests.core.rules.Java18ProjectTestSetup;
+import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 import org.eclipse.jdt.ui.text.java.IJavaCompletionProposal;
 import org.eclipse.jdt.ui.text.java.correction.CUCorrectionProposal;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
+@RunWith(JUnit4.class)
 public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 
-	private static final Class<NullAnnotationsQuickFixTest18> THIS= NullAnnotationsQuickFixTest18.class;
+	@Rule
+    public ProjectTestSetup projectsetup = new Java18ProjectTestSetup();
+
 	private IJavaProject fJProject1;
 	private IPackageFragmentRoot fSourceFolder;
 	private String ANNOTATION_JAR_PATH;
 
-	public NullAnnotationsQuickFixTest18(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return new Java18ProjectTestSetup(new TestSuite(THIS));
-	}
-
-	public static Test setUpTest(Test test) {
-		return new Java18ProjectTestSetup(test);
-	}
-
-	@Override
-	protected void setUp() throws Exception {
+	@Before
+	public void setUp() throws Exception {
 		Hashtable<String, String> options= TestOptions.getDefaultOptions();
 		options.put(DefaultCodeFormatterConstants.FORMATTER_TAB_CHAR, JavaCore.SPACE);
 		options.put(DefaultCodeFormatterConstants.FORMATTER_TAB_SIZE, "4");
@@ -115,8 +112,8 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 	}
 
-	@Override
-	protected void tearDown() throws Exception {
+	@After
+	public void tearDown() throws Exception {
 		JavaProjectHelper.clear(fJProject1, Java18ProjectTestSetup.getDefaultClasspath());
 	}
 
@@ -128,6 +125,7 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 	 * - change local to nonnull  (covariant return)
 	 * - change super to nonnull  (equal)
 	 */
+	@Test
 	public void testBug499716_a() throws Exception {
 		fJProject1.setOption(JavaCore.COMPILER_INHERIT_NULL_ANNOTATIONS, JavaCore.ENABLED);
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
@@ -135,7 +133,7 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("@org.eclipse.jdt.annotation.NonNullByDefault\n");
 		buf.append("package test1;\n");
 		pack1.createCompilationUnit("package-info.java", buf.toString(), false, null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("import org.eclipse.jdt.annotation.*;\n");
@@ -235,6 +233,7 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 	 * - change super to nonnull
 	 * No covariant parameter!
 	 */
+	@Test
 	public void testBug499716_b() throws Exception {
 		fJProject1.setOption(JavaCore.COMPILER_INHERIT_NULL_ANNOTATIONS, JavaCore.ENABLED);
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
@@ -242,7 +241,7 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("@org.eclipse.jdt.annotation.NonNullByDefault\n");
 		buf.append("package test1;\n");
 		pack1.createCompilationUnit("package-info.java", buf.toString(), false, null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("import org.eclipse.jdt.annotation.*;\n");
@@ -312,6 +311,7 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 	 * - change super to nullable
 	 * No contravariant return!
 	 */
+	@Test
 	public void testBug499716_c() throws Exception {
 		fJProject1.setOption(JavaCore.COMPILER_INHERIT_NULL_ANNOTATIONS, JavaCore.ENABLED);
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
@@ -392,13 +392,14 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 	 * - change super to implicit nonnull (by removing to make default apply)
 	 * No covariant parameter!
 	 */
+	@Test
 	public void testBug499716_d() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("@org.eclipse.jdt.annotation.NonNullByDefault\n");
 		buf.append("package test1;\n");
 		pack1.createCompilationUnit("package-info.java", buf.toString(), true, null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("import org.eclipse.jdt.annotation.*;\n");
@@ -465,13 +466,14 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 	 * Test that no redundant null annotations are created.
 	 * Variation 1: @NonNullByDefault applies everywhere, type is non-null
 	 */
+	@Test
 	public void test443146a() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("@org.eclipse.jdt.annotation.NonNullByDefault\n");
 		buf.append("package test1;\n");
 		pack1.createCompilationUnit("package-info.java", buf.toString(), true, null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
@@ -556,13 +558,14 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 	 * Variation 2: @NonNullByDefault applies everywhere
 	 * Note, that there is no @Nullable generated for the 'local variable' case.
 	 */
+	@Test
 	public void test443146b() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("@org.eclipse.jdt.annotation.NonNullByDefault\n");
 		buf.append("package test1;\n");
 		pack1.createCompilationUnit("package-info.java", buf.toString(), true, null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
@@ -646,13 +649,14 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 	 * Test that no redundant null annotations are created.
 	 * Variation 3: @NonNullByDefault doesn't apply at the target locations (so annotations ARE expected, but not for the local variable)
 	 */
+	@Test
 	public void test443146c() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("@org.eclipse.jdt.annotation.NonNullByDefault\n");
 		buf.append("package test1;\n");
 		pack1.createCompilationUnit("package-info.java", buf.toString(), true, null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
@@ -668,16 +672,16 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("	}\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("Test.java", buf.toString(), false, null);
-	
+
 		CompilationUnit astRoot= getASTRoot(cu);
 		ArrayList<IJavaCompletionProposal> proposals= collectCorrections(cu, astRoot);
 		assertNumberOfProposals(proposals, 4);
 		CUCorrectionProposal proposal= (CUCorrectionProposal)proposals.get(0);
-	
+
 		assertEqualString(proposal.getDisplayString(), "Create field 'x'");
-	
+
 		String preview= getPreviewContent(proposal);
-	
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
@@ -695,13 +699,13 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("	}\n");
 		buf.append("}\n");
 		assertEqualString(preview, buf.toString());
-	
+
 		proposal= (CUCorrectionProposal)proposals.get(1);
-	
+
 		assertEqualString(proposal.getDisplayString(), "Create parameter 'x'");
-	
+
 		preview= getPreviewContent(proposal);
-	
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
@@ -717,13 +721,13 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("	}\n");
 		buf.append("}\n");
 		assertEqualString(preview, buf.toString());
-	
+
 		proposal= (CUCorrectionProposal)proposals.get(2);
-	
+
 		assertEqualString(proposal.getDisplayString(), "Create local variable 'x'");
-	
+
 		preview= getPreviewContent(proposal);
-	
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
@@ -744,6 +748,7 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 	/*
 	 * Test that no null annotations are created in inapplicable location, here: cast.
 	 */
+	@Test
 	public void test443146d() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
@@ -757,16 +762,16 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("	}\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("Test.java", buf.toString(), false, null);
-	
+
 		CompilationUnit astRoot= getASTRoot(cu);
 		ArrayList<IJavaCompletionProposal> proposals= collectCorrections(cu, astRoot);
 		assertNumberOfProposals(proposals, 3);
 		CUCorrectionProposal proposal= (CUCorrectionProposal)proposals.get(0);
-	
+
 		assertEqualString(proposal.getDisplayString(), "Add cast to 'Map<String, Integer>'");
-	
+
 		String preview= getPreviewContent(proposal);
-	
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
@@ -782,13 +787,14 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 	/*
 	 * Variation: @NonNullByDefault applies everywhere, type is a type variable
 	 */
+	@Test
 	public void test443146e() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("@org.eclipse.jdt.annotation.NonNullByDefault\n");
 		buf.append("package test1;\n");
 		pack1.createCompilationUnit("package-info.java", buf.toString(), true, null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
@@ -872,13 +878,14 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 	/*
 	 * Variation: @NonNullByDefault applies everywhere, type contains explicit @NonNull on wildcard and type variable
 	 */
+	@Test
 	public void test443146f() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
 		buf.append("@org.eclipse.jdt.annotation.NonNullByDefault\n");
 		buf.append("package test1;\n");
 		pack1.createCompilationUnit("package-info.java", buf.toString(), true, null);
-		
+
 		buf= new StringBuffer();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
@@ -958,6 +965,7 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("}\n");
 		assertEqualString(preview, buf.toString());
 	}
+	@Test
 	public void testBug513682() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
@@ -996,6 +1004,7 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		assertEqualString(preview, buf.toString());
 	}
 
+	@Test
 	public void testBug513209a() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
@@ -1015,11 +1024,11 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("@NonNullByDefault\n");
 		buf.append("public class B extends A {\n");
 		buf.append("   @Override\n");
-		buf.append("   public void SomeMethod(\n"); 
-		buf.append("      String[] a)\n"); 
+		buf.append("   public void SomeMethod(\n");
+		buf.append("      String[] a)\n");
 		buf.append("   {\n");
 		buf.append("\n");
-		buf.append("   }\n"); 
+		buf.append("   }\n");
 		buf.append("}\n");
 		ICompilationUnit cu=pack1.createCompilationUnit("B.java", buf.toString(), false, null);
 
@@ -1038,15 +1047,16 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("@NonNullByDefault\n");
 		buf.append("public class B extends A {\n");
 		buf.append("   @Override\n");
-		buf.append("   public void SomeMethod(\n"); 
-		buf.append("      String @Nullable [] a)\n"); 
+		buf.append("   public void SomeMethod(\n");
+		buf.append("      String @Nullable [] a)\n");
 		buf.append("   {\n");
 		buf.append("\n");
-		buf.append("   }\n"); 
+		buf.append("   }\n");
 		buf.append("}\n");
 		assertEqualString(preview, buf.toString());
 	}
 
+	@Test
 	public void testBug513209b() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
@@ -1066,11 +1076,11 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("@NonNullByDefault\n");
 		buf.append("public class B extends A {\n");
 		buf.append("   @Override\n");
-		buf.append("   public void SomeMethod(\n"); 
-		buf.append("      int[][] a)\n"); 
+		buf.append("   public void SomeMethod(\n");
+		buf.append("      int[][] a)\n");
 		buf.append("   {\n");
 		buf.append("\n");
-		buf.append("   }\n"); 
+		buf.append("   }\n");
 		buf.append("}\n");
 		ICompilationUnit cu=pack1.createCompilationUnit("B.java", buf.toString(), false, null);
 
@@ -1089,15 +1099,16 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("@NonNullByDefault\n");
 		buf.append("public class B extends A {\n");
 		buf.append("   @Override\n");
-		buf.append("   public void SomeMethod(\n"); 
-		buf.append("      int @Nullable [][] a)\n"); 
+		buf.append("   public void SomeMethod(\n");
+		buf.append("      int @Nullable [][] a)\n");
 		buf.append("   {\n");
 		buf.append("\n");
-		buf.append("   }\n"); 
+		buf.append("   }\n");
 		buf.append("}\n");
 		assertEqualString(preview, buf.toString());
 	}
 
+	@Test
 	public void testBug513209c() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
@@ -1116,11 +1127,11 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("import org.eclipse.jdt.annotation.*;\n");
 		buf.append("public class B extends A {\n");
 		buf.append("   @Override\n");
-		buf.append("   public void SomeMethod(\n"); 
-		buf.append("      String @NonNull [] a)\n"); 
+		buf.append("   public void SomeMethod(\n");
+		buf.append("      String @NonNull [] a)\n");
 		buf.append("   {\n");
 		buf.append("\n");
-		buf.append("   }\n"); 
+		buf.append("   }\n");
 		buf.append("}\n");
 		ICompilationUnit cu=pack1.createCompilationUnit("B.java", buf.toString(), false, null);
 
@@ -1138,15 +1149,16 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("import org.eclipse.jdt.annotation.*;\n");
 		buf.append("public class B extends A {\n");
 		buf.append("   @Override\n");
-		buf.append("   public void SomeMethod(\n"); 
-		buf.append("      String @Nullable [] a)\n"); 
+		buf.append("   public void SomeMethod(\n");
+		buf.append("      String @Nullable [] a)\n");
 		buf.append("   {\n");
 		buf.append("\n");
-		buf.append("   }\n"); 
+		buf.append("   }\n");
 		buf.append("}\n");
 		assertEqualString(preview, buf.toString());
 	}
 
+	@Test
 	public void testBug513209d() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuffer buf= new StringBuffer();
@@ -1168,7 +1180,7 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("   public String[][][] SomeMethod()\n");
 		buf.append("   {\n");
 		buf.append("		return new String[0][][];\n");
-		buf.append("   }\n"); 
+		buf.append("   }\n");
 		buf.append("}\n");
 		ICompilationUnit cu=pack1.createCompilationUnit("B.java", buf.toString(), false, null);
 
@@ -1191,11 +1203,12 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		buf.append("   public String @NonNull [][][] SomeMethod()\n");
 		buf.append("   {\n");
 		buf.append("		return new String[0][][];\n");
-		buf.append("   }\n"); 
+		buf.append("   }\n");
 		buf.append("}\n");
 		assertEqualString(preview, buf.toString());
 	}
-	public void testBug525424() throws Exception {		
+	@Test
+	public void testBug525424() throws Exception {
 		Hashtable<String, String> options= JavaCore.getOptions();
 		try {
 			Hashtable<String, String> myOptions= new Hashtable<>(options);
@@ -1299,7 +1312,7 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 			JavaCore.setOptions(options);
 		}
 	}
-	public void runBug531511Test(boolean useTypeAnnotations, String defaultNullnessAnnotations, boolean expectReturnAnnotation, boolean expectParamAnnotation) throws Exception {		
+	public void runBug531511Test(boolean useTypeAnnotations, String defaultNullnessAnnotations, boolean expectReturnAnnotation, boolean expectParamAnnotation) throws Exception {
 		Map<String, String> options= fJProject1.getOptions(false);
 		try {
 			Hashtable<String, String> myOptions= new Hashtable<>(options);
@@ -1435,7 +1448,7 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 			buf.append("   @NonNull public Object someMethod(@NonNull Object p);\n");
 			buf.append("}\n");
 			api.createCompilationUnit("I.java", buf.toString(), false, null);
-			
+
 			IPackageFragment test= fSourceFolder.createPackageFragment("test", false, null);
 			buf= new StringBuffer();
 			buf.append("@my.NonNullByDefault(my.DefaultLocation.TYPE_BOUND)\n"); // create irrelevant package default, so no tested combination will be redunant
@@ -1446,7 +1459,7 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 			fJProject1.getProject().getWorkspace().build(IncrementalProjectBuilder.FULL_BUILD, null);
 			IMarker[] markers= fJProject1.getResource().findMarkers(null, true, IResource.DEPTH_INFINITE);
 			assertEquals(0, markers.length);
-			
+
 			// actual test begins here
 			buf= new StringBuffer();
 			buf.append("package test;\n");
@@ -1488,70 +1501,92 @@ public class NullAnnotationsQuickFixTest18 extends QuickFixTest {
 		}
 	}
 
-	public void testBug531511_none_type() throws Exception {		
+	@Test
+	public void testBug531511_none_type() throws Exception {
 		runBug531511Test(true, "", true, true);
 	}
-	public void testBug531511_none_decl() throws Exception {		
+	@Test
+	public void testBug531511_none_decl() throws Exception {
 		runBug531511Test(false, "", true, true);
 	}
-	public void testBug531511_combined_multi_first_type() throws Exception {		
+	@Test
+	public void testBug531511_combined_multi_first_type() throws Exception {
 		runBug531511Test(true, "@NNApi @NNFields", false, false);
 	}
-	public void testBug531511_combined_multi_first_decl() throws Exception {		
+	@Test
+	public void testBug531511_combined_multi_first_decl() throws Exception {
 		runBug531511Test(false, "@NNApi @NNFields", false, false);
 	}
-	public void testBug531511_combined_multi_second_type() throws Exception {		
+	@Test
+	public void testBug531511_combined_multi_second_type() throws Exception {
 		runBug531511Test(true, "@NNApi @NNFields", false, false);
 	}
-	public void testBug531511_combined_multi_second_decl() throws Exception {		
+	@Test
+	public void testBug531511_combined_multi_second_decl() throws Exception {
 		runBug531511Test(false, "@NNApi @NNFields", false, false);
 	}
-	public void testBug531511_param_multi_first_type() throws Exception {		
+	@Test
+	public void testBug531511_param_multi_first_type() throws Exception {
 		runBug531511Test(true, "@NNParams @NNFields", true, false);
 	}
-	public void testBug531511_param_multi_first_decl() throws Exception {		
+	@Test
+	public void testBug531511_param_multi_first_decl() throws Exception {
 		runBug531511Test(false, "@NNParams @NNFields", true, false);
 	}
-	public void testBug531511_param_multi_second_type() throws Exception {		
+	@Test
+	public void testBug531511_param_multi_second_type() throws Exception {
 		runBug531511Test(true, "@NNFields @NNParams", true, false);
 	}
-	public void testBug531511_param_multi_second_decl() throws Exception {		
+	@Test
+	public void testBug531511_param_multi_second_decl() throws Exception {
 		runBug531511Test(false, "@NNFields @NNParams", true, false);
 	}
-	public void testBug531511_return_multi_first_type() throws Exception {		
+	@Test
+	public void testBug531511_return_multi_first_type() throws Exception {
 		runBug531511Test(true, "@NNReturn @NNFields", false, true);
 	}
-	public void testBug531511_return_multi_first_decl() throws Exception {		
+	@Test
+	public void testBug531511_return_multi_first_decl() throws Exception {
 		runBug531511Test(false, "@NNReturn @NNFields", false, true);
 	}
-	public void testBug531511_return_multi_second_type() throws Exception {		
+	@Test
+	public void testBug531511_return_multi_second_type() throws Exception {
 		runBug531511Test(true, "@NNFields @NNReturn", false, true);
 	}
-	public void testBug531511_return_multi_second_decl() throws Exception {		
+	@Test
+	public void testBug531511_return_multi_second_decl() throws Exception {
 		runBug531511Test(false, "@NNFields @NNReturn", false, true);
 	}
-	public void testBug531511_boolean_default_type() throws Exception {		
+	@Test
+	public void testBug531511_boolean_default_type() throws Exception {
 		runBug531511Test(true, "@NNBDBoolean", false, false);
 	}
-	public void testBug531511_boolean_default_decl() throws Exception {		
+	@Test
+	public void testBug531511_boolean_default_decl() throws Exception {
 		runBug531511Test(false, "@NNBDBoolean", false, false);
 	}
-	public void testBug531511_boolean_true_type() throws Exception {		
+	@Test
+	public void testBug531511_boolean_true_type() throws Exception {
 		runBug531511Test(true, "@NNBDBoolean(true)", false, false);
 	}
-	public void testBug531511_boolean_true_decl() throws Exception {		
+	@Test
+	public void testBug531511_boolean_true_decl() throws Exception {
 		runBug531511Test(false, "@NNBDBoolean(true)", false, false);
 	}
-	public void testBug531511_boolean_false_type() throws Exception {		
+	@Test
+	public void testBug531511_boolean_false_type() throws Exception {
 		runBug531511Test(true, "@NNBDBoolean(false)", true, true);
 	}
-	public void testBug531511_boolean_false_decl() throws Exception {		
+	@Test
+	public void testBug531511_boolean_false_decl() throws Exception {
 		runBug531511Test(false, "@NNBDBoolean(false)", true, true);
 	}
-	public void testBug531511_unconfigurable_type() throws Exception {		
+	@Test
+	public void testBug531511_unconfigurable_type() throws Exception {
 		runBug531511Test(true, "@NNBDUnconfigurable", false, false);
 	}
-	public void testBug531511_unconfigurable_decl() throws Exception {		
+	@Test
+	public void testBug531511_unconfigurable_decl() throws Exception {
 		runBug531511Test(false, "@NNBDUnconfigurable", false, false);
 	}
 }
