@@ -157,7 +157,7 @@ public class Java50Fix extends CompilationUnitRewriteOperationsFix {
 	public static boolean isMissingOverrideAnnotationInterfaceProblem(int id) {
 		return id == IProblem.MissingOverrideAnnotationForInterfaceMethodImplementation;
 	}
-	
+
 	public static boolean isMissingOverrideAnnotationProblem(int id) {
 		return id == IProblem.MissingOverrideAnnotation || id == IProblem.MissingOverrideAnnotationForInterfaceMethodImplementation;
 	}
@@ -198,7 +198,7 @@ public class Java50Fix extends CompilationUnitRewriteOperationsFix {
 	public static Java50Fix createRawTypeReferenceFix(CompilationUnit compilationUnit, IProblemLocation problem) {
 		List<CompilationUnitRewriteOperation> operations= new ArrayList<>();
 		SimpleType node= createRawTypeReferenceOperations(compilationUnit, new IProblemLocation[] {problem}, operations);
-		if (operations.size() == 0)
+		if (operations.isEmpty())
 			return null;
 
 		return new Java50Fix(Messages.format(FixMessages.Java50Fix_AddTypeArguments_description,  BasicElementLabels.getJavaElementName(node.getName().getFullyQualifiedName())), compilationUnit, operations.toArray(new CompilationUnitRewriteOperation[operations.size()]));
@@ -234,7 +234,7 @@ public class Java50Fix extends CompilationUnitRewriteOperationsFix {
 		if (rawTypeReference)
 			createRawTypeReferenceOperations(compilationUnit, locations, operations);
 
-		if (operations.size() == 0)
+		if (operations.isEmpty())
 			return null;
 
 		String fixName;
@@ -273,7 +273,7 @@ public class Java50Fix extends CompilationUnitRewriteOperationsFix {
 			createRawTypeReferenceOperations(compilationUnit, problems, operations);
 
 
-		if (operations.size() == 0)
+		if (operations.isEmpty())
 			return null;
 
 		CompilationUnitRewriteOperation[] operationsArray= operations.toArray(new CompilationUnitRewriteOperation[operations.size()]);
@@ -281,9 +281,7 @@ public class Java50Fix extends CompilationUnitRewriteOperationsFix {
 	}
 
 	private static void createAddDeprecatedAnnotationOperations(CompilationUnit compilationUnit, IProblemLocation[] locations, List<CompilationUnitRewriteOperation> result) {
-		for (int i= 0; i < locations.length; i++) {
-			IProblemLocation problem= locations[i];
-
+		for (IProblemLocation problem : locations) {
 			if (isMissingDeprecationProblem(problem.getProblemId())) {
 				ASTNode selectedNode= problem.getCoveringNode(compilationUnit);
 				if (selectedNode != null) {
@@ -300,15 +298,14 @@ public class Java50Fix extends CompilationUnitRewriteOperationsFix {
 	}
 
 	private static void createAddOverrideAnnotationOperations(CompilationUnit compilationUnit, boolean addOverrideInterfaceAnnotation, IProblemLocation[] locations, List<CompilationUnitRewriteOperation> result) {
-		for (int i= 0; i < locations.length; i++) {
-			IProblemLocation problem= locations[i];
+		for (IProblemLocation problem : locations) {
 			int problemId= problem.getProblemId();
-			
+
 			if (isMissingOverrideAnnotationProblem(problemId)) {
 				if (!isMissingOverrideAnnotationInterfaceProblem(problemId) || addOverrideInterfaceAnnotation) {
 					ASTNode selectedNode= problem.getCoveringNode(compilationUnit);
 					if (selectedNode != null) {
-	
+
 						ASTNode declaringNode= getDeclaringNode(selectedNode);
 						if (declaringNode instanceof BodyDeclaration) {
 							BodyDeclaration declaration= (BodyDeclaration) declaringNode;
@@ -326,9 +323,7 @@ public class Java50Fix extends CompilationUnitRewriteOperationsFix {
 			return null;
 
 		List<SimpleType> result= new ArrayList<>();
-		for (int i= 0; i < locations.length; i++) {
-			IProblemLocation problem= locations[i];
-
+		for (IProblemLocation problem : locations) {
 			if (isRawTypeReferenceProblem(problem.getProblemId())) {
 				ASTNode node= problem.getCoveredNode(compilationUnit);
 				if (node instanceof ClassInstanceCreation) {
@@ -354,7 +349,7 @@ public class Java50Fix extends CompilationUnitRewriteOperationsFix {
 			}
 		}
 
-		if (result.size() == 0)
+		if (result.isEmpty())
 			return null;
 
 		SimpleType[] types= result.toArray(new SimpleType[result.size()]);
@@ -371,15 +366,13 @@ public class Java50Fix extends CompilationUnitRewriteOperationsFix {
 			return true;
 		}
 
-		IProblem[] problems= compilationUnit.getProblems();
-		for (int i= 0; i < problems.length; i++) {
-			if (problems[i].isError()) {
-				if (!(problems[i] instanceof CategorizedProblem))
+		for (IProblem problem : compilationUnit.getProblems()) {
+			if (problem.isError()) {
+				if (!(problem instanceof CategorizedProblem)) {
 					return true;
-
-				CategorizedProblem categorizedProblem= (CategorizedProblem) problems[i];
+				}
+				CategorizedProblem categorizedProblem= (CategorizedProblem) problem;
 				int categoryID= categorizedProblem.getCategoryID();
-
 				if (categoryID == CategorizedProblem.CAT_BUILDPATH)
 					return true;
 				if (categoryID == CategorizedProblem.CAT_SYNTAX)
@@ -453,10 +446,9 @@ public class Java50Fix extends CompilationUnitRewriteOperationsFix {
 	}
 
 	private static SimpleType getRawReference(SimpleName name, CompilationUnit compilationUnit) {
-		SimpleName[] names= LinkedNodeFinder.findByNode(compilationUnit, name);
-		for (int j= 0; j < names.length; j++) {
-			if (names[j].getParent() instanceof VariableDeclarationFragment) {
-				VariableDeclarationFragment fragment= (VariableDeclarationFragment)names[j].getParent();
+		for (SimpleName n : LinkedNodeFinder.findByNode(compilationUnit, name)) {
+			if (n.getParent() instanceof VariableDeclarationFragment) {
+				VariableDeclarationFragment fragment= (VariableDeclarationFragment) n.getParent();
 				if (fragment.getParent() instanceof VariableDeclarationStatement) {
 					VariableDeclarationStatement statement= (VariableDeclarationStatement)fragment.getParent();
 					ASTNode result= (ASTNode)statement.getStructuralProperty(VariableDeclarationStatement.TYPE_PROPERTY);
@@ -468,13 +460,13 @@ public class Java50Fix extends CompilationUnitRewriteOperationsFix {
 					if (isRawTypeReference(result))
 						return (SimpleType) result;
 				}
-			} else if (names[j].getParent() instanceof SingleVariableDeclaration) {
-				SingleVariableDeclaration declaration= (SingleVariableDeclaration)names[j].getParent();
+			} else if (n.getParent() instanceof SingleVariableDeclaration) {
+				SingleVariableDeclaration declaration= (SingleVariableDeclaration) n.getParent();
 				ASTNode result= (ASTNode)declaration.getStructuralProperty(SingleVariableDeclaration.TYPE_PROPERTY);
 				if (isRawTypeReference(result))
 					return (SimpleType) result;
-			} else if (names[j].getParent() instanceof MethodDeclaration) {
-				MethodDeclaration methodDecl= (MethodDeclaration)names[j].getParent();
+			} else if (n.getParent() instanceof MethodDeclaration) {
+				MethodDeclaration methodDecl= (MethodDeclaration) n.getParent();
 				ASTNode result= (ASTNode)methodDecl.getStructuralProperty(MethodDeclaration.RETURN_TYPE2_PROPERTY);
 				if (isRawTypeReference(result))
 					return (SimpleType) result;
