@@ -114,12 +114,7 @@ public class TypedSource {
 	}
 
 	public static Comparator<TypedSource> createTypeComparator() {
-		return new Comparator<TypedSource>(){
-			@Override
-			public int compare(TypedSource arg0, TypedSource arg1) {
-				return arg0.getType() - arg1.getType();
-			}
-		};
+		return (arg0, arg1) -> arg0.getType() - arg1.getType();
 	}
 	public static TypedSource[] createTypedSources(IJavaElement[] javaElements) throws CoreException {
 		//Map<ICompilationUnit, List<IJavaElement>>
@@ -150,8 +145,8 @@ public class TypedSource {
 	private static TypedSource[] createTypedSourcesForImportContainer(SourceTuple tuple, IImportContainer container) throws JavaModelException, CoreException {
 		IJavaElement[] imports= container.getChildren();
 		List<TypedSource> result= new ArrayList<>(imports.length);
-		for (int i= 0; i < imports.length; i++) {
-			result.addAll(Arrays.asList(createTypedSources(imports[i], tuple)));
+		for (IJavaElement importedElement : imports) {
+			result.addAll(Arrays.asList(createTypedSources(importedElement, tuple)));
 		}
 		return result.toArray(new TypedSource[result.size()]);
 	}
