@@ -14,8 +14,10 @@
 package org.eclipse.jdt.internal.corext.refactoring.binary;
 
 import java.util.ArrayList;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.TreeMap;
 
 import org.eclipse.core.runtime.Assert;
@@ -54,8 +56,7 @@ public class StubCreator {
 	protected void appendEnumConstants(final IType type) throws JavaModelException {
 		final IField[] fields= type.getFields();
 		final List<IField> list= new ArrayList<>(fields.length);
-		for (int index= 0; index < fields.length; index++) {
-			final IField field= fields[index];
+		for (IField field : fields) {
 			if (Flags.isEnum(field.getFlags()))
 				list.add(field);
 		}
@@ -70,7 +71,7 @@ public class StubCreator {
 	protected void appendExpression(final String signature) {
 		appendExpression(signature, false);
 	}
-	
+
 	protected void appendExpression(String signature, boolean castNull) {
 		switch (signature.charAt(0)) {
 			case Signature.C_BOOLEAN:
@@ -111,11 +112,19 @@ public class StubCreator {
 	}
 
 	protected void appendFlags(final IMember member) throws JavaModelException {
-		if (member instanceof IAnnotatable)
-			for (IAnnotation annotation : ((IAnnotatable) member).getAnnotations()) {
-				appendAnnotation(annotation);
+		if (member instanceof IAnnotatable) {
+			IAnnotation[] annotations= ((IAnnotatable) member).getAnnotations();
+			Set<IAnnotation> annotationSet= new HashSet<>();
+			for (IAnnotation annotation : annotations) {
+				if (!annotationSet.contains(annotation)) {
+					appendAnnotation(annotation);
+					annotationSet.add(annotation);
+				}
 			}
-		
+			annotationSet.clear();
+			annotationSet= null;
+		}
+
 		int flags= member.getFlags();
 		final int kind= member.getElementType();
 		if (kind == IJavaElement.TYPE) {
@@ -139,12 +148,12 @@ public class StubCreator {
 	private void appendAnnotation(IAnnotation annotation) throws JavaModelException {
 		String name= annotation.getElementName();
 		if (!fStubInvisible && name.startsWith("sun.") || name.startsWith("jdk.internal.")) //$NON-NLS-1$ //$NON-NLS-2$
-			return; // skip Sun-internal annotations 
-		
+			return; // skip Sun-internal annotations
+
 		fBuffer.append('@');
 		fBuffer.append(name.replace('$', '.'));
 		fBuffer.append('(');
-		
+
 		IMemberValuePair[] memberValuePairs= annotation.getMemberValuePairs();
 		for (IMemberValuePair pair : memberValuePairs) {
 			fBuffer.append(pair.getMemberName());
@@ -154,7 +163,7 @@ public class StubCreator {
 		}
 		if (memberValuePairs.length > 0)
 			fBuffer.deleteCharAt(fBuffer.length() - 1);
-		
+
 		fBuffer.append(')').append('\n');
 	}
 
@@ -169,7 +178,7 @@ public class StubCreator {
 			if (objects.length > 0)
 				fBuffer.deleteCharAt(fBuffer.length() - 1);
 			fBuffer.append('}');
-			
+
 		} else {
 			switch (valueKind) {
 				case IMemberValuePair.K_ANNOTATION:
@@ -178,7 +187,7 @@ public class StubCreator {
 				case IMemberValuePair.K_STRING:
 					fBuffer.append('"').append(value).append('"');
 					break;
-					
+
 				default:
 					fBuffer.append(value);
 					break;
@@ -189,16 +198,15 @@ public class StubCreator {
 	protected void appendMembers(final IType type, final IProgressMonitor monitor) throws JavaModelException {
 		try {
 			monitor.beginTask(RefactoringCoreMessages.StubCreationOperation_creating_type_stubs, 1);
-			final IJavaElement[] children= type.getChildren();
-			for (int index= 0; index < children.length; index++) {
-				final IMember child= (IMember) children[index];
+			for (IJavaElement childJavaElement : type.getChildren()) {
+				final IMember child= (IMember) childJavaElement;
 				final int flags= child.getFlags();
 				final boolean isPrivate= Flags.isPrivate(flags);
 				final boolean isDefault= !Flags.isPublic(flags) && !Flags.isProtected(flags) && !isPrivate;
 				final boolean stub= fStubInvisible || (!isPrivate && !isDefault);
 				if (child instanceof IType) {
 					if (stub || "java.lang.invoke.MethodHandle".equals(type.getFullyQualifiedName()) //$NON-NLS-1$
-							|| "java.util.concurrent.ConcurrentHashMap$CollectionView".equals(((IType) child).getFullyQualifiedName())) //$NON-NLS-1$
+						|| "java.util.concurrent.ConcurrentHashMap$CollectionView".equals(((IType) child).getFullyQualifiedName())) //$NON-NLS-1$
 						appendTypeDeclaration((IType) child, new SubProgressMonitor(monitor, 1));
 				} else if (child instanceof IField) {
 					if (stub && !Flags.isEnum(flags) && !Flags.isSynthetic(flags))
@@ -239,17 +247,16 @@ public class StubCreator {
 				final IType superclass= declaringType.getJavaProject().findType(Signature.getSignatureQualifier(superSignature), Signature.getSignatureSimpleName(superSignature));
 				if (superclass != null) {
 					final IMethod[] superMethods= superclass.getMethods();
-					
+
 					// collect super constructors by parameter count
 					Map<Integer, List<IMethod>> superConstructorsByParamCount= new TreeMap<>();
 					boolean multi= false;
 					IMethod superConstructor= null;
-					for (int i= 0; i < superMethods.length; i++) {
-						IMethod superMethod= superMethods[i];
+					for (IMethod superMethod : superMethods) {
 						if (superMethod.isConstructor()
-								&& !Flags.isPrivate(superMethod.getFlags())
-								&& !(Flags.isPackageDefault(superMethod.getFlags()) && !declaringType.getPackageFragment().equals(superclass.getPackageFragment()))
-								) {
+							&& !Flags.isPrivate(superMethod.getFlags())
+							&& !(Flags.isPackageDefault(superMethod.getFlags()) && !declaringType.getPackageFragment().equals(superclass.getPackageFragment()))
+							) {
 							int paramCount= superMethod.getNumberOfParameters();
 							if (paramCount == 0) {
 								superConstructor= superMethod;
@@ -278,7 +285,7 @@ public class StubCreator {
 								if (superConstructor == null) {
 									superConstructor= constructor;
 									multi= constructors.size() != 1;
-								}									
+								}
 							}
 						}
 						if (superConstructor == null) {
