@@ -1025,7 +1025,7 @@ public class RenameTypeProcessor extends JavaRenameProcessor implements ITextUpd
 				}
 			}
 		}
-		
+
 		for (ICompilationUnit conflict : conflicts) {
 			RefactoringStatusContext context= JavaStatusContext.create(conflict);
 			String message= Messages.format(RefactoringCoreMessages.RenameTypeRefactoring_another_type,
@@ -1775,7 +1775,7 @@ public class RenameTypeProcessor extends JavaRenameProcessor implements ITextUpd
 			return false;
 		if (fPreloadedElementToName == null)
 			return false;
-		if (fPreloadedElementToName.size() == 0)
+		if (fPreloadedElementToName.isEmpty())
 			return false;
 		return true;
 	}
