@@ -16,6 +16,7 @@ package org.eclipse.jdt.internal.corext.refactoring.structure;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -78,17 +79,19 @@ import org.eclipse.jdt.core.dom.rewrite.ASTRewrite;
 import org.eclipse.jdt.core.dom.rewrite.ImportRewrite.ImportRewriteContext;
 import org.eclipse.jdt.core.dom.rewrite.ListRewrite;
 import org.eclipse.jdt.core.formatter.CodeFormatter;
+import org.eclipse.jdt.core.manipulation.CodeGeneration;
 import org.eclipse.jdt.core.refactoring.CompilationUnitChange;
 import org.eclipse.jdt.core.refactoring.IJavaRefactorings;
 import org.eclipse.jdt.core.refactoring.descriptors.ExtractSuperclassDescriptor;
 import org.eclipse.jdt.core.refactoring.descriptors.JavaRefactoringDescriptor;
 
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
 import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.core.refactoring.descriptors.RefactoringSignatureDescriptorFactory;
 import org.eclipse.jdt.internal.corext.codemanipulation.CodeGenerationSettings;
 import org.eclipse.jdt.internal.corext.codemanipulation.ContextSensitiveImportRewriteContext;
-import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility;
 import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility2;
+import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility2Core;
 import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
 import org.eclipse.jdt.internal.corext.refactoring.Checks;
 import org.eclipse.jdt.internal.corext.refactoring.JDTRefactoringDescriptorComment;
@@ -106,7 +109,6 @@ import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.corext.util.JdtFlags;
 import org.eclipse.jdt.internal.corext.util.Messages;
 
-import org.eclipse.jdt.ui.CodeGeneration;
 import org.eclipse.jdt.ui.JavaElementLabels;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
@@ -250,15 +252,15 @@ public final class ExtractSupertypeProcessor extends PullUpRefactoringProcessor
 	 * @return the destination type
 	 */
 	public IType computeExtractedType(final String name) {
-		if (name != null && !name.equals("")) {//$NON-NLS-1$
+		if (name != null && !name.isEmpty()) {
 			final IType declaring= getDeclaringType();
 			try {
-				final ICompilationUnit[] units= declaring.getPackageFragment().getCompilationUnits(fOwner);
 				final String newName= JavaModelUtil.getRenamedCUName(declaring.getCompilationUnit(), name);
 				ICompilationUnit result= null;
-				for (int index= 0; index < units.length; index++) {
-					if (units[index].getElementName().equals(newName))
-						result= units[index];
+				for (ICompilationUnit unit : declaring.getPackageFragment().getCompilationUnits(fOwner)) {
+					if (unit.getElementName().equals(newName)) {
+						result= unit;
+					}
 				}
 				if (result != null) {
 					final IType type= result.getType(name);
@@ -436,23 +438,23 @@ public final class ExtractSupertypeProcessor extends PullUpRefactoringProcessor
 		if (superType != null) {
 			final ITypeBinding binding= targetDeclaration.resolveBinding();
 			if (binding != null && binding.isClass()) {
-				final IMethodBinding[] bindings= StubUtility2.getVisibleConstructors(binding, true, true);
+				final IMethodBinding[] bindings= StubUtility2Core.getVisibleConstructors(binding, true, true);
 				int deprecationCount= 0;
-				for (int i= 0; i < bindings.length; i++) {
-					if (bindings[i].isDeprecated())
+				for (IMethodBinding b : bindings) {
+					if (b.isDeprecated()) {
 						deprecationCount++;
+					}
 				}
 				final ListRewrite rewrite= targetRewrite.getASTRewrite().getListRewrite(targetDeclaration, TypeDeclaration.BODY_DECLARATIONS_PROPERTY);
 				if (rewrite != null) {
 					boolean createDeprecated= deprecationCount == bindings.length;
-					for (int i= 0; i < bindings.length; i++) {
-						IMethodBinding curr= bindings[i];
+					for (IMethodBinding curr : bindings) {
 						if (!curr.isDeprecated() || createDeprecated) {
 							MethodDeclaration stub;
 							try {
 								ImportRewriteContext context= new ContextSensitiveImportRewriteContext(targetDeclaration, targetRewrite.getImportRewrite());
 								stub= StubUtility2.createConstructorStub(targetRewrite.getCu(), targetRewrite.getASTRewrite(), targetRewrite.getImportRewrite(), context, curr, binding.getName(),
-										Modifier.PUBLIC, false, false, fSettings);
+									Modifier.PUBLIC, false, false, fSettings);
 								if (stub != null)
 									rewrite.insertLast(stub, null);
 							} catch (CoreException exception) {
@@ -511,10 +513,10 @@ public final class ExtractSupertypeProcessor extends PullUpRefactoringProcessor
 				final ITypeBinding superBinding= binding.getSuperclass();
 				if (superBinding != null)
 					fTypeBindings.add(superBinding);
+				ITypeBinding[] typeParameters= binding.getTypeParameters();
+				Collections.addAll(fTypeBindings, typeParameters);
 				final ITypeBinding[] bindings= binding.getInterfaces();
-				for (int i= 0; i < bindings.length; i++) {
-	                fTypeBindings.add(bindings[i]);
-                }
+				Collections.addAll(fTypeBindings, bindings);
 			}
 			final String imports= createTypeImports(extractedWorkingCopy, monitor);
 			if (imports != null && !"".equals(imports)) { //$NON-NLS-1$
@@ -524,7 +526,7 @@ public final class ExtractSupertypeProcessor extends PullUpRefactoringProcessor
 			source= createTypeTemplate(extractedWorkingCopy, "", fileComment, "", buffer.toString()); //$NON-NLS-1$ //$NON-NLS-2$
 			if (source == null) {
 				if (!declaring.getPackageFragment().isDefaultPackage()) {
-					if (imports.length() > 0)
+					if (imports != null && imports.length() > 0)
 						buffer.insert(0, imports);
 					buffer.insert(0, "package " + declaring.getPackageFragment().getElementName() + ";"); //$NON-NLS-1$//$NON-NLS-2$
 				}
@@ -695,8 +697,9 @@ public final class ExtractSupertypeProcessor extends PullUpRefactoringProcessor
 				final ITypeParameter[] parameters= extractedType.getTypeParameters();
 				if (parameters.length > 0) {
 					final ParameterizedType parameterized= ast.newParameterizedType(type);
-					for (int index= 0; index < parameters.length; index++)
-						parameterized.typeArguments().add(ast.newSimpleType(ast.newSimpleName(parameters[index].getElementName())));
+					for (ITypeParameter parameter : parameters) {
+						parameterized.typeArguments().add(ast.newSimpleType(ast.newSimpleName(parameter.getElementName())));
+					}
 					type= parameterized;
 				}
 			}
@@ -773,8 +776,7 @@ public final class ExtractSupertypeProcessor extends PullUpRefactoringProcessor
 				subTypes.add(declaring);
 			final Map<ICompilationUnit, Collection<IType>> unitToTypes= new HashMap<>(subTypes.size());
 			final Set<ICompilationUnit> units= new HashSet<>(subTypes.size());
-			for (int index= 0; index < subTypes.size(); index++) {
-				final IType type= subTypes.get(index);
+			for (final IType type : subTypes) {
 				final ICompilationUnit unit= type.getCompilationUnit();
 				units.add(unit);
 				Collection<IType> collection= unitToTypes.get(unit);
@@ -834,8 +836,7 @@ public final class ExtractSupertypeProcessor extends PullUpRefactoringProcessor
 								try {
 									final Collection<IType> types= unitToTypes.get(unit);
 									if (types != null) {
-										for (final Iterator<IType> innerIterator= types.iterator(); innerIterator.hasNext();) {
-											final IType currentType= innerIterator.next();
+										for (IType currentType : types) {
 											final AbstractTypeDeclaration currentDeclaration= ASTNodeSearchUtil.getAbstractTypeDeclarationNode(currentType, node);
 											if (currentDeclaration != null)
 												createModifiedSubType(unit, node, extractedType, extractBindings[0], currentDeclaration, status);
@@ -1134,14 +1135,13 @@ public final class ExtractSupertypeProcessor extends PullUpRefactoringProcessor
 					}
 				}
 			}
-			for (Iterator<Entry<ICompilationUnit, CompilationUnitChange>> iterator= fLayerChanges.entrySet().iterator(); iterator.hasNext();) {
-				final Entry<ICompilationUnit, CompilationUnitChange> entry= iterator.next();
+			for (Entry<ICompilationUnit, CompilationUnitChange> entry : fLayerChanges.entrySet()) {
 				manager.manage(entry.getKey(), entry.getValue());
 			}
-			ICompilationUnit[] units= manager.getAllCompilationUnits();
-			for (int index= 0; index < units.length; index++) {
-				if (units[index].getPath().equals(extractedUnit.getPath()))
-					manager.remove(units[index]);
+			for (ICompilationUnit cu : manager.getAllCompilationUnits()) {
+				if (cu.getPath().equals(extractedUnit.getPath())) {
+					manager.remove(cu);
+				}
 			}
 		} finally {
 			fLayerChanges.clear();
