@@ -108,8 +108,7 @@ public class ChangeParametersControl extends Composite {
 		}
 		private ParameterInfo[] removeMarkedAsDeleted(List<ParameterInfo> paramInfos){
 			List<ParameterInfo> result= new ArrayList<>(paramInfos.size());
-			for (Iterator<ParameterInfo> iter= paramInfos.iterator(); iter.hasNext();) {
-				ParameterInfo info= iter.next();
+			for (ParameterInfo info : paramInfos) {
 				if (! info.isDeleted())
 					result.add(info);
 			}
@@ -536,12 +535,12 @@ public class ChangeParametersControl extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				int index= getTable().getSelectionIndices()[0];
-				ParameterInfo[] selected= getSelectedElements();
-				for (int i= 0; i < selected.length; i++) {
-					if (selected[i].isAdded())
-						fParameterInfos.remove(selected[i]);
-					else
-						selected[i].markAsDeleted();
+				for (ParameterInfo s : getSelectedElements()) {
+					if (s.isAdded()) {
+						fParameterInfos.remove(s);
+					} else {
+						s.markAsDeleted();
+					}
 				}
 				restoreSelection(index);
 			}
@@ -684,8 +683,7 @@ public class ChangeParametersControl extends Composite {
 		List<ParameterInfo> res= new ArrayList<>(elements.size());
 		List<ParameterInfo> deleted= new ArrayList<>();
 		ParameterInfo floating= null;
-		for (Iterator<ParameterInfo> iter= elements.iterator(); iter.hasNext();) {
-			ParameterInfo curr= iter.next();
+		for (ParameterInfo curr : elements) {
 			if (move.contains(curr)) {
 				res.add(curr);
 			} else if (curr.isDeleted()) {
@@ -725,8 +723,7 @@ public class ChangeParametersControl extends Composite {
 		if (fParameterInfos == null) // during initialization
 			return 0;
 		int result= 0;
-		for (Iterator<ParameterInfo> iter= fParameterInfos.iterator(); iter.hasNext();) {
-			ParameterInfo info= iter.next();
+		for (ParameterInfo info : fParameterInfos) {
 			if (! info.isDeleted())
 				result++;
 		}
