@@ -200,16 +200,17 @@ public final class PushDownWizard extends RefactoringWizard {
 
 		private static int countEditableInfos(final MemberActionInfo[] infos) {
 			int result= 0;
-			for (int index= 0; index < infos.length; index++) {
-				if (infos[index].isEditable())
+			for (MemberActionInfo info : infos) {
+				if (info.isEditable()) {
 					result++;
+				}
 			}
 			return result;
 		}
 
 		private static void setInfoAction(final MemberActionInfo[] infos, final int action) {
-			for (int index= 0; index < infos.length; index++) {
-				infos[index].setAction(action);
+			for (MemberActionInfo info : infos) {
+				info.setAction(action);
 			}
 		}
 
@@ -250,10 +251,8 @@ public final class PushDownWizard extends RefactoringWizard {
 		}
 
 		private int countInfosForAction(final int action) {
-			final MemberActionInfo[] infos= (MemberActionInfo[]) fTableViewer.getInput();
 			int count= 0;
-			for (int index= 0; index < infos.length; index++) {
-				final MemberActionInfo info= infos[index];
+			for (MemberActionInfo info : (MemberActionInfo[]) fTableViewer.getInput()) {
 				if (info.getAction() == action)
 					count++;
 			}
@@ -471,8 +470,7 @@ public final class PushDownWizard extends RefactoringWizard {
 		private MemberActionInfo[] getActiveInfos() {
 			final MemberActionInfo[] infos= fProcessor.getMemberActionInfos();
 			final List<MemberActionInfo> result= new ArrayList<>(infos.length);
-			for (int index= 0; index < infos.length; index++) {
-				final MemberActionInfo info= infos[index];
+			for (MemberActionInfo info : infos) {
 				if (info.isActive())
 					result.add(info);
 			}
@@ -485,9 +483,10 @@ public final class PushDownWizard extends RefactoringWizard {
 				return -1;
 
 			final int code= infos[0].getAction();
-			for (int index= 0; index < infos.length; index++) {
-				if (code != infos[index].getAction())
+			for (MemberActionInfo info : infos) {
+				if (code != info.getAction()) {
 					return -1;
+				}
 			}
 			return code;
 		}
@@ -513,8 +512,8 @@ public final class PushDownWizard extends RefactoringWizard {
 		private IMember[] getMembers() {
 			final MemberActionInfo[] infos= (MemberActionInfo[]) fTableViewer.getInput();
 			final List<IMember> result= new ArrayList<>(infos.length);
-			for (int index= 0; index < infos.length; index++) {
-				result.add(infos[index].getMember());
+			for (MemberActionInfo info : infos) {
+				result.add(info.getMember());
 			}
 			return result.toArray(new IMember[result.size()]);
 		}
@@ -550,10 +549,11 @@ public final class PushDownWizard extends RefactoringWizard {
 
 		private void setActionForMembers(final IMember[] members, final int action) {
 			final MemberActionInfo[] infos= (MemberActionInfo[]) fTableViewer.getInput();
-			for (int offset= 0; offset < members.length; offset++) {
-				for (int index= 0; index < infos.length; index++) {
-					if (infos[index].getMember().equals(members[offset]))
-						infos[index].setAction(action);
+			for (IMember member : members) {
+				for (MemberActionInfo info : infos) {
+					if (info.getMember().equals(member)) {
+						info.setAction(action);
+					}
 				}
 			}
 		}
@@ -566,7 +566,7 @@ public final class PushDownWizard extends RefactoringWizard {
 
 				@Override
 				public void selectionChanged(final SelectionChangedEvent event) {
-					if (comboBoxCellEditor.getControl() == null & !table.isDisposed())
+					if (comboBoxCellEditor.getControl() == null && !table.isDisposed())
 						comboBoxCellEditor.create(table);
 					Assert.isTrue(event.getSelection() instanceof IStructuredSelection);
 					final IStructuredSelection ss= (IStructuredSelection) event.getSelection();
