@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,9 +14,12 @@
 package org.eclipse.jdt.internal.ui;
 
 import java.io.IOException;
+import java.util.HashSet;
 import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.LinkedHashMap;
+import java.util.Set;
+import java.util.StringTokenizer;
 
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
@@ -39,6 +42,7 @@ import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.MultiStatus;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.core.runtime.Status;
+import org.eclipse.core.runtime.preferences.IEclipsePreferences;
 import org.eclipse.core.runtime.preferences.InstanceScope;
 
 import org.eclipse.core.resources.IFile;
@@ -93,6 +97,7 @@ import org.eclipse.jdt.internal.corext.callhierarchy.MethodWrapperDynamic;
 import org.eclipse.jdt.internal.corext.fix.CleanUpRegistry;
 import org.eclipse.jdt.internal.corext.template.java.AbstractJavaContextType;
 import org.eclipse.jdt.internal.corext.template.java.JavaContextType;
+import org.eclipse.jdt.internal.corext.template.java.JavaPostfixContextType;
 import org.eclipse.jdt.internal.corext.template.java.SWTContextType;
 import org.eclipse.jdt.internal.corext.util.OpenTypeHistory;
 import org.eclipse.jdt.internal.corext.util.QualifiedTypeNameHistory;
@@ -139,6 +144,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * The view id for the workbench's Resource Navigator standard component.
 	 * @since 3.6
 	 */
+	@Deprecated
 	public static final String ID_RES_NAV= IPageLayout.ID_RES_NAV;
 
 	/**
@@ -151,16 +157,6 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * @since 3.0
 	 */
 	private static final String CODE_TEMPLATES_KEY= "org.eclipse.jdt.ui.text.custom_code_templates"; //$NON-NLS-1$
-	/**
-	 * The key to store whether the legacy templates have been migrated
-	 * @since 3.0
-	 */
-	private static final String TEMPLATES_MIGRATION_KEY= "org.eclipse.jdt.ui.text.templates_migrated"; //$NON-NLS-1$
-	/**
-	 * The key to store whether the legacy code templates have been migrated
-	 * @since 3.0
-	 */
-	private static final String CODE_TEMPLATES_MIGRATION_KEY= "org.eclipse.jdt.ui.text.code_templates_migrated"; //$NON-NLS-1$
 
 	public static boolean DEBUG_AST_PROVIDER;
 
@@ -211,6 +207,8 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 
 	private WorkingCopyManager fWorkingCopyManager;
 
+	private static final String CODE_ASSIST_MIGRATED= "code_assist_migrated"; //$NON-NLS-1$
+
 	/**
 	 * @deprecated to avoid deprecation warning
 	 */
@@ -303,7 +301,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	}
 
 	public static IWorkbenchWindow getActiveWorkbenchWindow() {
-		return getDefault().getWorkbench().getActiveWorkbenchWindow();
+		return PlatformUI.getWorkbench().getActiveWorkbenchWindow();
 	}
 
 	public static Shell getActiveWorkbenchShell() {
@@ -439,6 +437,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 
 		JavaManipulation.setCodeTemplateStore(getCodeTemplateStore());
 		JavaManipulation.setCodeTemplateContextRegistry(getCodeTemplateContextRegistry());
+		disableNewCodeAssistCategoryPreferences();
 	}
 
 	private void createOrUpdateWorkingSet(String name, String oldname, String label, final String id) {
@@ -455,7 +454,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 					workingSet.setLabel(label);
 			} else {
 				logErrorMessage("found existing workingset with name=\"" + name + "\" but id=\"" + workingSet.getId() + "\""); //$NON-NLS-1$ //$NON-NLS-2$//$NON-NLS-3$
-			}			
+			}
 		}
 		IWorkingSet oldWorkingSet= workingSetManager.getWorkingSet(oldname);
 		if (oldWorkingSet != null && id.equals(oldWorkingSet.getId())) {
@@ -568,7 +567,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	}
 
 	private IWorkbenchPage internalGetActivePage() {
-		IWorkbenchWindow window= getWorkbench().getActiveWorkbenchWindow();
+		IWorkbenchWindow window= PlatformUI.getWorkbench().getActiveWorkbenchWindow();
 		if (window == null)
 			return null;
 		return window.getActivePage();
@@ -576,7 +575,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 
 	/**
 	 * Private deprecated method to avoid deprecation warnings
-	 * 
+	 *
 	 * @return the deprecated buffer factory
 	 * @deprecated to avoid deprecation warnings
 	 */
@@ -634,7 +633,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 
 	/**
 	 * Returns the Java Core plug-in preferences.
-	 * 
+	 *
 	 * @return the Java Core plug-in preferences
 	 * @since 3.7
 	 */
@@ -765,6 +764,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 			registerJavaContext(registry, JavaContextType.ID_MEMBERS, all_contextType);
 			registerJavaContext(registry, JavaContextType.ID_STATEMENTS, all_contextType);
 			registerJavaContext(registry, JavaContextType.ID_MODULE, all_contextType);
+			registerJavaContext(registry, JavaContextType.ID_EMPTY, all_contextType);
 
 			registerJavaContext(registry, SWTContextType.ID_ALL, all_contextType);
 			all_contextType= registry.getContextType(SWTContextType.ID_ALL);
@@ -772,6 +772,9 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 			registerJavaContext(registry, SWTContextType.ID_MEMBERS, all_contextType);
 			registerJavaContext(registry, SWTContextType.ID_STATEMENTS, all_contextType);
 
+			registerJavaContext(registry, JavaPostfixContextType.ID_ALL, all_contextType);
+			all_contextType= registry.getContextType(JavaPostfixContextType.ID_ALL);
+
 			fContextTypeRegistry= registry;
 		}
 
@@ -802,14 +805,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	public TemplateStore getTemplateStore() {
 		if (fTemplateStore == null) {
 			final IPreferenceStore store= getPreferenceStore();
-			boolean alreadyMigrated= store.getBoolean(TEMPLATES_MIGRATION_KEY);
-			if (alreadyMigrated)
 				fTemplateStore= new ContributionTemplateStore(getTemplateContextRegistry(), store, TEMPLATES_KEY);
-			else {
-				fTemplateStore= new CompatibilityTemplateStore(getTemplateContextRegistry(), store, TEMPLATES_KEY, getOldTemplateStoreInstance());
-				store.setValue(TEMPLATES_MIGRATION_KEY, true);
-			}
-
 			try {
 				fTemplateStore.load();
 			} catch (IOException e) {
@@ -821,17 +817,6 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 		return fTemplateStore;
 	}
 
-	/**
-	 * Private deprecated method to avoid deprecation warnings
-	 * 
-	 * @return the deprecated template store
-	 * @deprecated to avoid deprecation warnings
-	 */
-	@Deprecated
-	private org.eclipse.jdt.internal.corext.template.java.Templates getOldTemplateStoreInstance() {
-		return org.eclipse.jdt.internal.corext.template.java.Templates.getInstance();
-	}
-
 	/**
 	 * Returns the template context type registry for the code generation
 	 * templates.
@@ -859,13 +844,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	public TemplateStore getCodeTemplateStore() {
 		if (fCodeTemplateStore == null) {
 			IPreferenceStore store= getPreferenceStore();
-			boolean alreadyMigrated= store.getBoolean(CODE_TEMPLATES_MIGRATION_KEY);
-			if (alreadyMigrated)
-				fCodeTemplateStore= new ContributionTemplateStore(getCodeTemplateContextRegistry(), store, CODE_TEMPLATES_KEY);
-			else {
-				fCodeTemplateStore= new CompatibilityTemplateStore(getCodeTemplateContextRegistry(), store, CODE_TEMPLATES_KEY, getOldCodeTemplateStoreInstance());
-				store.setValue(CODE_TEMPLATES_MIGRATION_KEY, true);
-			}
+			fCodeTemplateStore= new ContributionTemplateStore(getCodeTemplateContextRegistry(), store, CODE_TEMPLATES_KEY);
 
 			try {
 				fCodeTemplateStore.load();
@@ -875,26 +854,11 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 
 			fCodeTemplateStore.startListeningForPreferenceChanges();
 
-			// compatibility / bug fixing code for duplicated templates
-			// TODO remove for 3.0
-			CompatibilityTemplateStore.pruneDuplicates(fCodeTemplateStore, true);
-
 		}
 
 		return fCodeTemplateStore;
 	}
 
-	/**
-	 * Private deprecated method to avoid deprecation warnings
-	 * 
-	 * @return the deprecated code template store
-	 * @deprecated to avoid deprecation warnings
-	 */
-	@Deprecated
-	private org.eclipse.jdt.internal.corext.template.java.CodeTemplates getOldCodeTemplateStoreInstance() {
-		return org.eclipse.jdt.internal.corext.template.java.CodeTemplates.getInstance();
-	}
-
 	private synchronized ImageDescriptorRegistry internalGetImageDescriptorRegistry() {
 		if (fImageDescriptorRegistry == null)
 			fImageDescriptorRegistry= new ImageDescriptorRegistry();
@@ -918,7 +882,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 
 	/**
 	 * Flushes the instance scope of this plug-in.
-	 * 
+	 *
 	 * @since 3.7
 	 */
 	public static void flushInstanceScope() {
@@ -932,7 +896,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	/**
 	 * Returns the registry of the extensions to the
 	 * <code>org.eclipse.jdt.ui.javaFoldingStructureProvider</code> extension point.
-	 * 
+	 *
 	 * @return the registry of contributed <code>IJavaFoldingStructureProvider</code>
 	 * @since 3.0
 	 */
@@ -1069,4 +1033,80 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 		DEBUG_TYPE_CONSTRAINTS= options.getBooleanOption("org.eclipse.jdt.ui/debug/TypeConstraints", false); //$NON-NLS-1$
 		DEBUG_RESULT_COLLECTOR= options.getBooleanOption("org.eclipse.jdt.ui/debug/ResultCollector", false); //$NON-NLS-1$
 	}
+
+	/**
+	 * Add only 'initializeCodeAssistCategoryDisabled(String)' calls here for
+	 * proposal category id of *NEW* features meant to be disabled by deafult.
+	 *
+	 * Eg. initializeCodeAssistCategoryDisabled("org.eclipse.jdt.ui.javaPostfixProposalCategory"); //$NON-NLS-1$
+	 *
+	 * The call must be added here in addition to setting default disablement in
+	 * {@link PreferenceConstants} CODEASSIST_EXCLUDED_CATEGORIES and CODEASSIST_CATEGORY_ORDER.
+	 * This will only work correctly for newly added proposal categories for a given release.
+	 */
+	private static void disableNewCodeAssistCategoryPreferences() {
+		// Eg. initializeCodeAssistCategoryDisabled("org.eclipse.jdt.ui.javaPostfixProposalCategory"); //$NON-NLS-1$
+	}
+
+	/**
+	 * Disable (by default) the given category id for both the default content
+	 * assist list (CODEASSIST_EXCLUDED_CATEGORIES) and the cycling content
+	 * assist list (CODEASSIST_CATEGORY_ORDER)
+	 *
+	 * @param id The category id for the proposal feature to disable by default
+	 */
+	@SuppressWarnings("unused")
+	private static void initializeCodeAssistCategoryDisabled(String id) {
+		// If preference migrated, nothing to do
+		if (isCodeAssistMigrated(id)) {
+			return;
+		}
+
+		String currPrefExcludedValue= PreferenceConstants.getPreferenceStore().getString(PreferenceConstants.CODEASSIST_EXCLUDED_CATEGORIES);
+		Set<String> disabled= new HashSet<>();
+		StringTokenizer tok= new StringTokenizer(currPrefExcludedValue, "\0");  //$NON-NLS-1$
+		while (tok.hasMoreTokens()) {
+			disabled.add(tok.nextToken());
+		}
+
+		// preference not migrated, and not in user preferences
+		if (!disabled.isEmpty() && !disabled.contains(id)) {
+			String newPrefExcludedValue= currPrefExcludedValue + id + "\0"; //$NON-NLS-1$
+			PreferenceConstants.getPreferenceStore().setValue(PreferenceConstants.CODEASSIST_EXCLUDED_CATEGORIES, newPrefExcludedValue);
+
+			// retrieve the id=rank to add from CODEASSIST_CATEGORY_ORDER from the default preferences
+			String defPrefOrderValue= PreferenceConstants.getPreferenceStore().getDefaultString(PreferenceConstants.CODEASSIST_CATEGORY_ORDER);
+			tok= new StringTokenizer(defPrefOrderValue, "\0"); //$NON-NLS-1$
+			while (tok.hasMoreTokens()) {
+				StringTokenizer inner= new StringTokenizer(tok.nextToken(), ":"); //$NON-NLS-1$
+				String key= inner.nextToken();
+				int rank= Integer.parseInt(inner.nextToken());
+				if (id.equals(key)) {
+					String currPrefOrderValue= PreferenceConstants.getPreferenceStore().getString(PreferenceConstants.CODEASSIST_CATEGORY_ORDER);
+					String newPreferenceOrderValue= currPrefOrderValue + id + ":" + rank + "\0"; //$NON-NLS-1$ //$NON-NLS-2$
+					PreferenceConstants.getPreferenceStore().setValue(PreferenceConstants.CODEASSIST_CATEGORY_ORDER, newPreferenceOrderValue);
+				}
+			}
+		}
+
+		// set as migrated
+		setCodeAssistMigrated(id);
+	}
+
+	private static boolean isCodeAssistMigrated(String id) {
+		String key= CODE_ASSIST_MIGRATED + "_" + id; //$NON-NLS-1$
+		boolean res= Platform.getPreferencesService().getBoolean(JavaPlugin.getPluginId(), key, false, null);
+		return res;
+	}
+
+	private static void setCodeAssistMigrated(String id) {
+		String key= CODE_ASSIST_MIGRATED + "_" + id; //$NON-NLS-1$
+		IEclipsePreferences preferences= InstanceScope.INSTANCE.getNode(JavaPlugin.getPluginId());
+		preferences.putBoolean(key, true);
+		try {
+			preferences.flush();
+		} catch (BackingStoreException e) {
+			JavaPlugin.log(e);
+		}
+	}
 }
