@@ -28,6 +28,7 @@ import org.osgi.framework.Bundle;
 
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.ImageData;
+import org.eclipse.swt.widgets.Display;
 
 import org.eclipse.core.runtime.FileLocator;
 import org.eclipse.core.runtime.IPath;
@@ -450,7 +451,7 @@ public class JavaPluginImages {
 	public static final ImageDescriptor DESC_OVR_OPENS= createUnManagedCached(T_OVR, "opens_pkg_ovr.png"); //$NON-NLS-1$
 	public static final ImageDescriptor DESC_OVR_READS= createUnManagedCached(T_OVR, "reads_mod_ovr.png"); //$NON-NLS-1$
 	public static final ImageDescriptor DESC_OVR_PATCH= createUnManagedCached(T_OVR, "patch_ovr.png"); //$NON-NLS-1$
-	
+
     // Call Hierarchy
     public static final ImageDescriptor DESC_OVR_RECURSIVE= createUnManaged(T_OVR, "recursive_co.png");              //$NON-NLS-1$
     public static final ImageDescriptor DESC_OVR_MAX_LEVEL= createUnManaged(T_OVR, "maxlevel_co.png");                    //$NON-NLS-1$
@@ -504,6 +505,9 @@ public class JavaPluginImages {
 
 	public static final ImageDescriptor DESC_ELCL_MODIFYALL= createUnManaged(T_ELCL, "modifyall.png"); //$NON-NLS-1$
 
+	public static final ImageDescriptor DESC_ELCL_REMOVE_EXTRA_LINES= createUnManaged(T_ELCL, "remove_extra_lines.png"); //$NON-NLS-1$
+	public static final ImageDescriptor DESC_DLCL_REMOVE_EXTRA_LINES= createUnManaged(T_DLCL, "remove_extra_lines.png"); //$NON-NLS-1$
+
 	// Image descriptors used for formatter line wrapping preferences
 	public static final ImageDescriptor DESC_ELCL_INDENT_COLUMN= createUnManaged(T_ELCL, "indent_column.png"); //$NON-NLS-1$
 	public static final ImageDescriptor DESC_DLCL_INDENT_COLUMN= createUnManaged(T_DLCL, "indent_column.png"); //$NON-NLS-1$
@@ -563,11 +567,11 @@ public class JavaPluginImages {
 
 	private static class SmallIntMap<V> {
 		private static int fgSize = 1;
-		
+
 		private int[] keys = new int[fgSize];
 		@SuppressWarnings("unchecked")
 		private V[] values = (V[]) new Object[fgSize];
-		
+
 		/**
 		 * @param key any int except for 0
 		 * @param computer computes the value for the given key
@@ -663,7 +667,11 @@ public class JavaPluginImages {
 	 */
 	/* package */ static ImageRegistry getImageRegistry() {
 		if (fgImageRegistry == null) {
-			fgImageRegistry= new ImageRegistry();
+			Display display = Display.getCurrent();
+			if (display == null) {
+				display = Display.getDefault();
+			}
+			fgImageRegistry= new ImageRegistry(display);
 			for (Iterator<String> iter= fgAvoidSWTErrorMap.keySet().iterator(); iter.hasNext();) {
 				String key= iter.next();
 				fgImageRegistry.put(key, fgAvoidSWTErrorMap.get(key));
@@ -761,12 +769,9 @@ public class JavaPluginImages {
 		try {
 			URI uri= new URI("platform", null, uriPath.toString(), null); //$NON-NLS-1$
 			url= uri.toURL();
-		} catch (MalformedURLException e) {
-			// no image
-		} catch (URISyntaxException e) {
+		} catch (MalformedURLException | URISyntaxException e) {
 			// no image
 		}
-		
 		URL foundUrl= FileLocator.find(url);
 		if (foundUrl != null) {
 			return ImageDescriptor.createFromURL(url);
