@@ -16,7 +16,6 @@ package org.eclipse.jdt.internal.ui.compare;
 import java.lang.reflect.Field;
 import java.util.ArrayList;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.Map.Entry;
 
@@ -101,13 +100,13 @@ public class JavaMergeViewer extends TextMergeViewer {
 	public JavaMergeViewer(Composite parent, int styles, CompareConfiguration mp) {
 		super(parent, styles | SWT.LEFT_TO_RIGHT, mp);
 	}
-	
+
 	private IPreferenceStore getPreferenceStore() {
 		if (fPreferenceStore == null)
 			setPreferenceStore(createChainedPreferenceStore(null));
 		return fPreferenceStore;
 	}
-	
+
 	@Override
 	protected void handleDispose(DisposeEvent event) {
 		setPreferenceStore(null);
@@ -167,8 +166,7 @@ public class JavaMergeViewer extends TextMergeViewer {
 
 	private void handlePropertyChange(PropertyChangeEvent event) {
 		if (fSourceViewerConfiguration != null) {
-			for (Iterator<Entry<SourceViewer, JavaSourceViewerConfiguration>> iterator= fSourceViewerConfiguration.entrySet().iterator(); iterator.hasNext();) {
-				Entry<SourceViewer, JavaSourceViewerConfiguration> entry= iterator.next();
+			for (Entry<SourceViewer, JavaSourceViewerConfiguration> entry : fSourceViewerConfiguration.entrySet()) {
 				JavaSourceViewerConfiguration configuration= entry.getValue();
 				if (configuration.affectsTextPresentation(event)) {
 					configuration.handlePropertyChangeEvent(event);
@@ -233,7 +231,7 @@ public class JavaMergeViewer extends TextMergeViewer {
 				((CompilationUnitEditorAdapter)editor).setEditable(state);
 		}
 	}
-	
+
 	/*
 	 * @see org.eclipse.compare.contentmergeviewer.TextMergeViewer#isEditorBacked(org.eclipse.jface.text.ITextViewer)
 	 * @since 3.5
@@ -347,14 +345,13 @@ public class JavaMergeViewer extends TextMergeViewer {
 					children= javaContainer.getChildren();
 					if (children.length > 0) {
 						JavaNode packageDecl= null;
-						for (int i= 0; i < children.length; i++) {
-							JavaNode child= (JavaNode) children[i];
+						for (JavaNode child : (JavaNode[])children) {
 							switch (child.getTypeCode()) {
-							case JavaNode.PACKAGE:
-								packageDecl= child;
-								break;
-							case JavaNode.CLASS:
-								return child.getRange().getOffset();
+								case JavaNode.PACKAGE:
+									packageDecl= child;
+									break;
+								case JavaNode.CLASS:
+									return child.getRange().getOffset();
 							}
 						}
 						if (packageDecl != null) {
@@ -471,7 +468,7 @@ public class JavaMergeViewer extends TextMergeViewer {
 			fPreferenceStore.addPropertyChangeListener(fPreferenceChangeListener);
 		}
 	}
-	
+
 	/*
 	 * @see org.eclipse.compare.contentmergeviewer.TextMergeViewer#createSourceViewer(org.eclipse.swt.widgets.Composite, int)
 	 * @since 3.5
@@ -498,7 +495,7 @@ public class JavaMergeViewer extends TextMergeViewer {
 
 		return sourceViewer;
 	}
-	
+
 	@Override
 	protected void setActionsActivated(SourceViewer sourceViewer, boolean state) {
 		if (fEditor != null) {
@@ -531,15 +528,14 @@ public class JavaMergeViewer extends TextMergeViewer {
 			}
 		}
 	}
-	
+
 	@SuppressWarnings("unchecked")
 	@Override
 	public <T> T getAdapter(Class<T> adapter) {
 		if (adapter == ITextEditorExtension3.class) {
 			IEditorInput activeInput= super.getAdapter(IEditorInput.class);
 			if (activeInput != null) {
-				for (Iterator<CompilationUnitEditorAdapter> iterator= fEditor.values().iterator(); iterator.hasNext();) {
-					CompilationUnitEditorAdapter editor= iterator.next();
+				for (CompilationUnitEditorAdapter editor : fEditor.values()) {
 					if (activeInput.equals(editor.getEditorInput()))
 						return (T) editor;
 				}
@@ -553,7 +549,7 @@ public class JavaMergeViewer extends TextMergeViewer {
 		private boolean fInputSet = false;
 		private int fTextOrientation;
 		private boolean fEditable;
-		
+
 		CompilationUnitEditorAdapter(int textOrientation) {
 			super();
 			fTextOrientation = textOrientation;
@@ -595,7 +591,7 @@ public class JavaMergeViewer extends TextMergeViewer {
 				protected void handleDispose() {
 					super.handleDispose();
 
-					// dispose the compilation unit adapter 
+					// dispose the compilation unit adapter
 					dispose();
 
 					fEditor.remove(this);
@@ -654,17 +650,13 @@ public class JavaMergeViewer extends TextMergeViewer {
 		Field field= null;
 		try {
 			field= AbstractTextEditor.class.getDeclaredField("fSourceViewer"); //$NON-NLS-1$
-		} catch (SecurityException ex) {
-			JavaPlugin.log(ex);
-		} catch (NoSuchFieldException ex) {
+		} catch (SecurityException | NoSuchFieldException ex) {
 			JavaPlugin.log(ex);
 		}
 		field.setAccessible(true);
 		try {
 			field.set(editor, viewer);
-		} catch (IllegalArgumentException ex) {
-			JavaPlugin.log(ex);
-		} catch (IllegalAccessException ex) {
+		} catch (IllegalArgumentException | IllegalAccessException ex) {
 			JavaPlugin.log(ex);
 		}
 	}
