@@ -18,14 +18,18 @@ import java.util.HashSet;
 import java.util.List;
 
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.ModifyEvent;
+import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Link;
 import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.widgets.Text;
 
 import org.eclipse.core.runtime.IStatus;
 
@@ -33,9 +37,12 @@ import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.ToolBarManager;
 import org.eclipse.jface.dialogs.IDialogSettings;
 import org.eclipse.jface.viewers.CheckboxTreeViewer;
+import org.eclipse.jface.viewers.IBaseLabelProvider;
 import org.eclipse.jface.viewers.ITreeContentProvider;
+import org.eclipse.jface.viewers.LabelProvider;
 import org.eclipse.jface.viewers.Viewer;
 import org.eclipse.jface.viewers.ViewerComparator;
+import org.eclipse.jface.viewers.ViewerFilter;
 
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.dialogs.ContainerCheckedTreeViewer;
@@ -63,6 +70,7 @@ import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.JavaPluginImages;
 import org.eclipse.jdt.internal.ui.JavaUIMessages;
 import org.eclipse.jdt.internal.ui.javaeditor.CompilationUnitEditor;
+import org.eclipse.jdt.internal.ui.util.PatternMatcher;
 import org.eclipse.jdt.internal.ui.util.ViewerPane;
 import org.eclipse.jdt.internal.ui.viewsupport.BindingLabelProvider;
 
@@ -142,9 +150,10 @@ public class OverrideMethodDialog extends SourceActionDialog {
 		public Object[] getChildren(Object parentElement) {
 			if (parentElement instanceof ITypeBinding) {
 				ArrayList<IMethodBinding> result= new ArrayList<>(fMethods.length);
-				for (int index= 0; index < fMethods.length; index++) {
-					if (fMethods[index].getDeclaringClass().isEqualTo((IBinding) parentElement))
-						result.add(fMethods[index]);
+				for (IMethodBinding fMethod : fMethods) {
+					if (fMethod.getDeclaringClass().isEqualTo((IBinding) parentElement)) {
+						result.add(fMethod);
+					}
 				}
 				return result.toArray();
 			}
@@ -258,9 +267,10 @@ public class OverrideMethodDialog extends SourceActionDialog {
 		@Override
 		public IStatus validate(Object[] selection) {
 			int count= 0;
-			for (int index= 0; index < selection.length; index++) {
-				if (selection[index] instanceof IMethodBinding)
+			for (Object s : selection) {
+				if (s instanceof IMethodBinding) {
 					count++;
+				}
 			}
 			if (count == 0)
 				return new StatusInfo(IStatus.ERROR, ""); //$NON-NLS-1$
@@ -282,9 +292,8 @@ public class OverrideMethodDialog extends SourceActionDialog {
 			if (result != null)
 				return result;
 		}
-		final ITypeBinding[] types= binding.getInterfaces();
-		for (int index= 0; index < types.length; index++) {
-			final ITypeBinding result= getSuperType(types[index], name);
+		for (ITypeBinding t : binding.getInterfaces()) {
+			final ITypeBinding result= getSuperType(t, name);
 			if (result != null)
 				return result;
 		}
@@ -304,26 +313,23 @@ public class OverrideMethodDialog extends SourceActionDialog {
 			final IPackageBinding pack= binding.getPackage();
 			final IMethodBinding[] methods= StubUtility2Core.getOverridableMethods(fUnit.getAST(), binding, false);
 			List<IMethodBinding> list= new ArrayList<>(methods.length);
-			for (int index= 0; index < methods.length; index++) {
-				final IMethodBinding cur= methods[index];
+			for (IMethodBinding cur : methods) {
 				if (Bindings.isVisibleInHierarchy(cur, pack))
 					list.add(cur);
 			}
 			overridable= list.toArray(new IMethodBinding[list.size()]);
 		} else
 			overridable= new IMethodBinding[] {};
-		for (int i= 0; i < overridable.length; i++) {
-			if (Modifier.isAbstract(overridable[i].getModifiers())) {
-				toImplement.add(overridable[i]);
+		for (IMethodBinding b : overridable) {
+			if (Modifier.isAbstract(b.getModifiers())) {
+				toImplement.add(b);
 			}
 		}
 
 		if (binding != null) {
 			ITypeBinding cloneable= getSuperType(binding, "java.lang.Cloneable"); //$NON-NLS-1$
 			if (cloneable != null) {
-				IMethodBinding[] methods= fUnit.getAST().resolveWellKnownType("java.lang.Object").getDeclaredMethods(); //$NON-NLS-1$
-				for (int index= 0; index < methods.length; index++) {
-					IMethodBinding method= methods[index];
+				for (IMethodBinding method : fUnit.getAST().resolveWellKnownType("java.lang.Object").getDeclaredMethods()) { //$NON-NLS-1$
 					if (method.getName().equals("clone") && method.getParameterTypes().length == 0) //$NON-NLS-1$
 						toImplement.add(method);
 				}
@@ -334,13 +340,13 @@ public class OverrideMethodDialog extends SourceActionDialog {
 		setInitialSelections((Object[]) toImplementArray);
 
 		HashSet<ITypeBinding> expanded= new HashSet<>(toImplementArray.length);
-		for (int i= 0; i < toImplementArray.length; i++) {
-			expanded.add(toImplementArray[i].getDeclaringClass());
+		for (IMethodBinding b : toImplementArray) {
+			expanded.add(b.getDeclaringClass());
 		}
 
 		HashSet<ITypeBinding> types= new HashSet<>(overridable.length);
-		for (int i= 0; i < overridable.length; i++) {
-			types.add(overridable[i].getDeclaringClass());
+		for (IMethodBinding b : overridable) {
+			types.add(b.getDeclaringClass());
 		}
 
 		ITypeBinding[] typesArrays= types.toArray(new ITypeBinding[types.size()]);
@@ -422,8 +428,55 @@ public class OverrideMethodDialog extends SourceActionDialog {
 		return treeViewer;
 	}
 
+	@Override
+	protected Text createFilterComposite(Composite inner) {
+		Label filterTextLabel = new Label(inner, SWT.NONE);
+		filterTextLabel.setText(JavaUIMessages.OverrideMethodDialog_filter_description);
+		Text filterText= new Text(inner, SWT.SEARCH | SWT.BORDER);
+		filterText.setMessage(JavaUIMessages.OverrideMethodDialog_searchtext_message);
+		return filterText;
+	}
+
 	public boolean hasMethodsToOverride() {
 		return getContentProvider().getElements(null).length > 0;
 	}
 
+	@Override
+	protected void addMethodSearchFilter(Text filterText, CheckboxTreeViewer treeViewer) {
+
+		filterText.addModifyListener(new ModifyListener() {
+			@Override
+			public void modifyText(ModifyEvent e) {
+				final String searchText = filterText.getText();
+
+				PatternMatcher matcher = new PatternMatcher(searchText);
+				ViewerFilter vf = null;
+				if(!searchText.trim().isEmpty()) {
+					vf = new ViewerFilter() {
+
+						@Override
+						public boolean select(Viewer viewer, Object parentElement, Object element) {
+							IBaseLabelProvider lblProvider= getTreeViewer().getLabelProvider();
+							if(element instanceof ITypeBinding) {
+								return true;
+							}
+
+							String filterableName = null;
+							if(lblProvider instanceof LabelProvider) {
+								filterableName = ((LabelProvider)lblProvider).getText(element);
+								return matcher.matches(filterableName);
+							}
+
+							return false;
+						}
+					};
+					treeViewer.setFilters(vf);
+					treeViewer.expandAll();
+				} else {
+					treeViewer.resetFilters();
+				}
+			}
+		});
+	}
+
 }
