@@ -30,6 +30,7 @@ import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.widgets.Text;
 import org.eclipse.swt.widgets.TreeItem;
 
 import org.eclipse.jface.dialogs.IDialogConstants;
@@ -82,7 +83,7 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 	 * <li>{@link #INSERT_LAST_INDEX}</li>
 	 * <li>{@link #INSERT_POSITION_FROM_EDITOR}</li>
 	 * </ul>
-	 * 
+	 *
 	 * <strong>Note:</strong> Since 3.4.2 the key is "InsertPosition.v2" instead of "InsertPosition"
 	 * in order to reset to the new defaults.
 	 */
@@ -166,8 +167,7 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 		fLabels.add(ActionMessages.SourceActionDialog_first);
 		fLabels.add(ActionMessages.SourceActionDialog_last);
 
-		for (int i = 0; i < members.length; i++) {
-			IJavaElement curr= members[i];
+		for (IJavaElement curr : members) {
 			String methodLabel= JavaElementLabels.getElementLabel(curr, JavaElementLabels.M_PARAMETER_TYPES);
 			fLabels.add(Messages.format(ActionMessages.SourceActionDialog_after, methodLabel));
 			fInsertPositions.add(findSibling(curr, members));
@@ -382,7 +382,13 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 		innerLayout.marginWidth= 0;
 		inner.setLayout(innerLayout);
 		inner.setFont(parent.getFont());
-
+		Text filterText = createFilterComposite(inner);
+		if(filterText != null) {
+			gd = new GridData();
+			gd.widthHint = convertWidthInCharsToPixels(fWidth);
+			gd.horizontalSpan = 2 ;
+			filterText.setLayoutData(gd);
+		}
 		CheckboxTreeViewer treeViewer= createTreeViewer(inner);
 		gd= new GridData(GridData.FILL_BOTH);
 		gd.widthHint = convertWidthInCharsToPixels(fWidth);
@@ -409,11 +415,19 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 		gd= new GridData(GridData.FILL_BOTH);
 		composite.setLayoutData(gd);
 
+		if(filterText != null) {
+			addMethodSearchFilter(filterText, treeViewer);
+			filterText.forceFocus();
+		}
 		applyDialogFont(composite);
 
 		return composite;
 	}
 
+	protected Text createFilterComposite(@SuppressWarnings("unused") Composite inner) {
+		return null; // No filter as default
+	}
+
 	/**
 	 * Clients override to provide link control
 	 *
@@ -511,9 +525,9 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 		if (items.length > 0) {
 			Object revealedElement= items[0];
 
-			for (int i= 0; i < items.length; i++) {
-				if (items[i].getChecked()) {
-					revealedElement= items[i].getData();
+			for (TreeItem item : items) {
+				if (item.getChecked()) {
+					revealedElement= item.getData();
 					break;
 				}
 			}
@@ -704,4 +718,9 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 		return JavaPlugin.getDefault().getDialogSettingsSection("DialogBounds_" + getClass().getSimpleName()); //$NON-NLS-1$
 	}
 
+	@SuppressWarnings("unused")
+	protected void addMethodSearchFilter(Text filterText, CheckboxTreeViewer treeViewer) {
+		//Default is do nothing
+	}
+
 }
