@@ -88,7 +88,7 @@ public class RedundantSemicolonsCleanUp extends AbstractMultiFix implements ICle
 	@SuppressWarnings("nls")
 	@Override
 	public String getPreview() {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("\n");
 		buf.append("enum color {\n");
 		buf.append("  red, yellow, green\n");
@@ -122,7 +122,7 @@ public class RedundantSemicolonsCleanUp extends AbstractMultiFix implements ICle
 			textedits.add(new TextEditGroup(label, edit));
 		}
 	}
-	
+
 	@Override
 	protected ICleanUpFix createFix(CompilationUnit unit) throws CoreException {
 		if (!isEnabled(CleanUpConstants.REMOVE_REDUNDANT_SEMICOLONS)) {
@@ -176,7 +176,7 @@ public class RedundantSemicolonsCleanUp extends AbstractMultiFix implements ICle
 				}
 				return false;
 			}
-			
+
 			@Override
 			public boolean visit(Block node) {
 				if (!(node.getParent() instanceof LambdaExpression)) {
@@ -213,11 +213,10 @@ public class RedundantSemicolonsCleanUp extends AbstractMultiFix implements ICle
 			return null;
 
 		CompilationUnitChange result= new CompilationUnitChange(fName, fCompilationUnit);
-		for (int i= 0; i < fEditGroups.length; i++) {
-			TextEdit[] edits= fEditGroups[i].getTextEdits();
-			String groupName= fEditGroups[i].getName();
-			for (int j= 0; j < edits.length; j++) {
-				TextChangeCompatibility.addTextEdit(result, groupName, edits[j]);
+		for (TextEditGroup editGroup : fEditGroups) {
+			String groupName= editGroup.getName();
+			for (TextEdit edit : editGroup.getTextEdits()) {
+				TextChangeCompatibility.addTextEdit(result, groupName, edit);
 			}
 		}
 		return result;
