@@ -113,13 +113,10 @@ public final class ClipboardOperationAction extends TextEditorAction {
 		}
 
 		public ClipboardData(byte[] bytes) throws IOException {
-			DataInputStream dataIn = new DataInputStream(new ByteArrayInputStream(bytes));
-			try {
+			try (DataInputStream dataIn = new DataInputStream(new ByteArrayInputStream(bytes))) {
 				fOriginHandle= dataIn.readUTF();
 				fTypeImports= readArray(dataIn);
 				fStaticImports= readArray(dataIn);
-			} finally {
-				dataIn.close();
 			}
 		}
 
@@ -135,8 +132,8 @@ public final class ClipboardOperationAction extends TextEditorAction {
 
 		private static void writeArray(DataOutputStream dataOut, String[] array) throws IOException {
 			dataOut.writeInt(array.length);
-			for (int i = 0; i < array.length; i++) {
-				dataOut.writeUTF(array[i]);
+			for (String a : array) {
+				dataOut.writeUTF(a);
 			}
 		}
 
@@ -154,13 +151,11 @@ public final class ClipboardOperationAction extends TextEditorAction {
 
 		public byte[] serialize() throws IOException {
 			ByteArrayOutputStream out = new ByteArrayOutputStream();
-			DataOutputStream dataOut = new DataOutputStream(out);
-			try {
+			try (DataOutputStream dataOut = new DataOutputStream(out)) {
 				dataOut.writeUTF(fOriginHandle);
 				writeArray(dataOut, fTypeImports);
 				writeArray(dataOut, fStaticImports);
 			} finally {
-				dataOut.close();
 				out.close();
 			}
 
@@ -306,7 +301,7 @@ public final class ClipboardOperationAction extends TextEditorAction {
 
 	/**
 	 * Returns whether the Smart Insert Mode is selected.
-	 * 
+	 *
 	 * @return <code>true</code> if the Smart Insert Mode is selected
 	 * @since 3.7
 	 */
@@ -548,21 +543,18 @@ public final class ClipboardOperationAction extends TextEditorAction {
 
 	private void addImports(final ICompilationUnit unit, ClipboardData data) throws CoreException {
 		final ImportRewrite rewrite= StubUtility.createImportRewrite(unit, true);
-		String[] imports= data.getTypeImports();
-		for (int i= 0; i < imports.length; i++) {
-			String type= imports[i];
+		for (String type : data.getTypeImports()) {
 			if (type.indexOf('.') != -1 || JavaModelUtil.isVersionLessThan(unit.getJavaProject().getOption(JavaCore.COMPILER_COMPLIANCE, true), JavaCore.VERSION_1_4)) {
 				rewrite.addImport(type);
 			}
 		}
-		String[] staticImports= data.getStaticImports();
-		for (int i= 0; i < staticImports.length; i++) {
-			String name= Signature.getSimpleName(staticImports[i]);
+		for (String staticImport : data.getStaticImports()) {
+			String name= Signature.getSimpleName(staticImport);
 			boolean isField= !name.endsWith("()"); //$NON-NLS-1$
 			if (!isField) {
 				name= name.substring(0, name.length() - 2);
 			}
-			String qualifier= Signature.getQualifier(staticImports[i]);
+			String qualifier= Signature.getQualifier(staticImport);
 			rewrite.addStaticImport(qualifier, name, isField);
 		}
 
