@@ -339,25 +339,25 @@ public class JavaSourceViewer extends ProjectionViewer implements IPropertyChang
 
         return null;
     }
-    
+
 	/**
 	 * Sets the viewer's background color to the given control's background color.
 	 * The background color is <em>only</em> set if it's visibly distinct from the
 	 * default Java source text color.
-	 * 
+	 *
 	 * @param control the control with the default background color
 	 * @since 3.7
 	 */
 	public void adaptBackgroundColor(Control control) {
 		// workaround for dark editor background color, see https://bugs.eclipse.org/330680
-		
+
 		Color defaultColor= control.getBackground();
 		float[] defaultBgHSB= defaultColor.getRGB().getHSB();
-		
+
 		Color javaDefaultColor= JavaUI.getColorManager().getColor(IJavaColorConstants.JAVA_DEFAULT);
 		RGB javaDefaultRGB= javaDefaultColor != null ? javaDefaultColor.getRGB() : new RGB(255, 255, 255);
 		float[] javaDefaultHSB= javaDefaultRGB.getHSB();
-		
+
 		if (Math.abs(defaultBgHSB[2] - javaDefaultHSB[2]) >= 0.5f) {
 			getTextWidget().setBackground(defaultColor);
 			if (fBackgroundColor != null) {
@@ -715,24 +715,6 @@ public class JavaSourceViewer extends ProjectionViewer implements IPropertyChang
 		return null;
 	}
 
-	@Override
-	public void updateCodeMinings() {
-		// Here we disable this method which is called by AbstractTextEditor#installCodeMiningProviders which updates code mining (draw minings in the UI)
-		// In JDT code mining case, the update code mining must be done when ICompilationUnit is reconciled (and not when editor is opened).
-		// The update code mining is done by JavaCodeMiningReconciler which calls doUpdateCodeMinings:
-		// - on install
-		// - when compilation unit is reconciled
-	}
-
-	/**
-	 * Update java code minings.
-	 *
-	 * @since 3.16
-	 */
-	void doUpdateCodeMinings() {
-		super.updateCodeMinings();
-	}
-
 	/**
 	 * Reset the registered code mining providers.
 	 *
@@ -740,6 +722,5 @@ public class JavaSourceViewer extends ProjectionViewer implements IPropertyChang
 	 */
 	void resetCodeMinings() {
 		super.setCodeMiningProviders(null);
-		doUpdateCodeMinings();
 	}
 }
