@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -66,69 +66,69 @@ public class SemanticHighlightings {
 	/**
 	 * A named preference part that controls the highlighting of static final fields.
 	 */
-	public static final String STATIC_FINAL_FIELD="staticFinalField"; //$NON-NLS-1$
+	public static final String STATIC_FINAL_FIELD= SemanticHighlightingsCore.STATIC_FINAL_FIELD;
 
 	/**
 	 * A named preference part that controls the highlighting of static fields.
 	 */
-	public static final String STATIC_FIELD="staticField"; //$NON-NLS-1$
+	public static final String STATIC_FIELD= SemanticHighlightingsCore.STATIC_FIELD;
 
 	/**
 	 * A named preference part that controls the highlighting of fields.
 	 */
-	public static final String FIELD="field"; //$NON-NLS-1$
+	public static final String FIELD= SemanticHighlightingsCore.FIELD;
 
 	/**
 	 * A named preference part that controls the highlighting of method declarations.
 	 */
-	public static final String METHOD_DECLARATION="methodDeclarationName"; //$NON-NLS-1$
+	public static final String METHOD_DECLARATION= SemanticHighlightingsCore.METHOD_DECLARATION;
 
 	/**
 	 * A named preference part that controls the highlighting of static method invocations.
 	 */
-	public static final String STATIC_METHOD_INVOCATION="staticMethodInvocation"; //$NON-NLS-1$
+	public static final String STATIC_METHOD_INVOCATION= SemanticHighlightingsCore.STATIC_METHOD_INVOCATION;
 
 	/**
 	 * A named preference part that controls the highlighting of inherited method invocations.
 	 */
-	public static final String INHERITED_METHOD_INVOCATION="inheritedMethodInvocation"; //$NON-NLS-1$
+	public static final String INHERITED_METHOD_INVOCATION= SemanticHighlightingsCore.INHERITED_METHOD_INVOCATION;
 
 	/**
 	 * A named preference part that controls the highlighting of annotation element references.
 	 * @since 3.1
 	 */
-	public static final String ANNOTATION_ELEMENT_REFERENCE="annotationElementReference"; //$NON-NLS-1$
+	public static final String ANNOTATION_ELEMENT_REFERENCE= SemanticHighlightingsCore.ANNOTATION_ELEMENT_REFERENCE;
 
 	/**
 	 * A named preference part that controls the highlighting of abstract method invocations.
 	 */
-	public static final String ABSTRACT_METHOD_INVOCATION="abstractMethodInvocation"; //$NON-NLS-1$
+	public static final String ABSTRACT_METHOD_INVOCATION= SemanticHighlightingsCore.ABSTRACT_METHOD_INVOCATION;
 
 	/**
 	 * A named preference part that controls the highlighting of local variables.
 	 */
-	public static final String LOCAL_VARIABLE_DECLARATION="localVariableDeclaration"; //$NON-NLS-1$
+	public static final String LOCAL_VARIABLE_DECLARATION= SemanticHighlightingsCore.LOCAL_VARIABLE_DECLARATION;
 
 	/**
 	 * A named preference part that controls the highlighting of local variables.
 	 */
-	public static final String LOCAL_VARIABLE="localVariable"; //$NON-NLS-1$
+	public static final String LOCAL_VARIABLE= SemanticHighlightingsCore.LOCAL_VARIABLE;
 
 	/**
 	 * A named preference part that controls the highlighting of parameter variables.
 	 */
-	public static final String PARAMETER_VARIABLE="parameterVariable"; //$NON-NLS-1$
+	public static final String PARAMETER_VARIABLE= SemanticHighlightingsCore.PARAMETER_VARIABLE;
 
 	/**
 	 * A named preference part that controls the highlighting of deprecated members.
 	 */
-	public static final String DEPRECATED_MEMBER="deprecatedMember"; //$NON-NLS-1$
+	public static final String DEPRECATED_MEMBER= SemanticHighlightingsCore.DEPRECATED_MEMBER;
 
 	/**
 	 * A named preference part that controls the highlighting of type parameters.
 	 * @since 3.1
 	 */
-	public static final String TYPE_VARIABLE="typeParameter"; //$NON-NLS-1$
+	public static final String TYPE_VARIABLE= SemanticHighlightingsCore.TYPE_VARIABLE;
 
 	/**
 	 * A named preference part that controls the highlighting of methods
@@ -136,7 +136,7 @@ public class SemanticHighlightings {
 	 *
 	 * @since 3.1
 	 */
-	public static final String METHOD="method"; //$NON-NLS-1$
+	public static final String METHOD= SemanticHighlightingsCore.METHOD;
 
 	/**
 	 * A named preference part that controls the highlighting of auto(un)boxed
@@ -144,68 +144,73 @@ public class SemanticHighlightings {
 	 *
 	 * @since 3.1
 	 */
-	public static final String AUTOBOXING="autoboxing"; //$NON-NLS-1$
+	public static final String AUTOBOXING= SemanticHighlightingsCore.AUTOBOXING;
 
 	/**
 	 * A named preference part that controls the highlighting of classes.
 	 *
 	 * @since 3.2
 	 */
-	public static final String CLASS="class"; //$NON-NLS-1$
+	public static final String CLASS= SemanticHighlightingsCore.CLASS;
 
 	/**
 	 * A named preference part that controls the highlighting of enums.
 	 *
 	 * @since 3.2
 	 */
-	public static final String ENUM="enum"; //$NON-NLS-1$
+	public static final String ENUM= SemanticHighlightingsCore.ENUM;
 
 	/**
 	 * A named preference part that controls the highlighting of interfaces.
 	 *
 	 * @since 3.2
 	 */
-	public static final String INTERFACE="interface"; //$NON-NLS-1$
+	public static final String INTERFACE= SemanticHighlightingsCore.INTERFACE;
 
 	/**
 	 * A named preference part that controls the highlighting of annotations.
 	 *
 	 * @since 3.2
 	 */
-	public static final String ANNOTATION="annotation"; //$NON-NLS-1$
+	public static final String ANNOTATION= SemanticHighlightingsCore.ANNOTATION;
 
 	/**
 	 * A named preference part that controls the highlighting of type arguments.
 	 *
 	 * @since 3.2
 	 */
-	public static final String TYPE_ARGUMENT="typeArgument"; //$NON-NLS-1$
+	public static final String TYPE_ARGUMENT= SemanticHighlightingsCore.TYPE_ARGUMENT;
 
 	/**
 	 * A named preference part that controls the highlighting of numbers.
 	 *
 	 * @since 3.4
 	 */
-	public static final String NUMBER="number"; //$NON-NLS-1$
+	public static final String NUMBER= SemanticHighlightingsCore.NUMBER;
 
 	/**
 	 * A named preference part that controls the highlighting of abstract classes.
 	 *
 	 * @since 3.7
 	 */
-	public static final String ABSTRACT_CLASS="abstractClass"; //$NON-NLS-1$
+	public static final String ABSTRACT_CLASS= SemanticHighlightingsCore.ABSTRACT_CLASS;
 
 	/**
 	 * A named preference part that controls the highlighting of inherited fields.
 	 *
 	 * @since 3.8
 	 */
-	public static final String INHERITED_FIELD="inheritedField"; //$NON-NLS-1$
+	public static final String INHERITED_FIELD= SemanticHighlightingsCore.INHERITED_FIELD;
 
 	/**
 	 * A named preference part that controls the highlighting of 'var' keywords.
 	 */
-	public static final String VAR_KEYWORD= "varKeyword"; //$NON-NLS-1$
+	public static final String VAR_KEYWORD= SemanticHighlightingsCore.VAR_KEYWORD;
+
+	/**
+	 * A named preference part that controls the highlighting of 'yield' keywords.
+	 */
+	public static final String YIELD_KEYWORD= SemanticHighlightingsCore.YIELD_KEYWORD;
 
 	/**
 	 * Semantic highlightings
@@ -1967,6 +1972,47 @@ public class SemanticHighlightings {
 		}
 	}
 
+	/**
+	 * Semantic highlighting for 'yield' keyword.
+	 */
+	static final class YieldKeywordHighlighting extends SemanticHighlighting {
+
+		@Override
+		public String getPreferenceKey() {
+			return YIELD_KEYWORD;
+		}
+
+		@Override
+		public RGB getDefaultDefaultTextColor() {
+			return new RGB(127, 0, 85);
+		}
+
+		@Override
+		public boolean isBoldByDefault() {
+			return true;
+		}
+
+		@Override
+		public boolean isItalicByDefault() {
+			return false;
+		}
+
+		@Override
+		public boolean isEnabledByDefault() {
+			return true;
+		}
+
+		@Override
+		public String getDisplayName() {
+			return PreferencesMessages.JavaEditorPreferencePage_yieldKeyword;
+		}
+
+		@Override
+		public boolean consumes(SemanticToken token) {
+			return false;
+		}
+	}
+
 	/**
 	 * A named preference that controls the given semantic highlighting's color.
 	 *
@@ -2059,6 +2105,7 @@ public class SemanticHighlightings {
 				new InterfaceHighlighting(),
 				new NumberHighlighting(),
 				new VarKeywordHighlighting(),
+				new YieldKeywordHighlighting(),
 			};
 		return fgSemanticHighlightings;
 	}
@@ -2096,8 +2143,8 @@ public class SemanticHighlightings {
 	public static boolean affectsEnablement(IPreferenceStore store, PropertyChangeEvent event) {
 		String relevantKey= null;
 		SemanticHighlighting[] highlightings= getSemanticHighlightings();
-		for (int i= 0; i < highlightings.length; i++) {
-			if (event.getProperty().equals(getEnabledPreferenceKey(highlightings[i]))) {
+		for (SemanticHighlighting highlighting : highlightings) {
+			if (event.getProperty().equals(getEnabledPreferenceKey(highlighting))) {
 				relevantKey= event.getProperty();
 				break;
 			}
@@ -2105,8 +2152,8 @@ public class SemanticHighlightings {
 		if (relevantKey == null)
 			return false;
 
-		for (int i= 0; i < highlightings.length; i++) {
-			String key= getEnabledPreferenceKey(highlightings[i]);
+		for (SemanticHighlighting highlighting : highlightings) {
+			String key= getEnabledPreferenceKey(highlighting);
 			if (key.equals(relevantKey))
 				continue;
 			if (store.getBoolean(key))
@@ -2128,8 +2175,8 @@ public class SemanticHighlightings {
 	public static boolean isEnabled(IPreferenceStore store) {
 		SemanticHighlighting[] highlightings= getSemanticHighlightings();
 		boolean enable= false;
-		for (int i= 0; i < highlightings.length; i++) {
-			String enabledKey= getEnabledPreferenceKey(highlightings[i]);
+		for (SemanticHighlighting highlighting : highlightings) {
+			String enabledKey= getEnabledPreferenceKey(highlighting);
 			if (store.getBoolean(enabledKey)) {
 				enable= true;
 				break;
