@@ -82,6 +82,7 @@ class CodeAssistConfigurationBlock extends OptionsConfigurationBlock {
 	private static final Key PREF_CODEASSIST_DEPRECATION_CHECK= getJDTCoreKey(JavaCore.CODEASSIST_DEPRECATION_CHECK);
 	private static final Key PREF_CODEASSIST_CAMEL_CASE_MATCH= getJDTCoreKey(JavaCore.CODEASSIST_CAMEL_CASE_MATCH);
 	private static final Key PREF_CODEASSIST_SUBSTRING_MATCH= getJDTCoreKey(JavaCore.CODEASSIST_SUBSTRING_MATCH);
+	private static final Key PREF_CODEASSIST_SUBWORD_MATCH= getJDTCoreKey(JavaCore.CODEASSIST_SUBWORD_MATCH);
 
 	private static Key[] getAllKeys() {
 		return new Key[] {
@@ -102,6 +103,7 @@ class CodeAssistConfigurationBlock extends OptionsConfigurationBlock {
 				PREF_CODEASSIST_DEPRECATION_CHECK,
 				PREF_CODEASSIST_CAMEL_CASE_MATCH,
 				PREF_CODEASSIST_SUBSTRING_MATCH,
+				PREF_CODEASSIST_SUBWORD_MATCH,
 				PREF_CODEASSIST_DISABLE_COMPLETION_PROPOSAL_TRIGGER_CHARS
 		};
 	}
@@ -251,9 +253,8 @@ class CodeAssistConfigurationBlock extends OptionsConfigurationBlock {
 			private void deepSetEnabled(final Control control, boolean enabled) {
 				control.setEnabled(enabled);
 				if (control instanceof Composite) {
-					Control[] children= ((Composite)control).getChildren();
-					for (int i= 0; i < children.length; i++) {
-						deepSetEnabled(children[i], enabled);
+					for (Control child : ((Composite)control).getChildren()) {
+						deepSetEnabled(child, enabled);
 					}
 				}
 			}
@@ -286,6 +287,9 @@ class CodeAssistConfigurationBlock extends OptionsConfigurationBlock {
 		label= PreferencesMessages.CodeAssistConfigurationBlock_matchSubstring_label;
 		addCheckBox(composite, label, PREF_CODEASSIST_SUBSTRING_MATCH, enabledDisabled, 0);
 
+		label= PreferencesMessages.CodeAssistConfigurationBlock_matchSubword_label;
+		addCheckBox(composite, label, PREF_CODEASSIST_SUBWORD_MATCH, enabledDisabled, 0);
+
 		label= PreferencesMessages.JavaEditorPreferencePage_showOnlyProposalsVisibleInTheInvocationContext;
 		addCheckBox(composite, label, PREF_CODEASSIST_SHOW_VISIBLE_PROPOSALS, trueFalse, 0);
 
