@@ -85,13 +85,13 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 	 * <p>Values are { {@link #DEFAULT_CONF}, {@link #USER_CONF}, or {@link #DISABLED} }.
 	 */
 	private static final Key INTR_COMPLIANCE_FOLLOWS_EE= getLocalKey("internal.compliance.follows.ee"); //$NON-NLS-1$
-	
+
 	/**
 	 * Key for the "Use default compliance" setting.
 	 * <p>Values are { {@link #DEFAULT_CONF}, {@link #USER_CONF} }.
 	 */
 	private static final Key INTR_DEFAULT_COMPLIANCE= getLocalKey("internal.default.compliance"); //$NON-NLS-1$
-	
+
 	// Preference store keys, see JavaCore.getOptions
 	private static final Key PREF_PB_ASSERT_AS_IDENTIFIER= getJDTCoreKey(JavaCore.COMPILER_PB_ASSERT_IDENTIFIER);
 	private static final Key PREF_PB_ENUM_AS_IDENTIFIER= getJDTCoreKey(JavaCore.COMPILER_PB_ENUM_IDENTIFIER);
@@ -101,7 +101,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 	private static final Key PREF_RELEASE= getJDTCoreKey(JavaCore.COMPILER_RELEASE);
 	private static final Key PREF_ENABLE_PREVIEW= getJDTCoreKey(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES);
 	private static final Key PREF_PB_REPORT_PREVIEW= getJDTCoreKey(JavaCore.COMPILER_PB_REPORT_PREVIEW_FEATURES);
-	
+
 	/* see also BuildPathSupport#PREFS_COMPLIANCE */
 	private static final Key[] PREFS_COMPLIANCE= new Key[] { PREF_COMPLIANCE,
 		PREF_PB_ASSERT_AS_IDENTIFIER, PREF_PB_ENUM_AS_IDENTIFIER,
@@ -110,15 +110,15 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 		PREF_PB_ASSERT_AS_IDENTIFIER, PREF_PB_ENUM_AS_IDENTIFIER,
 		PREF_SOURCE_COMPATIBILITY, PREF_CODEGEN_TARGET_PLATFORM,
 		PREF_ENABLE_PREVIEW, PREF_PB_REPORT_PREVIEW};
-	
+
 	private static final Key PREF_CODEGEN_INLINE_JSR_BYTECODE= getJDTCoreKey(JavaCore.COMPILER_CODEGEN_INLINE_JSR_BYTECODE);
-	
+
 	private static final Key PREF_LOCAL_VARIABLE_ATTR=  getJDTCoreKey(JavaCore.COMPILER_LOCAL_VARIABLE_ATTR);
 	private static final Key PREF_LINE_NUMBER_ATTR= getJDTCoreKey(JavaCore.COMPILER_LINE_NUMBER_ATTR);
 	private static final Key PREF_SOURCE_FILE_ATTR= getJDTCoreKey(JavaCore.COMPILER_SOURCE_FILE_ATTR);
 	private static final Key PREF_CODEGEN_UNUSED_LOCAL= getJDTCoreKey(JavaCore.COMPILER_CODEGEN_UNUSED_LOCAL);
 	private static final Key PREF_CODEGEN_METHOD_PARAMETERS_ATTR= getJDTCoreKey(JavaCore.COMPILER_CODEGEN_METHOD_PARAMETERS_ATTR);
-	
+
 	// values
 	private static final String GENERATE= JavaCore.GENERATE;
 	private static final String DO_NOT_GENERATE= JavaCore.DO_NOT_GENERATE;
@@ -140,6 +140,8 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 	private static final String VERSION_10= JavaCore.VERSION_10;
 	private static final String VERSION_11= JavaCore.VERSION_11;
 	private static final String VERSION_12 = JavaCore.VERSION_12;
+	private static final String VERSION_13 = JavaCore.VERSION_13;
+	private static final String VERSION_LATEST = JavaCore.latestSupportedJavaVersion();
 	private static final String VERSION_JSR14= "jsr14"; //$NON-NLS-1$
 
 	private static final String ERROR= JavaCore.ERROR;
@@ -174,11 +176,11 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 	 * @see #IDX_REPORT_PREVIEW
 	 */
 	private String[] fRememberedUserCompliance;
-	
+
 	/**
 	 * Stored compliance settings that were active when the page was first shown. May be
 	 * <code>null</code>. Elements are identified by <code>IDX_*</code> constants.
-	 * 
+	 *
 	 * @see #IDX_ASSERT_AS_IDENTIFIER
 	 * @see #IDX_ENUM_AS_IDENTIFIER
 	 * @see #IDX_SOURCE_COMPATIBILITY
@@ -245,14 +247,14 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 				PREF_CODEGEN_TARGET_PLATFORM, PREF_PB_ASSERT_AS_IDENTIFIER, PREF_PB_ENUM_AS_IDENTIFIER, PREF_CODEGEN_METHOD_PARAMETERS_ATTR, PREF_RELEASE,
 				PREF_ENABLE_PREVIEW, PREF_PB_REPORT_PREVIEW
 			};
-		
+
 		if (projectSpecific) {
 			Key[] allKeys = new Key[keys.length + 1];
 			System.arraycopy(keys, 0, allKeys, 0, keys.length);
 			allKeys[keys.length]= INTR_COMPLIANCE_FOLLOWS_EE;
 			return allKeys;
 		}
-		
+
 		return keys;
 	}
 
@@ -296,7 +298,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 	private Composite createComplianceTabContent(Composite folder) {
 
 		final String[] complianceVersions= new String[] { VERSION_1_3, VERSION_1_4,
-				VERSION_1_5, VERSION_1_6, VERSION_1_7, VERSION_1_8, VERSION_9, VERSION_10, VERSION_11, VERSION_12 };
+				VERSION_1_5, VERSION_1_6, VERSION_1_7, VERSION_1_8, VERSION_9, VERSION_10, VERSION_11, VERSION_12, VERSION_13 };
 		final String[] complianceLabels= new String[] {
 			PreferencesMessages.ComplianceConfigurationBlock_version13,
 			PreferencesMessages.ComplianceConfigurationBlock_version14,
@@ -308,10 +310,11 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 			PreferencesMessages.ComplianceConfigurationBlock_version10,
 			PreferencesMessages.ComplianceConfigurationBlock_version_11,
 			PreferencesMessages.ComplianceConfigurationBlock_version_12,
+			PreferencesMessages.ComplianceConfigurationBlock_version_13,
 		};
-		
+
 		String[] targetVersions= new String[] { VERSION_CLDC_1_1, VERSION_1_1, VERSION_1_2, VERSION_1_3, VERSION_1_4,
-				VERSION_1_5, VERSION_1_6, VERSION_1_7, VERSION_1_8, VERSION_9, VERSION_10, VERSION_11, VERSION_12 };
+				VERSION_1_5, VERSION_1_6, VERSION_1_7, VERSION_1_8, VERSION_9, VERSION_10, VERSION_11, VERSION_12, VERSION_13 };
 		String[] targetLabels= new String[] {
 				PreferencesMessages.ComplianceConfigurationBlock_versionCLDC11,
 				PreferencesMessages.ComplianceConfigurationBlock_version11,
@@ -326,14 +329,15 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 				PreferencesMessages.ComplianceConfigurationBlock_version10,
 				PreferencesMessages.ComplianceConfigurationBlock_version_11,
 				PreferencesMessages.ComplianceConfigurationBlock_version_12,
+				PreferencesMessages.ComplianceConfigurationBlock_version_13,
 		};
 		if (ComplianceConfigurationBlock.VERSION_JSR14.equals(getValue(PREF_CODEGEN_TARGET_PLATFORM))) {
 			targetVersions= append(targetVersions, ComplianceConfigurationBlock.VERSION_JSR14);
 			targetLabels= append(targetLabels, ComplianceConfigurationBlock.VERSION_JSR14);
 		}
-		
+
 		String[] sourceVersions= new String[] { VERSION_1_3, VERSION_1_4,
-				VERSION_1_5, VERSION_1_6, VERSION_1_7, VERSION_1_8, VERSION_9, VERSION_10, VERSION_11, VERSION_12 };
+				VERSION_1_5, VERSION_1_6, VERSION_1_7, VERSION_1_8, VERSION_9, VERSION_10, VERSION_11, VERSION_12, VERSION_13 };
 		String[] sourceLabels= new String[] {
 				PreferencesMessages.ComplianceConfigurationBlock_version13,
 				PreferencesMessages.ComplianceConfigurationBlock_version14,
@@ -345,8 +349,9 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 				PreferencesMessages.ComplianceConfigurationBlock_version10,
 				PreferencesMessages.ComplianceConfigurationBlock_version_11,
 				PreferencesMessages.ComplianceConfigurationBlock_version_12,
+				PreferencesMessages.ComplianceConfigurationBlock_version_13,
 		};
-		
+
 		final ScrolledPageContent sc1 = new ScrolledPageContent(folder);
 		Composite composite= sc1.getBody();
 		GridLayout layout= new GridLayout();
@@ -376,7 +381,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 		group.setLayout(layout);
 
 		String[] defaultUserValues= new String[] { DEFAULT_CONF, USER_CONF };
-		
+
 		Control[] otherChildren= group.getChildren();
 		if (fProject != null) {
 			String label= PreferencesMessages.ComplianceConfigurationBlock_compliance_follows_EE_label;
@@ -388,19 +393,19 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 				}
 			});
 		}
-		
+
 		Control[] allChildren= group.getChildren();
 		fComplianceFollowsEEControls.addAll(Arrays.asList(allChildren));
 		fComplianceFollowsEEControls.removeAll(Arrays.asList(otherChildren));
 		otherChildren= allChildren;
-		
-		
+
+
 		String label= PreferencesMessages.ComplianceConfigurationBlock_compiler_compliance_label;
 		addComboBox(group, label, PREF_COMPLIANCE, complianceVersions, complianceLabels, 0);
 
 		label= PreferencesMessages.ComplianceConfigurationBlock_jrecompliance_backwardcompatibility_label;
 		fComplierReleaseCheck= addCheckBox(group, label, PREF_RELEASE, new String[] { DISABLED, ENABLED }, 0, false);
-		
+
 		label= PreferencesMessages.ComplianceConfigurationBlock_default_settings_label;
 		addCheckBox(group, label, INTR_DEFAULT_COMPLIANCE, defaultUserValues, 0);
 
@@ -408,8 +413,8 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 		fComplianceControls.addAll(Arrays.asList(allChildren));
 		fComplianceControls.removeAll(Arrays.asList(otherChildren));
 		otherChildren= allChildren;
-		
-		
+
+
 		int indent= LayoutUtil.getIndent();
 
 		String[] warningInfoIgnore= new String[] { WARNING, INFO, IGNORE };
@@ -419,7 +424,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 				PreferencesMessages.ComplianceConfigurationBlock_ignore
 		};
 
-		label= PreferencesMessages.ComplianceConfigurationBlock_enable_preview_label;
+		label= Messages.format(PreferencesMessages.ComplianceConfigurationBlock_enable_preview_label, new String[] { getVersionLabel(VERSION_LATEST) });
 		fEnablePreviewCheck= addCheckBox(group, label, PREF_ENABLE_PREVIEW, new String[] { ENABLED, DISABLED }, indent);
 		label= PreferencesMessages.ComplianceConfigurationBlock_enable_preview_severity_label;
 		fReportPreviewCombo= addComboBox(group, label, PREF_PB_REPORT_PREVIEW, warningInfoIgnore, warningInfoIgnoreLabels, indent * 2);
@@ -449,7 +454,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 		allChildren= group.getChildren();
 		fComplianceChildControls.addAll(Arrays.asList(allChildren));
 		fComplianceChildControls.removeAll(Arrays.asList(otherChildren));
-		
+
 
 		layout= new GridLayout();
 		layout.numColumns= nColumns;
@@ -477,19 +482,19 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 
 		label= PreferencesMessages.ComplianceConfigurationBlock_codegen_inline_jsr_bytecode_label;
 		addCheckBox(group, label, PREF_CODEGEN_INLINE_JSR_BYTECODE, enableDisableValues, 0);
-		
+
 		label= PreferencesMessages.ComplianceConfigurationBlock_codegen_method_parameters_attr;
 		addCheckBox(group, label, PREF_CODEGEN_METHOD_PARAMETERS_ATTR, generateValues, 0);
-		
+
 		Composite infoComposite= new Composite(fControlsComposite, SWT.NONE);
 		infoComposite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
 		infoComposite.setLayout(new GridLayout(2, false));
-		
+
 		fJRE50InfoImage= new Label(infoComposite, SWT.NONE);
 		fJRE50InfoImage.setImage(JFaceResources.getImage(Dialog.DLG_IMG_MESSAGE_WARNING));
 		GridData gd= new GridData(GridData.BEGINNING, GridData.BEGINNING, false, false);
 		fJRE50InfoImage.setLayoutData(gd);
-		
+
 		fJRE50InfoText= new Link(infoComposite, SWT.WRAP);
 		fJRE50InfoText.setFont(composite.getFont());
 		// set a text: not the real one, just for layouting
@@ -519,7 +524,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 		validateComplianceStatus();
 		return sc1;
 	}
-	
+
 	private void initializeReleaseCheckBox(boolean useProjectSpecificSettings) {
 		if (fProject != null && !useProjectSpecificSettings) {
 			String value= PREF_RELEASE.getStoredValue(new IScopeContext[] { new ProjectScope(fProject) }, false, null);
@@ -596,7 +601,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 			    Object oldDefault= getValue(INTR_DEFAULT_COMPLIANCE);
 				boolean rememberOld= USER_CONF.equals(oldDefault);
 				updateComplianceDefaultSettings(rememberOld, oldValue);
-				fComplianceStatus= validateCompliance();				
+				fComplianceStatus= validateCompliance();
 				validateComplianceStatus();
 			} else if (PREF_RELEASE.equals(changedKey)) {
 				setValue(PREF_RELEASE, DISABLED.equals(newValue) ? ENABLED : DISABLED);
@@ -646,13 +651,13 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 			updateInlineJSREnableState();
 			updateStoreMethodParamNamesEnableState();
 			fComplianceStatus= validateCompliance();
-			updateComplianceReleaseSettings();			
+			updateComplianceReleaseSettings();
 			updateReleaseOptionStatus();
 			validateComplianceStatus();
 		}
 		fContext.statusChanged(fComplianceStatus);
 	}
-	
+
 	public void refreshComplianceSettings() {
 		if (fOriginalStoredCompliance == null) {
 			fOriginalStoredCompliance= new String[] { // caution: order depends on IDX_* constants
@@ -667,7 +672,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 					getOriginalStoredValue(PREF_ENABLE_PREVIEW),
 					getOriginalStoredValue(PREF_PB_REPORT_PREVIEW)
 				};
-			
+
 		} else {
 			String[] storedCompliance= new String[] {
 					getOriginalStoredValue(PREF_PB_ASSERT_AS_IDENTIFIER),
@@ -683,9 +688,9 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 				};
 			if (!Arrays.equals(fOriginalStoredCompliance, storedCompliance)) {
 				// compliance changed on disk -> override user modifications
-				
+
 				fOriginalStoredCompliance= storedCompliance;
-				
+
 				setValue(PREF_PB_ASSERT_AS_IDENTIFIER, storedCompliance[IDX_ASSERT_AS_IDENTIFIER]);
 				setValue(PREF_PB_ENUM_AS_IDENTIFIER, storedCompliance[IDX_ENUM_AS_IDENTIFIER]);
 				setValue(PREF_SOURCE_COMPATIBILITY, storedCompliance[IDX_SOURCE_COMPATIBILITY]);
@@ -697,7 +702,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 				setValue(PREF_ENABLE_PREVIEW, storedCompliance[IDX_ENABLE_PREVIEW]);
 				setValue(PREF_PB_REPORT_PREVIEW, storedCompliance[IDX_REPORT_PREVIEW]);
 			}
-			
+
 			updateComplianceFollowsEE();
 			updateControls();
 			updateComplianceEnableState();
@@ -778,14 +783,14 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 				}
 			}
 
-			//TODO: Remove once Java SE 11 has been shipped:
-			//String selectedCompliance= getValue(PREF_COMPLIANCE);
-			//if (VERSION_12.equals(selectedCompliance)) {
-				//fJRE50InfoText.setText(
-					//	"This is an implementation of an early-draft specification developed under the Java Community Process (JCP) and is made available for testing and evaluation purposes only. The code is not compatible with any specification of the JCP."); //$NON-NLS-1$
-				//isVisible= true;
-			//}
-			
+			//TODO: Comment once Java SE 13 has been shipped:
+			/*String selectedCompliance= getValue(PREF_COMPLIANCE);
+			if (VERSION_13.equals(selectedCompliance)) {
+				fJRE50InfoText.setText(
+						"This is an implementation of an early-draft specification developed under the Java Community Process (JCP) and is made available for testing and evaluation purposes only. The code is not compatible with any specification of the JCP."); //$NON-NLS-1$
+				isVisible= true;
+			}*/
+
 			fJRE50InfoText.setVisible(isVisible);
 			fJRE50InfoImage.setImage(isVisible ? image : null);
 			fJRE50InfoImage.getParent().layout();
@@ -811,7 +816,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 				boolean isJREUnsupportedAndGreater= isJREVersionUnsupportedAndGreater(version, compilerCompliance);
 				if (!compilerCompliance.equals(compliance)) { // Discourage using compiler with version other than compliance
 					if (JavaModelUtil.is9OrHigher(compilerCompliance)) {
-						if (!JavaModelUtil.is16OrHigher(compliance) 
+						if (!JavaModelUtil.is16OrHigher(compliance)
 								|| ( JavaModelUtil.is12OrHigher(compilerCompliance)) && !JavaModelUtil.is17OrHigher(compliance)) {
 							fComplierReleaseCheck.setEnabled(false);
 							fComplierReleaseCheck.setSelection(false);
@@ -886,7 +891,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 		String compliance= getValue(PREF_COMPLIANCE);
 		String source= getValue(PREF_SOURCE_COMPATIBILITY);
 		String target= getValue(PREF_CODEGEN_TARGET_PLATFORM);
-		
+
 		if (ComplianceConfigurationBlock.VERSION_JSR14.equals(target)) {
 			target= source;
 		}
@@ -956,11 +961,11 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 			updateCheckBox(getCheckBox(INTR_COMPLIANCE_FOLLOWS_EE));
 			boolean enableComplianceFollowsEE= hasProjectSpecificOptions && ! DISABLED.equals(complianceFollowsEE); // is default or user
 			updateControlsEnableState(fComplianceFollowsEEControls, enableComplianceFollowsEE);
-		
+
 			enableComplianceControls= hasProjectSpecificOptions && ! DEFAULT_CONF.equals(complianceFollowsEE); // is disabled or user
 			updateControlsEnableState(fComplianceControls, enableComplianceControls);
 		}
-		
+
 		boolean enableComplianceChildren= enableComplianceControls && checkValue(INTR_DEFAULT_COMPLIANCE, USER_CONF);
 		updateControlsEnableState(fComplianceChildControls, enableComplianceChildren);
 		updateReleaseOptionStatus();
@@ -1005,15 +1010,15 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 		if (checkValue(INTR_DEFAULT_COMPLIANCE, USER_CONF)) {
 			String compatibility= getValue(PREF_SOURCE_COMPATIBILITY);
 
-			boolean isLessThan11= JavaModelUtil.isVersionLessThan(compatibility, VERSION_11);
-			updateRememberedComplianceOption(PREF_ENABLE_PREVIEW, IDX_ENABLE_PREVIEW, !isLessThan11, null);
+			boolean isLessThanLatest= JavaModelUtil.isVersionLessThan(compatibility, VERSION_LATEST);
+			updateRememberedComplianceOption(PREF_ENABLE_PREVIEW, IDX_ENABLE_PREVIEW, !isLessThanLatest, null);
 			updateRememberedComplianceOption(PREF_PB_REPORT_PREVIEW, IDX_REPORT_PREVIEW, fEnablePreviewCheck.isEnabled() && fEnablePreviewCheck.getSelection(), WARNING);
 		}
 	}
 
 	private void updatePreviewControls() {
 		String compliance= getValue(PREF_COMPLIANCE);
-		if (JavaCore.compareJavaVersions(compliance, JavaCore.VERSION_10) <= 0) {
+		if (JavaCore.compareJavaVersions(compliance, VERSION_LATEST) < 0) {
 			fEnablePreviewCheck.setSelection(false);
 			fReportPreviewCombo.select(0);
 		}
@@ -1036,7 +1041,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 			Button checkBox= getCheckBox(prefKey);
 			boolean wasCheckBoxEnabled= checkBox.isEnabled();
 			checkBox.setEnabled(enabled);
-			
+
 			if (enabled) {
 				if (!wasCheckBoxEnabled) {
 					String val= fRememberedUserCompliance[idx];
@@ -1060,7 +1065,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 		} else {
 			Combo combo= getComboBox(prefKey);
 			combo.setEnabled(enabled);
-			
+
 			if (!enabled) {
 				String val= getValue(prefKey);
 				if (!defaultComboValue.equals(val)) {
@@ -1137,7 +1142,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 	/**
 	 * Sets the default compliance values derived from the chosen level or restores the user
 	 * compliance settings.
-	 * 
+	 *
 	 * @param rememberOld if <code>true</code>, the current compliance settings are remembered as
 	 *            user settings. If <code>false</code>, overwrite the current settings.
 	 * @param oldComplianceLevel the previous compliance level
@@ -1148,7 +1153,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 		boolean isFollowEE= checkValue(INTR_COMPLIANCE_FOLLOWS_EE, DEFAULT_CONF);
 		String complianceLevel= getValue(PREF_COMPLIANCE);
 		boolean isRelease= checkValue(PREF_RELEASE, JavaCore.ENABLED) && JavaModelUtil.is16OrHigher(complianceLevel) && !isDefault;
-		
+
 		if (isDefault || isFollowEE || isRelease) {
 			if (rememberOld) {
 				if (oldComplianceLevel == null) {
@@ -1164,20 +1169,20 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 				fRememberedUserCompliance[IDX_RELEASE]= getValue(PREF_RELEASE);
 				fRememberedUserCompliance[IDX_COMPLIANCE]= oldComplianceLevel;
 			}
-			
+
 			if (isFollowEE) {
 				IExecutionEnvironment ee= getEE();
 				Map<String, String> eeOptions= BuildPathSupport.getEEOptions(ee);
 				if (eeOptions == null)
 					return;
-				
+
 				enablePreview= eeOptions.get(PREF_ENABLE_PREVIEW.getName());
 				reportPreview= eeOptions.get(PREF_PB_REPORT_PREVIEW.getName());
 				assertAsId= eeOptions.get(PREF_PB_ASSERT_AS_IDENTIFIER.getName());
 				enumAsId= eeOptions.get(PREF_PB_ENUM_AS_IDENTIFIER.getName());
 				source= eeOptions.get(PREF_SOURCE_COMPATIBILITY.getName());
 				target= eeOptions.get(PREF_CODEGEN_TARGET_PLATFORM.getName());
-				
+
 				setValue(PREF_COMPLIANCE, eeOptions.get(PREF_COMPLIANCE.getName()));
 				String inlineJSR= eeOptions.get(PREF_CODEGEN_INLINE_JSR_BYTECODE.getName());
 				if (inlineJSR != null) {
@@ -1188,7 +1193,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 					setValue(PREF_RELEASE, DISABLED);
 					fComplierReleaseCheck.setSelection(false);
 				}
-				
+
 			} else if (isRelease) {
 				enablePreview= getValue(PREF_ENABLE_PREVIEW);
 				reportPreview= getValue(PREF_PB_REPORT_PREVIEW);
@@ -1252,24 +1257,24 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 
 	private void updateComplianceReleaseSettings() {
 		String compliance= getValue(PREF_COMPLIANCE);
-		boolean isRelease= checkValue(PREF_RELEASE, JavaCore.ENABLED) && JavaModelUtil.is16OrHigher(compliance);		
+		boolean isRelease= checkValue(PREF_RELEASE, JavaCore.ENABLED) && JavaModelUtil.is16OrHigher(compliance);
 		if (isRelease) {
 			setValue(PREF_SOURCE_COMPATIBILITY, compliance);
-			setValue(PREF_CODEGEN_TARGET_PLATFORM, compliance);	
-		} 
+			setValue(PREF_CODEGEN_TARGET_PLATFORM, compliance);
+		}
 	}
-	
+
 	/**
 	 * Evaluate if the current compliance setting correspond to a default setting.
-	 * 
+	 *
 	 * @return {@link #DEFAULT_CONF} or {@link #USER_CONF}
 	 */
 	private String getCurrentCompliance() {
 		String complianceLevel= getValue(PREF_COMPLIANCE);
-		
+
 		HashMap<String, String> defaultOptions= new HashMap<>();
 		JavaModelUtil.setComplianceOptions(defaultOptions, complianceLevel);
-		
+
 		boolean isDefault= complianceLevel.equals(defaultOptions.get(JavaCore.COMPILER_COMPLIANCE))
 				&& getValue(PREF_SOURCE_COMPATIBILITY).equals(defaultOptions.get(JavaCore.COMPILER_SOURCE))
 				&& getValue(PREF_CODEGEN_TARGET_PLATFORM).equals(defaultOptions.get(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM))
@@ -1286,11 +1291,9 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 	private IExecutionEnvironment getEE() {
 		if (fProject == null)
 			return null;
-		
+
 		try {
-			IClasspathEntry[] entries= JavaCore.create(fProject).getRawClasspath();
-			for (int i= 0; i < entries.length; i++) {
-				IClasspathEntry entry= entries[i];
+			for (IClasspathEntry entry : JavaCore.create(fProject).getRawClasspath()) {
 				if (entry.getEntryKind() == IClasspathEntry.CPE_CONTAINER) {
 					String eeId= JavaRuntime.getExecutionEnvironmentId(entry.getPath());
 					if (eeId != null) {
@@ -1307,7 +1310,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 	/**
 	 * Evaluate if the builds path contains an execution environment and the current compliance
 	 * settings follow the EE options.
-	 * 
+	 *
 	 * @param ee the EE, or <code>null</code> if none available
 	 * @return {@link #DEFAULT_CONF} if the compliance follows the EE, or {@link #USER_CONF} if the
 	 *         settings differ, or {@link #DISABLED} if there's no EE at all
@@ -1325,15 +1328,14 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 	}
 
 	private String checkDefaults(Key[] keys, Map<String, String> options) {
-		for (int i= 0; i < keys.length; i++) {
-			Key key= keys[i];
+		for (Key key : keys) {
 			Object option= options.get(key.getName());
 			if (!checkValue(key, (String)option))
 				return USER_CONF;
 		}
 		return DEFAULT_CONF;
 	}
-	
+
 	@Override
 	protected String[] getFullBuildDialogStrings(boolean workspaceSettings) {
 		String title= PreferencesMessages.ComplianceConfigurationBlock_needsbuild_title;
@@ -1349,7 +1351,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 	/**
 	 * Sets the default compiler compliance options based on the current default JRE in the
 	 * workspace.
-	 * 
+	 *
 	 * @since 3.5
 	 */
 	private void setDefaultCompilerComplianceValues() {
@@ -1367,7 +1369,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 				setDefaultValue(PREF_RELEASE, DISABLED);
 				if (JavaCore.compareJavaVersions(complianceLevel, JavaCore.VERSION_10) > 0) {
 					setDefaultValue(PREF_ENABLE_PREVIEW, complianceOptions.get(PREF_ENABLE_PREVIEW.getName()));
-					setDefaultValue(PREF_PB_REPORT_PREVIEW, complianceOptions.get(PREF_PB_REPORT_PREVIEW.getName()));					
+					setDefaultValue(PREF_PB_REPORT_PREVIEW, complianceOptions.get(PREF_PB_REPORT_PREVIEW.getName()));
 				} else {
 					setDefaultValue(PREF_ENABLE_PREVIEW, DISABLED);
 					setDefaultValue(PREF_PB_REPORT_PREVIEW, WARNING);
@@ -1379,7 +1381,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 	/**
 	 * Tells whether the compliance option is the same as the original default.
 	 * @param complianceLevel the compliance level
-	 * 
+	 *
 	 * @return <code>true</code> if the compliance is the same as the original default
 	 * @since 3.6
 	 */
@@ -1403,7 +1405,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 
 	/**
 	 * Returns whether the option for the given key is the same in the map and the preferences.
-	 * 
+	 *
 	 * @param key the key of option to test
 	 * @param preferences the preferences
 	 * @param map the map
@@ -1420,7 +1422,7 @@ public class ComplianceConfigurationBlock extends OptionsConfigurationBlock {
 
 	/**
 	 * Returns whether the objects are equal.
-	 * 
+	 *
 	 * @param o1 an object
 	 * @param o2 an object
 	 * @return <code>true</code> if the two objects are equal
