@@ -586,10 +586,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 					libraryElement.setAttribute(TAG_NAME, curr.getName());
 					libraryElement.setAttribute(TAG_SYSTEMLIBRARY, String.valueOf(curr.isSystemLibrary()));
 
-					CPListElement[] children= curr.getChildren();
-					for (int k= 0; k < children.length; k++) {
-						CPListElement child= children[k];
-
+					for (CPListElement child : curr.getChildren()) {
 						Element childElement= document.createElement(TAG_ARCHIVE);
 						libraryElement.appendChild(childElement);
 
@@ -614,8 +611,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 						if (accessRules != null && accessRules.length > 0) {
 							Element rulesElement= document.createElement(TAG_ACCESSRULES);
 							childElement.appendChild(rulesElement);
-							for (int n= 0; n < accessRules.length; n++) {
-								IAccessRule rule= accessRules[n];
+							for (IAccessRule rule : accessRules) {
 								Element ruleElement= document.createElement(TAG_ACCESSRULE);
 								rulesElement.appendChild(ruleElement);
 								ruleElement.setAttribute(TAG_RULE_KIND, String.valueOf(rule.getKind()));
@@ -635,9 +631,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 				DOMSource source = new DOMSource(document);
 				StreamResult result = new StreamResult(stream);
 				transformer.transform(source, result);
-			} catch (ParserConfigurationException e) {
-				throw new IOException(e.getMessage());
-			} catch (TransformerException e) {
+			} catch (ParserConfigurationException | TransformerException e) {
 				throw new IOException(e.getMessage());
 			} finally {
 				try {
@@ -658,9 +652,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 				DocumentBuilder parser = DocumentBuilderFactory.newInstance().newDocumentBuilder();
 				parser.setErrorHandler(new DefaultHandler());
 				cpElement = parser.parse(new InputSource(stream)).getDocumentElement();
-			} catch (SAXException e) {
-				throw new IOException(PreferencesMessages.UserLibraryPreferencePage_LoadSaveDialog_load_badformat);
-			} catch (ParserConfigurationException e) {
+			} catch (SAXException | ParserConfigurationException e) {
 				throw new IOException(PreferencesMessages.UserLibraryPreferencePage_LoadSaveDialog_load_badformat);
 			} finally {
 				stream.close();
@@ -811,14 +803,13 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 		fLibraryList= new TreeListDialogField<>(adapter, buttonLabels, new CPListLabelProvider());
 		fLibraryList.setLabelText(PreferencesMessages.UserLibraryPreferencePage_libraries_label);
 
-		String[] names= JavaCore.getUserLibraryNames();
 		ArrayList<CPUserLibraryElement> elements= new ArrayList<>();
 
-		for (int i= 0; i < names.length; i++) {
-			IPath path= new Path(JavaCore.USER_LIBRARY_CONTAINER_ID).append(names[i]);
+		for (String name : JavaCore.getUserLibraryNames()) {
+			IPath path= new Path(JavaCore.USER_LIBRARY_CONTAINER_ID).append(name);
 			try {
 				IClasspathContainer container= JavaCore.getClasspathContainer(path, fDummyProject);
-				elements.add(new CPUserLibraryElement(names[i], container, fDummyProject));
+				elements.add(new CPUserLibraryElement(name, container, fDummyProject));
 			} catch (JavaModelException e) {
 				JavaPlugin.log(e);
 				// ignore
@@ -1003,11 +994,10 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 		CPListElement selElement= elem.getParent();
 		Object parentContainer= selElement.getParentContainer();
 
-		CPListElementAttribute[] allAttributes= selElement.getAllAttributes();
 		boolean canEditEncoding= false;
-		for (int i= 0; i < allAttributes.length; i++) {
-			if (CPListElement.SOURCE_ATTACHMENT_ENCODING.equals(allAttributes[i].getKey())) {
-				canEditEncoding= !(allAttributes[i].isNonModifiable() || allAttributes[i].isNotSupported());
+		for (CPListElementAttribute allAttribute : selElement.getAllAttributes()) {
+			if (CPListElement.SOURCE_ATTACHMENT_ENCODING.equals(allAttribute.getKey())) {
+				canEditEncoding= !(allAttribute.isNonModifiable() || allAttribute.isNotSupported());
 			}
 		}
 		if (key.equals(CPListElement.SOURCEATTACHMENT)) {
@@ -1033,7 +1023,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 					elem.setValue(result.getValue());
 					if(key.equals(CPListElement.TEST) || key.equals(CPListElement.WITHOUT_TEST_CODE)) {
 						fLibraryList.refresh(elem.getParent());
-					} else { 
+					} else {
 						fLibraryList.refresh(elem);
 					}
 					fLibraryList.refresh(parentContainer);
@@ -1069,24 +1059,36 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 	}
 
 	protected void doCustomButtonPressed(TreeListDialogField<CPUserLibraryElement> field, int index) {
-		if (index == IDX_NEW) {
+		switch (index) {
+		case IDX_NEW:
 			editUserLibraryElement(null);
-		} else if (index == IDX_ADD) {
+			break;
+		case IDX_ADD:
 			doAdd(field.getSelectedElements());
-		} else if (index == IDX_ADD_EXTERNAL) {
+			break;
+		case IDX_ADD_EXTERNAL:
 			doAddExternal(field.getSelectedElements());
-		} else if (index == IDX_REMOVE) {
+			break;
+		case IDX_REMOVE:
 			doRemove(field.getSelectedElements());
-		} else if (index == IDX_EDIT) {
+			break;
+		case IDX_EDIT:
 			doEdit(field.getSelectedElements());
-		} else if (index == IDX_SAVE) {
+			break;
+		case IDX_SAVE:
 			doSave();
-		} else if (index == IDX_LOAD) {
+			break;
+		case IDX_LOAD:
 			doLoad();
-		} else if (index == IDX_UP) {
+			break;
+		case IDX_UP:
 			doMoveUp(field.getSelectedElements());
-		} else if (index == IDX_DOWN) {
+			break;
+		case IDX_DOWN:
 			doMoveDown(field.getSelectedElements());
+			break;
+		default:
+			break;
 		}
 	}
 
@@ -1138,11 +1140,11 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 	private void editArchiveElement(CPListElement existingElement, CPUserLibraryElement parent) {
 		CPListElement[] elements= openJarFileDialog(existingElement, parent);
 		if (elements != null) {
-			for (int i= 0; i < elements.length; i++) {
+			for (CPListElement element : elements) {
 				if (existingElement != null) {
-					parent.replace(existingElement, elements[i]);
+					parent.replace(existingElement, element);
 				} else {
-					parent.add(elements[i]);
+					parent.add(element);
 				}
 			}
 			fLibraryList.refresh(parent);
@@ -1203,20 +1205,20 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 	private void doAdd(List<Object> list) {
 		if (canAdd(list)) {
 			CPUserLibraryElement parentLibrary = getSingleSelectedLibrary(list);
-			
+
 			IPath selection= getWorkbenchWindowSelection();
-			
+
 			IPath selectedPaths[] = BuildPathDialogAccess.chooseJAREntries(this.getShell(), selection, new IPath[0]);
-			
+
 			if (selectedPaths != null) {
 				List<CPListElement> elements = new ArrayList<>();
-				for (int i= 0; i < selectedPaths.length; i++) {
-					CPListElement cpElement = new CPListElement(parentLibrary, fDummyProject, IClasspathEntry.CPE_LIBRARY, selectedPaths[i], null);
+				for (IPath selectedPath : selectedPaths) {
+					CPListElement cpElement = new CPListElement(parentLibrary, fDummyProject, IClasspathEntry.CPE_LIBRARY, selectedPath, null);
 					cpElement.setAttribute(CPListElement.SOURCEATTACHMENT, BuildPathSupport.guessSourceAttachment(cpElement));
 					cpElement.setAttribute(CPListElement.JAVADOC, BuildPathSupport.guessJavadocLocation(cpElement));
-					
+
 					elements.add(cpElement);
-					
+
 					parentLibrary.add(cpElement);
 				}
 				fLibraryList.refresh(parentLibrary);
@@ -1249,7 +1251,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 						}
 					}
 				}
-				
+
 			}
 		}
 		return null;
@@ -1315,7 +1317,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 	}
 
 	private boolean canRemove(List<Object> list) {
-		if (list.size() == 0) {
+		if (list.isEmpty()) {
 			return false;
 		}
 		for (int i= 0; i < list.size(); i++) {
@@ -1419,15 +1421,15 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 		}
 		return false;
 	}
-	
+
 	private CPListElement[] openJarFileDialog(CPListElement existing, Object parent) {
 		if (existing == null) {
 			return doOpenExternalJarFileDialog(existing, parent);
 		}
-		
+
 		IWorkspaceRoot root= ResourcesPlugin.getWorkspace().getRoot();
 		IPath path = existing.getPath();
-		
+
 		if (root.exists(path)) {
 			return doOpenInternalJarFileDialog(existing, parent);
 		}
@@ -1437,21 +1439,21 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 	private CPListElement[] doOpenInternalJarFileDialog(CPListElement existing, Object parent) {
 		IPath path = existing.getPath();
 		IPath selectedPaths[] = BuildPathDialogAccess.chooseJAREntries(this.getShell(), path, new IPath[0]);
-		
+
 		if (selectedPaths != null) {
 			List<CPListElement> elements = new ArrayList<>();
-			for (int i= 0; i < selectedPaths.length; i++) {
-				CPListElement cpElement = new CPListElement(parent, fDummyProject, IClasspathEntry.CPE_LIBRARY, selectedPaths[i], null);
+			for (IPath selectedPath : selectedPaths) {
+				CPListElement cpElement = new CPListElement(parent, fDummyProject, IClasspathEntry.CPE_LIBRARY, selectedPath, null);
 				cpElement.setAttribute(CPListElement.SOURCEATTACHMENT, BuildPathSupport.guessSourceAttachment(cpElement));
 				cpElement.setAttribute(CPListElement.JAVADOC, BuildPathSupport.guessJavadocLocation(cpElement));
-				
+
 				elements.add(cpElement);
 			}
 			return elements.toArray(new CPListElement[0]);
 		}
 		return null;
 	}
-	
+
 	private CPListElement[] doOpenExternalJarFileDialog(CPListElement existing, Object parent) {
 		String lastUsedPath;
 		if (existing != null) {
