@@ -119,12 +119,12 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 			}
 			return out.toArray();
 		}
-		
+
 		@Override
 		public boolean select(Viewer viewer, Object parentElement, Object element) {
 			return selectTreePath(viewer, new TreePath(new Object[] { parentElement }), element);
 		}
-		
+
 		public boolean selectTreePath(Viewer viewer, TreePath parentPath, Object element) {
 			// Avoid endless loops, see https://bugs.eclipse.org/395202 :
 			// Cut off children of elements that are shown repeatedly.
@@ -133,7 +133,7 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 					return false;
 				}
 			}
-			
+
 			JavaElementPrefixPatternMatcher matcher= getMatcher();
 			if (matcher == null || !(viewer instanceof TreeViewer))
 				return true;
@@ -154,9 +154,11 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 				Object[] children= contentProvider instanceof ITreePathContentProvider
 						? ((ITreePathContentProvider) contentProvider).getChildren(elementPath)
 						: ((ITreeContentProvider) contentProvider).getChildren(element);
-				for (int i= 0; i < children.length; i++)
-					if (selectTreePath(viewer, elementPath, children[i]))
+				for (Object child : children) {
+					if (selectTreePath(viewer, elementPath, child)) {
 						return true;
+					}
+				}
 			}
 			return false;
 		}
@@ -445,7 +447,7 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 	 *
 	 * @param pattern the pattern
 	 * @param update <code>true</code> if the viewer should be updated
-	 * 
+	 *
 	 * @see JavaElementPrefixPatternMatcher
 	 */
 	protected void setMatcherString(String pattern, boolean update) {
@@ -520,8 +522,7 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 		ILabelProvider labelProvider= (ILabelProvider)fTreeViewer.getLabelProvider();
 
 		// First search at same level
-		for (int i= 0; i < items.length; i++) {
-			final TreeItem item= items[i];
+		for (TreeItem item : items) {
 			IJavaElement element= (IJavaElement)item.getData();
 			if (element != null) {
 				String label= labelProvider.getText(element);
@@ -529,10 +530,8 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 					return item;
 			}
 		}
-
 		// Go one level down for each item
-		for (int i= 0; i < items.length; i++) {
-			final TreeItem item= items[i];
+		for (TreeItem item : items) {
 			TreeItem foundItem= findElement(selectItems(item.getItems(), toBeSkipped), null, false);
 			if (foundItem != null)
 				return foundItem;
@@ -549,14 +548,15 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 		// Check root elements
 		return findElement(selectItems(items[0].getParent().getItems(), items), null, false);
 	}
-	
+
 	private boolean canSkip(TreeItem item, TreeItem[] toBeSkipped) {
 		if (toBeSkipped == null)
 			return false;
-		
-		for (int i= 0; i < toBeSkipped.length; i++) {
-			if (toBeSkipped[i] == item)
+
+		for (TreeItem curr : toBeSkipped) {
+			if (curr == item) {
 				return true;
+			}
 		}
 		return false;
 	}
@@ -566,8 +566,7 @@ public abstract class AbstractInformationControl extends PopupDialog implements
 			return items;
 
 		int j= 0;
-		for (int i= 0; i < items.length; i++) {
-			TreeItem item= items[i];
+		for (TreeItem item : items) {
 			if (!canSkip(item, toBeSkipped))
 				items[j++]= item;
 		}
