@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Renaud Waldura &lt;renaud+eclipse@waldura.com&gt; - New class/interface with wizard
@@ -42,6 +42,7 @@ import org.eclipse.core.resources.IFile;
 import org.eclipse.core.resources.IResource;
 
 import org.eclipse.ui.ISharedImages;
+import org.eclipse.ui.PlatformUI;
 
 import org.eclipse.ltk.core.refactoring.Change;
 import org.eclipse.ltk.core.refactoring.CompositeChange;
@@ -72,6 +73,7 @@ import org.eclipse.jdt.core.dom.ClassInstanceCreation;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.ConstructorInvocation;
 import org.eclipse.jdt.core.dom.EnhancedForStatement;
+import org.eclipse.jdt.core.dom.EnumConstantDeclaration;
 import org.eclipse.jdt.core.dom.Expression;
 import org.eclipse.jdt.core.dom.ExpressionMethodReference;
 import org.eclipse.jdt.core.dom.FieldAccess;
@@ -311,7 +313,7 @@ public class UnresolvedElementsSubProcessor {
 
 		// similar variables
 		addSimilarVariableProposals(cu, astRoot, binding, resolvedField, simpleName, isWriteAccess, proposals);
-		
+
 		if (binding == null) {
 			addStaticImportFavoriteProposals(context, simpleName, false, proposals);
 		}
@@ -356,7 +358,7 @@ public class UnresolvedElementsSubProcessor {
 					rewrite.remove(statement, null);
 				}
 				String label= CorrectionMessages.UnresolvedElementsSubProcessor_removestatement_description;
-				Image image= JavaPlugin.getDefault().getWorkbench().getSharedImages().getImage(ISharedImages.IMG_TOOL_DELETE);
+				Image image= PlatformUI.getWorkbench().getSharedImages().getImage(ISharedImages.IMG_TOOL_DELETE);
 				ASTRewriteCorrectionProposal proposal= new ASTRewriteCorrectionProposal(label, cu, rewrite, IProposalRelevance.REMOVE_ASSIGNMENT, image);
 				proposals.add(proposal);
 			}
@@ -541,9 +543,8 @@ public class UnresolvedElementsSubProcessor {
 
 							MethodInvocation newInv= ast.newMethodInvocation();
 							newInv.setName(ast.newSimpleName(curr.getName()));
-							ITypeBinding[] parameterTypes= curr.getParameterTypes();
-							for (int k= 0; k < parameterTypes.length; k++) {
-								ASTNode arg= ASTNodeFactory.newDefaultExpression(ast, parameterTypes[k]);
+							for (ITypeBinding parameterType : curr.getParameterTypes()) {
+								ASTNode arg= ASTNodeFactory.newDefaultExpression(ast, parameterType);
 								newInv.arguments().add(arg);
 								proposal.addLinkedPosition(rewrite.track(arg), false, null);
 							}
@@ -567,9 +568,8 @@ public class UnresolvedElementsSubProcessor {
 	}
 
 	private static boolean hasMethodWithName(ITypeBinding typeBinding, String name) {
-		IVariableBinding[] fields= typeBinding.getDeclaredFields();
-		for (int i= 0; i < fields.length; i++) {
-			if (fields[i].getName().equals(name)) {
+		for (IVariableBinding field : typeBinding.getDeclaredFields()) {
+			if (field.getName().equals(name)) {
 				return true;
 			}
 		}
@@ -581,9 +581,8 @@ public class UnresolvedElementsSubProcessor {
 	}
 
 	private static boolean hasFieldWithName(ITypeBinding typeBinding, String name) {
-		IMethodBinding[] methods= typeBinding.getDeclaredMethods();
-		for (int i= 0; i < methods.length; i++) {
-			if (methods[i].getName().equals(name)) {
+		for (IMethodBinding method : typeBinding.getDeclaredMethods()) {
+			if (method.getName().equals(name)) {
 				return true;
 			}
 		}
@@ -610,7 +609,7 @@ public class UnresolvedElementsSubProcessor {
 
 		IJavaProject javaProject= cu.getJavaProject();
 		int kind= evauateTypeKind(selectedNode, javaProject);
-		
+
 		if (kind == TypeKinds.REF_TYPES) {
 			addEnhancedForWithoutTypeProposals(cu, selectedNode, proposals);
 		}
@@ -650,7 +649,7 @@ public class UnresolvedElementsSubProcessor {
 					if (name.equals("var")) { //$NON-NLS-1$
 						isVarTypeProblem= true;
 					}
-				}				
+				}
 			}
 			if (isVarTypeProblem) {
 				// check if "var" is present as lambda parameter type
@@ -660,14 +659,14 @@ public class UnresolvedElementsSubProcessor {
 					parent= parent.getParent();
 					if (parent.getLocationInParent() == LambdaExpression.PARAMETERS_PROPERTY) {
 						isVarInLambdaParamType= true;
-					}						
+					}
 				}
-				
+
 				if (isVarInLambdaParamType) {
 					ReorgCorrectionsSubProcessor.getNeedHigherComplianceProposals(context, problem, proposals, JavaCore.VERSION_11);
 				} else {
-					ReorgCorrectionsSubProcessor.getNeedHigherComplianceProposals(context, problem, proposals, JavaCore.VERSION_10);						
-				}		
+					ReorgCorrectionsSubProcessor.getNeedHigherComplianceProposals(context, problem, proposals, JavaCore.VERSION_10);
+				}
 			}
 		}
 
@@ -707,7 +706,7 @@ public class UnresolvedElementsSubProcessor {
 			kind &= ~TypeKinds.ANNOTATIONS; // only propose annotations when there are no other suggestions
 		}
 		addNewTypeProposals(cu, node, kind, IProposalRelevance.NEW_TYPE, proposals);
-		
+
 		ReorgCorrectionsSubProcessor.addProjectSetupFixProposal(context, problem, node.getFullyQualifiedName(), proposals);
 	}
 
@@ -723,7 +722,7 @@ public class UnresolvedElementsSubProcessor {
 						int relevance= StubUtility.hasLocalVariableName(cu.getJavaProject(), name) ? 10 : 7;
 						String label= Messages.format(CorrectionMessages.UnresolvedElementsSubProcessor_create_loop_variable_description, BasicElementLabels.getJavaElementName(name));
 						Image image= JavaPluginImages.get(JavaPluginImages.IMG_CORRECTION_LOCAL);
-						
+
 						proposals.add(new NewVariableCorrectionProposal(label, cu, NewVariableCorrectionProposal.LOCAL, simpleName, null, relevance, image));
 					}
 				}
@@ -739,10 +738,10 @@ public class UnresolvedElementsSubProcessor {
 			if (!isImportName)
 				return;
 		}
-		
+
 		final IJavaProject javaProject= cu.getJavaProject();
 		String name= node.getFullyQualifiedName();
-		
+
 		String nullityAnnotation= null;
 		String[] annotationNameOptions= { JavaCore.COMPILER_NULLABLE_ANNOTATION_NAME, JavaCore.COMPILER_NONNULL_ANNOTATION_NAME, JavaCore.COMPILER_NONNULL_BY_DEFAULT_ANNOTATION_NAME };
 		Hashtable<String, String> defaultOptions= JavaCore.getDefaultOptions();
@@ -762,7 +761,7 @@ public class UnresolvedElementsSubProcessor {
 		Bundle[] annotationsBundles= JavaPlugin.getDefault().getBundles("org.eclipse.jdt.annotation", version); //$NON-NLS-1$
 		if (annotationsBundles == null)
 			return;
-		
+
 		if (! cu.getJavaProject().getProject().hasNature("org.eclipse.pde.PluginNature")) //$NON-NLS-1$
 			addCopyAnnotationsJarProposal(cu, node, nullityAnnotation, annotationsBundles[0], proposals);
 	}
@@ -809,7 +808,7 @@ public class UnresolvedElementsSubProcessor {
 				CompilationUnitChange addImportChange= createAddImportChange(cu, name, fullyQualifiedName);
 				return new CompositeChange(changeName, new Change[] { copyFileChange, addEntryChange, addImportChange});
 			}
-			
+
 			@Override
 			public Object getAdditionalProposalInfo(IProgressMonitor monitor) {
 				return CorrectionMessages.UnresolvedElementsSubProcessor_copy_annotation_jar_info;
@@ -877,8 +876,7 @@ public class UnresolvedElementsSubProcessor {
 		}
 
 		// add all similar elements
-		for (int i= 0; i < elements.length; i++) {
-			SimilarElement elem= elements[i];
+		for (SimilarElement elem : elements) {
 			if ((elem.getKind() & TypeKinds.ALL_TYPES) != 0) {
 				String fullName= elem.getName();
 				if (!fullName.equals(resolvedTypeName)) {
@@ -1238,8 +1236,8 @@ public class UnresolvedElementsSubProcessor {
 		IBinding[] bindings= (new ScopeAnalyzer(astRoot)).getDeclarationsInScope(nameNode, ScopeAnalyzer.METHODS);
 
 		HashSet<String> suggestedRenames= new HashSet<>();
-		for (int i= 0; i < bindings.length; i++) {
-			IMethodBinding binding= (IMethodBinding) bindings[i];
+		for (IBinding b : bindings) {
+			IMethodBinding binding= (IMethodBinding) b;
 			String curr= binding.getName();
 			if (!curr.equals(methodName) && binding.getParameterTypes().length == nArguments && NameMatcher.isSimilarName(methodName, curr) && suggestedRenames.add(curr)) {
 				String label= Messages.format(CorrectionMessages.UnresolvedElementsSubProcessor_changemethod_description, BasicElementLabels.getJavaElementName(curr));
@@ -1250,15 +1248,14 @@ public class UnresolvedElementsSubProcessor {
 
 		if (isOnlyParameterMismatch) {
 			ArrayList<IMethodBinding> parameterMismatchs= new ArrayList<>();
-			for (int i= 0; i < bindings.length; i++) {
-				IMethodBinding binding= (IMethodBinding) bindings[i];
+			for (IBinding binding : bindings) {
 				if (binding.getName().equals(methodName)) {
-					parameterMismatchs.add(binding);
+					parameterMismatchs.add((IMethodBinding) binding);
 				}
 			}
 			addParameterMissmatchProposals(context, problem, parameterMismatchs, invocationNode, arguments, proposals);
 		}
-		
+
 		if (sender == null) {
 			addStaticImportFavoriteProposals(context, nameNode, true, proposals);
 		}
@@ -1279,7 +1276,7 @@ public class UnresolvedElementsSubProcessor {
 		}
 
 	}
-	
+
 	private static void addStaticImportFavoriteProposals(IInvocationContext context, SimpleName node, boolean isMethod, Collection<ICommandAccess> proposals) throws JavaModelException {
 		IJavaProject project= context.getCompilationUnit().getJavaProject();
 		if (JavaModelUtil.is50OrHigher(project)) {
@@ -1291,19 +1288,16 @@ public class UnresolvedElementsSubProcessor {
 
 			CompilationUnit root= context.getASTRoot();
 			AST ast= root.getAST();
-			
+
 			String name= node.getIdentifier();
-			String[] staticImports= SimilarElementsRequestor.getStaticImportFavorites(context.getCompilationUnit(), name, isMethod, favourites);
-			for (int i= 0; i < staticImports.length; i++) {
-				String curr= staticImports[i];
-				
+			for (String curr : SimilarElementsRequestor.getStaticImportFavorites(context.getCompilationUnit(), name, isMethod, favourites)) {
 				ImportRewrite importRewrite= StubUtility.createImportRewrite(root, true);
 				ASTRewrite astRewrite= ASTRewrite.create(ast);
-				
+
 				String label;
 				String qualifiedTypeName= Signature.getQualifier(curr);
 				String elementLabel= BasicElementLabels.getJavaElementName(JavaModelUtil.concatenateName(Signature.getSimpleName(qualifiedTypeName), name));
-				
+
 				String res= importRewrite.addStaticImport(qualifiedTypeName, name, isMethod, new ContextSensitiveImportRewriteContext(root, node.getStartPosition(), importRewrite));
 				int dot= res.lastIndexOf('.');
 				if (dot != -1) {
@@ -1322,7 +1316,7 @@ public class UnresolvedElementsSubProcessor {
 			}
 		}
 	}
-	
+
 
 	private static void addNewMethodProposals(ICompilationUnit cu, CompilationUnit astRoot, Expression sender, List<Expression> arguments, boolean isSuperInvocation, ASTNode invocationNode, String methodName, Collection<ICommandAccess> proposals) throws JavaModelException {
 		ITypeBinding nodeParentType= Bindings.getBindingOfParentType(invocationNode);
@@ -1347,7 +1341,7 @@ public class UnresolvedElementsSubProcessor {
 				if (parameterTypes != null) {
 					String sig= org.eclipse.jdt.internal.ui.text.correction.ASTResolving.getMethodSignature(methodName, parameterTypes, false);
 					boolean is18OrHigher= JavaModelUtil.is18OrHigher(targetCU.getJavaProject());
-					boolean isSenderTypeAbstractClass = (senderDeclBinding.getModifiers() &  Modifier.ABSTRACT) > 0; 
+					boolean isSenderTypeAbstractClass = (senderDeclBinding.getModifiers() &  Modifier.ABSTRACT) > 0;
 					boolean isSenderBindingInterface= senderDeclBinding.isInterface();
 					if (nodeParentType == senderDeclBinding) {
 						label= Messages.format(CorrectionMessages.UnresolvedElementsSubProcessor_createmethod_description, sig);
@@ -1787,11 +1781,11 @@ public class UnresolvedElementsSubProcessor {
 					proposal.setDisplayName(Messages.format(CorrectionMessages.UnresolvedElementsSubProcessor_addargumentcast_description, arg));
 					proposals.add(proposal);
 				}
-				
+
 				TypeMismatchSubProcessor.addChangeSenderTypeProposals(context, nodeToCast, castType, false, IProposalRelevance.CAST_ARGUMENT_2, proposals);
 			}
 		}
-		
+
 		if (nDiffs == 2) { // try to swap
 			int idx1= indexOfDiff[0];
 			int idx2= indexOfDiff[1];
@@ -2002,13 +1996,21 @@ public class UnresolvedElementsSubProcessor {
 				recursiveConstructor= ASTResolving.findParentMethodDeclaration(selectedNode).resolveBinding();
 			}
 		}
+
+		if (selectedNode.getParent() instanceof EnumConstantDeclaration) {
+			EnumConstantDeclaration enumNode= (EnumConstantDeclaration) selectedNode.getParent();
+			ITypeBinding typeBinding= Bindings.getBindingOfParentType(selectedNode);
+			if (typeBinding != null && !typeBinding.isAnonymous()) {
+				targetBinding= typeBinding;
+				arguments= enumNode.arguments();
+			}
+		}
+
 		if (targetBinding == null) {
 			return;
 		}
-		IMethodBinding[] methods= targetBinding.getDeclaredMethods();
 		ArrayList<IMethodBinding> similarElements= new ArrayList<>();
-		for (int i= 0; i < methods.length; i++) {
-			IMethodBinding curr= methods[i];
+		for (IMethodBinding curr : targetBinding.getDeclaredMethods()) {
 			if (curr.isConstructor() && recursiveConstructor != curr) {
 				similarElements.add(curr); // similar elements can contain a implicit default constructor
 			}
@@ -2034,9 +2036,7 @@ public class UnresolvedElementsSubProcessor {
 		int offset= problem.getOffset();
 		int len= problem.getLength();
 
-		IJavaElement[] elements= cu.codeSelect(offset, len);
-		for (int i= 0; i < elements.length; i++) {
-			IJavaElement curr= elements[i];
+		for (IJavaElement curr : cu.codeSelect(offset, len)) {
 			if (curr instanceof IType && !TypeFilter.isFiltered((IType) curr)) {
 				String qualifiedTypeName= ((IType) curr).getFullyQualifiedName('.');
 
@@ -2066,9 +2066,8 @@ public class UnresolvedElementsSubProcessor {
 		SimpleName nameNode= decl.getName();
 		String methodName= nameNode.getIdentifier();
 
-		IBinding[] bindings= (new ScopeAnalyzer(root)).getDeclarationsInScope(nameNode, ScopeAnalyzer.METHODS);
-		for (int i= 0; i < bindings.length; i++) {
-			String currName= bindings[i].getName();
+		for (IBinding binding : (new ScopeAnalyzer(root)).getDeclarationsInScope(nameNode, ScopeAnalyzer.METHODS)) {
+			String currName= binding.getName();
 			if (NameMatcher.isSimilarName(methodName, currName)) {
 				String label= Messages.format(CorrectionMessages.UnresolvedElementsSubProcessor_arraychangetomethod_description, BasicElementLabels.getJavaElementName(currName));
 				proposals.add(new RenameNodeCorrectionProposal(label, context.getCompilationUnit(), nameNode.getStartPosition(), nameNode.getLength(), currName, IProposalRelevance.ARRAY_CHANGE_TO_METHOD));
@@ -2110,9 +2109,7 @@ public class UnresolvedElementsSubProcessor {
 
 		if (annotation instanceof NormalAnnotation) {
 			// similar names
-			IMethodBinding[] otherMembers= annotBinding.getDeclaredMethods();
-			for (int i= 0; i < otherMembers.length; i++) {
-				IMethodBinding binding= otherMembers[i];
+			for (IMethodBinding binding : annotBinding.getDeclaredMethods()) {
 				String curr= binding.getName();
 				int relevance= NameMatcher.isSimilarName(memberName, curr) ? IProposalRelevance.CHANGE_TO_ATTRIBUTE_SIMILAR_NAME : IProposalRelevance.CHANGE_TO_ATTRIBUTE;
 				String label= Messages.format(CorrectionMessages.UnresolvedElementsSubProcessor_UnresolvedElementsSubProcessor_changetoattribute_description, BasicElementLabels.getJavaElementName(curr));
