@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -58,7 +58,7 @@ import org.eclipse.jdt.internal.corext.dom.Bindings;
 import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.corext.util.JdtFlags;
 
-import org.eclipse.jdt.internal.ui.text.correction.ModifierCorrectionSubProcessor;
+import org.eclipse.jdt.internal.ui.text.correction.ModifierCorrectionSubProcessorCore;
 
 public class NewMethodCorrectionProposal extends AbstractMethodCorrectionProposal {
 
@@ -74,7 +74,7 @@ public class NewMethodCorrectionProposal extends AbstractMethodCorrectionProposa
 	}
 
 	protected int evaluateModifiers(ASTNode targetTypeDecl) {
-		if (getSenderBinding().isAnnotation()) {
+		if (getSenderBinding().isAnnotation() || getSenderBinding().isEnum()) {
 			return 0;
 		}
 		boolean isTargetInterface= getSenderBinding().isInterface();
@@ -150,7 +150,7 @@ public class NewMethodCorrectionProposal extends AbstractMethodCorrectionProposa
 	@Override
 	protected void addNewModifiers(ASTRewrite rewrite, ASTNode targetTypeDecl, List<IExtendedModifier> modifiers) {
 		modifiers.addAll(rewrite.getAST().newModifiers(evaluateModifiers(targetTypeDecl)));
-		ModifierCorrectionSubProcessor.installLinkedVisibilityProposals(getLinkedProposalModel(), rewrite, modifiers, getSenderBinding().isInterface());
+		ModifierCorrectionSubProcessorCore.installLinkedVisibilityProposals(getLinkedProposalModel(), rewrite, modifiers, getSenderBinding().isInterface());
 	}
 
 	@Override
@@ -238,8 +238,8 @@ public class NewMethodCorrectionProposal extends AbstractMethodCorrectionProposa
 
 		addLinkedPosition(rewrite.track(newTypeNode), false, KEY_TYPE);
 		if (otherProposals != null) {
-			for (int i= 0; i < otherProposals.length; i++) {
-				addLinkedPositionProposal(KEY_TYPE, otherProposals[i]);
+			for (ITypeBinding otherProposal : otherProposals) {
+				addLinkedPositionProposal(KEY_TYPE, otherProposal);
 			}
 		}
 
@@ -279,9 +279,8 @@ public class NewMethodCorrectionProposal extends AbstractMethodCorrectionProposa
 			binding= ASTResolving.normalizeWildcardType(binding, true, ast);
 		}
 		if (binding != null) {
-			ITypeBinding[] typeProposals= ASTResolving.getRelaxingTypes(ast, binding);
-			for (int i= 0; i < typeProposals.length; i++) {
-				addLinkedPositionProposal(key, typeProposals[i]);
+			for (ITypeBinding typeProposal : ASTResolving.getRelaxingTypes(ast, binding)) {
+				addLinkedPositionProposal(key, typeProposal);
 			}
 			return getImportRewrite().addImport(binding, ast, context, TypeLocation.PARAMETER);
 		}
@@ -291,8 +290,8 @@ public class NewMethodCorrectionProposal extends AbstractMethodCorrectionProposa
 	private String evaluateParameterName(List<String> takenNames, Expression argNode, Type type, String key) {
 		IJavaProject project= getCompilationUnit().getJavaProject();
 		String[] names= StubUtility.getVariableNameSuggestions(NamingConventions.VK_PARAMETER, project, type, argNode, takenNames);
-		for (int i= 0; i < names.length; i++) {
-			addLinkedPositionProposal(key, names[i], null);
+		for (String name : names) {
+			addLinkedPositionProposal(key, name, null);
 		}
 		String favourite= names[0];
 		takenNames.add(favourite);
