@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2019 IBM Corporation and others.
+ * Copyright (c) 2008, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -36,6 +36,7 @@ import java.util.zip.ZipFile;
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
+import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.Status;
@@ -124,7 +125,7 @@ import org.eclipse.jdt.internal.ui.viewsupport.JavaElementLinks;
 public class JavadocContentAccess2 {
 
 	private static final String BASE_URL_COMMENT_INTRO= "<!-- baseURL=\""; //$NON-NLS-1$
-	
+
 	private static final String BLOCK_TAG_START= "<dl>"; //$NON-NLS-1$
 	private static final String BLOCK_TAG_END= "</dl>"; //$NON-NLS-1$
 
@@ -145,12 +146,12 @@ public class JavadocContentAccess2 {
 	 * >1.5</a>, and <a href=
 	 * "http://download.oracle.com/javase/6/docs/technotes/tools/windows/javadoc.html#inheritingcomments"
 	 * >1.6</a>.
-	 * 
+	 *
 	 * <p>
 	 * Unfortunately, the implementation is broken in Javadoc implementations since 1.5, see <a
 	 * href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6376959">Sun's bug</a>.
 	 * </p>
-	 * 
+	 *
 	 * <p>
 	 * We adhere to the spec.
 	 * </p>
@@ -226,7 +227,7 @@ public class JavadocContentAccess2 {
 
 		/**
 		 * Visits the super interfaces of the given type in the given hierarchy, thereby skipping already visited types.
-		 * 
+		 *
 		 * @param visited set of visited types
 		 * @param currentType type whose super interfaces should be visited
 		 * @param typeHierarchy type hierarchy (must include <code>currentType</code>)
@@ -235,9 +236,7 @@ public class JavadocContentAccess2 {
 		 */
 		private Object visitInheritDocInterfaces(ArrayList<IType> visited, IType currentType, ITypeHierarchy typeHierarchy) throws JavaModelException {
 			ArrayList<IType> toVisitChildren= new ArrayList<>();
-			IType[] superInterfaces= typeHierarchy.getSuperInterfaces(currentType);
-			for (int i= 0; i < superInterfaces.length; i++) {
-				IType superInterface= superInterfaces[i];
+			for (IType superInterface : typeHierarchy.getSuperInterfaces(currentType)) {
 				if (visited.contains(superInterface))
 					continue;
 				visited.add(superInterface);
@@ -283,7 +282,7 @@ public class JavadocContentAccess2 {
 		private static interface DescriptionGetter {
 			/**
 			 * Returns a Javadoc tag description or <code>null</code>.
-			 * 
+			 *
 			 * @param contentAccess the content access
 			 * @return the description, or <code>null</code> if none
 			 * @throws JavaModelException unexpected problem
@@ -311,12 +310,7 @@ public class JavadocContentAccess2 {
 		 * 		or <code>null</code> if none could be found
 		 */
 		public CharSequence getInheritedMainDescription(IMethod method) {
-			return getInheritedDescription(method, new DescriptionGetter() {
-				@Override
-				public CharSequence getDescription(JavadocContentAccess2 contentAccess) {
-					return contentAccess.getMainDescription();
-				}
-			});
+			return getInheritedDescription(method, JavadocContentAccess2::getMainDescription);
 		}
 
 		/**
@@ -363,12 +357,7 @@ public class JavadocContentAccess2 {
 		 * 		or <code>null</code> if none could be found
 		 */
 		public CharSequence getInheritedReturnDescription(IMethod method) {
-			return getInheritedDescription(method, new DescriptionGetter() {
-				@Override
-				public CharSequence getDescription(JavadocContentAccess2 contentAccess) {
-					return contentAccess.getReturnDescription();
-				}
-			});
+			return getInheritedDescription(method, JavadocContentAccess2::getReturnDescription);
 		}
 
 		/**
@@ -478,7 +467,7 @@ public class JavadocContentAccess2 {
 	 * Either an IMember or an IPackageFragment.
 	 */
 	private final IJavaElement fElement;
-	
+
 	/**
 	 * The method, or <code>null</code> if {@link #fElement} is not a method where @inheritDoc could
 	 * work.
@@ -593,7 +582,7 @@ public class JavadocContentAccess2 {
 			}
 		}.visitInheritDoc(type, hierarchy);
 
-		boolean hasSuperInterfaceMethods= superInterfaceMethods.size() != 0;
+		boolean hasSuperInterfaceMethods= !superInterfaceMethods.isEmpty();
 		if (!hasSuperInterfaceMethods && superClassMethod[0] == null)
 			return null;
 
@@ -676,7 +665,7 @@ public class JavadocContentAccess2 {
 		String rawJavadoc= buf.getText(javadocRange.getOffset(), javadocRange.getLength());
 		return javadoc2HTML(member, element, rawJavadoc);
 	}
-	
+
 	private static String getJavaFxPropertyDoc(IMember member) throws JavaModelException {
 		// XXX: should not do this by default (but we don't have settings for Javadoc, see https://bugs.eclipse.org/424283 )
 		if (member instanceof IMethod) {
@@ -713,13 +702,13 @@ public class JavadocContentAccess2 {
 		}
 		return null;
 	}
-	
+
 	private static String firstToLower(String propertyName) {
 		char[] c = propertyName.toCharArray();
 		c[0] = Character.toLowerCase(c[0]);
 		return String.valueOf(c);
 	}
-	
+
 	private static Javadoc getJavadocNode(IJavaElement element, String rawJavadoc) {
 		//FIXME: take from SharedASTProvider if available
 		//Caveat: Javadoc nodes are not available when Javadoc processing has been disabled!
@@ -750,17 +739,17 @@ public class JavadocContentAccess2 {
 	private static CompilationUnit createAST(IJavaElement element, String cuSource) {
 		Assert.isNotNull(element);
 		ASTParser parser= ASTParser.newParser(IASTSharedValues.SHARED_AST_LEVEL);
-		
+
 		IJavaProject javaProject= element.getJavaProject();
 		parser.setProject(javaProject);
 		Map<String, String> options= javaProject.getOptions(true);
 		options.put(JavaCore.COMPILER_DOC_COMMENT_SUPPORT, JavaCore.ENABLED); // workaround for https://bugs.eclipse.org/bugs/show_bug.cgi?id=212207
 		parser.setCompilerOptions(options);
-		
+
 		parser.setSource(cuSource.toCharArray());
 		return (CompilationUnit) parser.createAST(null);
 	}
-	
+
 	private static String javadoc2HTML(IMember member, IJavaElement element, String rawJavadoc) {
 		Javadoc javadoc= getJavadocNode(member, rawJavadoc);
 
@@ -813,7 +802,7 @@ public class JavadocContentAccess2 {
 	 * @return the reader content as string
 	 */
 	private static String getString(Reader reader) {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		char[] buffer= new char[1024];
 		int count;
 		try {
@@ -941,6 +930,8 @@ public class JavadocContentAccess2 {
 		List<TagElement> parameters= new ArrayList<>();
 		TagElement returnTag= null;
 		List<TagElement> exceptions= new ArrayList<>();
+		List<TagElement> provides= new ArrayList<>();
+		List<TagElement> uses= new ArrayList<>();
 		List<TagElement> versions= new ArrayList<>();
 		List<TagElement> authors= new ArrayList<>();
 		List<TagElement> sees= new ArrayList<>();
@@ -949,8 +940,6 @@ public class JavadocContentAccess2 {
 		List<TagElement> apinote= new ArrayList<>(1);
 		List<TagElement> implspec= new ArrayList<>(1);
 		List<TagElement> implnote= new ArrayList<>(1);
-		List<TagElement> uses= new ArrayList<>(1);
-		List<TagElement> provides= new ArrayList<>(1);
 		List<TagElement> hidden= new ArrayList<>(1);
 
 		List<TagElement> tags= fJavadoc.tags();
@@ -1010,6 +999,10 @@ public class JavadocContentAccess2 {
 					}
 				}
 
+			} else if (TagElement.TAG_PROVIDES.equals(tagName)) {
+				provides.add(tag);
+			} else if (TagElement.TAG_USES.equals(tagName)) {
+				uses.add(tag);
 			} else if (TagElement.TAG_SINCE.equals(tagName)) {
 				since.add(tag);
 			} else if (TagElement.TAG_VERSION.equals(tagName)) {
@@ -1158,10 +1151,9 @@ public class JavadocContentAccess2 {
 	private List<String> initExceptionNames() {
 		if (fMethod != null) {
 			try {
-				String[] exceptionTypes= fMethod.getExceptionTypes();
 				ArrayList<String> exceptionNames= new ArrayList<>();
-				for (int i= 0; i < exceptionTypes.length; i++) {
-					exceptionNames.add(Signature.getSimpleName(Signature.toString(exceptionTypes[i])));
+				for (String exceptionType : fMethod.getExceptionTypes()) {
+					exceptionNames.add(Signature.getSimpleName(Signature.toString(exceptionType)));
 				}
 				return exceptionNames;
 			} catch (JavaModelException e) {
@@ -1397,24 +1389,23 @@ public class JavadocContentAccess2 {
 		return null;
 	}
 
-		
+
 	private void handleContentElements(List<? extends ASTNode> nodes) {
 		handleContentElements(nodes, false);
 	}
-	
+
 	private void handleContentElements(List<? extends ASTNode> nodes, boolean skipLeadingWhitespace) {
 		ASTNode previousNode= null;
-		for (Iterator<? extends ASTNode> iter= nodes.iterator(); iter.hasNext(); ) {
-			ASTNode child= iter.next();
+		for (ASTNode child : nodes) {
 			if (previousNode != null) {
 				int previousEnd= previousNode.getStartPosition() + previousNode.getLength();
 				int childStart= child.getStartPosition();
 				if (previousEnd > childStart) {
 					// should never happen, see https://bugs.eclipse.org/bugs/show_bug.cgi?id=304826
 					Exception exception= new Exception("Illegal ASTNode positions: previousEnd=" + previousEnd //$NON-NLS-1$
-							+ ", childStart=" + childStart //$NON-NLS-1$
-							+ ", element=" + fElement.getHandleIdentifier() //$NON-NLS-1$
-							+ ", Javadoc:\n" + fSource); //$NON-NLS-1$
+						+ ", childStart=" + childStart //$NON-NLS-1$
+						+ ", element=" + fElement.getHandleIdentifier() //$NON-NLS-1$
+						+ ", Javadoc:\n" + fSource); //$NON-NLS-1$
 					JavaPlugin.log(exception);
 				} else if (previousEnd != childStart) {
 					// Need to preserve whitespace before a node that's not
@@ -1534,7 +1525,7 @@ public class JavadocContentAccess2 {
 	}
 
 	private boolean handleValueTag(TagElement node) {
-		
+
 		List<? extends ASTNode> fragments= node.fragments();
 		try {
 			if (!(fElement instanceof IMember)) {
@@ -1549,31 +1540,35 @@ public class JavadocContentAccess2 {
 				Object first= fragments.get(0);
 				if (first instanceof MemberRef) {
 					MemberRef memberRef= (MemberRef) first;
-					if (memberRef.getQualifier() == null) {
-						SimpleName name= memberRef.getName();
-						IType type= fElement instanceof IType ? (IType) fElement : ((IMember) fElement).getDeclaringType();
-						while (type != null) {
-							IField field= type.getField(name.getIdentifier());
-							if (field != null && field.exists()) {
-								if (JdtFlags.isStatic(field) && JdtFlags.isFinal(field))
-									return handleConstantValue(field, true);
-								break;
-							}
-							type= type.getDeclaringType();
+					IType type= fElement instanceof IType ? (IType) fElement : ((IMember) fElement).getDeclaringType();
+					if (memberRef.getQualifier() != null) {
+						String[][] qualifierTypes= type.resolveType(memberRef.getQualifier().getFullyQualifiedName());
+						if (qualifierTypes != null && qualifierTypes.length == 1) {
+							type= type.getJavaProject().findType(String.join(".", qualifierTypes[0]), (IProgressMonitor)null); //$NON-NLS-1$
 						}
 					}
+					SimpleName name= memberRef.getName();
+					while (type != null) {
+						IField field= type.getField(name.getIdentifier());
+						if (field != null && field.exists()) {
+							if (JdtFlags.isStatic(field) && JdtFlags.isFinal(field))
+								return handleConstantValue(field, true);
+							break;
+						}
+						type= type.getDeclaringType();
+					}
 				}
 			}
 		} catch (JavaModelException e) {
 			JavaPlugin.log(e);
 		}
-		
+
 		return false;
 	}
 
 	private boolean handleConstantValue(IField field, boolean link) throws JavaModelException {
 		String text= null;
-		
+
 		ISourceRange nameRange= field.getNameRange();
 		if (SourceRange.isAvailable(nameRange)) {
 			CompilationUnit cuNode= SharedASTProviderCore.getAST(field.getTypeRoot(), SharedASTProviderCore.WAIT_ACTIVE_ONLY, null);
@@ -1595,14 +1590,14 @@ public class JavadocContentAccess2 {
 				}
 			}
 		}
-		
+
 		if (text == null) {
 			Object constant= field.getConstant();
 			if (constant != null) {
 				text= constant.toString();
 			}
 		}
-		
+
 		if (text != null) {
 			text= HTMLPrinter.convertToHTMLContentWithWhitespace(text);
 			if (link) {
@@ -1803,7 +1798,7 @@ public class JavadocContentAccess2 {
 	}
 
 	private void handleExceptionTags(List<TagElement> tags, List<String> exceptionNames, CharSequence[] exceptionDescriptions) {
-		if (tags.size() == 0 && containsOnlyNull(exceptionNames))
+		if (tags.isEmpty() && containsOnlyNull(exceptionNames))
 			return;
 
 		handleBlockTagTitle(JavaDocMessages.JavaDoc2HTMLTextReader_throws_section);
@@ -1842,7 +1837,7 @@ public class JavadocContentAccess2 {
 	}
 
 	private void handleParameterTags(List<TagElement> tags, List<String> parameterNames, CharSequence[] parameterDescriptions, boolean isTypeParameters) {
-		if (tags.size() == 0 && containsOnlyNull(parameterNames))
+		if (tags.isEmpty() && containsOnlyNull(parameterNames))
 			return;
 
 		String tagTitle= isTypeParameters ? JavaDocMessages.JavaDoc2HTMLTextReader_type_parameters_section : JavaDocMessages.JavaDoc2HTMLTextReader_parameters_section;
@@ -2020,7 +2015,7 @@ public class JavadocContentAccess2 {
 	private static boolean isWhitespaceTextElement(Object fragment) {
 		if (!(fragment instanceof TextElement))
 			return false;
-		
+
 		TextElement textElement= (TextElement) fragment;
 		return textElement.getText().trim().length() == 0;
 	}
@@ -2052,7 +2047,7 @@ public class JavadocContentAccess2 {
 
 	/**
 	 * Returns the Javadoc for a PackageDeclaration.
-	 * 
+	 *
 	 * @param packageDeclaration the Java element whose Javadoc has to be retrieved
 	 * @return the package documentation in HTML format or <code>null</code> if there is no
 	 *         associated Javadoc
@@ -2072,7 +2067,7 @@ public class JavadocContentAccess2 {
 	/**
 	 * Returns the Javadoc for a package which could be present in package.html, package-info.java
 	 * or from an attached Javadoc.
-	 * 
+	 *
 	 * @param packageFragment the package which is requesting for the document
 	 * @return the document content in HTML format or <code>null</code> if there is no associated
 	 *         Javadoc
@@ -2177,17 +2172,18 @@ public class JavadocContentAccess2 {
 		return getFileContentFromAttachedSource(root, filePath);
 	}
 
+	@SuppressWarnings("resource")
 	private static String getFileContentFromAttachedSource(IPackageFragmentRoot root, String filePath) throws CoreException {
 		IPath sourceAttachmentPath= root.getSourceAttachmentPath();
 		if (sourceAttachmentPath != null) {
 			File file= null ;
 			String encoding= null;
-			
+
 			if (sourceAttachmentPath.getDevice() == null) {
 				//the path could be a workspace relative path to a zip or to the source folder
 				IWorkspaceRoot wsRoot= ResourcesPlugin.getWorkspace().getRoot();
 				IResource res= wsRoot.findMember(sourceAttachmentPath);
-				
+
 				if (res instanceof IFile) {
 					// zip in the workspace
 					IPath location= res.getLocation();
@@ -2195,7 +2191,7 @@ public class JavadocContentAccess2 {
 						return null;
 					file= location.toFile();
 					encoding= ((IFile) res).getCharset(false);
-					
+
 				} else if (res instanceof IContainer) {
 					// folder in the workspace
 					res= ((IContainer) res).findMember(filePath);
@@ -2207,10 +2203,10 @@ public class JavadocContentAccess2 {
 					return getContentsFromInputStream(((IFile) res).getContents(), encoding);
 				}
 			}
-			
+
 			if (file == null || !file.exists())
 				file= sourceAttachmentPath.toFile();
-			
+
 			if (file.isDirectory()) {
 				//the path is an absolute filesystem path to the source folder
 				IPath packagedocPath= sourceAttachmentPath.append(filePath);
@@ -2265,7 +2261,7 @@ public class JavadocContentAccess2 {
 
 	private static String getContentsFromInputStream(InputStream in, String encoding) throws CoreException {
 		final int defaultFileSize= 15 * 1024;
-		StringBuffer buffer= new StringBuffer(defaultFileSize);
+		StringBuilder buffer= new StringBuilder(defaultFileSize);
 		Reader reader= null;
 
 		try {
@@ -2301,9 +2297,7 @@ public class JavadocContentAccess2 {
 		if (entry != null) {
 			int kind= entry.getEntryKind();
 			if (kind == IClasspathEntry.CPE_LIBRARY || kind == IClasspathEntry.CPE_VARIABLE) {
-				IClasspathAttribute[] extraAttributes= entry.getExtraAttributes();
-				for (int i= 0; i < extraAttributes.length; i++) {
-					IClasspathAttribute attrib= extraAttributes[i];
+				for (IClasspathAttribute attrib : entry.getExtraAttributes()) {
 					if (IClasspathAttribute.SOURCE_ATTACHMENT_ENCODING.equals(attrib.getName())) {
 						return attrib.getValue();
 					}
@@ -2316,7 +2310,7 @@ public class JavadocContentAccess2 {
 
 	/**
 	 * Reads the content of the IFile.
-	 * 
+	 *
 	 * @param file the file whose content has to be read
 	 * @return the content of the file
 	 * @throws CoreException if the file could not be successfully connected or disconnected
@@ -2341,7 +2335,7 @@ public class JavadocContentAccess2 {
 
 	/**
 	 * Reads the content of the java.io.File.
-	 * 
+	 *
 	 * @param file the file whose content has to be read
 	 * @return the content of the file
 	 * @throws CoreException if the file could not be successfully connected or disconnected
