@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -100,7 +100,7 @@ public abstract class AbstractSpellDictionary implements ISpellDictionary {
 		}
 	}
 
-	
+
 	/**
 	 * Canonical name for UTF-8 encoding
 	 * @since 3.6
@@ -147,7 +147,7 @@ public abstract class AbstractSpellDictionary implements ISpellDictionary {
 
 	/**
 	 * Returns the initial size of dictionary.
-	 * 
+	 *
 	 * @return The initial size of dictionary.
 	 * @since 3.6
 	 */
@@ -328,7 +328,7 @@ public abstract class AbstractSpellDictionary implements ISpellDictionary {
 	 * @since 3.3
 	 */
 	protected boolean isEmpty() {
-		return fHashBuckets.size() == 0;
+		return fHashBuckets.isEmpty();
 	}
 
 	/**
@@ -430,8 +430,7 @@ public abstract class AbstractSpellDictionary implements ISpellDictionary {
 		characters= word.toCharArray();
 		final char[] deleted= new char[characters.length - 1];
 
-		for (int index= 0; index < deleted.length; index++)
-			deleted[index]= characters[index];
+		System.arraycopy(characters, 0, deleted, 0, deleted.length);
 
 		next= characters[characters.length - 1];
 		offset= deleted.length;
@@ -452,7 +451,7 @@ public abstract class AbstractSpellDictionary implements ISpellDictionary {
 		neighborhood.remove(hash);
 		final Set<RankedWordProposal> matches= getCandidates(word, sentence, neighborhood);
 
-		if (matches.size() == 0 && candidates.size() == 0)
+		if (matches.isEmpty() && candidates.isEmpty())
 			getCandidates(word, sentence, candidates);
 
 		candidates.addAll(matches);
@@ -617,29 +616,31 @@ public abstract class AbstractSpellDictionary implements ISpellDictionary {
 					CharsetDecoder decoder= Charset.forName(getEncoding()).newDecoder();
 					decoder.onMalformedInput(CodingErrorAction.REPORT);
 					decoder.onUnmappableCharacter(CodingErrorAction.REPORT);
-					final BufferedReader reader= new BufferedReader(new InputStreamReader(stream, decoder));
+					try (final BufferedReader reader= new BufferedReader(new InputStreamReader(stream, decoder))) {
 
-					boolean doRead= true;
-					while (doRead) {
-						try {
-							word= reader.readLine();
-						} catch (MalformedInputException ex) {
-							// Tell the decoder to replace malformed input in order to read the line.
-							decoder.onMalformedInput(CodingErrorAction.REPLACE);
-							decoder.reset();
-							word= reader.readLine();
-							decoder.onMalformedInput(CodingErrorAction.REPORT);
+						boolean doRead= true;
+						while (doRead) {
+							try {
+								word= reader.readLine();
+							} catch (MalformedInputException ex) {
+								// Tell the decoder to replace malformed input in order to read the line.
+								decoder.onMalformedInput(CodingErrorAction.REPLACE);
+								decoder.reset();
+								word= reader.readLine();
+								decoder.onMalformedInput(CodingErrorAction.REPORT);
 
-							String message= Messages.format(JavaUIMessages.AbstractSpellingDictionary_encodingError, new String[] { word, decoder.replacement(), BasicElementLabels.getURLPart(url.toString()) });
-							IStatus status= new Status(IStatus.ERROR, JavaUI.ID_PLUGIN, IStatus.OK, message, ex);
-							JavaPlugin.log(status);
+								String message= Messages.format(JavaUIMessages.AbstractSpellingDictionary_encodingError,
+										new String[] { word, decoder.replacement(), BasicElementLabels.getURLPart(url.toString()) });
+								IStatus status= new Status(IStatus.ERROR, JavaUI.ID_PLUGIN, IStatus.OK, message, ex);
+								JavaPlugin.log(status);
 
+								doRead= word != null;
+								continue;
+							}
 							doRead= word != null;
-							continue;
+							if (doRead)
+								hashWord(word);
 						}
-						doRead= word != null;
-						if (doRead)
-							hashWord(word);
 					}
 					return true;
 				}
