@@ -94,7 +94,7 @@ public class JavaElementLinks {
 
 		/**
 		 * Handle link to given URL to open in browser.
-		 * 
+		 *
 		 * @param url the url to show
 		 * @param display the current display
 		 * @return <code>true</code> if the handler could open the link <code>false</code> if the
@@ -149,12 +149,10 @@ public class JavaElementLinks {
 		private String getPackageFragmentElementName(IJavaElement javaElement) {
 			IPackageFragmentRoot root= (IPackageFragmentRoot) javaElement.getAncestor(IJavaElement.PACKAGE_FRAGMENT_ROOT);
 			String javaElementName= javaElement.getElementName();
-			String[] individualSegmentNames= javaElementName.split("\\."); //$NON-NLS-1$
 			String packageName= null;
 			StringBuilder strBuffer= new StringBuilder();
 
-			for (int i= 0; i < individualSegmentNames.length; i++) {
-				String lastSegmentName= individualSegmentNames[i];
+			for (String lastSegmentName : javaElementName.split("\\.")) { //$NON-NLS-1$
 				if (packageName != null) {
 					strBuffer.append('.');
 					packageName= packageName + '.' + lastSegmentName;
@@ -181,7 +179,7 @@ public class JavaElementLinks {
 		@Override
 		protected String getSimpleTypeName(IJavaElement enclosingElement, String typeSig) {
 			String typeName= super.getSimpleTypeName(enclosingElement, typeSig);
-			
+
 			String title= ""; //$NON-NLS-1$
 			String qualifiedName= Signature.toString(Signature.getTypeErasure(typeSig));
 			int qualifierLength= qualifiedName.length() - typeName.length() - 1;
@@ -193,7 +191,7 @@ public class JavaElementLinks {
 					title= qualifiedName; // Not expected. Just show the whole qualifiedName.
 				}
 			}
-			
+
 			try {
 				String uri= createURI(JAVADOC_SCHEME, enclosingElement, qualifiedName, null, null);
 				return createHeaderLink(uri, typeName, title);
@@ -202,7 +200,7 @@ public class JavaElementLinks {
 				return typeName;
 			}
 		}
-		
+
 		@Override
 		protected String getMemberName(IJavaElement enclosingElement, String typeName, String memberName) {
 			try {
@@ -213,7 +211,7 @@ public class JavaElementLinks {
 				return memberName;
 			}
 		}
-		
+
 		@Override
 		protected void appendAnnotationLabels(IAnnotation[] annotations, long flags) throws JavaModelException {
 			fBuffer.append("<span style='font-weight:normal;'>"); //$NON-NLS-1$
@@ -279,33 +277,44 @@ public class JavaElementLinks {
 				try {
 					uri= new URI(loc);
 				} catch (URISyntaxException e) {
-					JavaPlugin.log(e); // log bad URL, but proceed in the hope that handleExternalLink(..) can deal with it 
+					JavaPlugin.log(e); // log bad URL, but proceed in the hope that handleExternalLink(..) can deal with it
 				}
 
 				String scheme= uri == null ? null : uri.getScheme();
-				if (JavaElementLinks.JAVADOC_VIEW_SCHEME.equals(scheme)) {
-					IJavaElement linkTarget= JavaElementLinks.parseURI(uri);
-					if (linkTarget == null)
-						return;
-
-					handler.handleJavadocViewLink(linkTarget);
-				} else if (JavaElementLinks.JAVADOC_SCHEME.equals(scheme)) {
-					IJavaElement linkTarget= JavaElementLinks.parseURI(uri);
-					if (linkTarget == null)
-						return;
-
-					handler.handleInlineJavadocLink(linkTarget);
-				} else if (JavaElementLinks.OPEN_LINK_SCHEME.equals(scheme)) {
-					IJavaElement linkTarget= JavaElementLinks.parseURI(uri);
-					if (linkTarget == null)
-						return;
-
-					handler.handleDeclarationLink(linkTarget);
-				} else {
+				boolean nomatch= false;
+				if (scheme != null) switch (scheme) {
+				case JavaElementLinks.JAVADOC_VIEW_SCHEME:
+					{
+						IJavaElement linkTarget= JavaElementLinks.parseURI(uri);
+						if (linkTarget == null)
+							return;
+						handler.handleJavadocViewLink(linkTarget);
+						break;
+					}
+				case JavaElementLinks.JAVADOC_SCHEME:
+					{
+						IJavaElement linkTarget= JavaElementLinks.parseURI(uri);
+						if (linkTarget == null)
+							return;
+						handler.handleInlineJavadocLink(linkTarget);
+						break;
+					}
+				case JavaElementLinks.OPEN_LINK_SCHEME:
+					{
+						IJavaElement linkTarget= JavaElementLinks.parseURI(uri);
+						if (linkTarget == null)
+							return;
+						handler.handleDeclarationLink(linkTarget);
+						break;
+					}
+				default:
+					nomatch= true;
+					break;
+				}
+				if (nomatch) {
 					try {
 						if (handler.handleExternalLink(new URL(loc), event.display))
 							return;
-
 						event.doit= true;
 					} catch (MalformedURLException e) {
 						JavaPlugin.log(e);
@@ -408,7 +417,7 @@ public class JavaElementLinks {
 			if (element instanceof IMember && !(element instanceof IType)) {
 				element= ((IMember) element).getDeclaringType();
 			}
-			
+
 			if (element instanceof IPackageFragment) {
 				try {
 					IPackageFragment root= (IPackageFragment) element;
@@ -422,7 +431,7 @@ public class JavaElementLinks {
 					JavaPlugin.log(e);
 				}
 			}
-			
+
 			if (element instanceof IType) {
 				try {
 					IType type= (IType) element;
@@ -452,13 +461,12 @@ public class JavaElementLinks {
 									// easily, since the Javadoc references are erasures
 
 									//Shortcut: only check name and parameter count:
-									methods= type.getMethods();
-									for (int i= 0; i < methods.length; i++) {
-										method= methods[i];
+									for (IMethod method1 : type.getMethods()) {
+										method= method1;
 										if (method.getElementName().equals(refMemberName) && method.getNumberOfParameters() == paramSignatures.length)
 											return method;
 									}
-									
+
 									// reference can also point to method from supertype:
 									ITypeHierarchy hierarchy= SuperTypeHierarchyCache.getTypeHierarchy(type);
 									method= JavaModelUtil.findMethodInHierarchy(hierarchy, type, refMemberName, paramSignatures, false);
@@ -470,9 +478,7 @@ public class JavaElementLinks {
 								if (field.exists()) {
 									return field;
 								} else {
-									IMethod[] methods= type.getMethods();
-									for (int i= 0; i < methods.length; i++) {
-										IMethod method= methods[i];
+									for (IMethod method : type.getMethods()) {
 										if (method.getElementName().equals(refMemberName))
 											return method;
 									}
@@ -498,13 +504,13 @@ public class JavaElementLinks {
 		// We follow the javadoc tool's implementation and only support fully-qualified type references:
 		IJavaProject javaProject= pack.getJavaProject();
 		return javaProject.findType(refTypeName, (IProgressMonitor) null);
-		
+
 		// This implementation would make sense, but the javadoc tool doesn't support it:
 //		IClassFile classFile= pack.getClassFile(JavaModelUtil.PACKAGE_INFO_CLASS);
 //		if (classFile.exists()) {
 //			return resolveType(classFile.getType(), refTypeName);
 //		}
-//		
+//
 //		// check if refTypeName is a qualified name
 //		int firstDot= refTypeName.indexOf('.');
 //		if (firstDot != -1) {
@@ -519,13 +525,13 @@ public class JavaElementLinks {
 //				return javaProject.findType(refTypeName, (IProgressMonitor) null);
 //			}
 //		}
-//		
+//
 //		ICompilationUnit cu= pack.getCompilationUnit(JavaModelUtil.PACKAGE_INFO_JAVA);
 //		if (! cu.exists()) {
 //			// refTypeName is a simple name in the package-info.java from the source attachment. Sorry, we give up here...
 //			return null;
 //		}
-//		
+//
 //		// refTypeName is a simple name in a CU. Let's play the shadowing rules of JLS7 6.4.1:
 //		// 1) single-type import
 //		// 2) enclosing package
@@ -547,17 +553,17 @@ public class JavaElementLinks {
 //				imports[i]= null;
 //			}
 //		}
-//		
+//
 //		// 2) enclosing package
 //		IType type= javaProject.findType(pack.getElementName() + '.' + refTypeName, (IProgressMonitor) null);
 //		if (type != null)
 //			return type;
-//		
+//
 //		// 3) java.lang.* (JLS7 7.3)
 //		type= javaProject.findType("java.lang." + refTypeName, (IProgressMonitor) null); //$NON-NLS-1$
 //		if (type != null)
 //			return type;
-//		
+//
 //		// 4) on-demand import
 //		for (int i= 0; i < imports.length; i++) {
 //			IImportDeclaration importDecl= imports[i];
@@ -576,27 +582,23 @@ public class JavaElementLinks {
 		while (baseElement != null) {
 			switch (baseElement.getElementType()) {
 				case IJavaElement.METHOD:
-					IMethod method= (IMethod)baseElement;
-					ITypeParameter[] typeParameters= method.getTypeParameters();
-					for (int i= 0; i < typeParameters.length; i++) {
-						ITypeParameter typeParameter= typeParameters[i];
+					for (ITypeParameter typeParameter : ((IMethod)baseElement).getTypeParameters()) {
 						if (typeParameter.getElementName().equals(typeVariableName)) {
 							return typeParameter;
 						}
 					}
 					break;
 
+
 				case IJavaElement.TYPE:
-					IType type= (IType)baseElement;
-					typeParameters= type.getTypeParameters();
-					for (int i= 0; i < typeParameters.length; i++) {
-						ITypeParameter typeParameter= typeParameters[i];
+					for (ITypeParameter typeParameter : ((IType)baseElement).getTypeParameters()) {
 						if (typeParameter.getElementName().equals(typeVariableName)) {
 							return typeParameter;
 						}
 					}
 					break;
 
+
 				case IJavaElement.JAVA_MODEL:
 				case IJavaElement.JAVA_PROJECT:
 				case IJavaElement.PACKAGE_FRAGMENT:
@@ -643,7 +645,7 @@ public class JavaElementLinks {
 
 	/**
 	 * Creates a link with the given URI and label text.
-	 * 
+	 *
 	 * @param uri the URI
 	 * @param label the label
 	 * @return the HTML link
@@ -652,10 +654,10 @@ public class JavaElementLinks {
 	public static String createLink(String uri, String label) {
 		return "<a href='" + uri + "'>" + label + "</a>"; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 	}
-	
+
 	/**
 	 * Creates a header link with the given URI and label text.
-	 * 
+	 *
 	 * @param uri the URI
 	 * @param label the label
 	 * @return the HTML link
@@ -664,10 +666,10 @@ public class JavaElementLinks {
 	public static String createHeaderLink(String uri, String label) {
 		return createHeaderLink(uri, label, ""); //$NON-NLS-1$
 	}
-	
+
 	/**
 	 * Creates a link with the given URI, label and title text.
-	 * 
+	 *
 	 * @param uri the URI
 	 * @param label the label
 	 * @param title the title to be displayed while hovering over the link (can be empty)
@@ -678,12 +680,12 @@ public class JavaElementLinks {
 		if (title.length() > 0) {
 			title= " title='" + title + "'";  //$NON-NLS-1$ //$NON-NLS-2$
 		}
-		return "<a class='header' href='" + uri + "'" + title + ">" + label + "</a>"; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ 
+		return "<a class='header' href='" + uri + "'" + title + ">" + label + "</a>"; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
 	}
-	
+
 	/**
 	 * Returns the label for a Java element with the flags as defined by {@link JavaElementLabels}.
-	 * Referenced element names in the label (except the given element's name) are rendered as 
+	 * Referenced element names in the label (except the given element's name) are rendered as
 	 * header links.
 	 *
 	 * @param element the element to render
