@@ -18,7 +18,6 @@ import java.net.URI;
 import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.Hashtable;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 
@@ -106,7 +105,7 @@ public class AddSourceFolderWizardPage extends NewElementWizardPage {
 
 			fLinkLocation.setLabelText(NewWizardMessages.LinkFolderDialog_dependenciesGroup_locationLabel_desc);
 			fLinkLocation.setButtonLabel(NewWizardMessages.LinkFolderDialog_dependenciesGroup_browseButton_desc);
-			fLinkLocation.setDialogFieldListener(this);			
+			fLinkLocation.setDialogFieldListener(this);
 
 			fVariables= new SelectionButtonDialogField(SWT.PUSH);
 			fVariables.setLabelText(NewWizardMessages.LinkFolderDialog_dependenciesGroup_variables_desc);
@@ -238,23 +237,18 @@ public class AddSourceFolderWizardPage extends NewElementWizardPage {
 		fOrginalInclusionFilters= new Hashtable<>();
 		fOrginalExlusionFiltersCopy= new Hashtable<>();
 		fOrginalInclusionFiltersCopy= new Hashtable<>();
-		for (Iterator<CPListElement> iter= existingEntries.iterator(); iter.hasNext();) {
-			CPListElement element= iter.next();
+		for (CPListElement element : existingEntries) {
 			IPath[] exlusions= (IPath[])element.getAttribute(CPListElement.EXCLUSION);
 			if (exlusions != null) {
 				IPath[] save= new IPath[exlusions.length];
-				for (int i= 0; i < save.length; i++) {
-					save[i]= exlusions[i];
-				}
+				System.arraycopy(exlusions, 0, save, 0, save.length);
 				fOrginalExlusionFiltersCopy.put(element, save);
 				fOrginalExlusionFilters.put(element, exlusions);
 			}
 			IPath[] inclusions= (IPath[])element.getAttribute(CPListElement.INCLUSION);
 			if (inclusions != null) {
 				IPath[] save= new IPath[inclusions.length];
-				for (int i= 0; i < save.length; i++) {
-					save[i]= inclusions[i];
-				}
+				System.arraycopy(inclusions, 0, save, 0, save.length);
 				fOrginalInclusionFiltersCopy.put(element, save);
 				fOrginalInclusionFilters.put(element, inclusions);
 			}
@@ -546,8 +540,7 @@ public class AddSourceFolderWizardPage extends NewElementWizardPage {
 	}
 
 	public void restore() {
-		for (Iterator<CPListElement> iter= fExistingEntries.iterator(); iter.hasNext();) {
-			CPListElement element= iter.next();
+		for (CPListElement element : fExistingEntries) {
 			if (fOrginalExlusionFilters.containsKey(element)) {
 				element.setAttribute(CPListElement.EXCLUSION, fOrginalExlusionFiltersCopy.get(element));
 			}
@@ -560,8 +553,7 @@ public class AddSourceFolderWizardPage extends NewElementWizardPage {
 
 	private void restoreCPElements() {
 		if (fNewElement.getPath() != null) {
-			for (Iterator<CPListElement> iter= fExistingEntries.iterator(); iter.hasNext();) {
-				CPListElement element= iter.next();
+			for (CPListElement element : fExistingEntries) {
 				if (fOrginalExlusionFilters.containsKey(element)) {
 					element.setAttribute(CPListElement.EXCLUSION, fOrginalExlusionFilters.get(element));
 				}
@@ -591,8 +583,7 @@ public class AddSourceFolderWizardPage extends NewElementWizardPage {
 			newPath= newPath.removeFirstSegments(projPath.segmentCount()).addTrailingSeparator();
 		}
 
-		for (Iterator<CPListElement> iter= fExistingEntries.iterator(); iter.hasNext();) {
-			CPListElement element= iter.next();
+		for (CPListElement element : fExistingEntries) {
 			IPath elementPath= element.getPath();
 			if (projPath.isPrefixOf(elementPath)) {
 				elementPath= elementPath.removeFirstSegments(projPath.segmentCount());
