@@ -164,12 +164,13 @@ public class ModuleDependenciesPage extends BuildPathBasePage {
 	private Collection<String> fAllDefaultSystemModules; // if current is unnamed module: transitive closure of default root modules (names)
 
 	public final Map<String,String> fPatchMap= new HashMap<>();
+	private boolean needReInit= false;
 
 	public ModuleDependenciesPage(IStatusChangeListener context, CheckedListDialogField<CPListElement> classPathList) {
 		fClassPathList= classPathList;
 		fContext= context;
 		fSWTControl= null;
-		
+
 		String[] buttonLabels= new String[] {
 				NewWizardMessages.ModuleDependenciesPage_modules_remove_button,
 				/* */ null,
@@ -222,7 +223,7 @@ public class ModuleDependenciesPage extends BuildPathBasePage {
 
 		fModuleList.createViewer(left, converter);
 		fModuleList.setSelectionChangedListener((elems, mod) -> selectModule(elems, mod));
-		
+
 		fAddSystemModuleButton= new Button(left, SWT.NONE);
 		fAddSystemModuleButton.setText(NewWizardMessages.ModuleDependenciesPage_addSystemModule_button);
 		fAddSystemModuleButton.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> addSystemModules()));
@@ -530,6 +531,7 @@ public class ModuleDependenciesPage extends BuildPathBasePage {
 		}
 		updateLimitModules(cpListElement.findAttributeElement(CPListElement.MODULE));
 		fModuleList.refresh();
+		this.needReInit= true;
 	}
 
 	public void addToSystemModules(List<IModuleDescription> modulesToAdd) throws JavaModelException {
@@ -564,6 +566,7 @@ public class ModuleDependenciesPage extends BuildPathBasePage {
 		List<CPListElement> selectedElements= fModuleList.getSelectedElements();
 		List<String> selectedModuleNames= new ArrayList<>();
 		Set<String> allModulesToRemove= new HashSet<>();
+		boolean removeConfirmed= false;
 		for (CPListElement selectedElement : selectedElements) {
 			if (fModuleList.getModuleKind(selectedElement) == ModuleKind.Focus) {
 				MessageDialog.openError(getShell(), NewWizardMessages.ModuleDependenciesPage_removeModule_dialog_title,
@@ -614,11 +617,23 @@ public class ModuleDependenciesPage extends BuildPathBasePage {
 				return;
 			}
 			selectedModuleNames.add(moduleName);
-			collectModulesToRemove(moduleName, allModulesToRemove);
+			String problemModule= collectModulesToRemove(moduleName, allModulesToRemove);
+			if (problemModule != null) {
+				int lastArrow= problemModule.lastIndexOf("->"); //$NON-NLS-1$
+				String leafMod= lastArrow == -1 ? problemModule : problemModule.substring(lastArrow+2);
+				int answer= MessageDialog.open(MessageDialog.WARNING, getShell(), NewWizardMessages.ModuleDependenciesPage_removeModule_dialog_title,
+								MessageFormat.format(NewWizardMessages.ModuleDependenciesPage_moduleIsRequired_warning, leafMod, problemModule),
+								SWT.NONE,
+								NewWizardMessages.ModuleDependenciesPage_remove_button, IDialogConstants.CANCEL_LABEL);
+				if (answer != 0) {
+					return;
+				}
+				removeConfirmed= true;
+			}
 		}
 		String seedModules= String.join(", ", selectedModuleNames); //$NON-NLS-1$
 		if (allModulesToRemove.size() == selectedModuleNames.size()) {
-			if (confirmRemoveModule(MessageFormat.format(NewWizardMessages.ModuleDependenciesPage_removingModule_message, seedModules))) {
+			if (removeConfirmed || confirmRemoveModule(MessageFormat.format(NewWizardMessages.ModuleDependenciesPage_removingModule_message, seedModules))) {
 				fModuleList.fNames.removeAll(selectedModuleNames);
 				fModuleList.refresh();
 			}
@@ -646,8 +661,19 @@ public class ModuleDependenciesPage extends BuildPathBasePage {
 				}
 			}
 		}
+		this.needReInit= true;
 	}
 
+	/** Destructively reed the needReInit flag.
+	 * @return {@code true} if the classpath needs to be reinitialized due to change of extent of the system library
+	 */
+	public boolean needReInit() {
+		try {
+			return this.needReInit;
+		} finally {
+			this.needReInit= false;
+		}
+	}
 	private Set<String> computeForwardClosure(List<String> seeds) {
 		Set<String> closure= new HashSet<>();
 		collectForwardClosure(seeds, closure);
@@ -664,17 +690,27 @@ public class ModuleDependenciesPage extends BuildPathBasePage {
 		}
 	}
 
-	private void collectModulesToRemove(String mod, Set<String> modulesToRemove) {
+	private String collectModulesToRemove(String mod, Set<String> modulesToRemove) {
 		if (fModuleList.fNames.contains(mod) && modulesToRemove.add(mod)) {
+			String problemModules= null; // at most one path is detected, even if several exist
 			List<String> requireds= fModuleRequiredByModules.get(mod);
 			if (requireds != null) {
 				for (String required : requireds) {
-					collectModulesToRemove(required, modulesToRemove);
+					if (fModuleList.getModuleKind(required) == ModuleKind.Focus) {
+						// direct dependency beats any indirect one:
+						problemModules= required + "->" + mod; //$NON-NLS-1$
+						continue; // do not attempt to remove the focus module
+					}
+					String probMods= collectModulesToRemove(required, modulesToRemove);
+					if (probMods != null && problemModules == null)
+						problemModules= probMods + "->" + mod; //$NON-NLS-1$
 				}
 			}
+			return problemModules;
 		}
+		return null;
 	}
-	
+
 	private boolean confirmRemoveModule(String message) {
 		int answer= MessageDialog.open(MessageDialog.QUESTION, getShell(),
 				NewWizardMessages.ModuleDependenciesPage_removeModule_dialog_title, message, SWT.NONE,
@@ -690,9 +726,9 @@ public class ModuleDependenciesPage extends BuildPathBasePage {
 				// no longer relevant, remove:
 				ModuleEncapsulationDetail[] details= (ModuleEncapsulationDetail[]) value;
 				int retainCount= 0;
-				for (int i= 0; i < details.length; i++) {
-					if (!(details[i] instanceof LimitModules)) {
-						details[retainCount++]= details[i];
+				for (ModuleEncapsulationDetail detail : details) {
+					if (!(detail instanceof LimitModules)) {
+						details[retainCount++]= detail;
 					}
 				}
 				if (retainCount < details.length)
@@ -741,7 +777,7 @@ public class ModuleDependenciesPage extends BuildPathBasePage {
 				List<String> dominators= fModuleRequiredByModules.get(name);
 				if (dominators != null) {
 					for (String dominator : dominators) {
-						if (names.contains(dominator)) {
+						if (names.contains(dominator) && fModuleList.getModuleKind(dominator) == ModuleKind.System) {
 							continue outer;
 						}
 					}
@@ -770,7 +806,7 @@ public class ModuleDependenciesPage extends BuildPathBasePage {
 	}
 
 	/**
-	 * Find a module attribute in the current classpath that satisfies the given predicate. 
+	 * Find a module attribute in the current classpath that satisfies the given predicate.
 	 * @param predicate this predicate must be fulfilled by any detail of a found module attribte
 	 * @return if a predicate match was found the enclosing module attribute will be returned, else {@code null}
 	 */
@@ -787,7 +823,7 @@ public class ModuleDependenciesPage extends BuildPathBasePage {
 		}
 		return null;
 	}
-	
+
 	public void showJMPSOptionsDialog() {
 		new ShowJPMSOptionsDialog(getShell(), fClassPathList, allDefaultSystemModules(), this::closure, this::reduceNames).open();
 	}
