@@ -89,7 +89,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 		protected Shell getShell() {
 			return SourceContainerWorkbookPage.this.getShell();
 		}
-		
+
 		@Override
 		public void propertyChange(PropertyChangeEvent event) {
 			if (event.getProperty().equals(IAction.RESULT)) {
@@ -340,7 +340,8 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 
 	protected void sourcePageCustomButtonPressed(DialogField field, int index) {
 		if (field == fFoldersList) {
-			if (index == IDX_ADD) {
+			switch (index) {
+			case IDX_ADD:
 				IProject project= fCurrJProject.getProject();
 				if (project.isAccessible() && hasFolders(project)) {
 					List<CPListElement> existingElements= fFoldersList.getElements();
@@ -355,15 +356,21 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 					OpenBuildPathWizardAction action= new OpenBuildPathWizardAction(wizard);
 					action.run();
 				}
-			} else if (index == IDX_ADD_LINK) {
+				break;
+			case IDX_ADD_LINK:
 				CPListElement newElement= new CPListElement(fCurrJProject, IClasspathEntry.CPE_SOURCE);
 				AddSourceFolderWizard wizard= newLinkedSourceFolderWizard(newElement, fFoldersList.getElements(), fOutputLocationField.getText(), true);
 				OpenBuildPathWizardAction action= new OpenBuildPathWizardAction(wizard);
 				action.run();
-			} else if (index == IDX_EDIT) {
+				break;
+			case IDX_EDIT:
 				editEntry();
-			} else if (index == IDX_REMOVE) {
+				break;
+			case IDX_REMOVE:
 				removeEntry();
+				break;
+			default:
+				break;
 			}
 		}
 	}
@@ -371,9 +378,8 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 	private boolean hasFolders(IContainer container) {
 
 		try {
-			IResource[] members= container.members();
-			for (int i= 0; i < members.length; i++) {
-				if (members[i] instanceof IContainer) {
+			for (IResource member : container.members()) {
+				if (member instanceof IContainer) {
 					return true;
 				}
 			}
@@ -385,7 +391,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 		if (elements.size() > 1)
 			return true;
 
-		if (elements.size() == 0)
+		if (elements.isEmpty())
 			return false;
 
 		CPListElement single= elements.get(0);
@@ -504,9 +510,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 			for (Iterator<Object> iter= selElements.iterator(); iter.hasNext();) {
 				CPListElement element= (CPListElement)iter.next();
 				if (element.getEntryKind() == IClasspathEntry.CPE_SOURCE) {
-					List<CPListElement> list= ClasspathModifier.removeFilters(element.getPath(), fCurrJProject, fFoldersList.getElements());
-					for (Iterator<CPListElement> iterator= list.iterator(); iterator.hasNext();) {
-						CPListElement modified= iterator.next();
+					for (CPListElement modified : ClasspathModifier.removeFilters(element.getPath(), fCurrJProject, fFoldersList.getElements())) {
 						fFoldersList.refresh(modified);
 						fFoldersList.expandElement(modified, 3);
 					}
@@ -517,7 +521,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 	}
 
 	private boolean canRemove(List<Object> selElements) {
-		if (selElements.size() == 0) {
+		if (selElements.isEmpty()) {
 			return false;
 		}
 		for (int i= 0; i < selElements.size(); i++) {
@@ -659,15 +663,13 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 
 	private void refresh(List<CPListElement> insertedElements, List<?> removedElements, List<CPListElement> modifiedElements, IPath outputLocation) {
 		fFoldersList.addElements(insertedElements);
-		for (Iterator<CPListElement> iter= insertedElements.iterator(); iter.hasNext();) {
-			CPListElement element= iter.next();
+		for (CPListElement element : insertedElements) {
 			fFoldersList.expandElement(element, 3);
 		}
 
 		fFoldersList.removeElements(removedElements);
 
-		for (Iterator<CPListElement> iter= modifiedElements.iterator(); iter.hasNext();) {
-			CPListElement element= iter.next();
+		for (CPListElement element : modifiedElements) {
 			fFoldersList.refresh(element);
 			fFoldersList.expandElement(element, 3);
 		}
