@@ -377,9 +377,10 @@ public class AddUnimplementedConstructorsAction extends SelectionDispatchAction
 
 		private int countSelectedMethods(Object[] selection) {
 			int count= 0;
-			for (int i= 0; i < selection.length; i++) {
-				if (selection[i] instanceof IMethodBinding)
+			for (Object s : selection) {
+				if (s instanceof IMethodBinding) {
 					count++;
+				}
 			}
 			return count;
 		}
@@ -548,8 +549,7 @@ public class AddUnimplementedConstructorsAction extends SelectionDispatchAction
 			}
 
 			ArrayList<IMethodBinding> result= new ArrayList<>();
-			for (int i= 0; i < elements.length; i++) {
-				Object elem= elements[i];
+			for (Object elem : elements) {
 				if (elem instanceof IMethodBinding) {
 					result.add((IMethodBinding) elem);
 				}
