@@ -47,17 +47,17 @@ import org.eclipse.jdt.core.dom.ITypeBinding;
 import org.eclipse.jdt.core.dom.IVariableBinding;
 import org.eclipse.jdt.core.dom.Modifier;
 import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
+import org.eclipse.jdt.core.manipulation.SharedASTProviderCore;
 
 import org.eclipse.jdt.internal.corext.codemanipulation.AddCustomConstructorOperation;
 import org.eclipse.jdt.internal.corext.codemanipulation.CodeGenerationSettings;
-import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility2;
+import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility2Core;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
 import org.eclipse.jdt.internal.corext.dom.Bindings;
 import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.corext.util.JdtFlags;
 
 import org.eclipse.jdt.ui.JavaUI;
-import org.eclipse.jdt.ui.SharedASTProvider;
 
 import org.eclipse.jdt.internal.ui.IJavaHelpContextIds;
 import org.eclipse.jdt.internal.ui.JavaPlugin;
@@ -145,8 +145,8 @@ public class GenerateNewConstructorUsingFieldsAction extends SelectionDispatchAc
 
 	private boolean canRunOn(IField[] fields) throws JavaModelException {
 		if (fields != null && fields.length > 0) {
-			for (int index= 0; index < fields.length; index++) {
-				if (JdtFlags.isEnum(fields[index])) {
+			for (IField field : fields) {
+				if (JdtFlags.isEnum(field)) {
 					MessageDialog.openInformation(getShell(), ActionMessages.GenerateConstructorUsingFieldsAction_error_title, ActionMessages.GenerateConstructorUsingFieldsAction_enum_not_applicable);
 					return false;
 				}
@@ -313,7 +313,7 @@ public class GenerateNewConstructorUsingFieldsAction extends SelectionDispatchAc
 
 		List<IField> allSelected= Arrays.asList(selectedFields);
 
-		CompilationUnit astRoot= SharedASTProvider.getAST(cu, SharedASTProvider.WAIT_YES, new NullProgressMonitor());
+		CompilationUnit astRoot= SharedASTProviderCore.getAST(cu, SharedASTProviderCore.WAIT_YES, new NullProgressMonitor());
 		ITypeBinding typeBinding= ASTNodes.getTypeBinding(astRoot, type);
 		if (typeBinding == null) {
 			MessageDialog.openInformation(getShell(), ActionMessages.GenerateConstructorUsingFieldsAction_error_title, ActionMessages.GenerateNewConstructorUsingFieldsAction_error_not_a_source_file);
@@ -324,9 +324,7 @@ public class GenerateNewConstructorUsingFieldsAction extends SelectionDispatchAc
 		HashMap<IJavaElement, IVariableBinding> fieldsToBindings= new HashMap<>();
 		ArrayList<IVariableBinding> selected= new ArrayList<>();
 
-		IVariableBinding[] candidates= typeBinding.getDeclaredFields();
-		for (int i= 0; i < candidates.length; i++) {
-			IVariableBinding curr= candidates[i];
+		for (IVariableBinding curr : typeBinding.getDeclaredFields()) {
 			if (curr.isSynthetic()) {
 				continue;
 			}
@@ -352,9 +350,8 @@ public class GenerateNewConstructorUsingFieldsAction extends SelectionDispatchAc
 		}
 
 		ArrayList<IVariableBinding> fields= new ArrayList<>();
-		IField[] allFields= type.getFields();
-		for (int i= 0; i < allFields.length; i++) {
-			IVariableBinding fieldBinding= fieldsToBindings.remove(allFields[i]);
+		for (IField field : type.getFields()) {
+			IVariableBinding fieldBinding= fieldsToBindings.remove(field);
 			if (fieldBinding != null) {
 				fields.add(fieldBinding);
 			}
@@ -372,7 +369,7 @@ public class GenerateNewConstructorUsingFieldsAction extends SelectionDispatchAc
 		if (typeBinding.isEnum()) {
 			bindings= new IMethodBinding[] {getObjectConstructor(astRoot.getAST())};
 		} else {
-			bindings= StubUtility2.getVisibleConstructors(typeBinding, false, true);
+			bindings= StubUtility2Core.getVisibleConstructors(typeBinding, false, true);
 			if (bindings.length == 0) {
 				MessageDialog.openInformation(getShell(), ActionMessages.GenerateConstructorUsingFieldsAction_error_title, ActionMessages.GenerateConstructorUsingFieldsAction_error_nothing_found);
 				notifyResult(false);
@@ -398,9 +395,10 @@ public class GenerateNewConstructorUsingFieldsAction extends SelectionDispatchAc
 				return;
 			}
 			ArrayList<IVariableBinding> result= new ArrayList<>(elements.length);
-			for (int index= 0; index < elements.length; index++) {
-				if (elements[index] instanceof IVariableBinding)
-					result.add((IVariableBinding) elements[index]);
+			for (Object element : elements) {
+				if (element instanceof IVariableBinding) {
+					result.add((IVariableBinding) element);
+				}
 			}
 			IVariableBinding[] variables= result.toArray(new IVariableBinding[result.size()]);
 
