@@ -69,14 +69,13 @@ public class CompletionProposalLabelProvider {
 	 * returned.
 	 * <p>
 	 * Examples:
-	 * 
+	 * </p>
+	 *
 	 * <pre>
 	 *   &quot;void method(int i, String s)&quot; -&gt; &quot;int i, String s&quot;
 	 *   &quot;? extends Number method(java.lang.String s, ? super Number n)&quot; -&gt; &quot;String s, Number n&quot;
 	 * </pre>
-	 * 
-	 * </p>
-	 * 
+	 *
 	 * @param proposal the proposal to create the parameter list for
 	 * @return the list of comma-separated parameters suitable for display
 	 */
@@ -731,8 +730,7 @@ public class CompletionProposalLabelProvider {
 		if (!deprecated) {
 			CompletionProposal[] requiredProposals= proposal.getRequiredProposals();
 			if (requiredProposals != null) {
-				for (int i= 0; i < requiredProposals.length; i++) {
-					CompletionProposal requiredProposal= requiredProposals[i];
+				for (CompletionProposal requiredProposal : requiredProposals) {
 					if (requiredProposal.getKind() == CompletionProposal.TYPE_REF) {
 						deprecated |= Flags.isDeprecated(requiredProposal.getFlags());
 					}
