@@ -187,8 +187,7 @@ public class RefactoringStatus {
 	 */
 	public RefactoringStatusEntry getEntryMatchingCode(String pluginId, int code) {
 		Assert.isTrue(pluginId != null);
-		for (Iterator<RefactoringStatusEntry> iter= fEntries.iterator(); iter.hasNext(); ) {
-			RefactoringStatusEntry entry= iter.next();
+		for (RefactoringStatusEntry entry : fEntries) {
 			if (pluginId.equals(entry.getPluginId()) && entry.getCode() == code)
 				return entry;
 		}
@@ -228,7 +227,7 @@ public class RefactoringStatus {
 	 * @since 3.1
 	 */
 	public RefactoringStatusEntry getEntryWithHighestSeverity() {
-		if (fEntries == null || fEntries.size() == 0)
+		if (fEntries == null || fEntries.isEmpty())
 			return null;
 		RefactoringStatusEntry result= fEntries.get(0);
 		for (int i= 1; i < fEntries.size(); i++) {
@@ -423,8 +422,8 @@ public class RefactoringStatus {
 		} else {
 			IStatus[] children= status.getChildren();
 			RefactoringStatus result= new RefactoringStatus();
-			for (int i= 0; i < children.length; i++) {
-				result.merge(RefactoringStatus.create(children[i]));
+			for (IStatus child : children) {
+				result.merge(RefactoringStatus.create(child));
 			}
 			return result;
 		}
@@ -672,7 +671,7 @@ public class RefactoringStatus {
 	 */
 	@Override
 	public String toString() {
-		StringBuffer buff= new StringBuffer();
+		StringBuilder buff= new StringBuilder();
 		buff.append("<") //$NON-NLS-1$
 			.append(getSeverityString(fSeverity)).append("\n"); //$NON-NLS-1$
 		if (!isOK()) {
